@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  * LGPL licensed version of MAMEs fmopl (V0.37a modified) by
  * Tatsuyuki Satoh. Included from LGPL'ed AdPlug.
  */
@@ -549,7 +546,7 @@ inline void OPL_CALC_RH(FM_OPL *OPL, OPL_CH *CH) {
 	// but EG_STEP = 96.0/EG_ENT, and WHITE_NOISE_db=6.0. So, that's equivalent to
 	// int(OPL->rnd.getRandomBit() * EG_ENT/16). We know that EG_ENT is 4096, or 1024,
 	// or 128, so we can safely avoid any FP ops.
-	int whitenoise = OPL->rnd.getRandomBit() * (EG_ENT>>4);
+	int whitenoise = OPL->rnd->getRandomBit() * (EG_ENT>>4);
 
 	int tone8;
 
@@ -728,6 +725,8 @@ static int OPLOpenTable(void) {
 
 
 	ENV_CURVE = (int *)malloc(sizeof(int) * (2*EG_ENT+1));
+	if (!ENV_CURVE)
+		error("[OPLOpenTable] Cannot allocate memory");
 
 	/* envelope counter -> envelope output table */
 	for (i=0; i < EG_ENT; i++) {
@@ -1131,6 +1130,15 @@ FM_OPL *OPLCreate(int type, int clock, int rate) {
 	OPL->rate  = rate;
 	OPL->max_ch = max_ch;
 
+	// Init the random source. Note: We use a fixed name for it here.
+	// So if multiple FM_OPL objects exist in parallel, then their
+	// random sources will have an equal name. At least in the
+	// current EventRecorder implementation, this causes no problems;
+	// but this is probably not guaranteed.
+	// Alas, it does not seem worthwhile to bother much with this
+	// at the time, so I am leaving it as it is.
+	OPL->rnd = new Common::RandomSource("mame");
+
 	/* init grobal tables */
 	OPL_initalize(OPL);
 
@@ -1139,9 +1147,10 @@ FM_OPL *OPLCreate(int type, int clock, int rate) {
 	return OPL;
 }
 
-/* ----------  Destroy one of vietual YM3812 ----------       */
+/* ----------  Destroy one of virtual YM3812 ----------       */
 void OPLDestroy(FM_OPL *OPL) {
 	OPL_UnLockTable();
+	delete OPL->rnd;
 	free(OPL);
 }
 
@@ -1236,4 +1245,3 @@ FM_OPL *makeAdLibOPL(int rate) {
 
 } // End of namespace MAME
 } // End of namespace OPL
-
