@@ -17,18 +17,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/keymapper/remap-dialog.cpp $
- * $Id: remap-dialog.cpp 49796 2010-06-15 11:02:42Z sev $
  */
 
 #include "backends/keymapper/remap-dialog.h"
 
 #ifdef ENABLE_KEYMAPPER
 
-#include "gui/GuiManager.h"
-#include "gui/PopUpWidget.h"
-#include "gui/ScrollBarWidget.h"
+#include "common/system.h"
+#include "gui/gui-manager.h"
+#include "gui/widgets/popup.h"
+#include "gui/widgets/scrollbar.h"
 #include "gui/ThemeEval.h"
 
 #include "common/translation.h"
