@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/dc/display.cpp $
- * $Id: display.cpp 49838 2010-06-15 12:21:08Z fingolfin $
- *
  */
 
 #define RONIN_TIMER_ACCESS
@@ -156,7 +153,7 @@ void OSystem_Dreamcast::setPalette(const byte *colors, uint start, uint num)
       *dst++ = ((colors[0]<<7)&0x7c00)|
 	((colors[1]<<2)&0x03e0)|
 	((colors[2]>>3)&0x001f);
-      colors += 4;
+      colors += 3;
     }
   _screen_dirty = true;
 }
@@ -169,16 +166,11 @@ void OSystem_Dreamcast::setCursorPalette(const byte *colors, uint start, uint nu
       *dst++ = ((colors[0]<<7)&0x7c00)|
 	((colors[1]<<2)&0x03e0)|
 	((colors[2]>>3)&0x001f);
-      colors += 4;
+      colors += 3;
     }
   _enable_cursor_palette = true;
 }
 
-void OSystem_Dreamcast::disableCursorPalette(bool disable)
-{
-  _enable_cursor_palette = !disable;
-}
-
 void OSystem_Dreamcast::grabPalette(byte *colors, uint start, uint num)
 {
   const unsigned short *src = palette + start;
@@ -188,8 +180,7 @@ void OSystem_Dreamcast::grabPalette(byte *colors, uint start, uint num)
       colors[0] = ((p&0x7c00)>>7)|((p&0x7000)>>12);
       colors[1] = ((p&0x03e0)>>2)|((p&0x0380)>>7);
       colors[2] = ((p&0x001f)<<3)|((p&0x001c)>>2);
-      colors[3] = 0xff;
-      colors += 4;
+      colors += 3;
     }
 }
 
@@ -721,7 +712,7 @@ Graphics::Surface *OSystem_Dreamcast::lockScreen()
   _framebuffer.w = _screen_w;
   _framebuffer.h = _screen_h;
   _framebuffer.pitch = SCREEN_W*2;
-  _framebuffer.bytesPerPixel = (_screenFormat == 0? 1 : 2);
+  _framebuffer.format = screenFormats[_screenFormat];
 
   return &_framebuffer;
 }
@@ -741,4 +732,3 @@ int16 OSystem_Dreamcast::getOverlayWidth()
 {
   return OVL_W;
 }
-
