@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/dc/time.cpp $
- * $Id: time.cpp 28966 2007-09-19 08:40:12Z peres001 $
- *
  */
 
 #define RONIN_TIMER_ACCESS
@@ -51,8 +48,8 @@ void OSystem_Dreamcast::delayMillis(uint msecs)
   unsigned int t, start = Timer();
   int time = (((unsigned int)msecs)*3125U)>>6;
   while (((int)((t = Timer())-start))<time) {
-    if (_timer != NULL)
-      _timer->handler();
+    if (_timerManager != NULL)
+      ((DefaultTimerManager *)_timerManager)->handler();
     checkSound();
   }
   getMillis();
