@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 #include <common/scummsys.h>
 #include "engines/engine.h"
 #include "dc.h"
