@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/platform/ds/arm9/source/dsmain.cpp $
- * $Id: dsmain.cpp 53056 2010-10-07 20:35:59Z agent-q $
- *
  */
 
 
@@ -71,6 +68,8 @@
 // - Try discworld?
 
 
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 
 
 #include <nds.h>
@@ -105,6 +104,7 @@
 #endif
 #include "engine.h"
 
+#include "backends/plugins/ds/ds-provider.h"
 #include "backends/fs/ds/ds-fs.h"
 #include "base/version.h"
 #include "common/util.h"
@@ -575,7 +575,7 @@ void initGame() {
 		for (int r = 0; r < NUM_SUPPORTED_GAMES; r++) {
 			if (!stricmp(gameName, gameList[r].gameId)) {
 				s_currentGame = &gameList[r];
-	//			consolePrintf("Game list num: %d\n", s_currentGame);
+	//			consolePrintf("Game list num: %d\n", r);
 			}
 		}
 	}
@@ -1668,8 +1668,7 @@ void addEventsToQueue() {
 
 
 		if (!keyboardEnable) {
-
-			if ((isScrollingWithDPad() || (indyFightState)) && (displayModeIs8Bit)) {
+			if ((!isScrollingWithDPad() || (indyFightState)) && (displayModeIs8Bit)) {
 				// Controls specific to the control method
 
 				if (s_currentGame->control == CONT_SKY) {
@@ -3213,6 +3212,9 @@ int main(void) {
 	const char *argv[] = {"/scummvmds"};
 #endif
 
+#ifdef DYNAMIC_MODULES
+	PluginManager::instance().addPluginProvider(new DSPluginProvider());
+#endif
 
 	while (1) {
 		scummvm_main(ARRAYSIZE(argv), (char **) &argv);
