@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
+#define FORBIDDEN_SYMBOL_ALLOW_ALL
+
 #include <romfs.h>
 
 #include <malloc.h> // Required for memalign
@@ -31,6 +30,10 @@
 #include "pakfs_save_manager.h"
 #include "framfs_save_manager.h"
 #include "backends/fs/n64/n64-fs-factory.h"
+#include "backends/saves/default/default-saves.h"
+#include "backends/timer/default/default-timer.h"
+
+typedef unsigned long long uint64;
 
 extern uint8 _romfs; // Defined by linker (used to calculate position of romfs image)
 
@@ -90,9 +93,9 @@ OSystem_N64::OSystem_N64() {
 	_shakeOffset = 0;
 
 	// Allocate memory for offscreen buffers
-	_offscreen_hic = (uint16*)memalign(8, _screenWidth * _screenHeight * 2);
-	_offscreen_pal = (uint8*)memalign(8, _screenWidth * _screenHeight);
-	_overlayBuffer = (uint16*)memalign(8, _overlayWidth * _overlayHeight * sizeof(OverlayColor));
+	_offscreen_hic = (uint16 *)memalign(8, _screenWidth * _screenHeight * 2);
+	_offscreen_pal = (uint8 *)memalign(8, _screenWidth * _screenHeight);
+	_overlayBuffer = (uint16 *)memalign(8, _overlayWidth * _overlayHeight * sizeof(OverlayColor));
 
 	_cursor_pal = NULL;
 	_cursor_hic = NULL;
@@ -111,9 +114,9 @@ OSystem_N64::OSystem_N64() {
 	_graphicMode = OVERS_NTSC_340X240;
 
 	// Clear palette array
-	_screenPalette = (uint16*)memalign(8, 256 * sizeof(uint16));
+	_screenPalette = (uint16 *)memalign(8, 256 * sizeof(uint16));
 #ifndef N64_EXTREME_MEMORY_SAVING
-	_screenExactPalette = (uint8*)memalign(8, 256 * 3);
+	_screenExactPalette = (uint8 *)memalign(8, 256 * 3);
 	memset(_screenExactPalette, 0, 256 * 3);
 #endif
 	memset(_screenPalette, 0, 256 * sizeof(uint16));
@@ -125,7 +128,7 @@ OSystem_N64::OSystem_N64() {
 	_audioEnabled = false;
 
 	// Initialize ROMFS access interface
-	initRomFSmanager((uint8*)(((uint32)&_romfs + (uint32)0xc00) | (uint32)0xB0000000));
+	initRomFSmanager((uint8 *)(((uint32)&_romfs + (uint32)0xc00) | (uint32)0xB0000000));
 
 	_mouseVisible = false;
 
@@ -136,9 +139,7 @@ OSystem_N64::OSystem_N64() {
 	_mouseMaxX = _overlayWidth;
 	_mouseMaxY = _overlayHeight;
 
-	_savefile = 0;
 	_mixer = 0;
-	_timer = 0;
 
 	_dirtyOffscreen = false;
 
@@ -153,10 +154,7 @@ OSystem_N64::OSystem_N64() {
 }
 
 OSystem_N64::~OSystem_N64() {
-	delete _savefile;
 	delete _mixer;
-	delete _timer;
-	delete _fsFactory;
 }
 
 void OSystem_N64::initBackend() {
@@ -169,7 +167,7 @@ void OSystem_N64::initBackend() {
 
 	if (FRAM_Detect()) { // Use FlashRAM
 		initFramFS();
-		_savefile = new FRAMSaveManager();
+		_savefileManager = new FRAMSaveManager();
 	} else { // Use PakFS
 		// Init Controller Pak
 		initPakFs();
@@ -184,28 +182,36 @@ void OSystem_N64::initBackend() {
 			}
 		}
 
-		_savefile = new PAKSaveManager();
+		_savefileManager = new PAKSaveManager();
 	}
 
-	_timer = new DefaultTimerManager();
+	_timerManager = new DefaultTimerManager();
 
 	setTimerCallback(&timer_handler, 10);
 
 	setupMixer();
 
-	OSystem::initBackend();
-
+	EventsBaseBackend::initBackend();
 }
 
 bool OSystem_N64::hasFeature(Feature f) {
-	return (f == kFeatureCursorHasPalette);
+	return (f == kFeatureCursorPalette);
 }
 
 void OSystem_N64::setFeatureState(Feature f, bool enable) {
-	return;
+	if (f == kFeatureCursorPalette) {
+		_cursorPaletteDisabled = !enable;
+
+		// Rebuild cursor hicolor buffer
+		rebuildOffscreenMouseBuffer();
+
+		_dirtyOffscreen = true;
+	}
 }
 
 bool OSystem_N64::getFeatureState(Feature f) {
+	if (f == kFeatureCursorPalette)
+		return !_cursorPaletteDisabled;
 	return false;
 }
 
@@ -374,7 +380,7 @@ void OSystem_N64::rebuildOffscreenGameBuffer(void) {
 
 	for (int h = 0; h < _gameHeight; h++) {
 		for (int w = 0; w < _gameWidth; w += 4) {
-			four_col_pal = *(uint32*)(_offscreen_pal + ((h * _screenWidth) + w));
+			four_col_pal = *(uint32 *)(_offscreen_pal + ((h * _screenWidth) + w));
 
 			four_col_hi = 0;
 			four_col_hi |= (uint64)_screenPalette[((four_col_pal >> 24) & 0xFF)] << 48;
@@ -383,7 +389,7 @@ void OSystem_N64::rebuildOffscreenGameBuffer(void) {
 			four_col_hi |= (uint64)_screenPalette[((four_col_pal >>  0) & 0xFF)] <<  0;
 
 			// Save the converted pixels into hicolor buffer
-			*(uint64*)((_offscreen_hic) + (h * _screenWidth) + w) = four_col_hi;
+			*(uint64 *)((_offscreen_hic) + (h * _screenWidth) + w) = four_col_hi;
 		}
 	}
 }
@@ -436,15 +442,6 @@ void OSystem_N64::setCursorPalette(const byte *colors, uint start, uint num) {
 	_dirtyOffscreen = true;
 }
 
-void OSystem_N64::disableCursorPalette(bool disable) {
-	_cursorPaletteDisabled = disable;
-
-	// Rebuild cursor hicolor buffer
-	rebuildOffscreenMouseBuffer();
-
-	_dirtyOffscreen = true;
-}
-
 void OSystem_N64::copyRectToScreen(const byte *buf, int pitch, int x, int y, int w, int h) {
 	//Clip the coordinates
 	if (x < 0) {
@@ -520,7 +517,7 @@ void OSystem_N64::updateScreen() {
 	// Obtain the framebuffer
 	while (!(_dc = lockDisplay()));
 
-	uint16 *overlay_framebuffer = (uint16*)_dc->conf.framebuffer; // Current screen framebuffer
+	uint16 *overlay_framebuffer = (uint16 *)_dc->conf.framebuffer; // Current screen framebuffer
 	uint16 *game_framebuffer = overlay_framebuffer + (_frameBufferWidth * skip_lines * 2); // Skip some lines to center the image vertically
 
 	uint16 currentHeight, currentWidth;
@@ -532,8 +529,8 @@ void OSystem_N64::updateScreen() {
 		tmpDst = game_framebuffer;
 		tmpSrc = _offscreen_hic + (_shakeOffset * _screenWidth);
 		for (currentHeight = _shakeOffset; currentHeight < _gameHeight; currentHeight++) {
-			uint64 *game_dest = (uint64*)(tmpDst + skip_pixels + _offscrPixels);
-			uint64 *game_src = (uint64*)tmpSrc;
+			uint64 *game_dest = (uint64 *)(tmpDst + skip_pixels + _offscrPixels);
+			uint64 *game_src = (uint64 *)tmpSrc;
 
 			// With uint64 we copy 4 pixels at a time
 			for (currentWidth = 0; currentWidth < _gameWidth; currentWidth += 4) {
@@ -552,8 +549,8 @@ void OSystem_N64::updateScreen() {
 		tmpDst = overlay_framebuffer;
 		tmpSrc = _overlayBuffer;
 		for (currentHeight = 0; currentHeight < _overlayHeight; currentHeight++) {
-			uint64 *over_dest = (uint64*)(tmpDst + _offscrPixels);
-			uint64 *over_src = (uint64*)tmpSrc;
+			uint64 *over_dest = (uint64 *)(tmpDst + _offscrPixels);
+			uint64 *over_src = (uint64 *)tmpSrc;
 
 			// Copy 4 pixels at a time
 			for (currentWidth = 0; currentWidth < _overlayWidth; currentWidth += 4) {
@@ -610,7 +607,7 @@ Graphics::Surface *OSystem_N64::lockScreen() {
 	_framebuffer.w = _gameWidth;
 	_framebuffer.h = _gameHeight;
 	_framebuffer.pitch = _screenWidth;
-	_framebuffer.bytesPerPixel = 1;
+	_framebuffer.format = Graphics::PixelFormat::createFormatCLUT8();
 
 	return &_framebuffer;
 }
@@ -790,8 +787,8 @@ void OSystem_N64::setMouseCursor(const byte *buf, uint w, uint h, int hotspotX,
 	}
 
 	if (!_cursor_pal) {
-		_cursor_pal = (uint8*)malloc(w * h);
-		_cursor_hic = (uint16*)malloc(w * h * sizeof(uint16));
+		_cursor_pal = (uint8 *)malloc(w * h);
+		_cursor_hic = (uint16 *)malloc(w * h * sizeof(uint16));
 	}
 
 	_cursorWidth = w;
@@ -851,21 +848,11 @@ void OSystem_N64::quit() {
 	return;
 }
 
-Common::SaveFileManager *OSystem_N64::getSavefileManager() {
-	assert(_savefile);
-	return _savefile;
-}
-
 Audio::Mixer *OSystem_N64::getMixer() {
 	assert(_mixer);
 	return _mixer;
 }
 
-Common::TimerManager *OSystem_N64::getTimerManager() {
-	assert(_timer);
-	return _timer;
-}
-
 void OSystem_N64::getTimeAndDate(TimeDate &t) const {
 	// No RTC inside the N64, read mips timer to simulate
 	// passing of time, not a perfect solution, but can't think
@@ -883,8 +870,16 @@ void OSystem_N64::getTimeAndDate(TimeDate &t) const {
 	return;
 }
 
-FilesystemFactory *OSystem_N64::getFilesystemFactory() {
-	return _fsFactory;
+void OSystem_N64::logMessage(LogMessageType::Type type, const char *message) {
+	FILE *output = 0;
+
+	if (type == LogMessageType::kInfo || type == LogMessageType::kDebug)
+		output = stdout;
+	else
+		output = stderr;
+
+	fputs(message, output);
+	fflush(output);
 }
 
 void OSystem_N64::setTimerCallback(TimerProc callback, int interval) {
@@ -907,10 +902,10 @@ void OSystem_N64::setupMixer(void) {
 
 /* Check all controller ports for a compatible input adapter. */
 void OSystem_N64::detectControllers(void) {
-	controller_data_status *ctrl_status = (controller_data_status*)memalign(8, sizeof(controller_data_status));
+	controller_data_status *ctrl_status = (controller_data_status *)memalign(8, sizeof(controller_data_status));
 	controller_Read_Status(ctrl_status);
 
-	_controllerPort = 0; // Use first controller as default
+	_controllerPort = -1; // Default no controller
 	_mousePort = -1; // Default no mouse
 	for (int8 ctrl_port = 3; ctrl_port >= 0; ctrl_port--) {
 		// Found a standard pad, use this by default.
@@ -927,4 +922,3 @@ void OSystem_N64::detectControllers(void) {
 inline uint16 colRGB888toBGR555(byte r, byte g, byte b) {
 	return ((r >> 3) << 1) | ((g >> 3) << 6) | ((b >> 3) << 11);
 }
-
