@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -45,6 +42,7 @@
 #include "audio/mixer_intern.h"
 #include "audio/fmopl.h"
 
+#include "backends/mutex/sdl/sdl-mutex.h"
 #include "backends/timer/sdl/sdl-timer.h"
 
 #include "gui/Actions.h"
@@ -66,6 +64,7 @@
 #include "backends/mixer/wincesdl/wincesdl-mixer.h"
 
 #ifdef DYNAMIC_MODULES
+#include <malloc.h>
 #include "backends/plugins/win32/win32-provider.h"
 #endif
 
@@ -73,6 +72,50 @@
 extern "C" _CRTIMP FILE *__cdecl   _wfreopen(const wchar_t *, const wchar_t *, FILE *);
 #endif
 
+#ifdef WRAP_MALLOC
+
+extern "C" void *__real_malloc(size_t size);
+extern "C" void __real_free(void *ptr);
+
+extern "C" void *__wrap_malloc(size_t size) {
+/*
+	void *ptr = __real_malloc(size);
+	printf("malloc(%d) = %p\n", size, ptr);
+	return ptr;
+*/
+	if (size < 64 * 1024) {
+		void *ptr = __real_malloc(size+4);
+//		printf("malloc(%d) = %p\n", size, ptr);
+		if (ptr != NULL) {
+			*((HANDLE*)ptr) = 0;
+			return 4+(char*)ptr;
+		}
+		return NULL;
+	}
+	HANDLE H = CreateFileMapping((HANDLE)INVALID_HANDLE_VALUE, 0, PAGE_READWRITE, 0, size+4, 0);
+	void *ptr = MapViewOfFile(H, FILE_MAP_ALL_ACCESS, 0, 0, 0);
+	*((HANDLE*)ptr) = H;
+	return 4+(char*)ptr;
+}
+
+extern "C" void __wrap_free(void *ptr) {
+/*
+	__real_free(ptr);
+	printf("free(%p)\n", ptr);
+*/
+	if (ptr != NULL) {
+		HANDLE H = *(HANDLE*)((char *)ptr-4);
+		if (H == 0) {
+			__real_free((char*)ptr-4);
+			return;
+		}
+		UnmapViewOfFile((char *)ptr-4);
+		CloseHandle(H);
+	}
+}
+
+#endif
+
 using namespace CEGUI;
 
 // ********************************************************************************************
@@ -381,14 +424,6 @@ void OSystem_WINCE3::initBackend() {
 
 	((WINCESdlEventSource *)_eventSource)->init((WINCESdlGraphicsManager *)_graphicsManager);
 
-	// Create the timer (but remove the timer manager from the SDL backend first).
-	// CE SDL does not support multiple timers (SDL_AddTimer).
-	// We work around this by using the SetTimer function, since we only use
-	// one timer in scummvm (for the time being)
-	delete _timerManager;
-	_timerManager = new DefaultTimerManager();
-	SDL_SetTimer(10, &timer_handler_wrapper);
-
 	// Call parent implementation of this method
 	OSystem_SDL::initBackend();
 
@@ -443,14 +478,9 @@ OSystem_WINCE3::OSystem_WINCE3() : OSystem_SDL(),
 }
 
 OSystem_WINCE3::~OSystem_WINCE3() {
-	delete _fsFactory;
 	delete _mixer;
 }
 
-FilesystemFactory *OSystem_WINCE3::getFilesystemFactory() {
-	return _fsFactory;
-}
-
 void OSystem_WINCE3::swap_sound_master() {
 	_soundMaster = !_soundMaster;
 
@@ -553,6 +583,24 @@ void OSystem_WINCE3::initSDL() {
 	}
 }
 
+void OSystem_WINCE3::init() {
+	// Create SdlMutexManager instance as the TimerManager relies on the
+	// MutexManager being already initialized
+	if (_mutexManager == 0)
+		_mutexManager = new SdlMutexManager();
+
+	// Create the timer. CE SDL does not support multiple timers (SDL_AddTimer).
+	// We work around this by using the SetTimer function, since we only use
+	// one timer in scummvm (for the time being)
+	if (_timerManager == 0) {
+		_timerManager = new DefaultTimerManager();
+		SDL_SetTimer(10, &timer_handler_wrapper);
+	}
+
+	// Call parent implementation of this method
+	OSystem_SDL::init();
+}
+
 void OSystem_WINCE3::quit() {
 	fclose(stdout_file);
 	fclose(stderr_file);
@@ -619,7 +667,7 @@ Common::String OSystem_WINCE3::getSystemLanguage() const {
 		GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_SABBREVCTRYNAME, ctryNameW, sizeof(ctryNameW)) != 0) {
 		WideCharToMultiByte(CP_ACP, 0, langNameW, -1, langName, (wcslen(langNameW) + 1), NULL, NULL);
 		WideCharToMultiByte(CP_ACP, 0, ctryNameW, -1, ctryName, (wcslen(ctryNameW) + 1), NULL, NULL);
-		
+
 		debug(1, "Trying to find posix locale name for %s_%s", langName, ctryName);
 		while (posixMappingTable[i][0] && !localeFound) {
 			if ( (!strcmp(posixMappingTable[i][0], langName) || !strcmp(posixMappingTable[i][0], "*")) &&
