@@ -18,23 +18,22 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
-* $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/backends/vkeybd/virtual-keyboard-gui.cpp $
-* $Id: virtual-keyboard-gui.cpp 47118 2010-01-07 15:07:36Z marcus_c $
-*
 */
 
+#include "common/scummsys.h"
+
 #ifdef ENABLE_VKEYBD
 
 #include "backends/vkeybd/virtual-keyboard-gui.h"
 
 #include "graphics/cursorman.h"
 #include "graphics/fontman.h"
-#include "gui/GuiManager.h"
+#include "gui/gui-manager.h"
 
 namespace Common {
 
 static void blit(Graphics::Surface *surf_dst, Graphics::Surface *surf_src, int16 x, int16 y, OverlayColor transparent) {
-	if (surf_dst->bytesPerPixel != sizeof(OverlayColor) || surf_src->bytesPerPixel != sizeof(OverlayColor))
+	if (surf_dst->format.bytesPerPixel != sizeof(OverlayColor) || surf_src->format.bytesPerPixel != sizeof(OverlayColor))
 		return;
 
 	const OverlayColor *src = (const OverlayColor *)surf_src->pixels;
@@ -131,7 +130,7 @@ void VirtualKeyboardGUI::setupDisplayArea(Rect& r, OverlayColor forecolor) {
 	_dispI = 0;
 	_dispForeColor = forecolor;
 	_dispBackColor = _dispForeColor + 0xFF;
-	_dispSurface.create(r.width(), _dispFont->getFontHeight(), sizeof(OverlayColor));
+	_dispSurface.create(r.width(), _dispFont->getFontHeight(), _system->getOverlayFormat());
 	_dispSurface.fillRect(Rect(_dispSurface.w, _dispSurface.h), _dispBackColor);
 	_displayEnabled = true;
 }
@@ -161,7 +160,7 @@ void VirtualKeyboardGUI::run() {
 		_system->showOverlay();
 		_system->clearOverlay();
 	}
-	_overlayBackup.create(_screenW, _screenH, sizeof(OverlayColor));
+	_overlayBackup.create(_screenW, _screenH, _system->getOverlayFormat());
 	_system->grabOverlay((OverlayColor*)_overlayBackup.pixels, _overlayBackup.w);
 
 	setupCursor();
@@ -201,7 +200,7 @@ void VirtualKeyboardGUI::moveToDefaultPosition()
 		case VirtualKeyboard::kAlignLeft:
 			x = 0;
 			break;
-		case VirtualKeyboard::kAlignCentre:
+		case VirtualKeyboard::kAlignCenter:
 			x = (_screenW - kbdW) / 2;
 			break;
 		case VirtualKeyboard::kAlignRight:
@@ -263,7 +262,7 @@ void VirtualKeyboardGUI::screenChanged() {
 		_screenW = newScreenW;
 		_screenH = newScreenH;
 
-		_overlayBackup.create(_screenW, _screenH, sizeof(OverlayColor));
+		_overlayBackup.create(_screenW, _screenH, _system->getOverlayFormat());
 		_system->grabOverlay((OverlayColor*)_overlayBackup.pixels, _overlayBackup.w);
 
 		if (!_kbd->checkModeResolutions()) {
@@ -356,7 +355,7 @@ void VirtualKeyboardGUI::redraw() {
 	if (w <= 0 || h <= 0) return;
 
 	Graphics::Surface surf;
-	surf.create(w, h, sizeof(OverlayColor));
+	surf.create(w, h, _system->getOverlayFormat());
 
 	OverlayColor *dst = (OverlayColor *)surf.pixels;
 	const OverlayColor *src = (OverlayColor *) _overlayBackup.getBasePtr(_dirtyRect.left, _dirtyRect.top);
