@@ -18,15 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/archive.cpp $
- * $Id: archive.cpp 48254 2010-03-13 21:55:49Z lordhoto $
- *
  */
 
 #include "common/archive.h"
 #include "common/fs.h"
-#include "common/util.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 namespace Common {
 
@@ -150,7 +147,7 @@ void SearchSet::addSubDirectoriesMatching(const FSNode &directory, String origPa
 	for (FSList::const_iterator i = subDirs.begin(); i != subDirs.end(); ++i) {
 		String name = i->getName();
 
-		if (Common::matchString(name.c_str(), pattern.c_str(), ignoreCase)) {
+		if (matchString(name.c_str(), pattern.c_str(), ignoreCase)) {
 			matchIter = multipleMatches.find(name);
 			if (matchIter == multipleMatches.end()) {
 				multipleMatches[name] = true;
@@ -288,7 +285,6 @@ void SearchManager::clear() {
 	addDirectory(".", ".", -2);
 }
 
+DECLARE_SINGLETON(SearchManager);
+
 } // namespace Common
-
-DECLARE_SINGLETON(Common::SearchManager)
-
