@@ -18,16 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/archive.h $
- * $Id: archive.h 52131 2010-08-16 19:58:20Z fingolfin $
- *
  */
 
 #ifndef COMMON_ARCHIVE_H
 #define COMMON_ARCHIVE_H
 
 #include "common/str.h"
-#include "common/hash-str.h"
 #include "common/list.h"
 #include "common/ptr.h"
 #include "common/singleton.h"
@@ -147,7 +143,7 @@ class SearchSet : public Archive {
 	ArchiveNodeList::iterator find(const String &name);
 	ArchiveNodeList::const_iterator find(const String &name) const;
 
-	// Add an archive keeping the list sorted by ascending priorities.
+	// Add an archive keeping the list sorted by descending priority.
 	void insert(const Node& node);
 
 public:
@@ -258,7 +254,7 @@ public:
 	virtual void clear();
 
 private:
-	friend class Common::Singleton<SingletonBaseType>;
+	friend class Singleton<SingletonBaseType>;
 	SearchManager();
 };
 
