@@ -17,13 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/fs.cpp $
- * $Id: fs.cpp 52127 2010-08-16 18:07:21Z sev $
  */
 
-#include "common/util.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 #include "backends/fs/abstract-fs.h"
 #include "backends/fs/fs-factory.h"
 
@@ -36,7 +33,7 @@ FSNode::FSNode(AbstractFSNode *realNode)
 	: _realNode(realNode) {
 }
 
-FSNode::FSNode(const Common::String &p) {
+FSNode::FSNode(const String &p) {
 	assert(g_system);
 	FilesystemFactory *factory = g_system->getFilesystemFactory();
 	AbstractFSNode *tmp = 0;
@@ -45,7 +42,7 @@ FSNode::FSNode(const Common::String &p) {
 		tmp = factory->makeCurrentDirectoryFileNode();
 	else
 		tmp = factory->makeFileNodePath(p);
-	_realNode = Common::SharedPtr<AbstractFSNode>(tmp);
+	_realNode = SharedPtr<AbstractFSNode>(tmp);
 }
 
 bool FSNode::operator<(const FSNode& node) const {
@@ -62,7 +59,7 @@ bool FSNode::exists() const {
 	return _realNode && _realNode->exists();
 }
 
-FSNode FSNode::getChild(const Common::String &n) const {
+FSNode FSNode::getChild(const String &n) const {
 	// If this node is invalid or not a directory, return an invalid node
 	if (_realNode == 0 || !_realNode->isDirectory())
 		return FSNode();
@@ -88,12 +85,12 @@ bool FSNode::getChildren(FSList &fslist, ListMode mode, bool hidden) const {
 	return true;
 }
 
-Common::String FSNode::getDisplayName() const {
+String FSNode::getDisplayName() const {
 	assert(_realNode);
 	return _realNode->getDisplayName();
 }
 
-Common::String FSNode::getName() const {
+String FSNode::getName() const {
 	assert(_realNode);
 	return _realNode->getName();
 }
@@ -110,7 +107,7 @@ FSNode FSNode::getParent() const {
 	}
 }
 
-Common::String FSNode::getPath() const {
+String FSNode::getPath() const {
 	assert(_realNode);
 	return _realNode->getPath();
 }
@@ -127,7 +124,7 @@ bool FSNode::isWritable() const {
 	return _realNode && _realNode->isWritable();
 }
 
-Common::SeekableReadStream *FSNode::createReadStream() const {
+SeekableReadStream *FSNode::createReadStream() const {
 	if (_realNode == 0)
 		return 0;
 
@@ -142,7 +139,7 @@ Common::SeekableReadStream *FSNode::createReadStream() const {
 	return _realNode->createReadStream();
 }
 
-Common::WriteStream *FSNode::createWriteStream() const {
+WriteStream *FSNode::createWriteStream() const {
 	if (_realNode == 0)
 		return 0;
 
@@ -259,7 +256,7 @@ void FSDirectory::cacheDirectoryRecursive(FSNode node, int depth, const String&
 		return;
 
 	FSList list;
-	node.getChildren(list, FSNode::kListAll, false);
+	node.getChildren(list, FSNode::kListAll, true);
 
 	FSList::iterator it = list.begin();
 	for ( ; it != list.end(); ++it) {
