@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/common/ptr.h $
- * $Id: ptr.h 51094 2010-07-21 18:17:51Z lordhoto $
  */
 
 #ifndef COMMON_PTR_H
@@ -27,6 +24,7 @@
 
 #include "common/scummsys.h"
 #include "common/noncopyable.h"
+#include "common/types.h"
 
 namespace Common {
 
@@ -188,12 +186,12 @@ public:
 	}
 
 	template<class T2>
-	bool operator==(const Common::SharedPtr<T2> &r) const {
+	bool operator==(const SharedPtr<T2> &r) const {
 		return _pointer == r.get();
 	}
 
 	template<class T2>
-	bool operator!=(const Common::SharedPtr<T2> &r) const {
+	bool operator!=(const SharedPtr<T2> &r) const {
 		return _pointer != r.get();
 	}
 
@@ -234,7 +232,6 @@ public:
 
 	ReferenceType operator*() const { return *_pointer; }
 	PointerType operator->() const { return _pointer; }
-	operator PointerType() const { return _pointer; }
 
 	/**
 	 * Implicit conversion operator to bool for convenience, to make
@@ -278,6 +275,40 @@ private:
 };
 
 
+template<typename T>
+class DisposablePtr : NonCopyable {
+public:
+	typedef T  ValueType;
+	typedef T *PointerType;
+	typedef T &ReferenceType;
+
+	explicit DisposablePtr(PointerType o, DisposeAfterUse::Flag dispose) : _pointer(o), _dispose(dispose) {}
+
+	~DisposablePtr() {
+		if (_dispose) delete _pointer;
+	}
+
+	ReferenceType operator*() const { return *_pointer; }
+	PointerType operator->() const { return _pointer; }
+
+	/**
+	 * Implicit conversion operator to bool for convenience, to make
+	 * checks like "if (scopedPtr) ..." possible.
+	 */
+	operator bool() const { return _pointer; }
+
+	/**
+	 * Returns the plain pointer value.
+	 *
+	 * @return the pointer the DisposablePtr manages
+	 */
+	PointerType get() const { return _pointer; }
+
+private:
+	PointerType           _pointer;
+	DisposeAfterUse::Flag _dispose;
+};
+
 } // End of namespace Common
 
 #endif
