@@ -27,9 +27,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 #include <stdarg.h>
 #include <stdio.h>
@@ -724,7 +721,7 @@ int gen_c_source(struct font* pf, char *path) {
 	char bbuf[256];
 	char hdr1[] = {
 		"/* Generated by convbdf on %s. */\n"
-		"#include \"graphics/font.h\"\n"
+		"#include \"graphics/fonts/bdf.h\"\n"
 		"\n"
 		"/* Font information:\n"
 		"   name: %s\n"
@@ -893,7 +890,7 @@ int gen_c_source(struct font* pf, char *path) {
 
 	fprintf(ofp,
 			"/* Exported structure definition. */\n"
-			"static const FontDesc desc = {\n"
+			"static const BdfFontDesc desc = {\n"
 			"\t" "\"%s\",\n"
 			"\t" "%d,\n"
 			"\t" "%d,\n"
@@ -920,7 +917,7 @@ int gen_c_source(struct font* pf, char *path) {
 			pf->defaultchar);
 
 	fprintf(ofp, "\n" "#if !(defined(__GP32__))\n");
-	fprintf(ofp, "extern const NewFont g_sysfont(desc);\n");
+	fprintf(ofp, "extern const BdfFont g_sysfont(desc);\n");
 	fprintf(ofp, "#else\n");
 	fprintf(ofp, "DEFINE_FONT(g_sysfont)\n");
 	fprintf(ofp, "#endif\n");
