@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
+//#define ENABLE_XCODE
+
 // HACK to allow building with the SDL backend on MinGW
 // see bug #1800764 "TOOLS: MinGW tools building broken"
 #ifdef main
@@ -31,11 +30,12 @@
 
 #include "config.h"
 #include "create_project.h"
-#include "codeblocks.h"
 
+#include "codeblocks.h"
 #include "msvc.h"
 #include "visualstudio.h"
 #include "msbuild.h"
+#include "xcode.h"
 
 #include <fstream>
 #include <iostream>
@@ -110,13 +110,14 @@ typedef std::list<FSNode> FileList;
 enum ProjectType {
 	kProjectNone,
 	kProjectCodeBlocks,
-	kProjectMSVC
+	kProjectMSVC,
+	kProjectXcode
 };
 
 int main(int argc, char *argv[]) {
 #ifndef USE_WIN32_API
 	// Initialize random number generator for UUID creation
-	std::srand(std::time(0));
+	std::srand((uint)std::time(0));
 #endif
 
 	if (argc < 2) {
@@ -178,6 +179,16 @@ int main(int argc, char *argv[]) {
 
 			projectType = kProjectMSVC;
 
+#ifdef ENABLE_XCODE
+		} else if (!std::strcmp(argv[i], "--xcode")) {
+			if (projectType != kProjectNone) {
+				std::cerr << "ERROR: You cannot pass more than one project type!\n";
+				return -1;
+			}
+
+			projectType = kProjectXcode;
+#endif
+
 		} else if (!std::strcmp(argv[i], "--msvc-version")) {
 			if (i + 1 >= argc) {
 				std::cerr << "ERROR: Missing \"version\" parameter for \"--msvc-version\"!\n";
@@ -245,6 +256,11 @@ int main(int argc, char *argv[]) {
 
 		} else if (!std::strcmp(argv[i], "--build-events")) {
 			setup.runBuildEvents = true;
+		} else if (!std::strcmp(argv[i], "--installer")) {
+			setup.runBuildEvents  = true;
+			setup.createInstaller = true;
+		} else if (!std::strcmp(argv[i], "--tools")) {
+			setup.devTools = true;
 		} else {
 			std::cerr << "ERROR: Unknown parameter \"" << argv[i] << "\"\n";
 			return -1;
@@ -313,6 +329,11 @@ int main(int argc, char *argv[]) {
 		return -1;
 
 	case kProjectCodeBlocks:
+		if (setup.devTools) {
+			std::cerr << "ERROR: Building tools is not supported for the CodeBlocks project type!\n";
+			return -1;
+		}
+
 		////////////////////////////////////////////////////////////////////////////
 		// Code::Blocks is using GCC behind the scenes, so we need to pass a list
 		// of options to enable or disable warnings
@@ -354,6 +375,11 @@ int main(int argc, char *argv[]) {
 
 		provider = new CreateProjectTool::CodeBlocksProvider(globalWarnings, projectWarnings);
 
+
+		// Those libraries are automatically added by MSVC, but we need to add them manually with mingw
+		setup.libraries.push_back("ole32");
+		setup.libraries.push_back("uuid");
+
 		break;
 
 	case kProjectMSVC:
@@ -463,6 +489,46 @@ int main(int argc, char *argv[]) {
 			provider = new CreateProjectTool::MSBuildProvider(globalWarnings, projectWarnings, msvcVersion);
 
 		break;
+
+	case kProjectXcode:
+		if (setup.devTools) {
+			std::cerr << "ERROR: Building tools is not supported for the XCode project type!\n";
+			return -1;
+		}
+
+		////////////////////////////////////////////////////////////////////////////
+		// Xcode is also using GCC behind the scenes. See Code::Blocks comment
+		// for info on all warnings
+		////////////////////////////////////////////////////////////////////////////
+		globalWarnings.push_back("-Wall");
+		globalWarnings.push_back("-Wno-long-long");
+		globalWarnings.push_back("-Wno-multichar");
+		globalWarnings.push_back("-Wno-unknown-pragmas");
+		globalWarnings.push_back("-Wno-reorder");
+		globalWarnings.push_back("-Wpointer-arith");
+		globalWarnings.push_back("-Wcast-qual");
+		globalWarnings.push_back("-Wcast-align");
+		globalWarnings.push_back("-Wshadow");
+		globalWarnings.push_back("-Wimplicit");
+		globalWarnings.push_back("-Wnon-virtual-dtor");
+		globalWarnings.push_back("-Wwrite-strings");
+		// The following are not warnings at all... We should consider adding them to
+		// a different list of parameters.
+		globalWarnings.push_back("-fno-rtti");
+		globalWarnings.push_back("-fno-exceptions");
+		globalWarnings.push_back("-fcheck-new");
+
+		provider = new CreateProjectTool::XCodeProvider(globalWarnings, projectWarnings);
+		break;
+	}
+
+	// Setup project name and description
+	setup.projectName        = PROJECT_NAME;
+	setup.projectDescription = PROJECT_DESCRIPTION;
+
+	if (setup.devTools) {
+		setup.projectName        += "-tools";
+		setup.projectDescription += "Tools";
 	}
 
 	provider->createProject(setup);
@@ -501,6 +567,7 @@ void displayHelp(const char *exe) {
 	        "Project specific settings:\n"
 	        " --codeblock              build Code::Blocks project files\n"
 	        " --msvc                   build Visual Studio project files\n"
+	        " --xcode                  build XCode project files\n"
 	        " --file-prefix prefix     allow overwriting of relative file prefix in the\n"
 	        "                          MSVC project files. By default the prefix is the\n"
 	        "                          \"path\\to\\source\" argument\n"
@@ -516,6 +583,11 @@ void displayHelp(const char *exe) {
 	        "                           The default is \"9\", thus \"Visual Studio 2008\"\n"
 	        " --build-events           Run custom build events as part of the build\n"
 	        "                          (default: false)\n"
+	        " --installer              Create NSIS installer after the build (implies --build-events)\n"
+	        "                          (default: false)\n"
+			" --tools                  Create project files for the devtools\n"
+			"                          (ignores --build-events and --installer, as well as engine settings)\n"
+			"                          (default: false)\n"
 	        "\n"
 	        "Engines settings:\n"
 	        " --list-engines           list all available engines and their default state\n"
@@ -634,7 +706,7 @@ bool setEngineBuildState(const std::string &name, EngineDescList &engines, bool
 		if (engine != engines.end()) {
 			engine->enable = enable;
 
-			// When we disable an einge, we also need to disable all the sub engines.
+			// When we disable an engine, we also need to disable all the sub engines.
 			if (!enable && !engine->subEngines.empty()) {
 				for (StringList::const_iterator j = engine->subEngines.begin(); j != engine->subEngines.end(); ++j) {
 					EngineDescList::iterator subEngine = std::find(engines.begin(), engines.end(), *j);
@@ -725,23 +797,35 @@ const Feature s_features[] = {
 	{     "mad",         "USE_MAD", "libmad",           true, "libmad (MP3) support" },
 	{  "vorbis",      "USE_VORBIS", "libvorbisfile_static libvorbis_static libogg_static", true, "Ogg Vorbis support" },
 	{    "flac",        "USE_FLAC", "libFLAC_static",   true, "FLAC support" },
-	{     "png",         "USE_PNG", "libpng",           false, "libpng support" },
-	{  "theora",   "USE_THEORADEC", "libtheora_static", false, "Theora decoding support" },
-	{   "mpeg2",       "USE_MPEG2", "libmpeg2",         false, "mpeg2 codec for cutscenes" },
+	{     "png",         "USE_PNG", "libpng",           true, "libpng support" },
+	{  "theora",   "USE_THEORADEC", "libtheora_static", true, "Theora decoding support" },
 
 	// Feature flags
+	{        "bink",        "USE_BINK",         "", true, "Bink video support" },
 	{     "scalers",     "USE_SCALERS",         "", true, "Scalers" },
 	{   "hqscalers",  "USE_HQ_SCALERS",         "", true, "HQ scalers" },
 	{       "16bit",   "USE_RGB_COLOR",         "", true, "16bit color support" },
 	{     "mt32emu",     "USE_MT32EMU",         "", true, "integrated MT-32 emulator" },
 	{        "nasm",        "USE_NASM",         "", true, "IA-32 assembly support" }, // This feature is special in the regard, that it needs additional handling.
 	{      "opengl",      "USE_OPENGL", "opengl32", false, "OpenGL support" },
-	{      "indeo3",      "USE_INDEO3",         "", true, "Indeo3 codec support"},
+	{     "taskbar",     "USE_TASKBAR",         "", true, "Taskbar integration support" },
 	{ "translation", "USE_TRANSLATION",         "", true, "Translation support" },
 	{      "vkeybd",   "ENABLE_VKEYBD",         "", false, "Virtual keyboard support"},
 	{  "langdetect",  "USE_DETECTLANG",         "", true, "System language detection support" } // This feature actually depends on "translation", there
 	                                                                                            // is just no current way of properly detecting this...
 };
+
+const Tool s_tools[] = {
+	{ "create_drascula",     true},
+	{ "create_hugo",         true},
+	{ "create_kyradat",      true},
+	{ "create_lure",         true},
+	{ "create_mads",         true},
+	{ "create_teenagent",    true},
+	{ "create_toon",         true},
+	{ "create_translations", true},
+	{ "qtable",              true}
+};
 } // End of anonymous namespace
 
 FeatureList getAllFeatures() {
@@ -788,6 +872,16 @@ bool setFeatureBuildState(const std::string &name, FeatureList &features, bool e
 	}
 }
 
+ToolList getAllTools() {
+	const size_t toolCount = sizeof(s_tools) / sizeof(s_tools[0]);
+
+	ToolList tools;
+	for (size_t i = 0; i < toolCount; ++i)
+		tools.push_back(s_tools[i]);
+
+	return tools;
+}
+
 namespace CreateProjectTool {
 
 //////////////////////////////////////////////////////////////////////////
@@ -1013,63 +1107,90 @@ ProjectProvider::ProjectProvider(StringList &global_warnings, std::map<std::stri
 }
 
 void ProjectProvider::createProject(const BuildSetup &setup) {
-	_uuidMap = createUUIDMap(setup);
+	if (setup.devTools) {
+		_uuidMap = createToolsUUIDMap();
 
-	// We also need to add the UUID of the main project file.
-	const std::string svmUUID = _uuidMap[PROJECT_NAME] = createUUID();
+		// We also need to add the UUID of the main project file.
+		const std::string svmUUID = _uuidMap[setup.projectName] = createUUID();
 
-	// Create Solution/Workspace file
-	createWorkspace(setup);
+		createWorkspace(setup);
 
-	StringList in, ex;
+		StringList in, ex;
 
-	// Create engine project files
-	for (UUIDMap::const_iterator i = _uuidMap.begin(); i != _uuidMap.end(); ++i) {
-		if (i->first == PROJECT_NAME)
-			continue;
+		// Create tools project files
+		for (UUIDMap::const_iterator i = _uuidMap.begin(); i != _uuidMap.end(); ++i) {
+			if (i->first == setup.projectName)
+				continue;
 
+			in.clear(); ex.clear();
+			const std::string moduleDir = setup.srcDir + "/devtools/" + i->first;
+
+			createModuleList(moduleDir, setup.defines, in, ex);
+			createProjectFile(i->first, i->second, setup, moduleDir, in, ex);
+		}
+
+		// Create other misc. build files
+		createOtherBuildFiles(setup);
+
+	} else {
+		_uuidMap = createUUIDMap(setup);
+
+		// We also need to add the UUID of the main project file.
+		const std::string svmUUID = _uuidMap[setup.projectName] = createUUID();
+
+		// Create Solution/Workspace file
+		createWorkspace(setup);
+
+		StringList in, ex;
+
+		// Create engine project files
+		for (UUIDMap::const_iterator i = _uuidMap.begin(); i != _uuidMap.end(); ++i) {
+			if (i->first == setup.projectName)
+				continue;
+
+			in.clear(); ex.clear();
+			const std::string moduleDir = setup.srcDir + "/engines/" + i->first;
+
+			createModuleList(moduleDir, setup.defines, in, ex);
+			createProjectFile(i->first, i->second, setup, moduleDir, in, ex);
+		}
+
+		// Last but not least create the main project file.
 		in.clear(); ex.clear();
-		const std::string moduleDir = setup.srcDir + "/engines/" + i->first;
 
-		createModuleList(moduleDir, setup.defines, in, ex);
-		createProjectFile(i->first, i->second, setup, moduleDir, in, ex);
-	}
-
-	// Last but not least create the main project file.
-	in.clear(); ex.clear();
-
-	// File list for the Project file
-	createModuleList(setup.srcDir + "/backends", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/backends/platform/sdl", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/base", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/common", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/engines", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/graphics", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/gui", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/audio", setup.defines, in, ex);
-	createModuleList(setup.srcDir + "/audio/softsynth/mt32", setup.defines, in, ex);
+		// File list for the Project file
+		createModuleList(setup.srcDir + "/backends", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/backends/platform/sdl", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/base", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/common", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/engines", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/graphics", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/gui", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/audio", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/audio/softsynth/mt32", setup.defines, in, ex);
 #if HAS_VIDEO_FOLDER
-	createModuleList(setup.srcDir + "/video", setup.defines, in, ex);
+		createModuleList(setup.srcDir + "/video", setup.defines, in, ex);
 #endif
 
-	// Resource files
-	in.push_back(setup.srcDir + "/icons/" + PROJECT_NAME + ".ico");
-	in.push_back(setup.srcDir + "/dists/" + PROJECT_NAME + ".rc");
+		// Resource files
+		in.push_back(setup.srcDir + "/icons/" + setup.projectName + ".ico");
+		in.push_back(setup.srcDir + "/dists/" + setup.projectName + ".rc");
 
-	// Various text files
-	in.push_back(setup.srcDir + "/AUTHORS");
-	in.push_back(setup.srcDir + "/COPYING");
-	in.push_back(setup.srcDir + "/COPYING.LGPL");
-	in.push_back(setup.srcDir + "/COPYRIGHT");
-	in.push_back(setup.srcDir + "/NEWS");
-	in.push_back(setup.srcDir + "/README");
-	in.push_back(setup.srcDir + "/TODO");
+		// Various text files
+		in.push_back(setup.srcDir + "/AUTHORS");
+		in.push_back(setup.srcDir + "/COPYING");
+		in.push_back(setup.srcDir + "/COPYING.LGPL");
+		in.push_back(setup.srcDir + "/COPYRIGHT");
+		in.push_back(setup.srcDir + "/NEWS");
+		in.push_back(setup.srcDir + "/README");
+		in.push_back(setup.srcDir + "/TODO");
 
-	// Create the main project file.
-	createProjectFile(PROJECT_NAME, svmUUID, setup, setup.srcDir, in, ex);
+		// Create the main project file.
+		createProjectFile(setup.projectName, svmUUID, setup, setup.srcDir, in, ex);
 
-	// Create other misc. build files
-	createOtherBuildFiles(setup);
+		// Create other misc. build files
+		createOtherBuildFiles(setup);
+	}
 }
 
 ProjectProvider::UUIDMap ProjectProvider::createUUIDMap(const BuildSetup &setup) const {
@@ -1085,6 +1206,20 @@ ProjectProvider::UUIDMap ProjectProvider::createUUIDMap(const BuildSetup &setup)
 	return result;
 }
 
+ProjectProvider::UUIDMap ProjectProvider::createToolsUUIDMap() const {
+	UUIDMap result;
+
+	ToolList tools = getAllTools();
+	for (ToolList::const_iterator i = tools.begin(); i != tools.end(); ++i) {
+		if (!i->enable)
+			continue;
+
+		result[i->name] = createUUID();
+	}
+
+	return result;
+}
+
 std::string ProjectProvider::createUUID() const {
 #ifdef USE_WIN32_API
 	UUID uuid;
@@ -1220,10 +1355,20 @@ void ProjectProvider::createModuleList(const std::string &moduleDir, const Strin
 					tokens = tokenize(line);
 					i = tokens.begin();
 				} else {
-					if (shouldInclude.top())
-						includeList.push_back(moduleDir + "/" + unifyPath(*i));
-					else
-						excludeList.push_back(moduleDir + "/" + unifyPath(*i));
+					const std::string filename = moduleDir + "/" + unifyPath(*i);
+
+					if (shouldInclude.top()) {
+						// In case we should include a file, we need to make
+						// sure it is not in the exclude list already. If it
+						// is we just drop it from the exclude list.
+						excludeList.remove(filename);
+
+						includeList.push_back(filename);
+					} else if (std::find(includeList.begin(), includeList.end(), filename) == includeList.end()) {
+						// We only add the file to the exclude list in case it
+						// has not yet been added to the include list.
+						excludeList.push_back(filename);
+					}
 					++i;
 				}
 			}
