@@ -18,19 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/agi.cpp $
- * $Id: agi.cpp 52839 2010-09-21 06:06:37Z eriktorbjorn $
- *
  */
 
 #include "common/md5.h"
 #include "common/events.h"
-#include "common/EventRecorder.h"
 #include "common/file.h"
+#include "common/memstream.h"
 #include "common/savefile.h"
 #include "common/config-manager.h"
 #include "common/debug-channels.h"
 #include "common/random.h"
+#include "common/textconsole.h"
 
 #include "engines/util.h"
 
@@ -39,8 +37,8 @@
 
 #include "graphics/cursorman.h"
 
-#include "sound/mididrv.h"
-#include "sound/mixer.h"
+#include "audio/mididrv.h"
+#include "audio/mixer.h"
 
 #include "agi/agi.h"
 #include "agi/graphics.h"
@@ -133,46 +131,65 @@ void AgiEngine::processEvents() {
 			switch (key = event.kbd.keycode) {
 			case Common::KEYCODE_LEFT:
 			case Common::KEYCODE_KP4:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP4)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_LEFT;
 				break;
 			case Common::KEYCODE_RIGHT:
 			case Common::KEYCODE_KP6:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP6)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_RIGHT;
 				break;
 			case Common::KEYCODE_UP:
 			case Common::KEYCODE_KP8:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP8)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP;
 				break;
 			case Common::KEYCODE_DOWN:
 			case Common::KEYCODE_KP2:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP2)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN;
 				break;
 			case Common::KEYCODE_PAGEUP:
 			case Common::KEYCODE_KP9:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP9)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP_RIGHT;
 				break;
 			case Common::KEYCODE_PAGEDOWN:
 			case Common::KEYCODE_KP3:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP3)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN_RIGHT;
 				break;
 			case Common::KEYCODE_HOME:
 			case Common::KEYCODE_KP7:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP7)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_UP_LEFT;
 				break;
 			case Common::KEYCODE_END:
 			case Common::KEYCODE_KP1:
-				if (_allowSynthetic || !event.synthetic)
+				if (_predictiveDialogRunning && key == Common::KEYCODE_KP1)
+					key = event.kbd.ascii;
+				else if (_allowSynthetic || !event.synthetic)
 					key = KEY_DOWN_LEFT;
 				break;
 			case Common::KEYCODE_KP5:
-				key = KEY_STATIONARY;
+				if (_predictiveDialogRunning)
+					key = event.kbd.ascii;
+				else
+					key = KEY_STATIONARY;
 				break;
 			case Common::KEYCODE_PLUS:
 				key = '+';
@@ -272,23 +289,16 @@ void AgiEngine::processEvents() {
 }
 
 void AgiEngine::pollTimer() {
-	uint32 dm;
+	_lastTick += 50;
 
-	if (_tickTimer < _lastTickTimer)
-		_lastTickTimer = 0;
-
-	while ((dm = _tickTimer - _lastTickTimer) < 5) {
+	while (_system->getMillis() < _lastTick) {
 		processEvents();
 		_console->onFrame();
 		_system->delayMillis(10);
 		_system->updateScreen();
 	}
-	_lastTickTimer = _tickTimer;
-}
 
-void AgiEngine::agiTimerFunctionLow(void *refCon) {
-	AgiEngine *self = (AgiEngine *)refCon;
-	self->_tickTimer++;
+	_lastTick = _system->getMillis();
 }
 
 void AgiEngine::pause(uint32 msec) {
@@ -352,20 +362,26 @@ int AgiEngine::agiInit() {
 
 	initPriTable();
 
-	// clear string buffer
-	for (i = 0; i < MAX_STRINGS; i++)
-		_game.strings[i][0] = 0;
+	// Clear the string buffer on startup, but not when the game restarts, as
+	// some scripts expect that the game strings remain unaffected after a
+	// restart. An example is script 98 in SQ2, which is not invoked on restart
+	// to ask Ego's name again. The name is supposed to be maintained in string 1.
+	// Fixes bug #3292784.
+	if (!_restartGame) {
+		for (i = 0; i < MAX_STRINGS; i++)
+			_game.strings[i][0] = 0;
+	}
 
 	// setup emulation
 
 	switch (getVersion() >> 12) {
 	case 2:
-		report("Emulating Sierra AGI v%x.%03x\n",
+		debug("Emulating Sierra AGI v%x.%03x",
 				(int)(getVersion() >> 12) & 0xF,
 				(int)(getVersion()) & 0xFFF);
 		break;
 	case 3:
-		report("Emulating Sierra AGI v%x.002.%03x\n",
+		debug("Emulating Sierra AGI v%x.002.%03x",
 				(int)(getVersion() >> 12) & 0xF,
 				(int)(getVersion()) & 0xFFF);
 		break;
@@ -382,10 +398,10 @@ int AgiEngine::agiInit() {
 		_game.sbuf = _game.sbuf256c;
 
 	if (_game.gameFlags & ID_AMIGA)
-		report("Amiga padded game detected.\n");
+		debug(1, "Amiga padded game detected.");
 
 	if (_game.gameFlags & ID_AGDS)
-		report("AGDS mode enabled.\n");
+		debug(1, "AGDS mode enabled.");
 
 	ec = _loader->init();	// load vol files, etc
 
@@ -459,9 +475,8 @@ int AgiEngine::agiLoadResource(int r, int n) {
 	if (i == errOK && getGameID() == GID_GOLDRUSH && r == rPICTURE && n == 147 && _game.dirPic[n].len == 1982) {
 		uint8 *pic = _game.pictures[n].rdata;
 		Common::MemoryReadStream picStream(pic, _game.dirPic[n].len);
-		char md5str[32+1];
-		Common::md5_file_string(picStream, md5str, _game.dirPic[n].len);
-		if (scumm_stricmp(md5str, "1c685eb048656cedcee4eb6eca2cecea") == 0) {
+		Common::String md5str = Common::computeStreamMD5AsString(picStream, _game.dirPic[n].len);
+		if (md5str == "1c685eb048656cedcee4eb6eca2cecea") {
 			pic[0x042] = 0x4B; // 0x49 -> 0x4B
 			pic[0x043] = 0x66; // 0x26 -> 0x66
 			pic[0x204] = 0x68; // 0x28 -> 0x68
@@ -494,10 +509,37 @@ static const GameSettings agiSettings[] = {
 AgiBase::AgiBase(OSystem *syst, const AGIGameDescription *gameDesc) : Engine(syst), _gameDescription(gameDesc) {
 	_noSaveLoadAllowed = false;
 
+	_rnd = new Common::RandomSource("agi");
+	_sound = 0;
+
 	initFeatures();
 	initVersion();
 }
 
+AgiBase::~AgiBase() {
+	delete _rnd;
+
+	if (_sound) {
+		_sound->deinitSound();
+		delete _sound;
+	}
+}
+
+void AgiBase::initRenderMode() {
+	_renderMode = Common::kRenderEGA;
+
+	if (ConfMan.hasKey("platform")) {
+		Common::Platform platform = Common::parsePlatform(ConfMan.get("platform"));
+		_renderMode = (platform == Common::kPlatformAmiga) ? Common::kRenderAmiga : Common::kRenderEGA;
+	}
+
+	if (ConfMan.hasKey("render_mode")) {
+		Common::RenderMode tmpMode = Common::parseRenderMode(ConfMan.get("render_mode").c_str());
+		if (tmpMode != Common::kRenderDefault)
+			_renderMode = tmpMode;
+	}
+}
+
 AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBase(syst, gameDesc) {
 
 	// Setup mixer
@@ -505,9 +547,6 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 
 	parseFeatures();
 
-	_rnd = new Common::RandomSource();
-	g_eventRec.registerRandomSource(*_rnd, "agi");
-
 	DebugMan.addDebugChannel(kDebugLevelMain, "Main", "Generic debug level");
 	DebugMan.addDebugChannel(kDebugLevelResources, "Resources", "Resources debugging");
 	DebugMan.addDebugChannel(kDebugLevelSprites, "Sprites", "Sprites debugging");
@@ -524,6 +563,8 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 	memset(&_debug, 0, sizeof(struct AgiDebug));
 	memset(&_mouse, 0, sizeof(struct Mouse));
 
+	_game._vm = this;
+
 	_game.clockEnabled = false;
 	_game.state = STATE_INIT;
 
@@ -532,9 +573,6 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 
 	_allowSynthetic = false;
 
-	_tickTimer = 0;
-	_lastTickTimer = 0;
-
 	_intobj = NULL;
 
 	_menu = NULL;
@@ -555,14 +593,10 @@ AgiEngine::AgiEngine(OSystem *syst, const AGIGameDescription *gameDesc) : AgiBas
 	_predictiveDictLineCount = 0;
 	_firstSlot = 0;
 
-	// NOTE: On game reload the keys do not get set again,
-	// thus it is incorrect to reset it in agiInit(). Fixes bug #2823762
-	_game.lastController = 0;
-	for (int i = 0; i < MAX_DIRS; i++)
-		_game.controllerOccured[i] = false;
+	resetControllers();
 
 	setupOpcodes();
-	_curLogic = NULL;
+	_game._curLogic = NULL;
 	_timerHack = 0;
 }
 
@@ -601,23 +635,7 @@ void AgiEngine::initialize() {
 		}
 	}
 
-	if (ConfMan.hasKey("render_mode")) {
-		_renderMode = Common::parseRenderMode(ConfMan.get("render_mode").c_str());
-	} else if (ConfMan.hasKey("platform")) {
-		switch (Common::parsePlatform(ConfMan.get("platform"))) {
-		case Common::kPlatformAmiga:
-			_renderMode = Common::kRenderAmiga;
-			break;
-		case Common::kPlatformPC:
-			_renderMode = Common::kRenderEGA;
-			break;
-		default:
-			_renderMode = Common::kRenderEGA;
-			break;
-		}
-	} else {
-		_renderMode = Common::kRenderDefault;
-	}
+	initRenderMode();
 
 	_buttonStyle = AgiButtonStyle(_renderMode);
 	_defaultButtonStyle = AgiButtonStyle();
@@ -646,42 +664,37 @@ void AgiEngine::initialize() {
 
 	_lastSaveTime = 0;
 
-	_timer->installTimerProc(agiTimerFunctionLow, 10 * 1000, this);
+	_lastTick = _system->getMillis();
 
 	debugC(2, kDebugLevelMain, "Detect game");
 
-
 	if (agiDetectGame() == errOK) {
 		_game.state = STATE_LOADED;
 		debugC(2, kDebugLevelMain, "game loaded");
 	} else {
-		report("Could not open AGI game");
+		warning("Could not open AGI game");
 	}
 
 	debugC(2, kDebugLevelMain, "Init sound");
 }
 
 AgiEngine::~AgiEngine() {
-	_timer->removeTimerProc(agiTimerFunctionLow);
-
-	// If the engine hasn't been initialized yet via AgiEngine::initialize(), don't attempt to free any resources,
-	// as they haven't been allocated. Fixes bug #1742432 - AGI: Engine crashes if no game is detected
+	// If the engine hasn't been initialized yet via
+	// AgiEngine::initialize(), don't attempt to free any resources, as
+	// they haven't been allocated. Fixes bug #1742432 - AGI: Engine
+	// crashes if no game is detected
 	if (_game.state == STATE_INIT) {
-		delete _rnd;	// delete _rnd, as it is allocated in the constructor, not in initialize()
 		return;
 	}
 
 	agiDeinit();
 	delete _loader;
-	_sound->deinitSound();
-	delete _sound;
 	_gfx->deinitVideo();
 	delete _sprites;
 	delete _picture;
 	free(_game.sbufOrig);
 	_gfx->deinitMachine();
 	delete _gfx;
-	delete _rnd;
 	delete _console;
 
 	free(_predictiveDictLine);
@@ -703,7 +716,6 @@ Common::Error AgiBase::init() {
 Common::Error AgiEngine::go() {
 	CursorMan.showMouse(true);
 
-	report(" \nAGI engine %s is ready.\n", gScummVMVersion);
 	if (_game.state < STATE_LOADED) {
 		do {
 			mainCycle();
@@ -716,6 +728,33 @@ Common::Error AgiEngine::go() {
 }
 
 void AgiEngine::parseFeatures() {
+
+	/* FIXME: Seems this method doesn't really do anything. It might
+	   be a leftover that could be removed, except that some of its
+	   intended purpose may still need to be reimplemented.
+
+	[0:29] <Fingolfin> can you tell me what the point behind AgiEngine::parseFeatures() is?
+	[0:30] <_sev> when games are created with WAGI studio
+	[0:31] <_sev> it creates .wag site with game-specific features such as full game title, whether to use AGIMOUSE etc
+	[0:32] <Fingolfin> ... and the "features" config key is created by our detector based on the wag file, I guess?
+	[0:33] <_sev> yes
+	[0:33] <Fingolfin> it's just that I cant seem to find a place we do that
+	[0:33] <_sev> it is used for fallback
+	[0:34] <_sev> ah, perhaps it was not updated
+	[0:34] <Fingolfin> I only see us check the value, but never set it
+	[0:34] <Fingolfin> maybe I am grepping wrong, who knows :)
+	[0:44] <Fingolfin> _sev: so, unless I miss something, it seem that function does nothing right now
+	[0:45] <_sev> Fingolfin: it could be unfinished. It was part of GSoC 3 years ago
+	[0:45] <Fingolfin> well
+	[0:45] <_sev> I just don't remember
+	[0:45] <Fingolfin> but don't we just re-parse the wag when the game is loaded anyway?
+	[0:45] <_sev> but it documents the format
+	[0:45] <Fingolfin> the advanced meta engine would re-run the detector, wouldn't it?
+	[0:45] <_sev> yep
+	[0:47] <Fingolfin> so... shouldn't we at least add a comment to the function explaining what it does and that it's unfinished etc.? maybe add a TODO to the wiki?
+	[0:47] <Fingolfin> otherwise it might stay as it is for another 3 years :)
+	*/
+
 	if (!ConfMan.hasKey("features"))
 		return;
 
@@ -747,13 +786,15 @@ void AgiEngine::parseFeatures() {
 	for (int i = 0; i < numFeatures; i++) {
 		for (const Flags *flag = flags; flag->name; flag++) {
 			if (!scumm_stricmp(feature[i], flag->name)) {
-				debug(0, "Added feature: %s", flag->name);
+				debug(2, "Added feature: %s", flag->name);
 
 				setFeature(flag->flag);
 				break;
 			}
 		}
 	}
+
+	free(features);
 }
 
 } // End of namespace Agi
