@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "agi/agi.h"
@@ -117,7 +114,7 @@ int AgiEngine::handleController(int key) {
 
 	debugC(3, kDebugLevelInput, "key = %04x", key);
 
-	for (i = 0; i < _game.lastController; i++) {
+	for (i = 0; i < MAX_CONTROLLERS; i++) {
 		if (_game.controllers[i].keycode == key) {
 			debugC(3, kDebugLevelInput, "event %d: key press", _game.controllers[i].controller);
 			_game.controllerOccured[_game.controllers[i].controller] = true;
@@ -183,15 +180,22 @@ int AgiEngine::handleController(int key) {
 		if (!(getFeatures() & GF_AGIMOUSE)) {
 			// Handle mouse button events
 			if (key == BUTTON_LEFT) {
-				v->flags |= ADJ_EGO_XY;
-				v->parm1 = WIN_TO_PIC_X(_mouse.x);
-				v->parm2 = WIN_TO_PIC_Y(_mouse.y);
-				return true;
+				if (getGameID() == GID_PQ1 && _game.vars[vCurRoom] == 116) {
+					// WORKAROUND: Special handling for mouse clicks in the newspaper
+					// screen of PQ1. Fixes bug #3018770.
+					d = 3;	// fake a right arrow key (next page)
+				} else {
+					// Click-to-walk mouse interface
+					v->flags |= fAdjEgoXY;
+					v->parm1 = WIN_TO_PIC_X(_mouse.x);
+					v->parm2 = WIN_TO_PIC_Y(_mouse.y);
+					return true;
+				}
 			}
 		}
 
 		if (d || key == KEY_STATIONARY) {
-			v->flags &= ~ADJ_EGO_XY;
+			v->flags &= ~fAdjEgoXY;
 			v->direction = v->direction == d ? 0 : d;
 			return true;
 		}
