@@ -18,15 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agi/sound.h $
- * $Id: sound.h 49757 2010-06-15 10:36:54Z sev $
- *
  */
 
 #ifndef AGI_SOUND_H
 #define AGI_SOUND_H
 
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Agi {
 
@@ -74,7 +71,7 @@ class SoundMgr;
 
 class SoundGen {
 public:
-	SoundGen(AgiEngine *vm, Audio::Mixer *pMixer) : _vm(vm), _mixer(pMixer) {
+	SoundGen(AgiBase *vm, Audio::Mixer *pMixer) : _vm(vm), _mixer(pMixer) {
 		_sampleRate = pMixer->getOutputRate();
 	}
 
@@ -83,7 +80,7 @@ public:
 	virtual void play(int resnum) = 0;
 	virtual void stop(void) = 0;
 
-	AgiEngine *_vm;
+	AgiBase *_vm;
 
 	Audio::Mixer *_mixer;
 	Audio::SoundHandle _soundHandle;
@@ -125,6 +122,8 @@ public:
 	~PCjrSound() { free(_data); }
 	virtual uint16 type() { return _type; }
 	const uint8 *getVoicePointer(uint voiceNum);
+	uint8 *getData() { return _data; }
+	uint32 getLength() { return _len; }
 protected:
 	uint8 *_data; ///< Raw sound resource data
 	uint32 _len;  ///< Length of the raw sound resource
@@ -134,7 +133,7 @@ protected:
 class SoundMgr {
 
 public:
-	SoundMgr(AgiEngine *agi, Audio::Mixer *pMixer);
+	SoundMgr(AgiBase *agi, Audio::Mixer *pMixer);
 	~SoundMgr();
 
 	void setVolume(uint8 volume);
@@ -150,7 +149,7 @@ public:
 
 private:
 	int _endflag;
-	AgiEngine *_vm;
+	AgiBase *_vm;
 
 	SoundGen *_soundGen;
 
