@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 // Music class
@@ -48,7 +45,7 @@ protected:
 
 class SoundGenMIDI : public SoundGen, public Audio::MidiPlayer {
 public:
-	SoundGenMIDI(AgiEngine *vm, Audio::Mixer *pMixer);
+	SoundGenMIDI(AgiBase *vm, Audio::Mixer *pMixer);
 
 	void play(int resnum);
 	// We must overload stop() here to implement the pure virtual
