@@ -525,25 +525,25 @@ MoviePlayer *makeMoviePlayer(AGOSEngine_Feeble *vm, const char *name) {
 		memcpy(shortName, baseName, 6);
 
 		sprintf(filename, "%s~1.dxa", shortName);
-		if (Common::File::exists(filename)) {
+		if (vm->_archives.hasFile(filename)) {
 			memset(baseName, 0, sizeof(baseName));
 			memcpy(baseName, filename, 8);
 		}
 
 		sprintf(filename, "%s~1.smk", shortName);
-		if (Common::File::exists(filename)) {
+		if (vm->_archives.hasFile(filename)) {
 			memset(baseName, 0, sizeof(baseName));
 			memcpy(baseName, filename, 8);
 		}
 	}
 
 	sprintf(filename, "%s.dxa", baseName);
-	if (Common::File::exists(filename)) {
+	if (vm->_archives.hasFile(filename)) {
 		return new MoviePlayerDXA(vm, baseName);
 	}
 
 	sprintf(filename, "%s.smk", baseName);
-	if (Common::File::exists(filename)) {
+	if (vm->_archives.hasFile(filename)) {
 		return new MoviePlayerSMK(vm, baseName);
 	}
 
