@@ -18,14 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/saveload.cpp $
- * $Id: saveload.cpp 52758 2010-09-17 12:54:00Z lordhoto $
- *
  */
 
 #include "common/file.h"
 #include "common/savefile.h"
-#include "common/system.h"
+#include "common/textconsole.h"
 #include "common/translation.h"
 
 #include "gui/about.h"
@@ -37,7 +34,7 @@
 namespace AGOS {
 
 int AGOSEngine::countSaveGames() {
-	Common::InSaveFile *f;
+	Common::InSaveFile *f = NULL;
 	Common::StringArray filenames;
 	uint i = 1;
 	char slot[4];
@@ -154,7 +151,7 @@ void AGOSEngine::quickLoadOrSave() {
 		Subroutine *sub;
 		success = loadGame(genSaveName(_saveLoadSlot));
 		if (!success) {
-			buf = Common::String::printf(_("Failed to load game state from file:\n\n%s"), filename);
+			buf = Common::String::format(_("Failed to load game state from file:\n\n%s"), filename);
 		} else if (getGameType() == GType_SIMON1 || getGameType() == GType_SIMON2) {
 			drawIconArray(2, me(), 0, 0);
 			setBitFlag(97, true);
@@ -189,7 +186,7 @@ void AGOSEngine::quickLoadOrSave() {
 	} else {
 		success = saveGame(_saveLoadSlot, _saveLoadName);
 		if (!success)
-			buf = Common::String::printf(_("Failed to save game state to file:\n\n%s"), filename);
+			buf = Common::String::format(_("Failed to save game state to file:\n\n%s"), filename);
 	}
 
 	if (!success) {
@@ -197,7 +194,7 @@ void AGOSEngine::quickLoadOrSave() {
 		dialog.runModal();
 
 	} else if (_saveLoadType == 1) {
-		buf = Common::String::printf(_("Successfully saved game state in file:\n\n%s"), filename);
+		buf = Common::String::format(_("Successfully saved game state in file:\n\n%s"), filename);
 		GUI::TimedMessageDialog dialog(buf, 1500);
 		dialog.runModal();
 
@@ -1022,9 +1019,7 @@ bool AGOSEngine::loadGame(const char *filename, bool restartMode) {
 
 	if (restartMode) {
 		// Load restart state
-		Common::File *file = new Common::File();
-		file->open(filename);
-		f = file;
+		f = _archives.open(filename);
 	} else {
 		f = _saveFileMan->openForLoading(filename);
 	}
@@ -1198,9 +1193,7 @@ bool AGOSEngine_Elvira2::loadGame(const char *filename, bool restartMode) {
 
 	if (restartMode) {
 		// Load restart state
-		Common::File *file = new Common::File();
-		file->open(filename);
-		f = file;
+		f = _archives.open(filename);
 	} else {
 		f = _saveFileMan->openForLoading(filename);
 	}
