@@ -18,27 +18,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/sound.cpp $
- * $Id: sound.cpp 52909 2010-09-26 12:29:40Z eriktorbjorn $
- *
  */
 
 #include "common/file.h"
+#include "common/memstream.h"
+#include "common/ptr.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
 #include "agos/agos.h"
 #include "agos/sound.h"
 
-#include "sound/audiostream.h"
-#include "sound/decoders/flac.h"
-#include "sound/mixer.h"
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/raw.h"
-#include "sound/decoders/voc.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/wave.h"
-
-using Common::File;
+#include "audio/audiostream.h"
+#include "audio/decoders/flac.h"
+#include "audio/mixer.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/raw.h"
+#include "audio/decoders/voc.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/wave.h"
 
 namespace AGOS {
 
@@ -46,15 +44,14 @@ namespace AGOS {
 
 class BaseSound : Common::NonCopyable {
 protected:
-	File *_file;
+	Common::DisposablePtr<Common::File> _file;
 	uint32 *_offsets;
 	Audio::Mixer *_mixer;
 	bool _freeOffsets;
-	DisposeAfterUse::Flag _disposeFile;
 
 public:
-	BaseSound(Audio::Mixer *mixer, File *file, uint32 base, bool bigEndian, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES);
-	BaseSound(Audio::Mixer *mixer, File *file, uint32 *offsets, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES);
+	BaseSound(Audio::Mixer *mixer, Common::File *file, uint32 base, bool bigEndian, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES);
+	BaseSound(Audio::Mixer *mixer, Common::File *file, uint32 *offsets, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES);
 	virtual ~BaseSound();
 
 	void playSound(uint sound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol = 0) {
@@ -64,8 +61,8 @@ public:
 	virtual Audio::AudioStream *makeAudioStream(uint sound) = 0;
 };
 
-BaseSound::BaseSound(Audio::Mixer *mixer, File *file, uint32 base, bool bigEndian, DisposeAfterUse::Flag disposeFileAfterUse)
-	: _mixer(mixer), _file(file), _disposeFile(disposeFileAfterUse) {
+BaseSound::BaseSound(Audio::Mixer *mixer, Common::File *file, uint32 base, bool bigEndian, DisposeAfterUse::Flag disposeFileAfterUse)
+	: _mixer(mixer), _file(file, disposeFileAfterUse) {
 
 	uint res = 0;
 	uint32 size;
@@ -98,8 +95,8 @@ BaseSound::BaseSound(Audio::Mixer *mixer, File *file, uint32 base, bool bigEndia
 	_offsets[res] = _file->size();
 }
 
-BaseSound::BaseSound(Audio::Mixer *mixer, File *file, uint32 *offsets, DisposeAfterUse::Flag disposeFileAfterUse)
-	: _mixer(mixer), _file(file), _disposeFile(disposeFileAfterUse) {
+BaseSound::BaseSound(Audio::Mixer *mixer, Common::File *file, uint32 *offsets, DisposeAfterUse::Flag disposeFileAfterUse)
+	: _mixer(mixer), _file(file, disposeFileAfterUse) {
 
 	_offsets = offsets;
 	_freeOffsets = false;
@@ -108,8 +105,6 @@ BaseSound::BaseSound(Audio::Mixer *mixer, File *file, uint32 *offsets, DisposeAf
 BaseSound::~BaseSound() {
 	if (_freeOffsets)
 		free(_offsets);
-	if (_disposeFile == DisposeAfterUse::YES)
-		delete _file;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -225,9 +220,9 @@ static void convertPan(int &pan) {
 
 class WavSound : public BaseSound {
 public:
-	WavSound(Audio::Mixer *mixer, File *file, uint32 base = 0, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES)
+	WavSound(Audio::Mixer *mixer, Common::File *file, uint32 base = 0, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES)
 		: BaseSound(mixer, file, base, false, disposeFileAfterUse) {}
-	WavSound(Audio::Mixer *mixer, File *file, uint32 *offsets) : BaseSound(mixer, file, offsets) {}
+	WavSound(Audio::Mixer *mixer, Common::File *file, uint32 *offsets) : BaseSound(mixer, file, offsets) {}
 	Audio::AudioStream *makeAudioStream(uint sound);
 	void playSound(uint sound, uint loopSound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol = 0);
 };
@@ -237,7 +232,7 @@ Audio::AudioStream *WavSound::makeAudioStream(uint sound) {
 		return NULL;
 
 	_file->seek(_offsets[sound], SEEK_SET);
-	return Audio::makeWAVStream(_file, DisposeAfterUse::NO);
+	return Audio::makeWAVStream(_file.get(), DisposeAfterUse::NO);
 }
 
 void WavSound::playSound(uint sound, uint loopSound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol) {
@@ -251,7 +246,7 @@ void WavSound::playSound(uint sound, uint loopSound, Audio::Mixer::SoundType typ
 class VocSound : public BaseSound {
 	const byte _flags;
 public:
-	VocSound(Audio::Mixer *mixer, File *file, bool isUnsigned, uint32 base = 0, bool bigEndian = false, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES)
+	VocSound(Audio::Mixer *mixer, Common::File *file, bool isUnsigned, uint32 base = 0, bool bigEndian = false, DisposeAfterUse::Flag disposeFileAfterUse = DisposeAfterUse::YES)
 		: BaseSound(mixer, file, base, bigEndian, disposeFileAfterUse), _flags(isUnsigned ? Audio::FLAG_UNSIGNED : 0) {}
 	Audio::AudioStream *makeAudioStream(uint sound);
 	void playSound(uint sound, uint loopSound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol = 0);
@@ -260,7 +255,7 @@ public:
 Audio::AudioStream *VocSound::makeAudioStream(uint sound) {
 	assert(_offsets);
 	_file->seek(_offsets[sound], SEEK_SET);
-	return Audio::makeVOCStream(_file, _flags);
+	return Audio::makeVOCStream(_file.get(), _flags);
 }
 
 void VocSound::playSound(uint sound, uint loopSound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol) {
@@ -275,7 +270,7 @@ void VocSound::playSound(uint sound, uint loopSound, Audio::Mixer::SoundType typ
 class RawSound : public BaseSound {
 	const byte _flags;
 public:
-	RawSound(Audio::Mixer *mixer, File *file, bool isUnsigned)
+	RawSound(Audio::Mixer *mixer, Common::File *file, bool isUnsigned)
 		: BaseSound(mixer, file, 0, SOUND_BIG_ENDIAN), _flags(isUnsigned ? Audio::FLAG_UNSIGNED : 0) {}
 	Audio::AudioStream *makeAudioStream(uint sound);
 	void playSound(uint sound, uint loopSound, Audio::Mixer::SoundType type, Audio::SoundHandle *handle, bool loop, int vol = 0);
@@ -305,9 +300,9 @@ void RawSound::playSound(uint sound, uint loopSound, Audio::Mixer::SoundType typ
 
 class CompressedSound : public BaseSound {
 public:
-	CompressedSound(Audio::Mixer *mixer, File *file, uint32 base) : BaseSound(mixer, file, base, false) {}
+	CompressedSound(Audio::Mixer *mixer, Common::File *file, uint32 base) : BaseSound(mixer, file, base, false) {}
 
-	Common::MemoryReadStream *loadStream(uint sound) const {
+	Common::SeekableReadStream *loadStream(uint sound) const {
 		if (_offsets == NULL)
 			return NULL;
 
@@ -334,9 +329,9 @@ public:
 #ifdef USE_MAD
 class MP3Sound : public CompressedSound {
 public:
-	MP3Sound(Audio::Mixer *mixer, File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
+	MP3Sound(Audio::Mixer *mixer, Common::File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
 	Audio::AudioStream *makeAudioStream(uint sound) {
-		Common::MemoryReadStream *tmp = loadStream(sound);
+		Common::SeekableReadStream *tmp = loadStream(sound);
 		if (!tmp)
 			return NULL;
 		return Audio::makeMP3Stream(tmp, DisposeAfterUse::YES);
@@ -350,9 +345,9 @@ public:
 #ifdef USE_VORBIS
 class VorbisSound : public CompressedSound {
 public:
-	VorbisSound(Audio::Mixer *mixer, File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
+	VorbisSound(Audio::Mixer *mixer, Common::File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
 	Audio::AudioStream *makeAudioStream(uint sound) {
-		Common::MemoryReadStream *tmp = loadStream(sound);
+		Common::SeekableReadStream *tmp = loadStream(sound);
 		if (!tmp)
 			return NULL;
 		return Audio::makeVorbisStream(tmp, DisposeAfterUse::YES);
@@ -366,9 +361,9 @@ public:
 #ifdef USE_FLAC
 class FLACSound : public CompressedSound {
 public:
-	FLACSound(Audio::Mixer *mixer, File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
+	FLACSound(Audio::Mixer *mixer, Common::File *file, uint32 base = 0) : CompressedSound(mixer, file, base) {}
 	Audio::AudioStream *makeAudioStream(uint sound) {
-		Common::MemoryReadStream *tmp = loadStream(sound);
+		Common::SeekableReadStream *tmp = loadStream(sound);
 		if (!tmp)
 			return NULL;
 		return Audio::makeFLACStream(tmp, DisposeAfterUse::YES);
@@ -379,7 +374,7 @@ public:
 ///////////////////////////////////////////////////////////////////////////////
 #pragma mark -
 
-static CompressedSound *makeCompressedSound(Audio::Mixer *mixer, File *file, const Common::String &basename) {
+static CompressedSound *makeCompressedSound(Audio::Mixer *mixer, Common::File *file, const Common::String &basename) {
 #ifdef USE_FLAC
 	file->open(basename + ".fla");
 	if (file->isOpen()) {
@@ -451,7 +446,7 @@ void Sound::loadVoiceFile(const GameSpecificSettings *gss) {
 
 
 	char filename[16];
-	File *file = new File();
+	Common::File *file = new Common::File();
 
 	if (!_hasVoiceFile) {
 		_voice = makeCompressedSound(_mixer, file, gss->speech_filename);
@@ -506,7 +501,7 @@ void Sound::loadVoiceFile(const GameSpecificSettings *gss) {
 
 void Sound::loadSfxFile(const GameSpecificSettings *gss) {
 	char filename[16];
-	File *file = new File();
+	Common::File *file = new Common::File();
 
 	if (!_hasEffectsFile) {
 		_effects = makeCompressedSound(_mixer, file, gss->effects_filename);
@@ -540,7 +535,7 @@ void Sound::readSfxFile(const Common::String &filename) {
 
 	_mixer->stopHandle(_effectsHandle);
 
-	File *file = new File();
+	Common::File *file = new Common::File();
 	file->open(filename);
 
 	if (file->isOpen() == false) {
@@ -557,7 +552,7 @@ void Sound::readSfxFile(const Common::String &filename) {
 }
 
 // This method is only used by Simon2
-void Sound::loadSfxTable(File *gameFile, uint32 base) {
+void Sound::loadSfxTable(Common::File *gameFile, uint32 base) {
 	stopAll();
 
 	delete _effects;
@@ -572,7 +567,7 @@ void Sound::loadSfxTable(File *gameFile, uint32 base) {
 void Sound::readVoiceFile(const Common::String &filename) {
 	_mixer->stopHandle(_voiceHandle);
 
-	File *file = new File();
+	Common::File *file = new Common::File();
 	file->open(filename);
 
 	if (file->isOpen() == false)
@@ -592,7 +587,7 @@ void Sound::playVoice(uint sound) {
 			char filename[16];
 			_lastVoiceFile = _filenums[sound];
 			sprintf(filename, "voices%d.dat", _filenums[sound]);
-			File *file = new File();
+			Common::File *file = new Common::File();
 			file->open(filename);
 			if (file->isOpen() == false)
 				error("playVoice: Can't load voice file %s", filename);
@@ -777,7 +772,7 @@ void Sound::playVoiceData(byte *soundData, uint sound) {
 
 void Sound::playSoundData(Audio::SoundHandle *handle, byte *soundData, uint sound, int pan, int vol, bool loop) {
 	int size = READ_LE_UINT32(soundData + 4) + 8;
-	Common::MemoryReadStream *stream = new Common::MemoryReadStream(soundData, size);
+	Common::SeekableReadStream *stream = new Common::MemoryReadStream(soundData, size);
 	Audio::RewindableAudioStream *sndStream = Audio::makeWAVStream(stream, DisposeAfterUse::YES);
 
 	convertVolume(vol);
@@ -801,7 +796,7 @@ void Sound::switchVoiceFile(const GameSpecificSettings *gss, uint disc) {
 	_lastVoiceFile = disc;
 
 	char filename[16];
-	File *file = new File();
+	Common::File *file = new Common::File();
 
 	if (!_hasVoiceFile) {
 		sprintf(filename, "%s%d", gss->speech_filename, disc);
