@@ -18,20 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/agos/subroutine.cpp $
- * $Id: subroutine.cpp 47451 2010-01-22 23:58:24Z fingolfin $
- *
  */
 
 
 
 #include "common/file.h"
+#include "common/textconsole.h"
 
 #include "agos/agos.h"
 #include "agos/intern.h"
 
-using Common::File;
-
 namespace AGOS {
 
 // Script opcodes to load into memory
@@ -262,22 +258,21 @@ void AGOSEngine::endCutscene() {
 	_runScriptReturn1 = true;
 }
 
-File *AGOSEngine::openTablesFile(const char *filename) {
+Common::SeekableReadStream *AGOSEngine::openTablesFile(const char *filename) {
 	if (getFeatures() & GF_OLD_BUNDLE)
 		return openTablesFile_simon1(filename);
 	else
 		return openTablesFile_gme(filename);
 }
 
-File *AGOSEngine::openTablesFile_simon1(const char *filename) {
-	File *fo = new File();
-	fo->open(filename);
-	if (fo->isOpen() == false)
+Common::SeekableReadStream *AGOSEngine::openTablesFile_simon1(const char *filename) {
+	Common::SeekableReadStream *in = _archives.open(filename);
+	if (!in)
 		error("openTablesFile: Can't open '%s'", filename);
-	return fo;
+	return in;
 }
 
-File *AGOSEngine::openTablesFile_gme(const char *filename) {
+Common::SeekableReadStream *AGOSEngine::openTablesFile_gme(const char *filename) {
 	uint res;
 	uint32 offs;
 
@@ -291,7 +286,7 @@ File *AGOSEngine::openTablesFile_gme(const char *filename) {
 bool AGOSEngine::loadTablesIntoMem(uint16 subrId) {
 	byte *p;
 	uint16 min_num, max_num, file_num;
-	File *in;
+	Common::SeekableReadStream *in;
 	char filename[30];
 
 	if (_tblList == NULL)
@@ -340,7 +335,7 @@ bool AGOSEngine::loadTablesIntoMem(uint16 subrId) {
 bool AGOSEngine_Waxworks::loadTablesIntoMem(uint16 subrId) {
 	byte *p;
 	uint min_num, max_num;
-	File *in;
+	Common::SeekableReadStream *in;
 
 	p = _tblList;
 	if (p == NULL)
@@ -407,7 +402,7 @@ bool AGOSEngine::loadXTablesIntoMem(uint16 subrId) {
 	int i;
 	uint min_num, max_num;
 	char filename[30];
-	File *in;
+	Common::SeekableReadStream *in;
 
 	p = _xtblList;
 	if (p == NULL)
@@ -457,9 +452,8 @@ bool AGOSEngine::loadXTablesIntoMem(uint16 subrId) {
 	return 0;
 }
 
-void AGOSEngine::closeTablesFile(File *in) {
+void AGOSEngine::closeTablesFile(Common::SeekableReadStream *in) {
 	if (getFeatures() & GF_OLD_BUNDLE) {
-		in->close();
 		delete in;
 	}
 }
@@ -572,7 +566,7 @@ restart:
 				_codePtr += 8;
 
 			if (_dumpOpcodes)
-				printf("; %d\n", sub->id);
+				debug("; %d", sub->id);
 			result = runScript();
 			if (result != 0) {
 				break;
