@@ -18,14 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "base/plugins.h"
 
 #include "engines/advancedDetector.h"
+#include "engines/obsolete.h"
 #include "common/system.h"
 #include "common/textconsole.h"
 
@@ -55,7 +53,7 @@ static const PlainGameDescriptor cineGames[] = {
 	{0, 0}
 };
 
-static const ADObsoleteGameID obsoleteGameIDsTable[] = {
+static const Engines::ObsoleteGameID obsoleteGameIDsTable[] = {
 	{"fw", "cine", Common::kPlatformUnknown},
 	{"os", "cine", Common::kPlatformUnknown},
 	{0, 0, Common::kPlatformUnknown}
@@ -63,44 +61,31 @@ static const ADObsoleteGameID obsoleteGameIDsTable[] = {
 
 #include "cine/detection_tables.h"
 
-static const ADParams detectionParams = {
-	// Pointer to ADGameDescription or its superset structure
-	(const byte *)Cine::gameDescriptions,
-	// Size of that superset structure
-	sizeof(Cine::CINEGameDescription),
-	// Number of bytes to compute MD5 sum for
-	5000,
-	// List of all engine targets
-	cineGames,
-	// Structure for autoupgrading obsolete targets
-	obsoleteGameIDsTable,
-	// Name of single gameid (optional)
-	"cine",
-	// List of files for file-based fallback detection (optional)
-	0,
-	// Flags
-	0,
-	// Additional GUI options (for every game}
-	Common::GUIO_NOSPEECH | Common::GUIO_NOMIDI,
-	// Maximum directory depth
-	1,
-	// List of directory globs
-	0
-};
-
 class CineMetaEngine : public AdvancedMetaEngine {
 public:
-	CineMetaEngine() : AdvancedMetaEngine(detectionParams) {}
+	CineMetaEngine() : AdvancedMetaEngine(Cine::gameDescriptions, sizeof(Cine::CINEGameDescription), cineGames) {
+		_singleid = "cine";
+		_guioptions = Common::GUIO_NOSPEECH | Common::GUIO_NOMIDI;
+	}
+
+	virtual GameDescriptor findGame(const char *gameid) const {
+		return Engines::findGameID(gameid, _gameids, obsoleteGameIDsTable);
+	}
 
 	virtual const char *getName() const {
-		return "Cinematique evo 1 engine";
+		return "Cine";
 	}
 
 	virtual const char *getOriginalCopyright() const {
 		return "Future Wars & Operation Stealth (C) Delphine Software";
 	}
 
+	virtual Common::Error createInstance(OSystem *syst, Engine **engine) const {
+		Engines::upgradeTargetIfNecessary(obsoleteGameIDsTable);
+		return AdvancedMetaEngine::createInstance(syst, engine);
+	}
 	virtual bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const;
+
 	virtual bool hasFeature(MetaEngineFeature f) const;
 	virtual SaveStateList listSaves(const char *target) const;
 	virtual int getMaximumSaveSlot() const;
@@ -156,7 +141,7 @@ SaveStateList CineMetaEngine::listSaves(const char *target) const {
 
 		for (file = filenames.begin(); file != filenames.end(); ++file) {
 			// Jump over savegame files that don't end with a digit (e.g. "fw.3" is ok, "fw.a" is not).
-			if (!isdigit(file->lastChar()))
+			if (!isdigit(static_cast<unsigned char>(file->lastChar())))
 				continue;
 
 			// Obtain the last digit of the filename, since they correspond to the save slot
@@ -188,10 +173,7 @@ void CineMetaEngine::removeSaveState(const char *target, int slot) const {
 	memset(saveNames, 0, sizeof(saveNames));
 
 	Common::InSaveFile *in;
-	char tmp[80];
-
-	snprintf(tmp, 80, "%s.dir", target);
-	in = g_system->getSavefileManager()->openForLoading(tmp);
+	in = g_system->getSavefileManager()->openForLoading(Common::String::format("%s.dir", target));
 
 	if (!in)
 		return;
@@ -205,12 +187,10 @@ void CineMetaEngine::removeSaveState(const char *target, int slot) const {
 	strncpy(saveNames[slot], slotName, 20);
 
 	// Update savegame descriptions
-	char indexFile[80];
-	snprintf(indexFile, 80, "%s.dir", target);
-
+	Common::String indexFile = Common::String::format("%s.dir", target);
 	Common::OutSaveFile *out = g_system->getSavefileManager()->openForSaving(indexFile);
 	if (!out) {
-		warning("Unable to open file %s for saving", indexFile);
+		warning("Unable to open file %s for saving", indexFile.c_str());
 		return;
 	}
 
@@ -240,21 +220,20 @@ Common::Error CineEngine::loadGameState(int slot) {
 	return gameLoaded ? Common::kNoError : Common::kUnknownError;
 }
 
-Common::Error CineEngine::saveGameState(int slot, const char *desc) {
+Common::Error CineEngine::saveGameState(int slot, const Common::String &desc) {
 	// Load savegame descriptions from index file
 	loadSaveDirectory();
 
 	// Set description for selected slot making sure it ends with a trailing zero
-	strncpy(currentSaveName[slot], desc, 20);
+	strncpy(currentSaveName[slot], desc.c_str(), 20);
 	currentSaveName[slot][sizeof(CommandeType) - 1] = 0;
 
 	// Update savegame descriptions
-	char indexFile[80];
-	snprintf(indexFile, 80, "%s.dir", _targetName.c_str());
+	Common::String indexFile = _targetName + ".dir";
 
 	Common::OutSaveFile *fHandle = _saveFileMan->openForSaving(indexFile);
 	if (!fHandle) {
-		warning("Unable to open file %s for saving", indexFile);
+		warning("Unable to open file %s for saving", indexFile.c_str());
 		return Common::kUnknownError;
 	}
 
