@@ -18,15 +18,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/cine/pal.cpp $
- * $Id: pal.cpp 52608 2010-09-06 21:04:12Z lordhoto $
- *
  */
 
 #include "cine/cine.h"
 #include "cine/various.h"
 #include "cine/pal.h"
-#include "common/system.h" // For g_system->setPalette
+#include "common/system.h" // For g_system->getPaletteManager()->setPalette
+#include "common/textconsole.h"
+
+#include "graphics/palette.h"
 
 namespace Cine {
 
@@ -141,9 +141,10 @@ int power(int base, int power) {
 
 // a.k.a. palRotate
 Palette &Palette::rotateRight(byte firstIndex, byte lastIndex, signed rotationAmount) {
-	assert(rotationAmount == 0 || rotationAmount == 1);
+	debug(1, "Palette::rotateRight(firstIndex: %d, lastIndex: %d, rotationAmount:%d)", firstIndex, lastIndex, rotationAmount);
+	assert(rotationAmount >= 0);
 
-	if (rotationAmount == 1) {
+	for (int j = 0; j < rotationAmount; j++) {
 		const Color lastColor = _colors[lastIndex];
 
 		for (int i = lastIndex; i > firstIndex; i--)
@@ -184,20 +185,20 @@ const Graphics::PixelFormat &Palette::colorFormat() const {
 }
 
 void Palette::setGlobalOSystemPalette() const {
-	byte buf[256 * 4]; // Allocate space for the largest possible palette
+	byte buf[256 * 3]; // Allocate space for the largest possible palette
 	// The color format used by OSystem's setPalette-function:
-	save(buf, sizeof(buf), Graphics::PixelFormat(4, 8, 8, 8, 0, 0, 8, 16, 0), CINE_LITTLE_ENDIAN);
+	save(buf, sizeof(buf), Graphics::PixelFormat(3, 8, 8, 8, 0, 0, 8, 16, 0), CINE_LITTLE_ENDIAN);
 
 	if (g_cine->getPlatform() == Common::kPlatformAmiga && colorCount() == 16) {
 		// The Amiga version of Future Wars does use the upper 16 colors for a darkened
 		// game palette to allow transparent dialog boxes. To support that in our code
 		// we do calculate that palette over here and append it to the screen palette.
-		for (uint i = 0; i < 16 * 4; ++i)
-			buf[16 * 4 + i] = buf[i] >> 1;
+		for (uint i = 0; i < 16 * 3; ++i)
+			buf[16 * 3 + i] = buf[i] >> 1;
 
-		g_system->setPalette(buf, 0, colorCount() * 2);
+		g_system->getPaletteManager()->setPalette(buf, 0, colorCount() * 2);
 	} else {
-		g_system->setPalette(buf, 0, colorCount());
+		g_system->getPaletteManager()->setPalette(buf, 0, colorCount());
 	}
 }
 
