@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/objects.cpp $
- * $Id: objects.cpp 52844 2010-09-21 17:20:44Z eriktorbjorn $
- *
  */
 
+#include "common/textconsole.h"
+
 #include "drascula/drascula.h"
 
 namespace Drascula {
@@ -75,7 +74,7 @@ void DrasculaEngine::gotoObject(int pointX, int pointY) {
 	roomY = pointY;
 	startWalking();
 
-	for (;;) {
+	while (!shouldQuit()) {
 		updateRoom();
 		updateScreen();
 		updateEvents();
