@@ -18,12 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/drascula/rooms.cpp $
- * $Id: rooms.cpp 49702 2010-06-15 10:18:08Z sev $
- *
  */
 
 #include "common/array.h"
+#include "common/textconsole.h"
 
 #include "drascula/drascula.h"
 
@@ -140,6 +138,21 @@ void DrasculaEngine::setupRoomsTable() {
 }
 
 void DrasculaEngine::freeRoomsTable() {
+	if (_roomHandlers == 0)
+		return;
+
+	for (uint32 i = 0; i < _roomHandlers->roomParsers.size(); i++)
+		delete _roomHandlers->roomParsers[i];
+	_roomHandlers->roomParsers.clear();
+
+	for (uint32 i = 0; i < _roomHandlers->roomPreupdaters.size(); i++)
+		delete _roomHandlers->roomPreupdaters[i];
+	_roomHandlers->roomPreupdaters.clear();
+
+	for (uint32 i = 0; i < _roomHandlers->roomUpdaters.size(); i++)
+		delete _roomHandlers->roomUpdaters[i];
+	_roomHandlers->roomUpdaters.clear();
+
 	delete _roomHandlers;
 	_roomHandlers = 0;
 }
@@ -170,11 +183,11 @@ bool DrasculaEngine::roomParse(int rN, int fl) {
 }
 
 bool DrasculaEngine::room_0(int fl) {
+	(void)fl;
+
 	static const int lookExcuses[3] = {100, 101, 54};
 	static const int actionExcuses[6] = {11, 109, 111, 110, 115, 116};
 
-	fl = -1; // avoid warning
-
 	// non-default actions
 	if (currentChapter == 2 || currentChapter == 4 ||
 		currentChapter == 5 || currentChapter == 6) {
@@ -1662,7 +1675,7 @@ void DrasculaEngine::enterRoom(int roomIndex) {
 	if (!stream) {
 		error("missing data file %s", fileName);
 	}
-	
+
 	TextResourceParser p(stream, DisposeAfterUse::YES);
 
 	p.parseInt(roomNumber);
@@ -1945,7 +1958,9 @@ bool DrasculaEngine::exitRoom(int doorNumber) {
 			hare_se_ve = 1;
 
 		clearRoom();
-		sscanf(_targetSurface[doorNumber], "%d", &roomNum);
+		if (!sscanf(_targetSurface[doorNumber], "%d", &roomNum)) {
+			error("Malformed roomNum in targetSurface (%s)", _targetSurface[doorNumber]);
+		}
 		curX = -1;
 		enterRoom(roomNum);
 
