@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/endian.h"
@@ -110,6 +107,9 @@ Draw::Draw(GobEngine *vm) : _vm(vm) {
 	_cursorHotspotXVar = -1;
 	_cursorHotspotYVar = -1;
 
+	_cursorHotspotX = -1;
+	_cursorHotspotY = -1;
+
 	_cursorAnim = 0;
 	for (int i = 0; i < 40; i++) {
 		_cursorAnimLow[i] = 0;
