@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef GOB_INIT_H
@@ -44,7 +41,7 @@ public:
 
 protected:
 	Video::PalDesc *_palDesc;
-	static const char *_fontNames[4];
+	static const char *const _fontNames[4];
 	GobEngine *_vm;
 
 	void cleanup();
@@ -59,6 +56,15 @@ public:
 	void initVideo();
 };
 
+class Init_Geisha : public Init_v1 {
+public:
+	Init_Geisha(GobEngine *vm);
+	~Init_Geisha();
+
+	void initVideo();
+	void initGame();
+};
+
 class Init_v2 : public Init_v1 {
 public:
 	Init_v2(GobEngine *vm);
