@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -82,9 +79,6 @@ bool PalAnim::fadeStep(int16 oper) {
 	byte newGreen;
 	byte newBlue;
 
-	if (_vm->_global->_colorCount != 256)
-		error("PalAnim::fadeStep(): Only 256 color mode is supported");
-
 	if (oper == 0) {
 		if (_vm->_global->_setAllPalette) {
 			if (_vm->_global->_inVM != 0)
@@ -137,12 +131,6 @@ void PalAnim::fade(Video::PalDesc *palDesc, int16 fadeV, int16 allColors) {
 
 	_fadeValue = (fadeV < 0) ? -fadeV : 2;
 
-	if (_vm->_global->_colorCount < 256) {
-		if (palDesc)
-			_vm->_video->setFullPalette(palDesc);
-		return;
-	}
-
 	if (!_vm->_global->_setAllPalette) {
 		if (!palDesc) {
 			for (i = 0; i < 16; i++) {
