@@ -18,13 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/adlib.cpp $
- * $Id: adlib.cpp 48637 2010-04-12 09:14:17Z fingolfin $
- *
  */
 
+#include "common/debug.h"
 #include "common/file.h"
 #include "common/endian.h"
+#include "common/textconsole.h"
 
 #include "gob/gob.h"
 #include "gob/sound/adlib.h"
@@ -240,7 +239,7 @@ void AdLib::setKey(byte voice, byte note, bool on, bool spec) {
 	freq = _freqs[_notLin[voice]][note - octa * 12];
 
 	writeOPL(0xA0 + voice,  freq & 0xFF);
-	writeOPL(0xB0 + voice, (freq >> 8) | (octa << 2) | 0x20 * on);
+	writeOPL(0xB0 + voice, (freq >> 8) | (octa << 2) | (0x20 * (on ? 1 : 0)));
 
 	if (!freq)
 		warning("AdLib::setKey Voice %d, note %02X unknown", voice, note);
@@ -736,7 +735,7 @@ void MDYPlayer::setVoices() {
 	_tbrStart = READ_LE_UINT16(timbrePtr);
 
 	timbrePtr += 2;
-	for (int i = 0; i < _tbrCount ; i++)
+	for (int i = 0; i < _tbrCount; i++)
 		setVoice(i, i, true);
 }
 
