@@ -18,15 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/sound/bgatmosphere.h $
- * $Id: bgatmosphere.h 48279 2010-03-18 15:07:11Z fingolfin $
- *
  */
 
 #ifndef GOB_SOUND_BGATMOSPHERE_H
 #define GOB_SOUND_BGATMOSPHERE_H
 
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 #include "common/mutex.h"
 #include "common/random.h"
 
@@ -46,8 +43,8 @@ public:
 	BackgroundAtmosphere(Audio::Mixer &mixer);
 	~BackgroundAtmosphere();
 
-	void play();
-	void stop();
+	void playBA();
+	void stopBA();
 
 	void setPlayMode(PlayMode mode);
 
