@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "gob/gob.h"
@@ -333,7 +330,7 @@ void Sound::adlibPlayBgMusic() {
 	if (!_adlPlayer)
 		_adlPlayer = new ADLPlayer(*_vm->_mixer);
 
-	static const char *tracksMac[] = {
+	static const char *const tracksMac[] = {
 //		"musmac1.adl", // TODO: This track isn't played correctly at all yet
 		"musmac2.adl",
 		"musmac3.adl",
@@ -342,7 +339,7 @@ void Sound::adlibPlayBgMusic() {
 		"musmac6.adl"
 	};
 
-	static const char *tracksWin[] = {
+	static const char *const tracksWin[] = {
 		"musmac1.mid",
 		"musmac2.mid",
 		"musmac3.mid",
@@ -437,6 +434,8 @@ void Sound::blasterPlay(SoundDesc *sndDesc, int16 repCount,
 	debugC(1, kDebugSound, "SoundBlaster: Playing sample (%d, %d, %d)",
 			repCount, frequency, fadeLength);
 
+	blasterStopComposition();
+
 	_blaster->playSample(*sndDesc, repCount, frequency, fadeLength);
 }
 
@@ -537,7 +536,7 @@ void Sound::cdPlayBgMusic() {
 	if (!_cdrom)
 		return;
 
-	static const char *tracks[][2] = {
+	static const char *const tracks[][2] = {
 		{"avt00.tot",  "mine"},
 		{"avt001.tot", "nuit"},
 		{"avt002.tot", "campagne"},
@@ -574,7 +573,7 @@ void Sound::cdPlayMultMusic() {
 	if (!_cdrom)
 		return;
 
-	static const char *tracks[][6] = {
+	static const char *const tracks[][6] = {
 		{"avt005.tot", "fra1", "all1", "ang1", "esp1", "ita1"},
 		{"avt006.tot", "fra2", "all2", "ang2", "esp2", "ita2"},
 		{"avt012.tot", "fra3", "all3", "ang3", "esp3", "ita3"},
@@ -670,15 +669,13 @@ void Sound::bgPlay(const char *base, const char *ext, SoundType type, int count)
 	_bgatmos->stopBA();
 	_bgatmos->queueClear();
 
-	int length = strlen(base) + 7;
-	char *fileName = new char[length];
 	SoundDesc *sndDesc;
 
 	for (int i = 1; i <= count; i++) {
-		snprintf(fileName, length, "%s%02d.%s", base, i, ext);
+		Common::String fileName = Common::String::format("%s%02d.%s", base, i, ext);
 
 		sndDesc = new SoundDesc;
-		if (sampleLoad(sndDesc, type, fileName))
+		if (sampleLoad(sndDesc, type, fileName.c_str()))
 			_bgatmos->queueSample(*sndDesc);
 		else
 			delete sndDesc;
