@@ -18,16 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/gob/util.h $
- * $Id: util.h 45616 2009-11-02 21:54:57Z fingolfin $
- *
  */
 
 #ifndef GOB_UTIL_H
 #define GOB_UTIL_H
 
+#include "common/str.h"
 #include "common/keyboard.h"
 
+namespace Common {
+	class SeekableReadStream;
+}
+
 namespace Gob {
 
 class GobEngine;
@@ -106,6 +108,7 @@ public:
 	int16 getKey();
 	int16 checkKey();
 	bool checkKey(int16 &key);
+	bool keyPressed();
 
 	void getMouseState(int16 *pX, int16 *pY, MouseButtons *pButtons);
 	void setMousePos(int16 x, int16 y);
@@ -131,6 +134,12 @@ public:
 	static void listDropFront(List *list);
 	static void deleteList(List *list);
 
+	static char *setExtension(char *str, const char *ext);
+	static Common::String setExtension(const Common::String &str, const Common::String &ext);
+
+	/** Read a constant-length string out of a stream. */
+	static Common::String readString(Common::SeekableReadStream &stream, int n);
+
 	Util(GobEngine *vm);
 
 protected:
