@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef GROOVIE_MUSIC_H
@@ -28,7 +25,6 @@
 
 #include "common/array.h"
 #include "common/mutex.h"
-#include "audio/mididrv.h"
 
 class MidiParser;
 
@@ -62,6 +58,11 @@ private:
 
 	uint16 _backgroundDelay;
 
+	// T7G iOS credits mp3 stream
+	void playCreditsIOS();
+	void stopCreditsIOS();
+	Audio::SoundHandle _handleCreditsIOS;
+
 	// Volume fading
 	uint32 _fadingStartTime;
 	uint16 _fadingStartVolume;
@@ -160,6 +161,20 @@ private:
 	Common::SeekableReadStream *decompressMidi(Common::SeekableReadStream *stream);
 };
 
+class MusicPlayerIOS : public MusicPlayer {
+public:
+	MusicPlayerIOS(GroovieEngine *vm);
+	~MusicPlayerIOS();
+
+protected:
+	void updateVolume();
+	bool load(uint32 fileref, bool loop);
+	void unload();
+
+private:
+	Audio::SoundHandle _handle;
+};
+
 } // End of Groovie namespace
 
 #endif // GROOVIE_MUSIC_H
