@@ -18,13 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/groovie/resource.cpp $
- * $Id: resource.cpp 49487 2010-06-07 17:14:42Z jvprat $
- *
  */
 
 #include "common/archive.h"
+#include "common/debug.h"
+#include "common/file.h"
 #include "common/macresman.h"
+#include "common/substream.h"
+#include "common/textconsole.h"
 
 #include "groovie/resource.h"
 #include "groovie/groovie.h"
@@ -91,7 +92,7 @@ ResMan_t7g::ResMan_t7g(Common::MacResManager *macResFork) : _macResFork(macResFo
 	}
 }
 
-uint16 ResMan_t7g::getRef(Common::String name, Common::String scriptname) {
+uint32 ResMan_t7g::getRef(Common::String name, Common::String scriptname) {
 	// Get the name of the RL file
 	Common::String rlFileName(t7g_gjds[_lastGjd]);
 	rlFileName += ".rl";
@@ -109,7 +110,7 @@ uint16 ResMan_t7g::getRef(Common::String name, Common::String scriptname) {
 	if (!rlFile)
 		error("Groovie::Resource: Couldn't open %s", rlFileName.c_str());
 
-	uint16 resNum;
+	uint32 resNum;
 	bool found = false;
 	for (resNum = 0; !found && !rlFile->err() && !rlFile->eos(); resNum++) {
 		// Read the resource name
@@ -133,7 +134,7 @@ uint16 ResMan_t7g::getRef(Common::String name, Common::String scriptname) {
 	// Verify we really found the resource
 	if (!found) {
 		error("Groovie::Resource: Couldn't find resource %s in %s", name.c_str(), rlFileName.c_str());
-		return (uint16)-1;
+		return (uint32)-1;
 	}
 
 	return (_lastGjd << 10) | (resNum - 1);
@@ -168,10 +169,12 @@ bool ResMan_t7g::getResInfo(uint32 fileRef, ResInfo &resInfo) {
 		error("Groovie::Resource: Invalid resource number: 0x%04X (%s)", resNum, rlFileName.c_str());
 	}
 
-	// Read the resource name (just for debugging purposes)
-	char resname[12];
+	// Read the resource name
+	char resname[13];
 	rlFile->read(resname, 12);
+	resname[12] = 0;
 	debugC(2, kGroovieDebugResource | kGroovieDebugAll, "Groovie::Resource: Resource name: %12s", resname);
+	resInfo.filename = resname;
 
 	// Read the resource information
 	resInfo.offset = rlFile->readUint32LE();
@@ -216,8 +219,42 @@ ResMan_v2::ResMan_v2() {
 	indexfile.close();
 }
 
-uint16 ResMan_v2::getRef(Common::String name, Common::String scriptname) {
-	return 0;
+uint32 ResMan_v2::getRef(Common::String name, Common::String scriptname) {
+	// Open the RL file
+	Common::File rlFile;
+	if (!rlFile.open("dir.rl")) {
+		error("Groovie::Resource: Couldn't open dir.rl");
+		return false;
+	}
+
+	uint32 resNum;
+	bool found = false;
+	for (resNum = 0; !found && !rlFile.err() && !rlFile.eos(); resNum++) {
+		// Seek past metadata
+		rlFile.seek(14, SEEK_CUR);
+
+		// Read the resource name
+		char readname[18];
+		rlFile.read(readname, 18);
+
+		// Test whether it's the resource we're searching
+		Common::String resname(readname, 18);
+		if (resname.hasPrefix(name.c_str())) {
+			debugC(2, kGroovieDebugResource | kGroovieDebugAll, "Groovie::Resource: Resource %18s matches %s", readname, name.c_str());
+			found = true;
+		}
+	}
+
+	// Close the RL file
+	rlFile.close();
+
+	// Verify we really found the resource
+	if (!found) {
+		error("Groovie::Resource: Couldn't find resource %s", name.c_str());
+		return (uint32)-1;
+	}
+
+	return resNum;
 }
 
 bool ResMan_v2::getResInfo(uint32 fileRef, ResInfo &resInfo) {
@@ -242,10 +279,12 @@ bool ResMan_v2::getResInfo(uint32 fileRef, ResInfo &resInfo) {
 	resInfo.size = rlFile.readUint32LE();
 	resInfo.gjd = rlFile.readUint16LE();
 
-	// Read the resource name (just for debugging purposes)
-	char resname[12];
-	rlFile.read(resname, 12);
-	debugC(2, kGroovieDebugResource | kGroovieDebugAll, "Groovie::Resource: Resource name: %12s", resname);
+	// Read the resource name
+	char resname[19];
+	resname[18] = 0;
+	rlFile.read(resname, 18);
+	debugC(2, kGroovieDebugResource | kGroovieDebugAll, "Groovie::Resource: Resource name: %18s", resname);
+	resInfo.filename = resname;
 
 	// 6 padding bytes? (it looks like they're always 0)
 
