@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 // ROQ video player based on this specification by Dr. Tim Ferguson:
@@ -46,9 +43,6 @@
 namespace Groovie {
 
 ROQPlayer::ROQPlayer(GroovieEngine *vm) :
-#ifdef DITHER
-	_dither(NULL),
-#endif
 	VideoPlayer(vm), _codingTypeCount(0),
 	_fg(&_vm->_graphicsMan->_foreground), _bg(&_vm->_graphicsMan->_background) {
 
@@ -58,38 +52,13 @@ ROQPlayer::ROQPlayer(GroovieEngine *vm) :
 
 	if (_vm->_mode8bit) {
 		byte pal[256 * 3];
-#ifdef DITHER
-		// Initialize to a black palette
-		memset(pal, 0, 256 * 3);
 
-		// Build a basic color palette
-		for (int r = 0; r < 4; r++) {
-			for (int g = 0; g < 4; g++) {
-				for (int b = 0; b < 4; b++) {
-					byte col = (r << 4) | (g << 2) | (b << 0);
-					pal[3 * col + 0] = r << 6;
-					pal[3 * col + 1] = g << 6;
-					pal[3 * col + 2] = b << 6;
-				}
-			}
-		}
-
-		// Initialize the dithering algorithm
-		_paletteLookup = new Graphics::PaletteLUT(8, Graphics::PaletteLUT::kPaletteYUV);
-		_paletteLookup->setPalette(pal, Graphics::PaletteLUT::kPaletteRGB, 8);
-		for (int i = 0; (i < 64) && !_vm->shouldQuit(); i++) {
-			debug("Groovie::ROQ: Building palette table: %02d/63", i);
-			_paletteLookup->buildNext();
-		}
-
-#else // !DITHER
 		// Set a grayscale palette
 		for (int i = 0; i < 256; i++) {
 			pal[(i * 3) + 0] = i;
 			pal[(i * 3) + 1] = i;
 			pal[(i * 3) + 2] = i;
 		}
-#endif // DITHER
 
 		_syst->getPaletteManager()->setPalette(pal, 0, 256);
 	}
@@ -101,12 +70,6 @@ ROQPlayer::~ROQPlayer() {
 	delete _currBuf;
 	_prevBuf->free();
 	delete _prevBuf;
-
-#ifdef DITHER
-	// Free the dithering algorithm
-	delete _dither;
-	delete _paletteLookup;
-#endif
 }
 
 uint16 ROQPlayer::loadInternal() {
@@ -150,22 +113,13 @@ uint16 ROQPlayer::loadInternal() {
 }
 
 void ROQPlayer::buildShowBuf() {
-#ifdef DITHER
-	// Start a new frame dithering
-	_dither->newFrame();
-#endif
-
 	for (int line = 0; line < _bg->h; line++) {
 		byte *out = (byte *)_bg->getBasePtr(0, line);
 		byte *in = (byte *)_currBuf->getBasePtr(0, line / _scaleY);
 		for (int x = 0; x < _bg->w; x++) {
 			if (_vm->_mode8bit) {
-#ifdef DITHER
-				*out = _dither->dither(*in, *(in + 1), *(in + 2), x);
-#else
 				// Just use the luminancy component
 				*out = *in;
-#endif // DITHER
 #ifdef USE_RGB_COLOR
 			} else {
 				// Do the format conversion (YUV -> RGB -> Screen format)
@@ -179,11 +133,8 @@ void ROQPlayer::buildShowBuf() {
 			// Skip to the next pixel
 			out += _vm->_pixelFormat.bytesPerPixel;
 			if (!(x % _scaleX))
-				in += _currBuf->bytesPerPixel;
+				in += _currBuf->format.bytesPerPixel;
 		}
-#ifdef DITHER
-		_dither->nextLine();
-#endif
 	}
 
 	// Swap buffers
@@ -332,8 +283,13 @@ bool ROQPlayer::processBlockInfo(ROQBlockHeader &blockHeader) {
 		_prevBuf->free();
 
 		// Allocate new buffers
-		_currBuf->create(width, height, 3);
-		_prevBuf->create(width, height, 3);
+		// These buffers use YUV data, since we can not describe it with a
+		// PixelFormat struct we just add some dummy PixelFormat with the
+		// correct bytes per pixel value. Since the surfaces are only used
+		// internally and no code assuming RGB data is present is used on
+		// them it should be just fine.
+		_currBuf->create(width, height, Graphics::PixelFormat(3, 0, 0, 0, 0, 0, 0, 0, 0));
+		_prevBuf->create(width, height, Graphics::PixelFormat(3, 0, 0, 0, 0, 0, 0, 0, 0));
 
 		// Clear the buffers with black YUV values
 		byte *ptr1 = (byte *)_currBuf->getBasePtr(0, 0);
@@ -347,11 +303,6 @@ bool ROQPlayer::processBlockInfo(ROQBlockHeader &blockHeader) {
 			*ptr2++ = 128;
 		}
 
-#ifdef DITHER
-		// Reset the dithering algorithm with the new width
-		delete _dither;
-		_dither = new Graphics::SierraLight(width * _scaleX, _paletteLookup);
-#endif
 	}
 
 	return true;
@@ -701,7 +652,7 @@ void ROQPlayer::copy(byte size, int destx, int desty, int offx, int offy) {
 
 	for (int i = 0; i < size; i++) {
 		// Copy the current line
-		memcpy(dst, src, size * _currBuf->bytesPerPixel);
+		memcpy(dst, src, size * _currBuf->format.bytesPerPixel);
 
 		// Move to the beginning of the next line
 		dst += _currBuf->pitch;
