@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 /*
@@ -84,9 +81,9 @@ public:
 	virtual ~Parser();
 
 	bool isWordPresent(char **wordArr) const;
-	
+
 	uint16 getCmdDefaultVerbIdx(const uint16 index) const;
-	
+
 	void charHandler();
 	void command(const char *format, ...);
 	void freeParser();
@@ -100,6 +97,7 @@ public:
 
 	virtual void lineHandler() = 0;
 	virtual void showInventory() const = 0;
+	virtual void takeObject(object_t *obj) = 0;
 
 protected:
 	HugoEngine *_vm;
@@ -138,10 +136,10 @@ public:
 
 	virtual void lineHandler();
 	virtual void showInventory() const;
+	virtual void takeObject(object_t *obj);
 
 protected:
-	virtual void  dropObject(object_t *obj);
-	virtual void  takeObject(object_t *obj);
+	virtual void dropObject(object_t *obj);
 
 	const char *findNextNoun(const char *noun) const;
 	bool  isBackgroundWord_v1(const char *noun, const char *verb, objectList_t obj) const;
