@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 /*
@@ -122,7 +119,7 @@ char *strlwr(char *buffer) {
 	char *result = buffer;
 
 	while (*buffer != '\0') {
-		if (isupper(*buffer))
+		if (isupper(static_cast<unsigned char>(*buffer)))
 			*buffer = tolower(*buffer);
 		buffer++;
 	}
