@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/debugger.h $
- * $Id: debugger.h 41351 2009-06-07 20:43:43Z lordhoto $
- *
  */
 
 #ifndef KYRA_DEBUGGER_H
@@ -62,9 +59,6 @@ public:
 protected:
 	KyraEngine_LoK *_vm;
 
-	virtual void preEnter();
-	virtual void postEnter();
-
 	bool cmd_enterRoom(int argc, const char **argv);
 	bool cmd_listScenes(int argc, const char **argv);
 	bool cmd_giveItem(int argc, const char **argv);
@@ -112,4 +106,3 @@ protected:
 } // End of namespace Kyra
 
 #endif
-
