@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
  */
 
 #include "kyra/kyra_lok.h"
@@ -50,39 +47,17 @@ const char * const directoryGlobs[] = {
 	0
 };
 
-static const ADParams detectionParams = {
-	// Pointer to ADGameDescription or its superset structure
-	(const byte *)adGameDescs,
-	// Size of that superset structure
-	sizeof(KYRAGameDescription),
-	// Number of bytes to compute MD5 sum for
-	1024 * 1024,
-	// List of all engine targets
-	gameList,
-	// Structure for autoupgrading obsolete targets
-	0,
-	// Name of single gameid (optional)
-	0,
-	// List of files for file-based fallback detection (optional)
-	0,
-	// Flags
-	0,
-	// Additional GUI options (for every game}
-	Common::GUIO_NONE,
-	// Maximum directory depth
-	2,
-	// List of directory globs
-	directoryGlobs
-};
-
 } // End of anonymous namespace
 
 class KyraMetaEngine : public AdvancedMetaEngine {
 public:
-	KyraMetaEngine() : AdvancedMetaEngine(detectionParams) {}
-
+	KyraMetaEngine() : AdvancedMetaEngine(adGameDescs, sizeof(KYRAGameDescription), gameList) {
+		_md5Bytes = 1024 * 1024;
+		_maxScanDepth = 2;
+		_directoryGlobs = directoryGlobs;
+	}
 	const char *getName() const {
-		return "Legend of Kyrandia Engine";
+		return "Kyra";
 	}
 
 	const char *getOriginalCopyright() const {
@@ -212,6 +187,7 @@ void KyraMetaEngine::removeSaveState(const char *target, int slot) const {
 SaveStateDescriptor KyraMetaEngine::querySaveMetaInfos(const char *target, int slot) const {
 	Common::String filename = Kyra::KyraEngine_v1::getSavegameFilename(target, slot);
 	Common::InSaveFile *in = g_system->getSavefileManager()->openForLoading(filename);
+	const bool lolGame = ConfMan.getDomain(target)->getVal("gameid").equalsIgnoreCase("lol");
 
 	if (in) {
 		Kyra::KyraEngine_v1::SaveHeader header;
@@ -223,14 +199,13 @@ SaveStateDescriptor KyraMetaEngine::querySaveMetaInfos(const char *target, int s
 		if (error == Kyra::KyraEngine_v1::kRSHENoError) {
 			SaveStateDescriptor desc(slot, header.description);
 
-			bool lolGame = ConfMan.getDomain(target)->getVal("gameid").equalsIgnoreCase("lol");
-
 			// Slot 0 is used for the 'restart game' save in all three Kyrandia games, thus
 			// we prevent it from being deleted.
 			desc.setDeletableFlag(slot != 0 || lolGame);
 
 			// We don't allow quick saves (slot 990 till 998) to be overwritten.
-			// The same goes for the 'Autosave', which is slot 999.
+			// The same goes for the 'Autosave', which is slot 999. Slot 0 will also
+			// be protected in Kyra 1-3, since it's the 'restart game' save.
 			desc.setWriteProtectedFlag((slot == 0 && !lolGame) || slot >= 990);
 			desc.setThumbnail(header.thumbnail);
 
@@ -238,7 +213,14 @@ SaveStateDescriptor KyraMetaEngine::querySaveMetaInfos(const char *target, int s
 		}
 	}
 
-	return SaveStateDescriptor();
+	SaveStateDescriptor desc(slot, Common::String());
+
+	// We don't allow quick saves (slot 990 till 998) to be overwritten.
+	// The same goes for the 'Autosave', which is slot 999. Slot 0 will also
+	// be protected in Kyra 1-3, since it's the 'restart game' save.
+	desc.setWriteProtectedFlag((slot == 0 && !lolGame) || slot >= 990);
+
+	return desc;
 }
 
 #if PLUGIN_ENABLED_DYNAMIC(KYRA)
@@ -246,4 +228,3 @@ SaveStateDescriptor KyraMetaEngine::querySaveMetaInfos(const char *target, int s
 #else
 	REGISTER_PLUGIN_STATIC(KYRA, PLUGIN_TYPE_ENGINE, KyraMetaEngine);
 #endif
-
