@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef KYRA_KYRA_HOF_H
@@ -569,8 +566,8 @@ protected:
 	// -
 
 	char _internStringBuf[200];
-	static const char *_languageExtension[];
-	static const char *_scriptLangExt[];
+	static const char *const _languageExtension[];
+	static const char *const _scriptLangExt[];
 
 	// character
 	bool _useCharPal;
@@ -928,4 +925,3 @@ protected:
 } // End of namespace Kyra
 
 #endif
-
