@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "kyra/kyra_lok.h"
@@ -101,6 +98,8 @@ KyraEngine_LoK::KyraEngine_LoK(OSystem *system, const GameFlags &flags)
 
 	_malcolmFrame = 0;
 	_malcolmTimer1 = _malcolmTimer2 = 0;
+
+	_soundFiles = 0;
 }
 
 KyraEngine_LoK::~KyraEngine_LoK() {
@@ -124,6 +123,8 @@ KyraEngine_LoK::~KyraEngine_LoK() {
 	delete _animator;
 	delete _seq;
 
+	delete[] _soundFiles;
+
 	delete[] _characterList;
 
 	delete[] _roomTable;
@@ -824,14 +825,6 @@ void KyraEngine_LoK::updateMousePointer(bool forceUpdate) {
 		newY = 4;
 	}
 
-	if (_updateHandItemCursor) {
-		// This works around an issue which would occur when setHandItem(_itemInHand)
-		// was called from inside loadGameState(). When loading via GMM the
-		// mouse cursor would not be set correctly.
-		_updateHandItemCursor = false;
-		setHandItem(_itemInHand);
-	}
-
 	if ((newMouseState && _mouseState != newMouseState) || (newMouseState && forceUpdate)) {
 		_mouseState = newMouseState;
 		_screen->hideMouse();
