@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "kyra/kyra_v1.h"
@@ -32,12 +29,11 @@
 #include "common/error.h"
 #include "common/config-manager.h"
 #include "common/debug-channels.h"
-#include "common/EventRecorder.h"
 
 namespace Kyra {
 
 KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
-	: Engine(system), _flags(flags) {
+	: Engine(system), _flags(flags), _rnd("kyra") {
 	_res = 0;
 	_sound = 0;
 	_text = 0;
@@ -60,7 +56,6 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 	_gameToLoad = -1;
 
 	_mouseState = -1;
-	_updateHandItemCursor = false;
 	_deathHandler = -1;
 
 	memset(_flagsTable, 0, sizeof(_flagsTable));
@@ -81,8 +76,6 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 	DebugMan.addDebugChannel(kDebugLevelSequence, "Sequence", "Sequence debug level");
 	DebugMan.addDebugChannel(kDebugLevelMovie, "Movie", "Movie debug level");
 	DebugMan.addDebugChannel(kDebugLevelTimer, "Timer", "Timer debug level");
-
-	g_eventRec.registerRandomSource(_rnd, "kyra");
 }
 
 ::GUI::Debugger *KyraEngine_v1::getDebugger() {
@@ -91,6 +84,8 @@ KyraEngine_v1::KyraEngine_v1(OSystem *system, const GameFlags &flags)
 
 void KyraEngine_v1::pauseEngineIntern(bool pause) {
 	Engine::pauseEngineIntern(pause);
+	if (_sound)
+		_sound->pause(pause);	
 	_timer->pause(pause);
 }
 
@@ -99,15 +94,6 @@ Common::Error KyraEngine_v1::init() {
 	syncSoundSettings();
 
 	if (!_flags.useDigSound) {
-		// In Kyra 1 users who have specified a default MT-32 device in the launcher settings
-		// will get MT-32 music, otherwise AdLib. In Kyra 2 and LoL users who have specified a
-		// default GM device in the launcher will get GM music, otherwise AdLib. Users who want
-		// MT-32 music in Kyra2 or LoL have to select this individually (since we assume that
-		// most users rather have a GM device than a MT-32 device).
-		// Users who want PC speaker sound always have to select this individually for all
-		// Kyra games.
-		MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_PCSPK | MDT_MIDI | MDT_ADLIB | ((_flags.gameID == GI_KYRA2 || _flags.gameID == GI_LOL) ? MDT_PREFER_GM : MDT_PREFER_MT32));
-
 		if (_flags.platform == Common::kPlatformFMTowns) {
 			if (_flags.gameID == GI_KYRA1)
 				_sound = new SoundTowns(this, _mixer);
@@ -120,43 +106,53 @@ Common::Error KyraEngine_v1::init() {
 				_sound = new SoundTownsPC98_v2(this, _mixer);
 		} else if (_flags.platform == Common::kPlatformAmiga) {
 			_sound = new SoundAmiga(this, _mixer);
-		} else if (MidiDriver::getMusicType(dev) == MT_ADLIB) {
-			_sound = new SoundAdLibPC(this, _mixer);
 		} else {
-			Sound::kType type;
-			const MusicType midiType = MidiDriver::getMusicType(dev);
-
-			if (midiType == MT_PCSPK || midiType == MT_NULL)
-				type = Sound::kPCSpkr;
-			else if (midiType == MT_MT32 || ConfMan.getBool("native_mt32"))
-				type = Sound::kMidiMT32;
-			else
-				type = Sound::kMidiGM;
-
-			MidiDriver *driver = 0;
-
-			if (MidiDriver::getMusicType(dev) == MT_PCSPK) {
-				driver = new MidiDriver_PCSpeaker(_mixer);
+			// In Kyra 1 users who have specified a default MT-32 device in the launcher settings
+			// will get MT-32 music, otherwise AdLib. In Kyra 2 and LoL users who have specified a
+			// default GM device in the launcher will get GM music, otherwise AdLib. Users who want
+			// MT-32 music in Kyra2 or LoL have to select this individually (since we assume that
+			// most users rather have a GM device than a MT-32 device).
+			// Users who want PC speaker sound always have to select this individually for all
+			// Kyra games.
+			MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_PCSPK | MDT_MIDI | MDT_ADLIB | ((_flags.gameID == GI_KYRA2 || _flags.gameID == GI_LOL) ? MDT_PREFER_GM : MDT_PREFER_MT32));
+			if (MidiDriver::getMusicType(dev) == MT_ADLIB) {
+				_sound = new SoundAdLibPC(this, _mixer);
 			} else {
-				driver = MidiDriver::createMidi(dev);
-				if (type == Sound::kMidiMT32)
-					driver->property(MidiDriver::PROP_CHANNEL_MASK, 0x03FE);
-			}
+				Sound::kType type;
+				const MusicType midiType = MidiDriver::getMusicType(dev);
 
-			assert(driver);
+				if (midiType == MT_PCSPK || midiType == MT_NULL)
+					type = Sound::kPCSpkr;
+				else if (midiType == MT_MT32 || ConfMan.getBool("native_mt32"))
+					type = Sound::kMidiMT32;
+				else
+					type = Sound::kMidiGM;
 
-			SoundMidiPC *soundMidiPc = new SoundMidiPC(this, _mixer, driver, type);
-			_sound = soundMidiPc;
-			assert(_sound);
+				MidiDriver *driver = 0;
 
-			// Unlike some SCUMM games, it's not that the MIDI sounds are
-			// missing. It's just that at least at the time of writing they
-			// are decidedly inferior to the AdLib ones.
-			if (ConfMan.getBool("multi_midi")) {
-				SoundAdLibPC *adlib = new SoundAdLibPC(this, _mixer);
-				assert(adlib);
+				if (MidiDriver::getMusicType(dev) == MT_PCSPK) {
+					driver = new MidiDriver_PCSpeaker(_mixer);
+				} else {
+					driver = MidiDriver::createMidi(dev);
+					if (type == Sound::kMidiMT32)
+						driver->property(MidiDriver::PROP_CHANNEL_MASK, 0x03FE);
+				}
 
-				_sound = new MixedSoundDriver(this, _mixer, soundMidiPc, adlib);
+				assert(driver);
+
+				SoundMidiPC *soundMidiPc = new SoundMidiPC(this, _mixer, driver, type);
+				_sound = soundMidiPc;
+				assert(_sound);
+
+				// Unlike some SCUMM games, it's not that the MIDI sounds are
+				// missing. It's just that at least at the time of writing they
+				// are decidedly inferior to the AdLib ones.
+				if (ConfMan.getBool("multi_midi")) {
+					SoundAdLibPC *adlib = new SoundAdLibPC(this, _mixer);
+					assert(adlib);
+
+					_sound = new MixedSoundDriver(this, _mixer, soundMidiPc, adlib);
+				}
 			}
 		}
 
@@ -356,23 +352,43 @@ int KyraEngine_v1::checkInput(Button *buttonList, bool mainLoop, int eventFlag)
 }
 
 void KyraEngine_v1::setupKeyMap() {
-	static const Common::KeyCode keyboardEvents[] = {
-		Common::KEYCODE_SPACE,  Common::KEYCODE_RETURN, Common::KEYCODE_UP,     Common::KEYCODE_KP8,
-		Common::KEYCODE_RIGHT,  Common::KEYCODE_KP6,    Common::KEYCODE_DOWN,   Common::KEYCODE_KP2,
-		Common::KEYCODE_KP5,	Common::KEYCODE_LEFT,   Common::KEYCODE_KP4,	Common::KEYCODE_HOME,
-		Common::KEYCODE_KP7,	Common::KEYCODE_PAGEUP, Common::KEYCODE_KP9,    Common::KEYCODE_F1,
-		Common::KEYCODE_F2,		Common::KEYCODE_F3,     Common::KEYCODE_o,      Common::KEYCODE_r,
-		Common::KEYCODE_SLASH,	Common::KEYCODE_ESCAPE
+	struct KeyMapEntry {
+		Common::KeyCode kcScummVM;
+		int16 kcDOS;
+		int16 kcPC98;
 	};
 
-	static const int16 keyCodesDOS[] = { 61, 43, 96, 96, 102, 102, 98, 98, 97, 92, 92, 91, 91, 101, 101, 112, 113, 114, 25, 20, 55, 110};
-	static const int16 keyCodesPC98[] = { 53, 29, 68, 68, 73, 73, 76, 76, 72, 71, 71, 67, 67, 69, 69, 99, 100, 101, 25, 20, 55, 1 };
+#define KC(x) Common::KEYCODE_##x
+	static const KeyMapEntry keys[] = {
+		{ KC(SPACE), 61, 53 },
+		{ KC(RETURN), 43, 29 },
+		{ KC(UP), 96, 68 },
+		{ KC(KP8), 96, 68 },
+		{ KC(RIGHT), 102, 73 },
+		{ KC(KP6), 102, 73 },
+		{ KC(DOWN), 98, 76 },
+		{ KC(KP2), 98, 76 },
+		{ KC(KP5), 97, 72 },
+		{ KC(LEFT), 92, 71 },
+		{ KC(KP4), 92, 71 },
+		{ KC(HOME), 91, 67 },
+		{ KC(KP7), 91, 67 },
+		{ KC(PAGEUP), 101, 69 },
+		{ KC(KP9), 101, 69 },
+		{ KC(F1), 112, 99 },
+		{ KC(F2), 113, 100 },
+		{ KC(F3), 114, 101 },
+		{ KC(o), 25, 25 },
+		{ KC(r), 20, 20 },
+		{ KC(SLASH), 55, 55 },
+		{ KC(ESCAPE), 110, 1 },
+	};
+#undef KC
 
-	const int16 *keyCodes = _flags.platform == Common::kPlatformPC98 ? keyCodesPC98 : keyCodesDOS;
 	_keyMap.clear();
 
-	for (int i = 0; i < ARRAYSIZE(keyboardEvents); i++)
-		_keyMap[keyboardEvents[i]] = keyCodes[i];
+	for (int i = 0; i < ARRAYSIZE(keys); i++)
+		_keyMap[keys[i].kcScummVM] = (_flags.platform == Common::kPlatformPC98) ? keys[i].kcPC98 : keys[i].kcDOS;
 }
 
 void KyraEngine_v1::updateInput() {
@@ -634,4 +650,3 @@ void KyraEngine_v1::syncSoundSettings() {
 }
 
 } // End of namespace Kyra
-
