@@ -18,20 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/saveload_lol.cpp $
- * $Id: saveload_lol.cpp 47354 2010-01-18 07:21:54Z athrxx $
- *
  */
 
 #ifdef ENABLE_LOL
 
 #include "kyra/lol.h"
 #include "kyra/screen_lol.h"
-#include "kyra/resource.h"
 
-#include "common/endian.h"
 #include "common/savefile.h"
-#include "common/system.h"
+#include "common/substream.h"
+#include "common/memstream.h"
 
 #include "graphics/scaler.h"
 
@@ -49,6 +45,9 @@ Common::Error LoLEngine::loadGameState(int slot) {
 		return Common::kNoError;
 	}
 
+	if (header.originalSave)
+		warning("Trying to load savegame from original interpreter, while this is possible, it is not officially supported");
+
 	_screen->fadeClearSceneWindow(10);
 	completeDoorOperations();
 	_screen->fillRect(112, 0, 287, 119, 0, 0);
@@ -58,38 +57,40 @@ Common::Error LoLEngine::loadGameState(int slot) {
 
 	for (int i = 0; i < 4; i++) {
 		LoLCharacter *c = &_characters[i];
-		c->flags = in.readUint16BE();
+		c->flags = in.readUint16();
 		in.read(c->name, 11);
 		c->raceClassSex = in.readByte();
-		c->id = in.readSint16BE();
+		c->id = in.readSint16();
 		c->curFaceFrame = in.readByte();
 		c->tempFaceFrame = in.readByte();
 		c->screamSfx = in.readByte();
+		if (header.originalSave)
+			in.skip(4);
 		for (int ii = 0; ii < 8; ii++)
-			c->itemsMight[ii] = in.readUint16BE();
+			c->itemsMight[ii] = in.readUint16();
 		for (int ii = 0; ii < 8; ii++)
-			c->protectionAgainstItems[ii] = in.readUint16BE();
-		c->itemProtection = in.readUint16BE();
-		c->hitPointsCur = in.readSint16BE();
-		c->hitPointsMax = in.readUint16BE();
-		c->magicPointsCur = in.readSint16BE();
-		c->magicPointsMax = in.readUint16BE();
+			c->protectionAgainstItems[ii] = in.readUint16();
+		c->itemProtection = in.readUint16();
+		c->hitPointsCur = in.readSint16();
+		c->hitPointsMax = in.readUint16();
+		c->magicPointsCur = in.readSint16();
+		c->magicPointsMax = in.readUint16();
 		c->field_41 = in.readByte();
-		c->damageSuffered = in.readUint16BE();
-		c->weaponHit = in.readUint16BE();
-		c->totalMightModifier = in.readUint16BE();
-		c->totalProtectionModifier = in.readUint16BE();
-		c->might = in.readUint16BE();
-		c->protection = in.readUint16BE();
-		c->nextAnimUpdateCountdown = in.readSint16BE();
+		c->damageSuffered = in.readUint16();
+		c->weaponHit = in.readUint16();
+		c->totalMightModifier = in.readUint16();
+		c->totalProtectionModifier = in.readUint16();
+		c->might = in.readUint16();
+		c->protection = in.readUint16();
+		c->nextAnimUpdateCountdown = in.readSint16();
 		for (int ii = 0; ii < 11; ii++)
-			c->items[ii] = in.readUint16BE();
+			c->items[ii] = in.readUint16();
 		for (int ii = 0; ii < 3; ii++)
 			c->skillLevels[ii] = in.readByte();
 		for (int ii = 0; ii < 3; ii++)
 			c->skillModifiers[ii] = in.readSByte();
 		for (int ii = 0; ii < 3; ii++)
-			c->experiencePts[ii] = in.readUint32BE();
+			c->experiencePts[ii] = in.readUint32();
 		for (int ii = 0; ii < 5; ii++)
 			c->characterUpdateEvents[ii] = in.readByte();
 		for (int ii = 0; ii < 5; ii++)
@@ -101,39 +102,48 @@ Common::Error LoLEngine::loadGameState(int slot) {
 		}
 	}
 
-	in.read(_wllBuffer4, 80);
+	if (!header.originalSave)
+		in.read(_wllBuffer4, 80);
 
-	_currentBlock = in.readUint16BE();
-	_partyPosX = in.readUint16BE();
-	_partyPosY = in.readUint16BE();
-	_updateFlags = in.readUint16BE();
+	_currentBlock = in.readUint16();
+	_partyPosX = in.readUint16();
+	_partyPosY = in.readUint16();
+	_updateFlags = in.readUint16();
 	_scriptDirection = in.readByte();
 	_selectedSpell = in.readByte();
+
+	if (header.originalSave)
+		in.skip(2);
+
 	_sceneDefaultUpdate = in.readByte();
 	_compassBroken = in.readByte();
 	_drainMagic = in.readByte();
-	_currentDirection = in.readUint16BE();
-	_compassDirection = in.readUint16BE();
+	_currentDirection = in.readUint16();
+	_compassDirection = in.readUint16();
 	_selectedCharacter = in.readSByte();
+
+	if (header.originalSave)
+		in.skip(1);
+
 	_currentLevel = in.readByte();
 	for (int i = 0; i < 48; i++)
-		_inventory[i] = in.readUint16BE();
-	_inventoryCurItem = in.readSint16BE();
-	_itemInHand = in.readSint16BE();
-	_lastMouseRegion = in.readSint16BE();
+		_inventory[i] = in.readSint16();
+	_inventoryCurItem = in.readSint16();
+	_itemInHand = in.readSint16();
+	_lastMouseRegion = in.readSint16();
 
-	if (header.version <= 15) {
+	if (header.originalSave || header.version <= 15) {
 		uint16 flags[40];
 		memset(flags, 0, sizeof(flags));
 
 		if (header.version == 14) {
 			for (int i = 0; i < 16; i++)
-				flags[i] = in.readUint16BE();
-			flags[26] = in.readUint16BE();
-			flags[36] = in.readUint16BE();
-		} else if (header.version == 15) {
+				flags[i] = in.readUint16();
+			flags[26] = in.readUint16();
+			flags[36] = in.readUint16();
+		} else if (header.originalSave || header.version == 15) {
 			for (int i = 0; i < 40; i++)
-				flags[i] = in.readUint16BE();
+				flags[i] = in.readUint16();
 		}
 
 		memset(_flagsTable, 0, sizeof(_flagsTable));
@@ -144,37 +154,56 @@ Common::Error LoLEngine::loadGameState(int slot) {
 			}
 		}
 	} else {
-		uint32 flagsSize = in.readUint32BE();
+		uint32 flagsSize = in.readUint32();
 		assert(flagsSize <= sizeof(_flagsTable));
 		in.read(_flagsTable, flagsSize);
 	}
 
+	if (header.originalSave)
+		in.skip(120);
+
 	for (int i = 0; i < 24; i++)
-		_globalScriptVars[i] = in.readUint16BE();
+		_globalScriptVars[i] = in.readUint16();
+
+	if (header.originalSave)
+		in.skip(152);
+
 	_brightness = in.readByte();
 	_lampOilStatus = in.readByte();
 	_lampEffect = in.readSByte();
-	_credits = in.readUint16BE();
+
+	if (header.originalSave)
+		in.skip(1);
+
+	_credits = in.readUint16();
 	for (int i = 0; i < 8; i++)
-		_globalScriptVars2[i] = in.readUint16BE();
+		_globalScriptVars2[i] = in.readUint16();
 	in.read(_availableSpells, 7);
-	_hasTempDataFlags = in.readUint32BE();
+	_hasTempDataFlags = in.readUint32();
+
+	uint8 *origCmp = 0;
+	if (header.originalSave) {
+		in.skip(6);
+		origCmp = new uint8[2496];
+	}
 
 	for (int i = 0; i < 400; i++) {
 		ItemInPlay *t = &_itemsInPlay[i];
-		t->nextAssignedObject = in.readUint16BE();
-		t->nextDrawObject = in.readUint16BE();
+		t->nextAssignedObject = in.readUint16();
+		t->nextDrawObject = in.readUint16();
 		t->flyingHeight = in.readByte();
-		t->block = in.readUint16BE();
-		t->x = in.readUint16BE();
-		t->y = in.readUint16BE();
+		t->block = in.readUint16();
+		t->x = in.readUint16();
+		t->y = in.readUint16();
 		t->level = in.readSByte();
-		t->itemPropertyIndex = in.readUint16BE();
-		t->shpCurFrame_flg = in.readUint16BE();
-		t->destDirection = in.readByte();
-		t->hitOffsX = in.readSByte();
-		t->hitOffsY = in.readSByte();
-		t->currentSubFrame = in.readByte();
+		t->itemPropertyIndex = in.readUint16();
+		t->shpCurFrame_flg = in.readUint16();
+		if (!header.originalSave) {
+			t->destDirection = in.readByte();		
+			t->hitOffsX = in.readSByte();
+			t->hitOffsY = in.readSByte();
+			t->currentSubFrame = in.readByte();
+		}
 	}
 
 	for (int i = 0; i < 1024; i++) {
@@ -184,8 +213,13 @@ Common::Error LoLEngine::loadGameState(int slot) {
 	}
 
 	for (int i = 0; i < 29; i++) {
-		if (!(_hasTempDataFlags & (1 << i)))
+		if (!(_hasTempDataFlags & (1 << i))) {
+			if (header.originalSave) {
+				if (in.size() - in.pos() >= 2500)
+					in.skip(2500);
+			}
 			continue;
+		}
 
 		if (_lvlTempData[i]) {
 			delete[] _lvlTempData[i]->wallsXorData;
@@ -201,21 +235,36 @@ Common::Error LoLEngine::loadGameState(int slot) {
 		_lvlTempData[i]->monsters = new MonsterInPlay[30];
 		_lvlTempData[i]->flyingObjects = new FlyingObject[8];
 		LevelTempData *l = _lvlTempData[i];
+		
+		uint32 next = in.pos() + 2500;
 
-		in.read(l->wallsXorData, 4096);
-		in.read(l->flags, 1024);
+		if (header.originalSave) {
+			in.skip(4);
+			in.read(origCmp, in.readUint16());
+			_screen->decodeFrame4(origCmp, _tempBuffer5120, 5120);
+			memcpy(l->wallsXorData, _tempBuffer5120, 4096);
+			for (int ii = 0; ii < 1024; ii++)
+				l->flags[ii] = _tempBuffer5120[4096 + ii];
+		} else {
+			in.read(l->wallsXorData, 4096);
+			for (int ii = 0; ii < 1024; ii++)
+				l->flags[ii] = in.readByte();
+		}
+
+		if (header.originalSave)
+			l->monsterDifficulty =  in.readUint16();
 
 		for (int ii = 0; ii < 30; ii++) {
 			MonsterInPlay *m = &l->monsters[ii];
-			m->nextAssignedObject = in.readUint16BE();
-			m->nextDrawObject = in.readUint16BE();
+			m->nextAssignedObject = in.readUint16();
+			m->nextDrawObject = in.readUint16();
 			m->flyingHeight = in.readByte();
-			m->block = in.readUint16BE();
-			m->x = in.readUint16BE();
-			m->y = in.readUint16BE();
+			m->block = in.readUint16();
+			m->x = in.readUint16();
+			m->y = in.readUint16();
 			m->shiftStep = in.readSByte();
-			m->destX = in.readUint16BE();
-			m->destY = in.readUint16BE();
+			m->destX = in.readUint16();
+			m->destY = in.readUint16();
 			m->destDirection = in.readByte();
 			m->hitOffsX = in.readSByte();
 			m->hitOffsY = in.readSByte();
@@ -225,15 +274,19 @@ Common::Error LoLEngine::loadGameState(int slot) {
 			m->id = in.readByte();
 			m->direction = in.readByte();
 			m->facing = in.readByte();
-			m->flags = in.readUint16BE();
-			m->damageReceived = in.readUint16BE();
-			m->hitPoints = in.readSint16BE();
+			m->flags = in.readUint16();
+			m->damageReceived = in.readUint16();
+			m->hitPoints = in.readSint16();
 			m->speedTick = in.readByte();
 			m->type = in.readByte();
+
+			if (header.originalSave)
+				in.skip(4);
+
 			m->numDistAttacks = in.readByte();
 			m->curDistWeapon = in.readByte();
 			m->distAttackTick = in.readSByte();
-			m->assignedItems = in.readUint16BE();
+			m->assignedItems = in.readUint16();
 			m->properties = &_monsterProperties[m->type];
 			in.read(m->equipmentShapes, 4);
 		}
@@ -242,10 +295,10 @@ Common::Error LoLEngine::loadGameState(int slot) {
 			FlyingObject *m = &l->flyingObjects[ii];
 			m->enable = in.readByte();
 			m->objectType = in.readByte();
-			m->attackerId = in.readUint16BE();
-			m->item = in.readUint16BE();
-			m->x = in.readUint16BE();
-			m->y = in.readUint16BE();
+			m->attackerId = in.readUint16();
+			m->item = in.readSint16();
+			m->x = in.readUint16();
+			m->y = in.readUint16();
 			m->flyingHeight = in.readByte();
 			m->direction = in.readByte();
 			m->distance = in.readByte();
@@ -254,9 +307,15 @@ Common::Error LoLEngine::loadGameState(int slot) {
 			m->flags = in.readByte();
 			m->wallFlags = in.readByte();
 		}
-		l->monsterDifficulty = in.readByte();
+
+		if (header.originalSave)
+			in.seek(next, SEEK_SET);
+		else
+			l->monsterDifficulty =  in.readByte();
 	}
 
+	delete[] origCmp;
+
 	calcCharPortraitXpos();
 	memset(_moneyColumnHeight, 0, sizeof(_moneyColumnHeight));
 	int t = _credits;
@@ -274,7 +333,7 @@ Common::Error LoLEngine::loadGameState(int slot) {
 	return Common::kNoError;
 }
 
-Common::Error LoLEngine::saveGameState(int slot, const char *saveName, const Graphics::Surface *thumbnail) {
+Common::Error LoLEngine::saveGameStateIntern(int slot, const char *saveName, const Graphics::Surface *thumbnail) {
 	const char *fileName = getSavegameFilename(slot);
 
 	Common::OutSaveFile *out = openSaveForWriting(fileName, saveName, thumbnail);
@@ -340,7 +399,7 @@ Common::Error LoLEngine::saveGameState(int slot, const char *saveName, const Gra
 	out->writeSByte(_selectedCharacter);
 	out->writeByte(_currentLevel);
 	for (int i = 0; i < 48; i++)
-		out->writeUint16BE(_inventory[i]);
+		out->writeSint16BE(_inventory[i]);
 	out->writeSint16BE(_inventoryCurItem);
 	out->writeSint16BE(_itemInHand);
 	out->writeSint16BE(_lastMouseRegion);
@@ -370,6 +429,7 @@ Common::Error LoLEngine::saveGameState(int slot, const char *saveName, const Gra
 		out->writeSByte(t->level);
 		out->writeUint16BE(t->itemPropertyIndex);
 		out->writeUint16BE(t->shpCurFrame_flg);
+		
 		out->writeByte(t->destDirection);
 		out->writeSByte(t->hitOffsX);
 		out->writeSByte(t->hitOffsY);
@@ -423,7 +483,7 @@ Common::Error LoLEngine::saveGameState(int slot, const char *saveName, const Gra
 			out->writeByte(m->enable);
 			out->writeByte(m->objectType);
 			out->writeUint16BE(m->attackerId);
-			out->writeUint16BE(m->item);
+			out->writeSint16BE(m->item);
 			out->writeUint16BE(m->x);
 			out->writeUint16BE(m->y);
 			out->writeByte(m->flyingHeight);
@@ -477,4 +537,3 @@ Graphics::Surface *LoLEngine::generateSaveThumbnail() const {
 } // End of namespace Kyra
 
 #endif // ENABLE_LOL
-
