@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/script.h $
- * $Id: script.h 49069 2010-05-17 23:29:44Z lordhoto $
- *
  */
 
 #ifndef KYRA_SCRIPT_H
@@ -84,9 +81,9 @@ public:
 		// Both lead to some problems in our IFF parser, either reading after the end
 		// of file or producing a "Chunk overread" error message. To work around this
 		// we need to adjust the size field properly.
-		if (_formType == MKID_BE('EMC2'))
+		if (_formType == MKTAG('E','M','C','2'))
 			_formChunk.size -= 8;
-		else if (_formType == MKID_BE('AVFS'))
+		else if (_formType == MKTAG('A','V','F','S'))
 			_formChunk.size += 4;
 	}
 };
@@ -143,4 +140,3 @@ private:
 } // End of namespace Kyra
 
 #endif
-
