@@ -124,7 +124,7 @@ int LoLEngine::olol_setWallType(EMCState *script) {
 
 int LoLEngine::olol_getWallType(EMCState *script) {
 	debugC(3, kDebugLevelScriptFuncs, "LoLEngine::olol_getWallType(%p) (%d, %d)", (const void *)script, stackPos(0), stackPos(1));
-	return _levelBlockProperties[stackPos(0)].walls[stackPos(1) & 3];
+	return (int8)_levelBlockProperties[stackPos(0)].walls[stackPos(1) & 3];
 }
 
 int LoLEngine::olol_drawScene(EMCState *script) {
@@ -676,6 +676,8 @@ int LoLEngine::olol_getGlobalVar(EMCState *script) {
 		return _drainMagic;
 	case 13:
 		return getVolume(kVolumeSpeech) - 2;
+	case 14:
+		return _tim->_abortFlag;
 	default:
 		break;
 	}
@@ -842,7 +844,7 @@ int LoLEngine::olol_initMonster(EMCState *script) {
 		l->direction = l->facing << 1;
 		l->hitPoints = (l->properties->hitPoints * _monsterModifiers[_monsterDifficulty]) >> 8;
 
-		if (_currentLevel == 12 && l->type == 2)
+		if (_currentLevel != 12 || l->type != 2)
 			l->hitPoints = (l->hitPoints * (rollDice(1, 128) + 192)) >> 8;
 
 		l->numDistAttacks = l->properties->numDistAttacks;
@@ -859,7 +861,7 @@ int LoLEngine::olol_initMonster(EMCState *script) {
 		l->destDirection = l->direction;
 
 		for (int ii = 0; ii < 4; ii++)
-			l->equipmentShapes[ii] = stackPos(7 + ii);
+			l->equipmentShapes[ii] = stackPos(7 + ii) & 0xff;
 
 		checkSceneUpdateNeed(l->block);
 		return i;
@@ -2056,17 +2058,16 @@ int LoLEngine::olol_changeItemTypeOrFlag(EMCState *script) {
 		return 0;
 
 	ItemInPlay *i = &_itemsInPlay[stackPos(0)];
-	int r = stackPos(2) & 0x1fff;
+	int16 val = stackPos(2);
 
-	if (stackPos(1) == 4) {
-		i->itemPropertyIndex = r;
-		return r;
-	} else if (stackPos(1) == 15) {
-		i->shpCurFrame_flg = (i->shpCurFrame_flg & 0xe000) | r;
-		return r;
-	}
+	if (stackPos(1) == 4)
+		i->itemPropertyIndex = val;
+	else if (stackPos(1) == 15)
+		i->shpCurFrame_flg = (i->shpCurFrame_flg & 0xe000) | (val & 0x1fff);
+	else
+		val = -1;
 
-	return -1;
+	return val;
 }
 
 int LoLEngine::olol_placeInventoryItemInHand(EMCState *script) {
