@@ -18,16 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/script_v2.cpp $
- * $Id: script_v2.cpp 44634 2009-10-04 21:26:33Z fingolfin $
- *
  */
 
 #include "kyra/kyra_v2.h"
 #include "kyra/screen_v2.h"
 #include "kyra/timer.h"
 
-#include "common/endian.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -69,7 +66,7 @@ int KyraEngine_v2::o2_trySceneChange(EMCState *script) {
 	if (success) {
 		_emc->init(script, script->dataPtr);
 		_unk4 = 0;
-		_unk3 = -1;
+		_savedMouseState = -1;
 		_unk5 = 1;
 		return 0;
 	} else {
@@ -343,4 +340,3 @@ int KyraEngine_v2::o2a_setResetFrame(EMCState *script) {
 }
 
 } // End of namespace Kyra
-
