@@ -18,24 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/seqplayer.cpp $
- * $Id: seqplayer.cpp 49069 2010-05-17 23:29:44Z lordhoto $
- *
  */
 
+#include "kyra/seqplayer.h"
+#include "kyra/resource.h"
+#include "kyra/sound.h"
 
 #include "common/system.h"
 
-#include "engines/engine.h"
-
-#include "kyra/resource.h"
-#include "kyra/screen.h"
-#include "kyra/sound.h"
-#include "kyra/wsamovie.h"
-#include "kyra/text.h"
-
-#include "kyra/seqplayer.h"
-
 #define SEQOP(n, x) { n, &SeqPlayer::x, #x }
 
 namespace Kyra {
@@ -634,7 +624,7 @@ bool SeqPlayer::playSequence(const uint8 *seqData, bool skipSeq) {
 				if (_vm->gameFlags().lang == Common::JA_JPN)
 					charStr[1] = _vm->seqTextsTable()[_seqDisplayedText][++_seqDisplayedChar];
 				_screen->printText(charStr, _seqDisplayedTextX, 180, 0xF, 0xC);
-				_seqDisplayedTextX += _screen->getCharWidth(charStr[0]);
+				_seqDisplayedTextX += _screen->getCharWidth((uint8)charStr[0]);
 				++_seqDisplayedChar;
 
 				if (_vm->seqTextsTable()[_seqDisplayedText][_seqDisplayedChar] == '\0')
@@ -667,4 +657,3 @@ bool SeqPlayer::playSequence(const uint8 *seqData, bool skipSeq) {
 
 
 } // End of namespace Kyra
-
