@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "kyra/kyra_lok.h"
@@ -253,7 +250,7 @@ bool KyraEngine_LoK::seq_introStory() {
 	if (!textEnabled() && speechEnabled() && _flags.lang != Common::IT_ITA)
 		return false;
 
-	if ((_flags.lang == Common::EN_ANY && !_flags.isTalkie && _flags.platform == Common::kPlatformPC) || _flags.platform == Common::kPlatformAmiga)
+	if (((_flags.lang == Common::EN_ANY || _flags.lang == Common::RU_RUS) && !_flags.isTalkie && _flags.platform == Common::kPlatformPC) || _flags.platform == Common::kPlatformAmiga)
 		_screen->loadBitmap("TEXT.CPS", 3, 3, &_screen->getPalette(0));
 	else if (_flags.lang == Common::EN_ANY || _flags.lang == Common::JA_JPN)
 		_screen->loadBitmap("TEXT_ENG.CPS", 3, 3, &_screen->getPalette(0));
@@ -1325,7 +1322,7 @@ void KyraEngine_LoK::seq_playCredits() {
 			_screen->copyRegion(0, 32, 0, 32, 320, 128, 4, 2, Screen::CR_NO_P_CHECK);
 			bottom = 0;
 
-			for (CreditsLineList::iterator it = lines.begin(); it != lines.end(); ++it) {
+			for (CreditsLineList::iterator it = lines.begin(); it != lines.end();) {
 				if (it->y < 0) {
 					it = lines.erase(it);
 					continue;
@@ -1341,6 +1338,8 @@ void KyraEngine_LoK::seq_playCredits() {
 				it->y--;
 				if (it->y > bottom)
 					bottom = it->y;
+
+				++it;
 			}
 
 			_screen->copyRegion(0, 32, 0, 32, 320, 128, 2, 0, Screen::CR_NO_P_CHECK);
@@ -2115,4 +2114,3 @@ void KyraEngine_LoK::drawJewelsFadeOutEnd(int jewel) {
 }
 
 } // End of namespace Kyra
-
