@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifdef ENABLE_LOL
@@ -205,7 +202,6 @@ void LoLEngine::setupPrologueData(bool load) {
 void LoLEngine::showIntro() {
 	_tim = new TIMInterpreter(this, _screen, _system);
 	assert(_tim);
-	_animator = _tim->animator();
 
 	if (_flags.platform == Common::kPlatformPC98)
 		showStarcraftLogo();
@@ -265,7 +261,6 @@ void LoLEngine::showIntro() {
 
 	delete _tim;
 	_tim = 0;
-	_animator = 0;
 
 	_screen->fadePalette(_screen->getPalette(1), 30, 0);
 }
@@ -273,7 +268,6 @@ void LoLEngine::showIntro() {
 int LoLEngine::chooseCharacter() {
 	_tim = new TIMInterpreter(this, _screen, _system);
 	assert(_tim);
-	_animator = _tim->animator();
 
 	_tim->setLangData("LOLINTRO.DIP");
 
@@ -312,9 +306,8 @@ int LoLEngine::chooseCharacter() {
 
 			Screen::FontId old = _screen->setFont(Screen::FID_SJIS_FNT);
 			for (int j = 0; j < 3; ++j) {
-				char buffer[3];
-				snprintf(buffer, sizeof(buffer), "%2d", _charPreviews[i].attrib[j]);
-				_screen->printText(buffer, _charPosXPC98[i] + 16, 176 + j * 8, 0x81, 0x00);
+				Common::String attribString = Common::String::format("%2d", _charPreviews[i].attrib[j]);
+				_screen->printText(attribString.c_str(), _charPosXPC98[i] + 16, 176 + j * 8, 0x81, 0x00);
 			}
 			_screen->setFont(old);
 		}
@@ -323,8 +316,9 @@ int LoLEngine::chooseCharacter() {
 		_screen->printText(_tim->getCTableEntry(53), 72, 184, 0x81, 0x00);
 		_screen->printText(_tim->getCTableEntry(55), 72, 192, 0x81, 0x00);
 	} else {
+		const char *const *previewNames = (_flags.lang == Common::RU_RUS && !_flags.isTalkie) ? _charPreviewNamesRussianFloppy : _charPreviewNamesDefault;
 		for (int i = 0; i < 4; ++i) {
-			_screen->fprintStringIntro("%s", _charPreviews[i].x + 16, _charPreviews[i].y + 36, 0xC0, 0x00, 0x9C, 0x120, _charPreviews[i].name);
+			_screen->fprintStringIntro("%s", _charPreviews[i].x + 16, _charPreviews[i].y + 36, 0xC0, 0x00, 0x9C, 0x120, previewNames[i]);
 			_screen->fprintStringIntro("%d", _charPreviews[i].x + 21, _charPreviews[i].y + 48, 0x98, 0x00, 0x9C, 0x220, _charPreviews[i].attrib[0]);
 			_screen->fprintStringIntro("%d", _charPreviews[i].x + 21, _charPreviews[i].y + 56, 0x98, 0x00, 0x9C, 0x220, _charPreviews[i].attrib[1]);
 			_screen->fprintStringIntro("%d", _charPreviews[i].x + 21, _charPreviews[i].y + 64, 0x98, 0x00, 0x9C, 0x220, _charPreviews[i].attrib[2]);
@@ -390,7 +384,6 @@ int LoLEngine::chooseCharacter() {
 
 	delete _tim;
 	_tim = 0;
-	_animator = 0;
 
 	return _charSelection;
 }
@@ -1064,7 +1057,6 @@ void LoLEngine::showOutro(int character, bool maxDifficulty) {
 	setupEpilogueData(true);
 	TIMInterpreter *timBackUp = _tim;
 	_tim = new TIMInterpreter(this, _screen, _system);
-	_animator = _tim->animator();
 
 	_screen->getPalette(0).clear();
 	_screen->setScreenPalette(_screen->getPalette(0));
@@ -1120,47 +1112,49 @@ void LoLEngine::showOutro(int character, bool maxDifficulty) {
 
 	_screen->fadeToBlack(30);
 
-	showCredits();
+	if (!shouldQuit())
+		showCredits();
 
 	_eventList.clear();
 
-	switch (character) {
-	case 0:
-		_screen->loadBitmap("KIERAN.CPS", 3, 3, &_screen->getPalette(0));
-		break;
+	if (!shouldQuit()) {
+		switch (character) {
+		case 0:
+			_screen->loadBitmap("KIERAN.CPS", 3, 3, &_screen->getPalette(0));
+			break;
 
-	case 1:
-		_screen->loadBitmap("AK'SHEL.CPS", 3, 3, &_screen->getPalette(0));
-		break;
+		case 1:
+			_screen->loadBitmap("AK'SHEL.CPS", 3, 3, &_screen->getPalette(0));
+			break;
 
-	case 2:
-		_screen->loadBitmap("MICHAEL.CPS", 3, 3, &_screen->getPalette(0));
-		break;
+		case 2:
+			_screen->loadBitmap("MICHAEL.CPS", 3, 3, &_screen->getPalette(0));
+			break;
 
-	case 3:
-		_screen->loadBitmap("CONRAD.CPS", 3, 3, &_screen->getPalette(0));
-		break;
+		case 3:
+			_screen->loadBitmap("CONRAD.CPS", 3, 3, &_screen->getPalette(0));
+			break;
 
-	default:
-		_screen->clearPage(3);
-		_screen->getPalette(0).clear();
+		default:
+			_screen->clearPage(3);
+			_screen->getPalette(0).clear();
+		}
+
+		_screen->copyRegion(0, 0, 0, 0, 320, 200, 2, 0, Screen::CR_NO_P_CHECK);
+		if (maxDifficulty && !_flags.use16ColorMode)
+			_tim->displayText(0x8000, 0, 0xDC);
+		_screen->updateScreen();
+		_screen->fadePalette(_screen->getPalette(0), 30, 0);
+
+		while (!checkInput(0) && !shouldQuit())
+			delay(_tickLength);
+
+		_screen->fadeToBlack(30);
 	}
 
-	_screen->copyRegion(0, 0, 0, 0, 320, 200, 2, 0, Screen::CR_NO_P_CHECK);
-	if (maxDifficulty && !_flags.use16ColorMode)
-		_tim->displayText(0x8000, 0, 0xDC);
-	_screen->updateScreen();
-	_screen->fadePalette(_screen->getPalette(0), 30, 0);
-
-	while (!checkInput(0) && !shouldQuit())
-		delay(_tickLength);
-
-	_screen->fadeToBlack(30);
-
 	_tim->clearLangData();
 	delete _tim;
 	_tim = timBackUp;
-	_animator = 0;
 
 	setupEpilogueData(false);
 }
@@ -1248,7 +1242,7 @@ void LoLEngine::processCredits(char *t, int dimState, int page, int delayTime) {
 
 	int curShapeFile = 0;
 	uint8 *shapes[12];
-	memset(&shapes, 0, sizeof(shapes));
+	memset(shapes, 0, sizeof(shapes));
 
 	loadOutroShapes(curShapeFile++, shapes);
 	uint8 *monsterPal = 0;
@@ -1525,4 +1519,3 @@ void LoLEngine::loadOutroShapes(int file, uint8 **storage) {
 } // End of namespace Kyra
 
 #endif // ENABLE_LOL
-
