@@ -18,19 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sound_amiga.cpp $
- * $Id: sound_amiga.cpp 49069 2010-05-17 23:29:44Z lordhoto $
- *
  */
 
-#include "common/system.h"
-#include "common/mutex.h"
-#include "kyra/resource.h"
 #include "kyra/sound_intern.h"
+#include "kyra/resource.h"
 
-#include "sound/mixer.h"
-#include "sound/mods/maxtrax.h"
-#include "sound/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/mods/maxtrax.h"
 
 namespace Kyra {
 
@@ -220,4 +214,3 @@ void SoundAmiga::playSoundEffect(uint8 track) {
 }
 
 } // End of namespace Kyra
-
