@@ -18,20 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sound_digital.cpp $
- * $Id: sound_digital.cpp 52699 2010-09-13 12:19:19Z lordhoto $
- *
  */
 
 #include "kyra/sound.h"
 #include "kyra/resource.h"
 #include "kyra/kyra_mr.h"
 
-#include "sound/audiostream.h"
+#include "audio/audiostream.h"
 
-#include "sound/decoders/mp3.h"
-#include "sound/decoders/vorbis.h"
-#include "sound/decoders/flac.h"
+#include "audio/decoders/mp3.h"
+#include "audio/decoders/vorbis.h"
+#include "audio/decoders/flac.h"
 
 namespace Kyra {
 
@@ -547,4 +544,3 @@ const SoundDigital::AudioCodecs SoundDigital::_supportedCodecs[] = {
 
 
 } // End of namespace Kyra
-
