@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/sound_intern.h $
- * $Id: sound_intern.h 51695 2010-08-03 14:58:01Z athrxx $
- *
  */
 
 #ifndef KYRA_SOUND_INTERN_H
@@ -31,11 +28,11 @@
 
 #include "common/mutex.h"
 
-#include "sound/softsynth/fmtowns_pc98/towns_pc98_driver.h"
-#include "sound/softsynth/fmtowns_pc98/towns_euphony.h"
+#include "audio/softsynth/fmtowns_pc98/towns_pc98_driver.h"
+#include "audio/softsynth/fmtowns_pc98/towns_euphony.h"
 
-#include "sound/softsynth/emumidi.h"
-#include "sound/midiparser.h"
+#include "audio/softsynth/emumidi.h"
+#include "audio/midiparser.h"
 
 namespace Audio {
 class PCSpeaker;
@@ -68,12 +65,14 @@ public:
 
 	void playTrack(uint8 track);
 	void haltTrack();
-	bool isPlaying();
+	bool isPlaying() const;
 
 	void playSoundEffect(uint8 track);
 	void stopAllSoundEffects();
 
 	void beginFadeOut();
+
+	void pause(bool paused);
 private:
 	static void onTimer(void *data);
 
@@ -141,8 +140,6 @@ private:
 	uint8 _sfxChannel;
 
 	TownsEuphonyDriver *_driver;
-	
-	Common::Mutex _mutex;
 
 	bool _cdaPlaying;
 
@@ -219,12 +216,12 @@ public:
 	~MidiDriver_PCSpeaker();
 
 	// MidiDriver interface
-	void close() {}
+	virtual void close() {}
 
-	void send(uint32 data);
+	virtual void send(uint32 data);
 
-	MidiChannel *allocateChannel() { return 0; }
-	MidiChannel *getPercussionChannel() { return 0; }
+	virtual MidiChannel *allocateChannel() { return 0; }
+	virtual MidiChannel *getPercussionChannel() { return 0; }
 
 	// MidiDriver_Emulated interface
 	void generateSamples(int16 *buffer, int numSamples);
