@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "kyra/resource.h"
@@ -41,7 +38,7 @@
 
 namespace Kyra {
 
-#define RESFILE_VERSION 73
+#define RESFILE_VERSION 78
 
 namespace {
 bool checkKyraDat(Common::SeekableReadStream *file) {
@@ -83,7 +80,7 @@ const IndexTable iGameTable[] = {
 };
 
 byte getGameID(const GameFlags &flags) {
-	return Common::find(iGameTable, iGameTable + ARRAYSIZE(iGameTable) - 1, flags.gameID)->value;
+	return Common::find(iGameTable, ARRAYEND(iGameTable) - 1, flags.gameID)->value;
 }
 
 const IndexTable iLanguageTable[] = {
@@ -93,11 +90,12 @@ const IndexTable iLanguageTable[] = {
 	{ Common::ES_ESP, 4 },
 	{ Common::IT_ITA, 5 },
 	{ Common::JA_JPN, 6 },
+	{ Common::RU_RUS, 7 },
 	{ -1, -1 }
 };
 
 byte getLanguageID(const GameFlags &flags) {
-	return Common::find(iLanguageTable, iLanguageTable + ARRAYSIZE(iLanguageTable) - 1, flags.lang)->value;
+	return Common::find(iLanguageTable, ARRAYEND(iLanguageTable) - 1, flags.lang)->value;
 }
 
 const IndexTable iPlatformTable[] = {
@@ -110,11 +108,13 @@ const IndexTable iPlatformTable[] = {
 };
 
 byte getPlatformID(const GameFlags &flags) {
-	return Common::find(iPlatformTable, iPlatformTable + ARRAYSIZE(iPlatformTable) - 1, flags.platform)->value;
+	return Common::find(iPlatformTable, ARRAYEND(iPlatformTable) - 1, flags.platform)->value;
 }
 
 byte getSpecialID(const GameFlags &flags) {
-	if (flags.isDemo && flags.isTalkie)
+	if (flags.isOldFloppy)
+		return 4;
+	else if (flags.isDemo && flags.isTalkie)
 		return 3;
 	else if (flags.isDemo)
 		return 2;
@@ -751,7 +751,17 @@ void KyraEngine_LoK::initStaticResource() {
 
 	_storyStrings = _staticres->loadStrings(k1PC98StoryStrings, _storyStringsSize);
 
-	_soundFiles = _staticres->loadStrings(k1AudioTracks, _soundFilesSize);
+	int size1, size2;
+	const char *const *soundfiles1 = _staticres->loadStrings(k1AudioTracks, size1);
+	const char *const *soundfiles2 = _staticres->loadStrings(k1AudioTracks2, size2);
+	_soundFilesSize = size1 + size2;
+	if (_soundFilesSize) {
+		delete[] _soundFiles;
+		const char **soundfiles = new const char*[_soundFilesSize];
+		for (int i = 0; i < _soundFilesSize; i++)
+			soundfiles[i] = (i < size1) ? soundfiles1[i] : soundfiles2[i - size1];
+		_soundFiles = soundfiles;
+	}
 	_soundFilesIntro = _staticres->loadStrings(k1AudioTracksIntro, _soundFilesIntroSize);
 	_cdaTrackTable = (const int32 *)_staticres->loadRawData(k1TownsCDATable, _cdaTrackTableSize);
 
@@ -784,8 +794,8 @@ void KyraEngine_LoK::initStaticResource() {
 	}
 
 	// audio data tables
-	static const char *tIntro98[] = { "INTRO%d.DAT" };
-	static const char *tIngame98[] = { "KYRAM%d.DAT" };
+	static const char *const tIntro98[] = { "INTRO%d.DAT" };
+	static const char *const tIngame98[] = { "KYRAM%d.DAT" };
 
 	// FIXME: It seems Kyra1 MAC CD includes AdLib and MIDI music and sfx, thus we enable
 	// support for those for now. (Based on patch #2767489 "Support for Mac Kyrandia 1 CD" by satz).
@@ -929,7 +939,7 @@ void KyraEngine_LoK::loadButtonShapes() {
 void KyraEngine_LoK::loadMainScreen(int page) {
 	_screen->clearPage(page);
 
-	if ((_flags.lang == Common::EN_ANY && !_flags.isTalkie && _flags.platform == Common::kPlatformPC) || _flags.platform == Common::kPlatformAmiga)
+	if (((_flags.lang == Common::EN_ANY || _flags.lang == Common::RU_RUS) && !_flags.isTalkie && _flags.platform == Common::kPlatformPC) || _flags.platform == Common::kPlatformAmiga)
 		_screen->loadBitmap("MAIN15.CPS", page, page, &_screen->getPalette(0));
 	else if (_flags.lang == Common::EN_ANY || _flags.lang == Common::JA_JPN || (_flags.isTalkie && _flags.lang == Common::IT_ITA))
 		_screen->loadBitmap("MAIN_ENG.CPS", page, page, 0);
@@ -1001,13 +1011,13 @@ void KyraEngine_HoF::initStaticResource() {
 	_sequenceSoundList = tmpSndLst;
 
 	// assign music data
-	static const char *fmtMusicFileListIntro[] = { "intro%d.twn" };
-	static const char *fmtMusicFileListFinale[] = { "finale%d.twn" };
-	static const char *fmtMusicFileListIngame[] = { "km%02d.twn" };
+	static const char *const fmtMusicFileListIntro[] = { "intro%d.twn" };
+	static const char *const fmtMusicFileListFinale[] = { "finale%d.twn" };
+	static const char *const fmtMusicFileListIngame[] = { "km%02d.twn" };
 
-	static const char *pc98MusicFileListIntro[] = { "intro%d.86" };
-	static const char *pc98MusicFileListFinale[] = { "finale%d.86" };
-	static const char *pc98MusicFileListIngame[] = { "km%02d.86" };
+	static const char *const pc98MusicFileListIntro[] = { "intro%d.86" };
+	static const char *const pc98MusicFileListFinale[] = { "finale%d.86" };
+	static const char *const pc98MusicFileListIngame[] = { "km%02d.86" };
 
 	memset(_soundData, 0, sizeof(_soundData));
 	if (_flags.platform == Common::kPlatformPC) {
@@ -1377,7 +1387,7 @@ const int GUI_v2::_sliderBarsPosition[] = {
 
 const uint8 KyraEngine_HoF::_seqTextColorPresets[] = { 0x01, 0x01, 0x00, 0x3f, 0x3f, 0x3f };
 
-const char *KyraEngine_HoF::_languageExtension[] = {
+const char *const KyraEngine_HoF::_languageExtension[] = {
 	"ENG",
 	"FRE",
 	"GER",/*,
@@ -1386,7 +1396,7 @@ const char *KyraEngine_HoF::_languageExtension[] = {
 	"JPN",
 };
 
-const char *KyraEngine_HoF::_scriptLangExt[] = {
+const char *const KyraEngine_HoF::_scriptLangExt[] = {
 	"EMC",
 	"FMC",
 	"GMC",/*,
@@ -1875,7 +1885,7 @@ const uint8 KyraEngine_HoF::_rainbowRoomData[] = {
 
 // kyra 3 static res
 
-const char *KyraEngine_MR::_languageExtension[] = {
+const char *const KyraEngine_MR::_languageExtension[] = {
 	"TRE",
 	"TRF",
 	"TRG"/*,
@@ -2132,4 +2142,3 @@ const int8 KyraEngine_MR::_albumWSAY[] = {
 };
 
 } // End of namespace Kyra
-
