@@ -18,17 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/text_hof.cpp $
- * $Id: text_hof.cpp 51757 2010-08-05 14:41:00Z lordhoto $
- *
  */
 
 #include "kyra/text_hof.h"
-#include "kyra/kyra_hof.h"
-#include "kyra/script_tim.h"
 #include "kyra/resource.h"
 
-#include "common/endian.h"
+#include "common/system.h"
 
 namespace Kyra {
 
@@ -199,7 +194,7 @@ void KyraEngine_HoF::objectChat(const char *str, int object, int vocHigh, int vo
 	assert(_mainCharacter.facing * 3 + chatType < ARRAYSIZE(talkScriptTable));
 	int script = talkScriptTable[_mainCharacter.facing * 3 + chatType];
 
-	static const char *chatScriptFilenames[] = {
+	static const char *const chatScriptFilenames[] = {
 		"_Z1FSTMT.EMC",
 		"_Z1FQUES.EMC",
 		"_Z1FEXCL.EMC",
@@ -441,15 +436,16 @@ void KyraEngine_HoF::updateDlgBuffer() {
 	_npcTalkChpIndex = _currentChapter;
 	_npcTalkDlgIndex = _mainCharacter.dlgIndex;
 
-	char filename[13];
-	snprintf(filename, 13, "CH%.02d-S%.02d.DLG", _currentChapter, _npcTalkDlgIndex);
+	Common::String filename = Common::String::format("CH%.02d-S%.02d.DL", _currentChapter, _npcTalkDlgIndex);
 
 	const char *suffix = _flags.isTalkie ? suffixTalkie : suffixTowns;
 	if (_flags.platform != Common::kPlatformPC || _flags.isTalkie)
-		filename[11] = suffix[_lang];
+		filename += suffix[_lang];
+	else
+		filename += 'G';
 
 	delete[] _dlgBuffer;
-	_dlgBuffer = _res->fileData(filename, 0);
+	_dlgBuffer = _res->fileData(filename.c_str(), 0);
 }
 
 void KyraEngine_HoF::loadDlgHeader(int &csEntry, int &vocH, int &scIndex1, int &scIndex2) {
@@ -544,7 +540,7 @@ void KyraEngine_HoF::processDialogue(int dlgOffset, int vocH, int csEntry) {
 					}
 					objectChat((const char *)_unkBuf500Bytes, 0, vocHi, vocLo);
 				} else {
-					if (activeTimSequence != nextTimSequence ) {
+					if (activeTimSequence != nextTimSequence) {
 						if (activeTimSequence > -1) {
 							deinitTalkObject(activeTimSequence);
 							activeTimSequence = -1;
