@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/text_lol.h $
- * $Id: text_lol.h 44634 2009-10-04 21:26:33Z fingolfin $
- *
  */
 
 #ifdef ENABLE_LOL
@@ -28,9 +25,11 @@
 #ifndef KYRA_TEXT_LOL_H
 #define KYRA_TEXT_LOL_H
 
+#include "common/scummsys.h"
+
 namespace Kyra {
 
-class Screen_v2;
+class Screen_LoL;
 class LoLEngine;
 struct EMCState;
 
@@ -90,7 +89,7 @@ private:
 		uint8 line;
 	};
 
-	TextDimData _textDimData[14];
+	TextDimData *_textDimData;
 };
 
 } // End of namespace Kyra
@@ -98,4 +97,3 @@ private:
 #endif
 
 #endif // ENABLE_LOL
-
