@@ -18,15 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/text_mr.cpp $
- * $Id: text_mr.cpp 51757 2010-08-05 14:41:00Z lordhoto $
- *
  */
 
 #include "kyra/text_mr.h"
-#include "kyra/screen_mr.h"
 #include "kyra/resource.h"
 
+#include "common/system.h"
+
 namespace Kyra {
 
 TextDisplayer_MR::TextDisplayer_MR(KyraEngine_MR *vm, Screen_MR *screen)
@@ -218,7 +216,7 @@ void KyraEngine_MR::objectChat(const char *str, int object, int vocHigh, int voc
 		0x08, 0x09, 0x0A, 0x0B
 	};
 
-	static const char *talkFilenameTable[] = {
+	static const char *const talkFilenameTable[] = {
 		"MTFL00S.EMC", "MTFL00Q.EMC", "MTFL00E.EMC", "MTFL00T.EMC",
 		"MTFR00S.EMC", "MTFR00Q.EMC", "MTFR00E.EMC", "MTFR00T.EMC",
 		 "MTL00S.EMC",  "MTL00Q.EMC",  "MTL00E.EMC",  "MTL00T.EMC",
@@ -340,10 +338,8 @@ void KyraEngine_MR::objectChatWaitToFinish() {
 			_emc->start(&_chatScriptState, 1);
 
 		_animNeedUpdate = false;
-		while (!_animNeedUpdate && _emc->isValid(&_chatScriptState) && !shouldQuit()) {
-			musicUpdate(0);
+		while (!_animNeedUpdate && _emc->isValid(&_chatScriptState) && !shouldQuit())
 			_emc->run(&_chatScriptState);
-		}
 
 		int curFrame = _animNewFrame;
 		uint32 delayTime = _animDelayTime;
@@ -629,24 +625,20 @@ void KyraEngine_MR::malcolmSceneStartupChat() {
 }
 
 void KyraEngine_MR::updateDlgBuffer() {
-	char dlgFile[16];
-	char cnvFile[16];
-
 	if (_cnvFile)
 		_cnvFile->seek(0, SEEK_SET);
 
 	if (_curDlgIndex == _mainCharacter.dlgIndex && _curDlgChapter == _currentChapter && _curDlgLang == _lang)
 		return;
 
-	snprintf(dlgFile, 16, "CH%.02d-S%.02d.", _currentChapter, _mainCharacter.dlgIndex);
-	appendLanguage(dlgFile, _lang, 16);
-	snprintf(cnvFile, 16, "CH%.02d-S%.02d.CNV", _currentChapter, _mainCharacter.dlgIndex);
+	Common::String dlgFile = Common::String::format("CH%.02d-S%.02d.%s", _currentChapter, _mainCharacter.dlgIndex, _languageExtension[_lang]);
+	Common::String cnvFile = Common::String::format("CH%.02d-S%.02d.CNV", _currentChapter, _mainCharacter.dlgIndex);
 
 	delete _cnvFile;
 	delete _dlgBuffer;
 
-	_res->exists(cnvFile, true);
-	_res->exists(dlgFile, true);
+	_res->exists(cnvFile.c_str(), true);
+	_res->exists(dlgFile.c_str(), true);
 	_cnvFile = _res->createReadStream(cnvFile);
 	_dlgBuffer = _res->createReadStream(dlgFile);
 	assert(_cnvFile);
@@ -860,7 +852,7 @@ void KyraEngine_MR::randomSceneChat() {
 	processDialog(vocHighIndex, vocHighBase, 0);
 }
 
-void KyraEngine_MR::runDialog(int dlgIndex, int funcNum) {
+void KyraEngine_MR::doDialog(int dlgIndex, int funcNum) {
 	switch (_currentChapter-2) {
 	case 0:
 		dlgIndex -= 34;
@@ -906,4 +898,3 @@ void KyraEngine_MR::runDialog(int dlgIndex, int funcNum) {
 }
 
 } // End of namespace Kyra
-
