@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/kyra/vqa.cpp $
- * $Id: vqa.cpp 51187 2010-07-23 00:39:23Z lordhoto $
- *
  */
 
 // Player for Kyrandia 3 VQA movies, based on the information found at
@@ -33,15 +30,13 @@
 
 
 #include "kyra/vqa.h"
+#include "kyra/resource.h"
 
 #include "common/system.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
-#include "sound/decoders/raw.h"
 
-#include "kyra/sound.h"
-#include "kyra/screen.h"
-#include "kyra/resource.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
+#include "audio/decoders/raw.h"
 
 namespace Kyra {
 
@@ -106,6 +101,9 @@ uint32 VQAMovie::readTag() {
 
 	uint32 tag = _file->readUint32BE();
 
+	if (_file->eos())
+		return 0;
+
 	if (!(tag & 0xFF000000)) {
 		tag = (tag << 8) | _file->readByte();
 	}
@@ -201,7 +199,7 @@ bool VQAMovie::open(const char *filename) {
 	if (!_file)
 		return false;
 
-	if (_file->readUint32BE() != MKID_BE('FORM')) {
+	if (_file->readUint32BE() != MKTAG('F','O','R','M')) {
 		warning("VQAMovie::open: Cannot find `FORM' tag");
 		return false;
 	}
@@ -209,7 +207,7 @@ bool VQAMovie::open(const char *filename) {
 	// For now, we ignore the size of the FORM chunk.
 	_file->readUint32BE();
 
-	if (_file->readUint32BE() != MKID_BE('WVQA')) {
+	if (_file->readUint32BE() != MKTAG('W','V','Q','A')) {
 		warning("WQAMovie::open: Cannot find `WVQA' tag");
 		return false;
 	}
@@ -225,7 +223,7 @@ bool VQAMovie::open(const char *filename) {
 		uint32 size = _file->readUint32BE();
 
 		switch (tag) {
-		case MKID_BE('VQHD'):	// VQA header
+		case MKTAG('V','Q','H','D'):	// VQA header
 			_header.version     = _file->readUint16LE();
 			_header.flags       = _file->readUint16LE();
 			_header.numFrames   = _file->readUint16LE();
@@ -301,7 +299,7 @@ bool VQAMovie::open(const char *filename) {
 			foundHeader = true;
 			break;
 
-		case MKID_BE('FINF'):	// Frame info
+		case MKTAG('F','I','N','F'):	// Frame info
 			if (!foundHeader) {
 				warning("VQAMovie::open: Found `FINF' before `VQHD'");
 				return false;
@@ -340,7 +338,7 @@ bool VQAMovie::open(const char *filename) {
 					if (_file->eos())
 						break;
 
-					if (scanTag == MKID_BE('VQFR')) {
+					if (scanTag == MKTAG('V','Q','F','R')) {
 						_frameInfo[0] = (_file->pos() - 8) | 0x80000000;
 						break;
 					}
@@ -418,7 +416,7 @@ void VQAMovie::displayFrame(uint frameNum) {
 		int32 end;
 
 		switch (tag) {
-		case MKID_BE('SND0'):	// Uncompressed sound
+		case MKTAG('S','N','D','0'):	// Uncompressed sound
 			foundSound = true;
 			inbuf = (byte *)malloc(size);
 			_file->read(inbuf, size);
@@ -426,7 +424,7 @@ void VQAMovie::displayFrame(uint frameNum) {
 			_stream->queueBuffer(inbuf, size, DisposeAfterUse::YES, Audio::FLAG_UNSIGNED);
 			break;
 
-		case MKID_BE('SND1'):	// Compressed sound, almost like AUD
+		case MKTAG('S','N','D','1'):	// Compressed sound, almost like AUD
 			foundSound = true;
 			outsize = _file->readUint16LE();
 			insize = _file->readUint16LE();
@@ -446,13 +444,13 @@ void VQAMovie::displayFrame(uint frameNum) {
 			}
 			break;
 
-		case MKID_BE('SND2'):	// Compressed sound
+		case MKTAG('S','N','D','2'):	// Compressed sound
 			foundSound = true;
 			warning("VQAMovie::displayFrame: `SND2' is not implemented");
 			_file->seek(size, SEEK_CUR);
 			break;
 
-		case MKID_BE('VQFR'):
+		case MKTAG('V','Q','F','R'):
 			foundFrame = true;
 			end = _file->pos() + size - 8;
 
@@ -461,49 +459,49 @@ void VQAMovie::displayFrame(uint frameNum) {
 				size = _file->readUint32BE();
 
 				switch (tag) {
-				case MKID_BE('CBF0'):	// Full codebook
+				case MKTAG('C','B','F','0'):	// Full codebook
 					_file->read(_codeBook, size);
 					break;
 
-				case MKID_BE('CBFZ'):	// Full codebook
+				case MKTAG('C','B','F','Z'):	// Full codebook
 					inbuf = (byte *)allocBuffer(0, size);
 					_file->read(inbuf, size);
 					Screen::decodeFrame4(inbuf, _codeBook, _codeBookSize);
 					break;
 
-				case MKID_BE('CBP0'):	// Partial codebook
+				case MKTAG('C','B','P','0'):	// Partial codebook
 					_compressedCodeBook = false;
 					_file->read(_partialCodeBook + _partialCodeBookSize, size);
 					_partialCodeBookSize += size;
 					_numPartialCodeBooks++;
 					break;
 
-				case MKID_BE('CBPZ'):	// Partial codebook
+				case MKTAG('C','B','P','Z'):	// Partial codebook
 					_compressedCodeBook = true;
 					_file->read(_partialCodeBook + _partialCodeBookSize, size);
 					_partialCodeBookSize += size;
 					_numPartialCodeBooks++;
 					break;
 
-				case MKID_BE('CPL0'):	// Palette
+				case MKTAG('C','P','L','0'):	// Palette
 					assert(size <= 3 * 256);
 					_file->read(_screen->getPalette(0).getData(), size);
 					break;
 
-				case MKID_BE('CPLZ'):	// Palette
+				case MKTAG('C','P','L','Z'):	// Palette
 					inbuf = (byte *)allocBuffer(0, size);
 					_file->read(inbuf, size);
 					Screen::decodeFrame4(inbuf, _screen->getPalette(0).getData(), 768);
 					break;
 
-				case MKID_BE('VPT0'):	// Frame data
+				case MKTAG('V','P','T','0'):	// Frame data
 					assert(size / 2 <= _numVectorPointers);
 
 					for (i = 0; i < size / 2; i++)
 						_vectorPointers[i] = _file->readUint16LE();
 					break;
 
-				case MKID_BE('VPTZ'):	// Frame data
+				case MKTAG('V','P','T','Z'):	// Frame data
 					inbuf = (byte *)allocBuffer(0, size);
 					outbuf = (byte *)allocBuffer(1, 2 * _numVectorPointers);
 
@@ -610,13 +608,13 @@ void VQAMovie::play() {
 			}
 
 			switch (tag) {
-			case MKID_BE('SND0'):	// Uncompressed sound
+			case MKTAG('S','N','D','0'):	// Uncompressed sound
 				inbuf = (byte *)malloc(size);
 				_file->read(inbuf, size);
 				_stream->queueBuffer(inbuf, size, DisposeAfterUse::YES, Audio::FLAG_UNSIGNED);
 				break;
 
-			case MKID_BE('SND1'):	// Compressed sound
+			case MKTAG('S','N','D','1'):	// Compressed sound
 				outsize = _file->readUint16LE();
 				insize = _file->readUint16LE();
 
@@ -633,12 +631,12 @@ void VQAMovie::play() {
 				}
 				break;
 
-			case MKID_BE('SND2'):	// Compressed sound
+			case MKTAG('S','N','D','2'):	// Compressed sound
 				warning("VQAMovie::play: `SND2' is not implemented");
 				_file->seek(size, SEEK_CUR);
 				break;
 
-			case MKID_BE('CMDS'):	// Unused tag, always empty in kyra3
+			case MKTAG('C','M','D','S'):	// Unused tag, always empty in kyra3
 				_file->seek(size, SEEK_CUR);
 				break;
 
