@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/entities/august.h"
@@ -36,9 +33,11 @@
 #include "lastexpress/game/object.h"
 #include "lastexpress/game/savepoint.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/helpers.h"
 #include "lastexpress/lastexpress.h"
 
@@ -202,7 +201,7 @@ IMPLEMENT_FUNCTION_END
 
 //////////////////////////////////////////////////////////////////////////
 IMPLEMENT_FUNCTION_S(13, August, playSound16)
-	Entity::playSound(savepoint, false, SoundManager::kFlagDefault);
+	Entity::playSound(savepoint, false, kFlagDefault);
 IMPLEMENT_FUNCTION_END
 
 //////////////////////////////////////////////////////////////////////////
@@ -341,7 +340,7 @@ IMPLEMENT_FUNCTION_II(19, August, function19, bool, bool)
 	case kAction1:
 		getData()->inventoryItem = kItemNone;
 		getSound()->playSound(kEntityPlayer, "CAT1002");
-		getSound()->playSound(kEntityAugust, "AUG3101", SoundManager::kFlagInvalid, 15);
+		getSound()->playSound(kEntityAugust, "AUG3101", kFlagInvalid, 15);
 		break;
 
 	case kActionDefault:
@@ -1430,7 +1429,7 @@ IMPLEMENT_FUNCTION(29, August, function29)
 		if (getState()->time < kTime1134000) {
 
 			if (!getEntities()->isInRestaurant(kEntityPlayer)
-			 || getSound()->isBuffered("MRB1076") || getSound()->isBuffered("MRB1078") || getSound()->isBuffered("MRB1078A"))
+			 || getSoundQueue()->isBuffered("MRB1076") || getSoundQueue()->isBuffered("MRB1078") || getSoundQueue()->isBuffered("MRB1078A"))
 				params->param3 = (uint)getState()->time + 225;
 
 			if (params->param3 > getState()->time)
@@ -1765,7 +1764,7 @@ IMPLEMENT_FUNCTION(34, August, function34)
 		break;
 
 	case kActionNone:
-		if (!getSound()->isBuffered(kEntityAugust) && getProgress().field_18 != 4)
+		if (!getSoundQueue()->isBuffered(kEntityAugust) && getProgress().field_18 != 4)
 			getSound()->playSound(kEntityAugust, "AUG1057");    // August snoring
 		break;
 
@@ -2182,11 +2181,11 @@ IMPLEMENT_FUNCTION_III(42, August, function42, CarIndex, EntityPosition, bool)
 		getData()->inventoryItem = kItemNone;
 
 		getSound()->playSound(kEntityPlayer, "CAT1002");
-		getSound()->playSound(kEntityAugust, getEvent(kEventAugustBringBriefcase) ? "AUG3103" : "AUG3100", SoundManager::kFlagInvalid, 15);
+		getSound()->playSound(kEntityAugust, getEvent(kEventAugustBringBriefcase) ? "AUG3103" : "AUG3100", kFlagInvalid, 15);
 		break;
 
 	case kActionExcuseMe:
-		if (!getSound()->isBuffered(kEntityAugust))
+		if (!getSoundQueue()->isBuffered(kEntityAugust))
 			getSound()->excuseMe(kEntityAugust);
 		break;
 
@@ -2388,7 +2387,7 @@ IMPLEMENT_FUNCTION(45, August, function45)
 	case kAction1:
 		getData()->inventoryItem = kItemNone;
 		getSound()->playSound(kEntityPlayer, "CAT1002");
-		getSound()->playSound(kEntityAugust, "AUG3102", SoundManager::kFlagInvalid, 15);
+		getSound()->playSound(kEntityAugust, "AUG3102", kFlagInvalid, 15);
 		break;
 
 	case kActionDefault:
@@ -3346,7 +3345,7 @@ IMPLEMENT_FUNCTION(65, August, function65)
 
 		getObjects()->update(kObjectCompartment3, kEntityPlayer, kObjectLocation1, kCursorHandKnock, kCursorHand);
 
-		if (!getSound()->isBuffered(kEntityAugust))
+		if (!getSoundQueue()->isBuffered(kEntityAugust))
 			getSound()->playSound(kEntityAugust, "AUG1057");   // August snoring
 		break;
 	}
@@ -3507,9 +3506,9 @@ IMPLEMENT_FUNCTION(69, August, unhookCars)
 		break;
 
 	case kActionDefault:
-		getSound()->processEntries();
-		if (getSound()->isBuffered("ARRIVE"))
-			getSound()->removeFromQueue("ARRIVE");
+		getSoundQueue()->processEntries();
+		if (getSoundQueue()->isBuffered("ARRIVE"))
+			getSoundQueue()->removeFromQueue("ARRIVE");
 
 		setCallback(1);
 		setup_savegame(kSavegameTypeEvent, kEventAugustUnhookCarsBetrayal);
@@ -3519,7 +3518,7 @@ IMPLEMENT_FUNCTION(69, August, unhookCars)
 		if (getCallback() == 1) {
 			getAction()->playAnimation(getProgress().field_C ? kEventAugustUnhookCarsBetrayal : kEventAugustUnhookCars);
 			getEntities()->clearSequences(kEntityAugust);
-			getSound()->resetState();
+			getSoundQueue()->resetState();
 			getSound()->playSound(kEntityPlayer, "MUS050");
 			getScenes()->loadSceneFromPosition(kCarRestaurant, 85, 1);
 			getSavePoints()->pushAll(kEntityAugust, kActionProceedChapter5);
