@@ -18,23 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/entities/salko.h"
 
+#include "lastexpress/fight/fight.h"
+
 #include "lastexpress/game/action.h"
 #include "lastexpress/game/entities.h"
-#include "lastexpress/game/fight.h"
 #include "lastexpress/game/logic.h"
 #include "lastexpress/game/object.h"
 #include "lastexpress/game/savepoint.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/lastexpress.h"
 #include "lastexpress/helpers.h"
 
@@ -598,8 +598,8 @@ IMPLEMENT_FUNCTION(24, Salko, chapter5Handler)
 			break;
 
 		case 1:
-			if (getSound()->isBuffered("MUS050"))
-				getSound()->processEntry("MUS050");
+			if (getSoundQueue()->isBuffered("MUS050"))
+				getSoundQueue()->processEntry("MUS050");
 
 			getAction()->playAnimation(kEventCathSalkoTrainTopFight);
 
