@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/entities/verges.h"
@@ -32,9 +29,11 @@
 #include "lastexpress/game/object.h"
 #include "lastexpress/game/savepoint.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/lastexpress.h"
 #include "lastexpress/helpers.h"
 
@@ -126,7 +125,7 @@ IMPLEMENT_FUNCTION_END
 
 //////////////////////////////////////////////////////////////////////////
 IMPLEMENT_FUNCTION_NOSETUP(5, Verges, playSound16)
-	Entity::playSound(savepoint, false, SoundManager::kFlagDefault);
+	Entity::playSound(savepoint, false, kFlagDefault);
 IMPLEMENT_FUNCTION_END
 
 //////////////////////////////////////////////////////////////////////////
@@ -142,7 +141,7 @@ IMPLEMENT_FUNCTION_END
 //////////////////////////////////////////////////////////////////////////
 IMPLEMENT_FUNCTION_II(8, Verges, updateEntity, CarIndex, EntityPosition)
 	if (savepoint.action == kActionExcuseMeCath) {
-		if (!getSound()->isBuffered(kEntityVerges))
+		if (!getSoundQueue()->isBuffered(kEntityVerges))
 			getSound()->playSound(kEntityPlayer, "TRA1113", getSound()->getSoundFlag(kEntityVerges));
 
 		return;
@@ -190,7 +189,7 @@ switch (savepoint.action) {
 			break;
 
 		case 2:
-			if (!getSound()->isBuffered(kEntityVerges))
+			if (!getSoundQueue()->isBuffered(kEntityVerges))
 				getSound()->playSound(kEntityVerges, (char *)&params->seq1);
 
 			getEntities()->drawSequenceRight(kEntityVerges, "813DS");
@@ -235,7 +234,7 @@ IMPLEMENT_FUNCTION_IIS(10, Verges, function10, CarIndex, EntityPosition)
 
 	case kActionNone:
 		if (!params->param7) {
-			if (!getSound()->isBuffered(kEntityVerges)) {
+			if (!getSoundQueue()->isBuffered(kEntityVerges)) {
 				getSound()->playSound(kEntityVerges, (char *)&params->seq);
 				params->param7 = 1;
 			}
@@ -261,7 +260,7 @@ IMPLEMENT_FUNCTION_IIS(10, Verges, function10, CarIndex, EntityPosition)
 		break;
 
 	case kActionDefault:
-		if (!getSound()->isBuffered(kEntityVerges)) {
+		if (!getSoundQueue()->isBuffered(kEntityVerges)) {
 			getSound()->playSound(kEntityVerges, (char *)&params->seq);
 			params->param7 = 1;
 		}
@@ -702,12 +701,12 @@ IMPLEMENT_FUNCTION(24, Verges, policeGettingOffTrain)
 		break;
 
 	case kActionDefault:
-		getSound()->playSound(kEntityVerges, "POL1101", SoundManager::kFlagDefault);
+		getSound()->playSound(kEntityVerges, "POL1101", kFlagDefault);
 		break;
 
 	case kActionCallback:
 		if (getCallback() == 1) {
-			getSound()->processEntry(kEntityVerges);
+			getSoundQueue()->processEntry(kEntityVerges);
 			getAction()->playAnimation(kEventGendarmesArrestation);
 			getLogic()->gameOver(kSavegameTypeIndex, 1, kSceneGameOverPolice1, true);
 		}
@@ -1317,7 +1316,7 @@ IMPLEMENT_FUNCTION(32, Verges, function32)
 			break;
 
 		case 2:
-			if (!getSound()->isBuffered(kEntityVerges))
+			if (!getSoundQueue()->isBuffered(kEntityVerges))
 				getSound()->playSound(kEntityVerges, "TRA3004");
 
 			getEntities()->drawSequenceRight(kEntityVerges, "813DS");
@@ -1755,16 +1754,16 @@ IMPLEMENT_FUNCTION(40, Verges, chapter5Handler)
 		break;
 
 	case kActionNone:
-		if (getEntities()->isInSalon(kEntityPlayer) && !getSound()->isBuffered(kEntityVerges))
+		if (getEntities()->isInSalon(kEntityPlayer) && !getSoundQueue()->isBuffered(kEntityVerges))
 			getSound()->playSound(kEntityVerges, "WAT5000");
 		break;
 
 	case kActionOpenDoor:
-		if (getSound()->isBuffered(kEntityVerges))
-			getSound()->processEntry(kEntityVerges);
+		if (getSoundQueue()->isBuffered(kEntityVerges))
+			getSoundQueue()->processEntry(kEntityVerges);
 
-		if (getSound()->isBuffered("MUS050"))
-			getSound()->processEntry("MUS050");
+		if (getSoundQueue()->isBuffered("MUS050"))
+			getSoundQueue()->processEntry("MUS050");
 
 		getObjects()->update(kObject65, kEntityPlayer, kObjectLocationNone, kCursorNormal, kCursorForward);
 
@@ -1814,7 +1813,7 @@ IMPLEMENT_FUNCTION(41, Verges, function41)
 			// Fallback to next case
 
 		case 2:
-			if (getSound()->isBuffered(kEntityVerges)) {
+			if (getSoundQueue()->isBuffered(kEntityVerges)) {
 				setCallback(2);
 				setup_updateFromTime(225);
 			} else {
