@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/game/entities.h"
@@ -71,9 +68,11 @@
 #include "lastexpress/game/logic.h"
 #include "lastexpress/game/savepoint.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/graphics.h"
 #include "lastexpress/helpers.h"
 #include "lastexpress/lastexpress.h"
@@ -203,7 +202,7 @@ Entity *Entities::get(EntityIndex entity) {
 	assert((uint)entity < _entities.size());
 
 	if (entity == kEntityPlayer)
-		error("Cannot get entity for index == 0!");
+		error("[Entities::get] Cannot get entity for kEntityPlayer");
 
 	return _entities[entity];
 }
@@ -221,24 +220,24 @@ int Entities::getPosition(CarIndex car, Position position) const {
 	int index = 100 * car + position;
 
 	if (car > 10)
-		error("Entities::getPosition: trying to access an invalid car (was: %d, valid:0-9)", car);
+		error("[Entities::getPosition] Trying to access an invalid car (was: %d, valid:0-9)", car);
 
 	if (position > 100)
-		error("Entities::getPosition: trying to access an invalid position (was: %d, valid:0-100)", position);
+		error("[Entities::getPosition] Trying to access an invalid position (was: %d, valid:0-100)", position);
 
 	return _positions[index];
 }
 
 int Entities::getCompartments(int index) const {
 	if (index >= _compartmentsCount)
-		error("Entities::getCompartments: trying to access an invalid compartment (was: %d, valid:0-15)", index);
+		error("[Entities::getCompartments] Trying to access an invalid compartment (was: %d, valid:0-15)", index);
 
 	return _compartments[index];
 }
 
 int Entities::getCompartments1(int index) const {
 	if (index >= _compartmentsCount)
-		error("Entities::getCompartments: trying to access an invalid compartment (was: %d, valid:0-15)", index);
+		error("[Entities::getCompartments] Trying to access an invalid compartment (was: %d, valid:0-15)", index);
 
 	return _compartments1[index];
 }
@@ -302,7 +301,7 @@ void Entities::setupChapter(ChapterIndex chapter) {
 		memset(&_compartments1, 0, sizeof(_compartments1));
 		memset(&_positions, 0, sizeof(_positions));
 
-		getSound()->resetQueue(SoundManager::kSoundType13);
+		getSoundQueue()->resetQueue(kSoundType13);
 	}
 
 	// we skip the header when doing entity setup
@@ -372,8 +371,8 @@ void Entities::resetState(EntityIndex entityIndex) {
 	getData(entityIndex)->currentCall = 0;
 	getData(entityIndex)->inventoryItem = kItemNone;
 
-	if (getSound()->isBuffered(entityIndex))
-		getSound()->removeFromQueue(entityIndex);
+	if (getSoundQueue()->isBuffered(entityIndex))
+		getSoundQueue()->removeFromQueue(entityIndex);
 
 	clearSequences(entityIndex);
 
@@ -754,50 +753,48 @@ label_nosequence:
 	if (!data->sequence)
 		goto label_nosequence;
 
-	if (data->frame->getInfo()->field_30 > data->field_49B + 1 || (data->direction == kDirectionLeft && data->sequence->count() == 1)) {
+	if (data->frame->getInfo()->field_30 > (data->field_49B + 1) || (data->direction == kDirectionLeft && data->sequence->count() == 1)) {
 		++data->field_49B;
-		INCREMENT_DIRECTION_COUNTER();
-		return;
-	}
-
-	if (data->frame->getInfo()->field_30 > data->field_49B && !data->frame->getInfo()->keepPreviousFrame) {
-		++data->field_49B;
-		INCREMENT_DIRECTION_COUNTER();
-		return;
-	}
-
-	if (data->frame->getInfo()->keepPreviousFrame == 1)
-		keepPreviousFrame = true;
-
-	// Increment current frame
-	++data->currentFrame;
-
-	if (data->currentFrame > (int16)(data->sequence->count() - 1) || (data->field_4A9 && checkSequenceFromPosition(entityIndex))) {
-
-		if (data->direction == kDirectionLeft) {
-			data->currentFrame = 0;
+	} else {
+		if (data->frame->getInfo()->field_30 > data->field_49B && !data->frame->getInfo()->keepPreviousFrame) {
+			++data->field_49B;
 		} else {
-			keepPreviousFrame = true;
-			drawNextSequence(entityIndex);
+			if (data->frame->getInfo()->keepPreviousFrame == 1)
+				keepPreviousFrame = true;
+
+			// Increment current frame
+			++data->currentFrame;
+
+			if (data->currentFrame > (int16)(data->sequence->count() - 1) || (data->field_4A9 && checkSequenceFromPosition(entityIndex))) {
+
+				if (data->direction == kDirectionLeft) {
+					data->currentFrame = 0;
+				} else {
+					keepPreviousFrame = true;
+					drawNextSequence(entityIndex);
+
+					if (getFlags()->flag_entities_0 || data->doProcessEntity)
+						return;
+
+					if (!data->sequence2) {
+						updateEntityPosition(entityIndex);
+						data->doProcessEntity = false;
+						return;
+					}
+
+					copySequenceData(entityIndex);
+				}
+
+			}
+
+			processFrame(entityIndex, keepPreviousFrame, false);
 
 			if (getFlags()->flag_entities_0 || data->doProcessEntity)
 				return;
-
-			if (!data->sequence2) {
-				updateEntityPosition(entityIndex);
-				data->doProcessEntity = false;
-				return;
-			}
-
-			copySequenceData(entityIndex);
 		}
-
 	}
 
-	processFrame(entityIndex, keepPreviousFrame, false);
-
-	if (!getFlags()->flag_entities_0 && !data->doProcessEntity)
-		INCREMENT_DIRECTION_COUNTER();
+	INCREMENT_DIRECTION_COUNTER();
 }
 
 void Entities::computeCurrentFrame(EntityIndex entityIndex) const {
@@ -1110,9 +1107,8 @@ void Entities::processFrame(EntityIndex entityIndex, bool keepPreviousFrame, boo
 	// Get new frame info
 	FrameInfo *info = data->sequence->getFrameInfo((uint16)data->currentFrame);
 
-	if (data->frame && data->frame->getInfo()->subType != kFrameType3)
-		if (!info->field_2E || keepPreviousFrame)
-			getScenes()->setCoordinates(data->frame);
+	if (data->frame && data->frame->getInfo()->subType != kFrameType3 && (!info->field_2E || keepPreviousFrame))
+		getScenes()->setCoordinates(data->frame);
 
 	// Update position
 	if (info->entityPosition) {
@@ -1783,7 +1779,7 @@ void Entities::enterCompartment(EntityIndex entity, ObjectIndex compartment, boo
 	// Update compartments
 	int index = (compartment < 32 ? compartment - 1 : compartment - 24);
 	if (index >= 16)
-		error("Entities::exitCompartment: invalid compartment index!");
+		error("[Entities::enterCompartment] Invalid compartment index");
 
 	if (useCompartment1)
 		_compartments1[index] |= STORE_VALUE(entity);
@@ -1869,7 +1865,7 @@ void Entities::exitCompartment(EntityIndex entity, ObjectIndex compartment, bool
 	// Update compartments
 	int index = (compartment < 32 ? compartment - 1 : compartment - 24);
 	if (index >= 16)
-		error("Entities::exitCompartment: invalid compartment index!");
+		error("[Entities::exitCompartment] Invalid compartment index");
 
 	if (useCompartment1)
 		_compartments1[index] &= ~STORE_VALUE(entity);
@@ -2358,7 +2354,7 @@ bool Entities::changeCar(EntityData::EntityCallData *data, EntityIndex entity, C
 	if (data->car == newCar) {
 		if (isInGreenCarEntrance(kEntityPlayer)) {
 			getSound()->playSoundEvent(kEntityPlayer, 14);
-			getSound()->excuseMe(entity, kEntityPlayer, SoundManager::kFlagDefault);
+			getSound()->excuseMe(entity, kEntityPlayer, kFlagDefault);
 			getScenes()->loadSceneFromPosition(kCarGreenSleeping, 1);
 			getSound()->playSound(kEntityPlayer, "CAT1127A");
 			getSound()->playSoundEvent(kEntityPlayer, 15);
@@ -2377,7 +2373,7 @@ bool Entities::changeCar(EntityData::EntityCallData *data, EntityIndex entity, C
 	if (data->car == newCar) {
 		if (isInKronosCarEntrance(kEntityPlayer)) {
 			getSound()->playSoundEvent(kEntityPlayer, 14);
-			getSound()->excuseMe(entity, kEntityPlayer, SoundManager::kFlagDefault);
+			getSound()->excuseMe(entity, kEntityPlayer, kFlagDefault);
 			getScenes()->loadSceneFromPosition(kCarGreenSleeping, 62);
 			getSound()->playSound(kEntityPlayer, "CAT1127A");
 			getSound()->playSoundEvent(kEntityPlayer, 15);
