@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/game/inventory.h"
@@ -30,11 +27,14 @@
 #include "lastexpress/data/snd.h"
 
 #include "lastexpress/game/logic.h"
-#include "lastexpress/game/menu.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/menu/menu.h"
+
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/graphics.h"
 #include "lastexpress/helpers.h"
 #include "lastexpress/lastexpress.h"
@@ -43,13 +43,13 @@
 
 namespace LastExpress {
 
-Inventory::Inventory(LastExpressEngine *engine) : _engine(engine), _selectedItem(kItemNone), _highlightedItem(kItemNone), _itemsShown(0),
+Inventory::Inventory(LastExpressEngine *engine) : _engine(engine), _selectedItem(kItemNone), _highlightedItemIndex(0), _itemsShown(0),
 	_showingHourGlass(false), _blinkingEgg(false), _blinkingTime(0), _blinkingInterval(_defaultBlinkingInterval), _blinkingBrightness(1),
-	_useMagnifier(false), _flag1(false), _isOpened(false), _eggHightlighted(false), _itemScene(NULL) {
+	_useMagnifier(false), _portraitHighlighted(false), _isOpened(false), _eggHightlighted(false), _itemScene(NULL) {
 
-	_inventoryRect = Common::Rect(0, 0, 32, 32);
-	_menuRect = Common::Rect(608, 448, 640, 480);
-	_selectedRect = Common::Rect(44, 0, 76, 32);
+	//_inventoryRect = Common::Rect(0, 0, 32, 32);
+	_menuEggRect = Common::Rect(608, 448, 640, 480);
+	_selectedItemRect = Common::Rect(44, 0, 76, 32);
 
 	init();
 }
@@ -127,22 +127,18 @@ void Inventory::init() {
 	_selectedItem = kItemNone;
 }
 
-// FIXME we need to draw cursors with full background opacity so that whatever is in the background is erased
-// this saved us clearing some part of the background when switching between states
-
-// TODO if we draw inventory objects on screen, we need to load a new scene.
-// Signal that the inventory has taken over the screen and stop processing mouse events after we have been called
 void Inventory::handleMouseEvent(const Common::Event &ev) {
 	_useMagnifier = false;
 
 	// Egg (menu)
-	if (!_menuRect.contains(ev.mouse)) {
+	if (!_menuEggRect.contains(ev.mouse)) {
 		// Remove highlight if needed
 		if (_eggHightlighted) {
 			if (!getGlobalTimer()) {
 				drawItem((CursorStyle)(getMenu()->getGameId() + 39), 608, 448, 1);
 				askForRedraw();
 			}
+
 			_eggHightlighted = false;
 		}
 	} else {
@@ -159,17 +155,17 @@ void Inventory::handleMouseEvent(const Common::Event &ev) {
 		// If clicked, show the menu
 		if (ev.type == Common::EVENT_LBUTTONDOWN) {
 			_eggHightlighted = false;
-			_flag1 = false;
+			_portraitHighlighted = false;
 			_isOpened = false;
 
-			getSound()->playSoundWithSubtitles("LIB039.SND", SoundManager::kFlagMenuClock, kEntityPlayer);
+			getSound()->playSoundWithSubtitles("LIB039.SND", kFlagMenuClock, kEntityPlayer);
 
 			getMenu()->show(true, kSavegameTypeIndex, 0);
 
 		} else if (ev.type == Common::EVENT_RBUTTONDOWN) {
 			if (getGlobalTimer()) {
-				if (getSound()->isBuffered("TIMER"))
-					getSound()->removeFromQueue("TIMER");
+				if (getSoundQueue()->isBuffered("TIMER"))
+					getSoundQueue()->removeFromQueue("TIMER");
 
 				setGlobalTimer(900);
 			}
@@ -178,14 +174,171 @@ void Inventory::handleMouseEvent(const Common::Event &ev) {
 
 	// Selected item
 	if (ev.mouse.x >= 32) {
-		// TODO
+		if (_isOpened) {
+			// If we are currently inside inventory with the mouse pressed
+			if (getFlags()->mouseLeftPressed) {
+				if (_highlightedItemIndex)
+					drawHighlight(_highlightedItemIndex, true);
+			} else {
+				// The user released the mouse button, we need to update the inventory state (clear hightlight and items)
+				drawItem((CursorStyle)getProgress().portrait, 0, 0, 1);
+				_engine->getGraphicsManager()->clear(GraphicsManager::kBackgroundInventory, Common::Rect(0, 44, 32, (int16)(40 * _itemsShown + 40)));
+				_isOpened = false;
+				askForRedraw();
+
+				drawSelectedItem();
+
+				// Load backup scene
+				if (getState()->sceneUseBackup) {
+					SceneIndex scene = kSceneNone;
+					if (getState()->sceneBackup2) {
+						scene = getState()->sceneBackup2;
+						getState()->sceneBackup2 = kSceneNone;
+
+						// Load our scene
+						getScenes()->loadScene(scene);
+					} else if (!getEvent(kEventKronosBringFirebird) && !getProgress().isEggOpen) {
+						getState()->sceneUseBackup = false;
+						scene = getState()->sceneBackup;
+
+						if (getEntities()->getPosition(getScenes()->get(scene)->car, getScenes()->get(scene)->position))
+							scene = getScenes()->processIndex(getState()->sceneBackup);
+
+						// Load our scene
+						getScenes()->loadScene(scene);
+					}
+				}
+			}
+		} else {
+			if (_portraitHighlighted) {
+				drawItem((CursorStyle)getProgress().portrait, 0, 0, 1);
+				askForRedraw();
+				_portraitHighlighted = false;
+			}
+
+			// Magnifier
+			if (_selectedItem != kItemNone
+			 && get(_selectedItem)->scene != kSceneNone
+			 && _selectedItemRect.contains(ev.mouse)) {
+
+				if (!getState()->sceneUseBackup || (getState()->sceneBackup2 && getFirstExaminableItem() == _selectedItem))
+					_useMagnifier = true;
+
+				if (getFlags()->mouseLeftPressed) {
+					if (getState()->sceneUseBackup) {
+						if (getState()->sceneBackup2
+						 && getFirstExaminableItem() == _selectedItem) {
+							 SceneIndex sceneIndex = getState()->sceneBackup2;
+							 getState()->sceneBackup2 = kSceneNone;
+
+							 getScenes()->loadScene(sceneIndex);
+						}
+					} else {
+						getState()->sceneBackup = getState()->scene;
+						getState()->sceneUseBackup = true;
+
+						getScenes()->loadScene(get(_selectedItem)->scene);
+					}
+				}
+			}
+		}
 
 		return;
 	}
 
 	// Opened inventory
 	if (ev.mouse.y >= 32) {
-		// TODO
+		// Draw portrait (darkened) if the inventory is closed (and we are not on top of it)
+		if (!_isOpened) {
+			if (_portraitHighlighted) {
+				drawItem((CursorStyle)getProgress().portrait, 0, 0, 1);
+				askForRedraw();
+				_portraitHighlighted = false;
+			}
+
+			return;
+		}
+
+		// Change item highlight on list
+		if (getFlags()->mouseLeftPressed) {
+			uint32 index = ev.mouse.y / 40;
+
+			if (_highlightedItemIndex && _highlightedItemIndex != index)
+				drawHighlight(_highlightedItemIndex, true);
+
+			if (index && index <= _itemsShown && index != _highlightedItemIndex)
+				drawHighlight(index, false);
+
+			return;
+		}
+
+		// User released the mouse button, check if we were on a valid item
+		uint32 index = _highlightedItemIndex ? getItemIndex(_highlightedItemIndex) : 0;
+
+		// Reset items and portrait
+		drawItem((CursorStyle)getProgress().portrait, 0, 0, 1);
+		_engine->getGraphicsManager()->clear(GraphicsManager::kBackgroundInventory, Common::Rect(0, 44, 32, (int16)(40 * _itemsShown + 40)));
+		askForRedraw();
+		_highlightedItemIndex = 0;
+		_itemsShown = 0;
+
+		// Load the scene if an item has been selected
+		if (index) {
+			InventoryEntry entry = _entries[index];
+
+			// If a scene is affected to the item
+			if (entry.scene) {
+				if (getState()->sceneUseBackup) {
+					if (getFirstExaminableItem() && !getState()->sceneBackup2)
+						getState()->sceneBackup2 = getState()->scene;
+				} else {
+					getState()->sceneUseBackup = true;
+					getState()->sceneBackup = getState()->scene;
+				}
+
+				getScenes()->loadScene(entry.scene);
+			}
+
+			if (entry.field_2)
+				selectItem((InventoryItem)index);
+			else
+				drawSelectedItem();
+
+			// Set inventory as closed (will cause a cleanup on next call)
+			_isOpened = false;
+
+			return;
+		}
+
+		// Draw the currently selected item
+		drawSelectedItem();
+
+		// Stop processing if we are not looking at an item already
+		if (!getState()->sceneUseBackup) {
+			_isOpened = false;
+			return;
+		}
+
+		SceneIndex scene = kSceneNone;
+		if (getState()->sceneBackup2) {
+			scene = getState()->sceneBackup2;
+			getState()->sceneBackup2 = kSceneNone;
+		} else {
+			if (getEvent(kEventKronosBringFirebird) || getProgress().isEggOpen) {
+				_isOpened = false;
+				return;
+			}
+
+			getState()->sceneUseBackup = false;
+			scene = getState()->sceneBackup;
+
+			if (getEntities()->getPosition(getScenes()->get(scene)->car, getScenes()->get(scene)->position))
+				scene = getScenes()->processIndex(getState()->sceneBackup);
+		}
+
+		getScenes()->loadScene(scene);
+
+		_isOpened = false;
 
 		return;
 	}
@@ -202,10 +355,10 @@ void Inventory::handleMouseEvent(const Common::Event &ev) {
 			return;
 		}
 
-		if (!_flag1 && !_isOpened) {
+		if (!_portraitHighlighted && !_isOpened) {
 			drawItem((CursorStyle)getProgress().portrait, 0, 0);
-			_flag1 = true;
-		} else if (!_isOpened || (ev.type == Common::EVENT_LBUTTONDOWN || ev.type == Common::EVENT_LBUTTONUP)) {
+			_portraitHighlighted = true;
+		} else if (!_isOpened || getFlags()->mouseLeftPressed) {
 			// Do nothing
 		} else if (_isOpened) {
 			close();
@@ -239,12 +392,12 @@ void Inventory::handleMouseEvent(const Common::Event &ev) {
 				}
 			}
 
-			_flag1 = true;
+			_portraitHighlighted = true;
 		}
 
 		// Draw highlighted item
-		if (_highlightedItem)
-			drawHighlight();
+		if (_highlightedItemIndex)
+			drawHighlight(_highlightedItemIndex, true);
 	}
 }
 
@@ -256,7 +409,7 @@ void Inventory::show() {
 	askForRedraw();
 
 	// Show portrait (first draw, cannot be highlighted)
-	drawItem((CursorStyle)getProgress().portrait, 0, 0);
+	drawItem((CursorStyle)getProgress().portrait, 0, 0, 1);
 
 	// Show selected item
 	if (_selectedItem != kItemNone)
@@ -286,7 +439,7 @@ void Inventory::showHourGlass(){
 //////////////////////////////////////////////////////////////////////////
 Inventory::InventoryEntry *Inventory::get(InventoryItem item) {
 	if (item >= kPortraitOriginal)
-		error("Inventory::getEntry: Invalid inventory item!");
+		error("[Inventory::get] Invalid inventory item");
 
 	return &_entries[item];
 }
@@ -470,7 +623,7 @@ void Inventory::drawEgg() {
 // Blinking egg: we need to blink the egg for delta time, with the blinking getting faster until it's always lit.
 void Inventory::drawBlinkingEgg() {
 
-	warning("Inventory::drawEgg - blinking not implemented!");
+	warning("[Inventory::drawBlinkingEgg] Blinking not implemented");
 
 	//// TODO show egg (with or without mouseover)
 
@@ -479,7 +632,7 @@ void Inventory::drawBlinkingEgg() {
 	//	if (getGlobalTimer() + ticks >= 90)
 	//		getSound()->playSoundWithSubtitles("TIMER.SND", 50331664, kEntityPlayer);
 
-	//	if (getSound()->isBuffered("TIMER"))
+	//	if (getSoundQueue()->isBuffered("TIMER"))
 	//		setGlobalTimer(0);
 	//}
 
@@ -511,9 +664,27 @@ void Inventory::drawItem(CursorStyle id, uint16 x, uint16 y, int16 brightnessInd
 	_engine->getGraphicsManager()->draw(&icon, GraphicsManager::kBackgroundInventory);
 }
 
-// Close inventory: clear items and reset icon
+void Inventory::drawSelectedItem() {
+	// Draw the selected item if any
+	if (!_selectedItem || get(_selectedItem)->manualSelect) {
+		_selectedItem = getFirstExaminableItem();
+
+		if (_selectedItem) {
+			drawItem(get(_selectedItem)->cursor, 44, 0);
+		} else {
+			clearSelectedItem();
+		}
+		askForRedraw();
+	}
+}
+
+void Inventory::clearSelectedItem() {
+	_engine->getGraphicsManager()->clear(GraphicsManager::kBackgroundInventory, Common::Rect(44, 0, 44 + 32, 32));
+}
+
+// Open inventory: show portrait selected and draw contents
 void Inventory::open() {
-	_flag1 = false;
+	_portraitHighlighted = false;
 	_isOpened = true;
 
 	// Draw highlighted portrait
@@ -552,9 +723,18 @@ void Inventory::close() {
 	askForRedraw();
 }
 
-void Inventory::drawHighlight() {
-	int32 count = 0;
-	uint32 index = 0;
+void Inventory::drawHighlight(uint32 currentIndex, bool reset) {
+	uint32 index = getItemIndex(currentIndex);
+
+	if (index) {
+		drawItem(_entries[index].cursor, 0, 40 * currentIndex + 4, reset ? 1 : -1);
+		_highlightedItemIndex = reset ? 0 : currentIndex;
+		askForRedraw();
+	}
+}
+
+uint32 Inventory::getItemIndex(uint32 currentIndex) {
+	uint32 count = 0;
 
 	for (uint32 i = 1; i < ARRAYSIZE(_entries); i++) {
 		if (!_entries[i].isPresent)
@@ -565,17 +745,13 @@ void Inventory::drawHighlight() {
 
 		if (count < 11) {
 			++count;
-			if (count == _highlightedItem) {
-				index = i;
-				break;
-			}
+
+			if (count == currentIndex)
+				return i;
 		}
 	}
 
-	if (index) {
-		drawItem(_entries[index].cursor, 0, 40 * _highlightedItem + 4, 1);
-		_highlightedItem = kItemNone;
-	}
+	return 0;
 }
 
 } // End of namespace LastExpress
