@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "lastexpress/game/logic.h"
@@ -33,20 +30,25 @@
 // Entities
 #include "lastexpress/entities/chapters.h"
 
+// Fight
+#include "lastexpress/fight/fight.h"
+
 // Game
 #include "lastexpress/game/action.h"
 #include "lastexpress/game/beetle.h"
 #include "lastexpress/game/entities.h"
-#include "lastexpress/game/fight.h"
 #include "lastexpress/game/inventory.h"
-#include "lastexpress/game/menu.h"
 #include "lastexpress/game/object.h"
 #include "lastexpress/game/savegame.h"
 #include "lastexpress/game/savepoint.h"
 #include "lastexpress/game/scenes.h"
-#include "lastexpress/game/sound.h"
 #include "lastexpress/game/state.h"
 
+#include "lastexpress/menu/menu.h"
+
+#include "lastexpress/sound/queue.h"
+#include "lastexpress/sound/sound.h"
+
 #include "lastexpress/graphics.h"
 #include "lastexpress/helpers.h"
 #include "lastexpress/lastexpress.h"
@@ -89,7 +91,7 @@ Logic::~Logic() {
 #define REDRAW_CURSOR() { \
 	if (getInventory()->isMagnifierInUse()) \
 		_engine->getCursor()->setStyle(kCursorMagnifier); \
-	if (getInventory()->isFlag1() \
+	if (getInventory()->isPortraitHighlighted() \
 	|| getInventory()->isOpened() \
 	|| getInventory()->isEggHighlighted()) \
 		_engine->getCursor()->setStyle(kCursorNormal); \
@@ -104,7 +106,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 	getFlags()->mouseRightClick = false;
 
 	// Process event flags
-	if (ev.type == Common::EVENT_LBUTTONUP) {
+	if (ev.type == Common::EVENT_LBUTTONDOWN) {
 
 		if (getFlags()->frameInterval)
 			_ignoreFrameInterval = false;
@@ -113,7 +115,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 	}
 
 	if (getFlags()->flag_0) {
-		if (ev.type == Common::EVENT_LBUTTONUP || ev.type == Common::EVENT_RBUTTONUP) {
+		if (ev.type == Common::EVENT_LBUTTONDOWN || ev.type == Common::EVENT_RBUTTONDOWN) {
 			getFlags()->flag_0 = false;
 			getFlags()->shouldRedraw = true;
 			updateCursor(true);
@@ -143,7 +145,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 	 && !getProgress().isEggOpen
 	 && !getEntities()->isPlayerPosition(kCarGreenSleeping, 59)
 	 && !getEntities()->isPlayerPosition(kCarGreenSleeping, 76)
-	 && !getInventory()->isFlag1()
+	 && !getInventory()->isPortraitHighlighted()
 	 && !getInventory()->isOpened()
 	 && !getInventory()->isEggHighlighted()
 	 && !getInventory()->isMagnifierInUse()) {
@@ -152,7 +154,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 		_engine->getCursor()->setStyle(getInventory()->get(kItemWhistle)->cursor);
 
 		// Check if clicked
-		if (ev.type == Common::EVENT_LBUTTONUP && !getSound()->isBuffered("LIB045")) {
+		if (ev.type == Common::EVENT_LBUTTONUP && !getSoundQueue()->isBuffered("LIB045")) {
 
 			getSound()->playSoundEvent(kEntityPlayer, 45);
 
@@ -173,7 +175,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 	if (getInventory()->getSelectedItem() == kItemMatch
 	 && (getEntities()->isPlayerInCar(kCarGreenSleeping) || getEntities()->isPlayerInCar(kCarRedSleeping))
 	 && getProgress().jacket == kJacketGreen
-	 && !getInventory()->isFlag1()
+	 && !getInventory()->isPortraitHighlighted()
 	 && !getInventory()->isOpened()
 	 && !getInventory()->isEggHighlighted()
 	 && !getInventory()->isMagnifierInUse()
@@ -198,7 +200,7 @@ void Logic::eventMouse(const Common::Event &ev) {
 	// Handle entity item case
 	EntityIndex entityIndex = getEntities()->canInteractWith(ev.mouse);
 	if (entityIndex
-	 && !getInventory()->isFlag1()
+	 && !getInventory()->isPortraitHighlighted()
 	 && !getInventory()->isOpened()
 	 && !getInventory()->isEggHighlighted()
 	 && !getInventory()->isMagnifierInUse()) {
@@ -223,17 +225,17 @@ void Logic::eventMouse(const Common::Event &ev) {
 
 	//////////////////////////////////////////////////////////////////////////
 	// Handle standard actions
-	if (getInventory()->isFlag1() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
+	if (getInventory()->isPortraitHighlighted() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
 		_engine->getCursor()->setStyle(kCursorNormal);
 
-	if (hotspotHandled || getInventory()->isFlag1() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
+	if (hotspotHandled || getInventory()->isPortraitHighlighted() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
 		return;
 
 	// Magnifier in use
 	if (getInventory()->isMagnifierInUse()) {
 		_engine->getCursor()->setStyle(kCursorMagnifier);
 
-		if (getInventory()->isFlag1()
+		if (getInventory()->isPortraitHighlighted()
 		 || getInventory()->isOpened()
 		 || getInventory()->isEggHighlighted())
 			_engine->getCursor()->setStyle(kCursorNormal);
@@ -411,7 +413,7 @@ void Logic::eventTick(const Common::Event &) {
 void Logic::resetState() {
 	getState()->scene = kSceneDefault;
 
-	warning("Logic::resetState: not implemented! You need to restart the engine until this is implemented.");
+	warning("[Logic::resetState] Not implemented! You need to restart the engine until this is implemented.");
 }
 
 /**
@@ -424,7 +426,7 @@ void Logic::resetState() {
  */
 void Logic::gameOver(SavegameType type, uint32 value, SceneIndex sceneIndex, bool showScene) const {
 
-	getSound()->processEntries();
+	getSoundQueue()->processEntries();
 	getEntities()->reset();
 	getFlags()->isGameRunning = false;
 	getSavePoints()->reset();
@@ -432,16 +434,16 @@ void Logic::gameOver(SavegameType type, uint32 value, SceneIndex sceneIndex, boo
 
 	if (showScene) {
 
-		getSound()->processEntry(SoundManager::kSoundType11);
+		getSoundQueue()->processEntry(kSoundType11);
 
 		if (sceneIndex && !getFlags()->mouseRightClick) {
 			getScenes()->loadScene(sceneIndex);
 
-			while (getSound()->isBuffered(kEntityTables4)) {
+			while (getSoundQueue()->isBuffered(kEntityTables4)) {
 				if (getFlags()->mouseRightClick)
 					break;
 
-				getSound()->updateQueue();
+				getSoundQueue()->updateQueue();
 			}
 		}
 	}
@@ -451,7 +453,7 @@ void Logic::gameOver(SavegameType type, uint32 value, SceneIndex sceneIndex, boo
 }
 
 void Logic::switchChapter() const {
-	getSound()->clearStatus();
+	getSoundQueue()->clearStatus();
 
 	switch(getState()->progress.chapter) {
 	default:
@@ -491,7 +493,7 @@ void Logic::switchChapter() const {
 }
 
 void Logic::playFinalSequence() const {
-	getSound()->processEntries();
+	getSoundQueue()->processEntries();
 
 	_action->playAnimation(kEventFinalSequence);
 	showCredits();
@@ -504,7 +506,7 @@ void Logic::playFinalSequence() const {
 }
 
 void Logic::showCredits() const {
-	error("Logic::showCredits: not implemented!");
+	error("[Logic::showCredits] Not implemented");
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -518,7 +520,7 @@ void Logic::updateCursor(bool) const { /* the cursor is always updated, even whe
 	 || getProgress().isEggOpen
 	 || getEntities()->isPlayerPosition(kCarGreenSleeping, 59)
 	 || getEntities()->isPlayerPosition(kCarGreenSleeping, 76)
-	 || getInventory()->isFlag1()
+	 || getInventory()->isPortraitHighlighted()
 	 || getInventory()->isOpened()
 	 || getInventory()->isEggHighlighted()
 	 || getInventory()->isMagnifierInUse()) {
@@ -526,7 +528,7 @@ void Logic::updateCursor(bool) const { /* the cursor is always updated, even whe
 		if (getInventory()->getSelectedItem() != kItemMatch
 		 || (!getEntities()->isPlayerInCar(kCarGreenSleeping) && !getEntities()->isPlayerInCar(kCarRedSleeping))
 		 || getProgress().jacket != kJacketGreen
-		 || getInventory()->isFlag1()
+		 || getInventory()->isPortraitHighlighted()
 		 || getInventory()->isOpened()
 		 || getInventory()->isEggHighlighted()
 		 || getInventory()->isMagnifierInUse()
@@ -536,7 +538,7 @@ void Logic::updateCursor(bool) const { /* the cursor is always updated, even whe
 
 			EntityIndex entity = getEntities()->canInteractWith(getCoords());
 			if (entity
-			 && !getInventory()->isFlag1()
+			 && !getInventory()->isPortraitHighlighted()
 			 && !getInventory()->isOpened()
 			 && !getInventory()->isEggHighlighted()
 			 && !getInventory()->isMagnifierInUse()) {
@@ -550,7 +552,7 @@ void Logic::updateCursor(bool) const { /* the cursor is always updated, even whe
 			}
 
 			if (!interact
-			 && !getInventory()->isFlag1()
+			 && !getInventory()->isPortraitHighlighted()
 			 && !getInventory()->isOpened()
 			 && !getInventory()->isEggHighlighted()
 			 && !getInventory()->isMagnifierInUse()) {
@@ -587,7 +589,7 @@ void Logic::updateCursor(bool) const { /* the cursor is always updated, even whe
 	if (getInventory()->isMagnifierInUse())
 		style = kCursorMagnifier;
 
-	if (getInventory()->isFlag1() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
+	if (getInventory()->isPortraitHighlighted() || getInventory()->isOpened() || getInventory()->isEggHighlighted())
 		style = kCursorNormal;
 
 	_engine->getCursor()->setStyle(style);
