@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef LASTEXPRESS_STATE_H
@@ -328,7 +325,7 @@ public:
 
 			switch (index) {
 			default:
-				error("GameProgress::isEqual: invalid index value (was: %d, max:127)", index);
+				error("[GameProgress::getValueName] Invalid index value (was: %d, max:127)", index);
 				break;
 
 			EXPOSE_VALUE(0, field_0);
@@ -566,6 +563,9 @@ public:
 		bool mouseLeftClick;
 		bool mouseRightClick;
 
+		bool mouseLeftPressed;
+		bool mouseRightPressed;
+
 		bool flag_entities_0;
 		bool flag_entities_1;
 
@@ -587,6 +587,9 @@ public:
 			mouseRightClick = false;
 			mouseLeftClick = false;
 
+			mouseLeftPressed = false;
+			mouseRightPressed = false;
+
 			flag_entities_0 = false;
 			flag_entities_1 = false;
 
