@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/events.cpp $
- * $Id: events.cpp 44634 2009-10-04 21:26:33Z fingolfin $
- *
  */
 
 
@@ -141,7 +138,8 @@ void Mouse::waitForRelease() {
 	LureEngine &engine = LureEngine::getReference();
 
 	do {
-		while (e.pollEvent() && !engine.shouldQuit()) ;
+		while (e.pollEvent() && !engine.shouldQuit())
+			;
 		g_system->delayMillis(20);
 	} while (!engine.shouldQuit() && (lButton() || rButton() || mButton()));
 }
