@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/lure/scripts.cpp $
- * $Id: scripts.cpp 52972 2010-10-02 00:10:21Z dreammaster $
- *
  */
 
 #include "lure/animseq.h"
@@ -34,7 +31,6 @@
 #include "lure/sound.h"
 #include "common/stack.h"
 #include "common/endian.h"
-#include "common/EventRecorder.h"
 
 namespace Lure {
 
@@ -1131,7 +1127,7 @@ uint16 Script::execute(uint16 startOffset) {
 			break;
 
 		case S_OPCODE_RANDOM:
-			param = r.random() >> 8; // make number between 0 to 255
+			param = r.getRandom() >> 8; // make number between 0 to 255
 			break;
 
 		case S_OPCODE_END:
