@@ -18,13 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/actor.cpp $
- * $Id: actor.cpp 48256 2010-03-14 05:39:47Z dreammaster $
- *
  */
 
 #include "common/system.h"
 #include "common/array.h"
+#include "common/textconsole.h"
 #include "m4/actor.h"
 #include "m4/m4_views.h"
 #include "m4/assets.h"
@@ -59,7 +57,7 @@ void Actor::placeWalkerSpriteAt(int spriteNum, int x, int y) {
 	info.height = info.sprite->height();
 	info.scaleX = info.scaleY = _scaling;
 	info.palette = _walkerSprites[_direction]->getPalette();
-	info.inverseColourTable = _m4Vm->scene()->getInverseColourTable();
+	info.inverseColorTable = _m4Vm->scene()->getInverseColorTable();
 
 	_vm->_scene->drawSprite(x, y, info, Common::Rect(640, 400));
 }
