@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/system.h"
@@ -97,7 +94,7 @@ void M4Surface::loadCodesM4(Common::SeekableReadStream *source) {
 	uint16 widthVal = source->readUint16LE();
 	uint16 heightVal = source->readUint16LE();
 
-	create(widthVal, heightVal, 1);
+	create(widthVal, heightVal, Graphics::PixelFormat::createFormatCLUT8());
 	source->read(pixels, widthVal * heightVal);
 }
 
@@ -111,7 +108,7 @@ void M4Surface::loadCodesMads(Common::SeekableReadStream *source) {
 	uint16 heightVal = 156;
 	byte *walkMap = new byte[source->size()];
 
-	create(widthVal, heightVal, 1);
+	create(widthVal, heightVal, Graphics::PixelFormat::createFormatCLUT8());
 	source->read(walkMap, source->size());
 
 	byte *ptr = (byte *)getBasePtr(0, 0);
@@ -411,7 +408,7 @@ void M4Surface::copyFrom(M4Surface *src, const Common::Rect &srcBounds, int dest
  * Copies a given image onto a destination surface with scaling, transferring only pixels that meet
  * the specified depth requirement on a secondary surface contain depth information
  */
-void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth, 
+void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 						 M4Surface *depthsSurface, int scale, int transparentColor) {
 
 	if (scale == 100) {
@@ -454,7 +451,7 @@ void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 		}
 
 		src->freeData();
-		depthsSurface->freeData();	
+		depthsSurface->freeData();
 		return;
 	}
 
@@ -504,7 +501,7 @@ void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 	widthAmount -= destRight;
 	if (widthAmount > 0)
 		spriteWidth -= widthAmount;
-	
+
 	int spriteRight = spriteLeft + spriteWidth;
 	if (spriteWidth <= 0)
 		return;
@@ -571,7 +568,7 @@ void M4Surface::copyFrom(M4Surface *src, int destX, int destY, int depth,
 	}
 
 	src->freeData();
-	depthsSurface->freeData();	
+	depthsSurface->freeData();
 	this->freeData();
 }
 
@@ -761,7 +758,7 @@ void M4Surface::rexLoadBackground(Common::SeekableReadStream *source, RGBList **
 	sourceUnc = packData.getItemStream(1);
 	assert((int)sourceUnc->size() >= sceneSize);
 
-	create(sceneWidth, sceneHeight, 1);
+	create(sceneWidth, sceneHeight, Graphics::PixelFormat::createFormatCLUT8());
 	byte *pData = (byte *)pixels;
 	sourceUnc->read(pData, sceneSize);
 
@@ -814,7 +811,7 @@ void M4Surface::m4LoadBackground(Common::SeekableReadStream *source) {
 	assert(width() == (int)widthVal);
 	//debugCN(kDebugGraphics, "width(): %d, widthVal: %d, height(): %d, heightVal: %d\n", width(), widthVal, height(), heightVal);
 
-	tileBuffer->create(tileWidth, tileHeight, 1);
+	tileBuffer->create(tileWidth, tileHeight, Graphics::PixelFormat::createFormatCLUT8());
 
 	for (curTileY = 0; curTileY < tilesY; curTileY++) {
 		clipY = MIN(heightVal, (1 + curTileY) * tileHeight) - (curTileY * tileHeight);
@@ -855,7 +852,7 @@ void M4Surface::madsLoadInterface(const Common::String &filename) {
 
 	// Chunk 1, data
 	intStream = intFile.getItemStream(1);
-	create(320, 44, 1);
+	create(320, 44, Graphics::PixelFormat::createFormatCLUT8());
 	intStream->read(pixels, 320 * 44);
 	delete intStream;
 
@@ -922,7 +919,7 @@ void M4Surface::scrollY(int yAmount) {
 		// Vertically shift all the lines
 		Common::copy(pixelsP + (pitch * ySize), pixelsP + (pitch * height()), pixelsP);
 		// Transfer the buffered lines to the bottom of the screen
-		Common::copy(tempData, tempData + blockSize, pixelsP + (pitch * (height() - ySize))); 
+		Common::copy(tempData, tempData + blockSize, pixelsP + (pitch * (height() - ySize)));
 	}
 
 	::free(tempData);
@@ -948,7 +945,7 @@ void M4Surface::translate(RGBList *list, bool isTransparent) {
 M4Surface *M4Surface::flipHorizontal() const {
 	M4Surface *dest = new M4Surface(width(), height());
 	dest->_rgbList = (this->_rgbList == NULL) ? NULL : this->_rgbList->clone();
-	
+
 	byte *destP = dest->getBasePtr();
 
 	for (int y = 0; y < height(); ++y) {
