@@ -18,12 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/m4_menus.cpp $
- * $Id: m4_menus.cpp 47732 2010-01-31 00:42:47Z dreammaster $
- *
  */
 
 #include "common/algorithm.h"		// for find()
+#include "common/textconsole.h"
+#include "common/translation.h"
 #include "gui/dialog.h"
 #include "gui/message.h"
 
@@ -136,7 +135,7 @@ void OrionCallbacks::saveLoadSaveFn(DialogView *view, MenuObject *item) {
 	bool succeeded = view->vm()->_saveLoad->save(view->_selectedSlot + 1, textItem->getText());
 
 	if (!succeeded) {
-		GUI::MessageDialog dialog("Save game failed!");
+		GUI::MessageDialog dialog(_("Save game failed!"));
 		dialog.runModal();
 	}
 
