@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/m4_views.cpp $
- * $Id: m4_views.cpp 49352 2010-05-31 12:38:15Z wjpalenstijn $
- *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/m4_views.h"
 #include "m4/events.h"
 #include "m4/font.h"
@@ -218,7 +217,7 @@ const char *INTERFACE_SERIES = "999intr";
 
 #define SPR(x) _sprites->getFrame(x)
 
-M4InterfaceView::M4InterfaceView(MadsM4Engine *vm): 
+M4InterfaceView::M4InterfaceView(MadsM4Engine *vm):
 		GameInterfaceView(vm, Common::Rect(0, vm->_screen->height() - INTERFACE_HEIGHT,
 				vm->_screen->width(), vm->_screen->height())),
 		_statusText(GUITextField(this, Common::Rect(200, 1, 450, 21))),
@@ -232,11 +231,9 @@ M4InterfaceView::M4InterfaceView(MadsM4Engine *vm):
 	_selected = false;
 
 	Common::SeekableReadStream *data = _vm->res()->get(INTERFACE_SERIES);
-	RGB8 *palette;
-
 	_sprites = new SpriteAsset(_vm, data, data->size(), INTERFACE_SERIES);
-	palette = _sprites->getPalette();
 
+	//RGB8 *palette = _sprites->getPalette();
 	//Palette.setPalette(palette, 0, _sprites->getColorCount());
 
 	_vm->res()->toss(INTERFACE_SERIES);
