@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/mads_anim.cpp $
- * $Id: mads_anim.cpp 50523 2010-06-30 10:13:20Z dreammaster $
- *
  */
 
+#include "common/textconsole.h"
+
 #include "m4/mads_anim.h"
 #include "m4/m4.h"
 #include "m4/compression.h"
@@ -60,7 +59,7 @@ TextviewView::TextviewView(MadsM4Engine *vm):
 	_vm->_palette->setPalette(&palData[0], 4, 3);
 	_vm->_palette->blockRange(4, 3);
 
-	_vm->_font->current()->setColours(5, 6, 4);
+	_vm->_font->current()->setColors(5, 6, 4);
 
 	clear();
 	_bgSurface.clear();
@@ -537,7 +536,7 @@ void AnimviewView::updateState() {
 		// Clear up current background and sprites
 		_backgroundSurface.reset();
 		clearLists();
-		
+
 		// Reset flags
 		_startFrame = -1;
 
@@ -604,7 +603,7 @@ static bool tempFlag = true;//****DEBUG - Temporarily allow me to skip several i
 		flags |= 0x100;
 
 	_activeAnimation = new MadsAnimation(_vm, this);
-	_activeAnimation->initialise(_currentLine, flags, &_backgroundSurface, &_codeSurface);
+	_activeAnimation->initialize(_currentLine, flags, &_backgroundSurface, &_codeSurface);
 
 	if (_startFrame != -1)
 		_activeAnimation->setCurrentFrame(_startFrame);
@@ -721,21 +720,21 @@ void AnimviewView::processCommand() {
 
 	case 'O':
 		param = param + 2;
-		//printf("O:%i ", atoi(param));
+		//warning(kDebugGraphics, "O:%i ", atoi(param));
 		_transition = atoi(param);
 		break;
 
 	case 'R':
 		param = param + 2;
-		//printf("R:%s ", param);
+		//warning(kDebugGraphics, "R:%s ", param);
 		break;
 
 	case 'W':
-		//printf("W ");
+		//warning(kDebugGraphics, "W ");
 		break;
 
 	case 'X':
-		//printf("X ");
+		//warning(kDebugGraphics, "X ");
 		break;
 
 	default:
