@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/mads_views.cpp $
- * $Id: mads_views.cpp 52364 2010-08-25 06:42:54Z dreammaster $
- *
  */
 
 #include "m4/m4_views.h"
@@ -34,6 +31,7 @@
 #include "m4/staticres.h"
 
 #include "common/algorithm.h"
+#include "common/textconsole.h"
 
 namespace M4 {
 
@@ -101,9 +99,9 @@ void MadsAction::set() {
 			// Use/to action
 			int selectedObject = _madsVm->scene()->getInterface()->getSelectedObject();
 			MadsObject *objEntry = _madsVm->globals()->getObject(selectedObject);
-			
-			_action.objectNameId = objEntry->descId;
-			_currentAction = objEntry->vocabList[_selectedRow].vocabId;
+
+			_action.objectNameId = objEntry->_descId;
+			_currentAction = objEntry->_vocabList[_selectedRow].vocabId;
 
 			// Set up the status text stirng
 			strcpy(_statusText, useStr);
@@ -121,7 +119,7 @@ void MadsAction::set() {
 					int selectedObject = _madsVm->scene()->getInterface()->getSelectedObject();
 					MadsObject *objEntry = _madsVm->globals()->getObject(selectedObject);
 
-					_currentAction = objEntry->vocabList[_selectedRow].vocabId;
+					_currentAction = objEntry->_vocabList[_selectedRow].vocabId;
 				}
 
 				appendVocab(_currentAction, true);
@@ -167,7 +165,7 @@ void MadsAction::set() {
 				if ((_actionMode2 == ACTMODE2_2) || (_actionMode2 == ACTMODE2_5)) {
 					// Get name from given inventory object
 					int objectId = _madsVm->scene()->getInterface()->getInventoryObject(_hotspotId);
-					_action.objectNameId = _madsVm->globals()->getObject(objectId)->descId;
+					_action.objectNameId = _madsVm->globals()->getObject(objectId)->_descId;
 				} else if (_hotspotId < hotspotCount) {
 					// Get name from scene hotspot
 					_action.objectNameId = (*_madsVm->scene()->getSceneResources().hotspots)[_hotspotId].getVocabID();
@@ -186,7 +184,7 @@ void MadsAction::set() {
 
 					if ((_v86F42 == 2) || (_v86F42 == 5)) {
 						int objectId = _madsVm->scene()->getInterface()->getInventoryObject(_hotspotId);
-						articleNum = _madsVm->globals()->getObject(objectId)->article;
+						articleNum = _madsVm->globals()->getObject(objectId)->_article;
 					} else if (_v86F3A < hotspotCount) {
 						articleNum = (*_madsVm->scene()->getSceneResources().hotspots)[_hotspotId].getArticle();
 					} else {
@@ -244,10 +242,10 @@ void MadsAction::refresh() {
 			}
 
 			// Add a new text display entry to display the status text at the bottom of the screen area
-			uint colours = (_vm->getGameType() == GType_DragonSphere) ? 0x0300 : 0x0003;
+			uint colors = (_vm->getGameType() == GType_DragonSphere) ? 0x0300 : 0x0003;
 
-			_statusTextIndex = _owner._textDisplay.add(160 - (strWidth / 2), 
-				MADS_SURFACE_HEIGHT + _owner._posAdjust.y - 13, colours, textSpacing, _statusText, font);
+			_statusTextIndex = _owner._textDisplay.add(160 - (strWidth / 2),
+				MADS_SURFACE_HEIGHT + _owner._posAdjust.y - 13, colors, textSpacing, _statusText, font);
 		}
 	}
 
@@ -258,7 +256,7 @@ void MadsAction::startAction() {
 	_madsVm->_player.moveComplete();
 
 	_inProgress = true;
-	_v8453A = 0;
+	_v8453A = ABORTMODE_0;
 	_savedFields.selectedRow = _selectedRow;
 	_savedFields.articleNumber = _articleNumber;
 	_savedFields.actionMode = _actionMode;
@@ -273,7 +271,7 @@ void MadsAction::startAction() {
 	strcpy(_dialogTitle, _statusText);
 
 	if ((_savedFields.actionMode2 == ACTMODE2_4) && (savedV86F42 == 0))
-		_v8453A = true;
+		_v8453A = ABORTMODE_1;
 
 	_startWalkFlag = false;
 	int hotspotId = -1;
@@ -397,6 +395,7 @@ int MadsSpriteSlots::addSprites(const char *resName, bool suppressErrors, int fl
 	// Append on a '.SS' suffix if the resource doesn't already have an extension
 	char buffer[100];
 	strncpy(buffer, resName, 95);
+	buffer[95] = '\0';
 	if (!strchr(buffer, '.'))
 		strcat(buffer, ".SS");
 
@@ -477,7 +476,7 @@ void MadsSpriteSlots::drawBackground() {
 
 				if (slot.depth > 1) {
 					// Draw the frame with depth processing
-					_owner._bgSurface->copyFrom(frame, xp, yp, slot.depth, _owner._depthSurface, 100, 
+					_owner._bgSurface->copyFrom(frame, xp, yp, slot.depth, _owner._depthSurface, 100,
 						frame->getTransparencyIndex());
 				} else {
 					// No depth, so simply draw the image
@@ -527,7 +526,7 @@ void MadsSpriteSlots::drawForeground(M4Surface *viewport) {
 
 		if ((slot.scale < 100) && (slot.scale != -1)) {
 			// Minimalised drawing
-			viewport->copyFrom(spr, slot.xp, slot.yp, slot.depth, _owner._depthSurface, slot.scale, 
+			viewport->copyFrom(spr, slot.xp, slot.yp, slot.depth, _owner._depthSurface, slot.scale,
 				sprite->getTransparencyIndex());
 		} else {
 			int xp, yp;
@@ -615,7 +614,7 @@ void MadsTextDisplay::clear() {
 		_entries[i].active = false;
 }
 
-int MadsTextDisplay::add(int xp, int yp, uint fontColour, int charSpacing, const char *msg, Font *font) {
+int MadsTextDisplay::add(int xp, int yp, uint fontColor, int charSpacing, const char *msg, Font *font) {
 	int usedSlot = -1;
 
 	for (int idx = 0; idx < TEXT_DISPLAY_SIZE; ++idx) {
@@ -628,8 +627,8 @@ int MadsTextDisplay::add(int xp, int yp, uint fontColour, int charSpacing, const
 			_entries[idx].msg = msg;
 			_entries[idx].bounds.setWidth(font->getWidth(msg, charSpacing));
 			_entries[idx].bounds.setHeight(font->getHeight());
-			_entries[idx].colour1 = fontColour & 0xff;
-			_entries[idx].colour2 = fontColour >> 8;
+			_entries[idx].color1 = fontColor & 0xff;
+			_entries[idx].color2 = fontColor >> 8;
 			_entries[idx].spacing = charSpacing;
 			_entries[idx].expire = 1;
 			_entries[idx].active = true;
@@ -665,8 +664,8 @@ void MadsTextDisplay::setDirtyAreas2() {
 void MadsTextDisplay::draw(M4Surface *view) {
 	for (uint idx = 0; idx < _entries.size(); ++idx) {
 		if (_entries[idx].active && (_entries[idx].expire >= 0)) {
-			_entries[idx].font->setColours(_entries[idx].colour1, _entries[idx].colour2, 0);
-			_entries[idx].font->writeString(view, _entries[idx].msg, 
+			_entries[idx].font->setColors(_entries[idx].color1, _entries[idx].color2, 0);
+			_entries[idx].font->writeString(view, _entries[idx].msg,
 				_entries[idx].bounds.left, _entries[idx].bounds.top, _entries[idx].bounds.width(),
 				_entries[idx].spacing);
 		}
@@ -706,7 +705,7 @@ void MadsKernelMessageList::clear() {
 	_talkFont = _vm->_font->getFont(FONT_CONVERSATION_MADS);
 }
 
-int MadsKernelMessageList::add(const Common::Point &pt, uint fontColour, uint8 flags, uint8 abortTimers, uint32 timeout, const char *msg) {
+int MadsKernelMessageList::add(const Common::Point &pt, uint fontColor, uint8 flags, uint8 abortTimers, uint32 timeout, const char *msg) {
 	// Find a free slot
 	uint idx = 0;
 	while ((idx < _entries.size()) && ((_entries[idx].flags & KMSG_ACTIVE) != 0))
@@ -721,15 +720,15 @@ int MadsKernelMessageList::add(const Common::Point &pt, uint fontColour, uint8 f
 	MadsKernelMessageEntry &rec = _entries[idx];
 	strcpy(rec.msg, msg);
 	rec.flags = flags | KMSG_ACTIVE;
-	rec.colour1 = fontColour & 0xff;
-	rec.colour2 = fontColour >> 8;
+	rec.color1 = fontColor & 0xff;
+	rec.color2 = fontColor >> 8;
 	rec.position = pt;
 	rec.textDisplayIndex = -1;
 	rec.timeout = timeout;
 	rec.frameTimer = _madsVm->_currentTimer;
 	rec.abortTimers = abortTimers;
 	rec.abortMode = _owner._abortTimersMode2;
-	
+
 	for (int i = 0; i < 3; ++i)
 		rec.actionNouns[i] = _madsVm->globals()->actionNouns[i];
 
@@ -851,7 +850,7 @@ void MadsKernelMessageList::processText(int msgIndex) {
 			y1 = seqEntry.msgPos.y;
 		}
 	}
-	
+
 	if (msg.flags & KMSG_PLAYER_TIMEOUT) {
 		if (word_8469E != 0) {
 			// TODO: Figure out various flags
@@ -868,7 +867,7 @@ void MadsKernelMessageList::processText(int msgIndex) {
 		msg.msg[msg.msgOffset] = msg.asciiChar;
 		char *msgP = &msg.msg[++msg.msgOffset];
 		*msgP = msg.asciiChar2;
-		
+
 		msg.asciiChar = *msgP;
 		msg.asciiChar2 = *(msgP + 1);
 
@@ -885,7 +884,7 @@ void MadsKernelMessageList::processText(int msgIndex) {
 		flag = true;
 	}
 
-	int strWidth = _talkFont->getWidth(msg.msg, _owner._textSpacing); 
+	int strWidth = _talkFont->getWidth(msg.msg, _owner._textSpacing);
 
 	if (msg.flags & (KMSG_RIGHT_ALIGN | KMSG_CENTER_ALIGN)) {
 		x1 -= (msg.flags & KMSG_CENTER_ALIGN) ? strWidth / 2 : strWidth;
@@ -917,7 +916,7 @@ void MadsKernelMessageList::processText(int msgIndex) {
 
 	if (msg.textDisplayIndex < 0) {
 		// Need to create a new text display entry for this message
-		int idx = _owner._textDisplay.add(x1, y1, msg.colour1 | (msg.colour2 << 8), _owner._textSpacing, msg.msg, _talkFont);
+		int idx = _owner._textDisplay.add(x1, y1, msg.color1 | (msg.color2 << 8), _owner._textSpacing, msg.msg, _talkFont);
 		if (idx >= 0)
 			msg.textDisplayIndex = idx;
 	}
@@ -936,7 +935,7 @@ ScreenObjects::ScreenObjects(MadsView &owner): _owner(owner) {
 	_category = 0;
 	_objectIndex = 0;
 }
-	
+
 /**
  * Clears the entries list
  */
@@ -1154,7 +1153,7 @@ void MadsDirtyAreas::setSpriteSlot(int dirtyIdx, const MadsSpriteSlot &spriteSlo
 
 		SpriteAsset &spriteSet = _owner._spriteSlots.getSprite(spriteSlot.spriteListIndex);
 		M4Sprite *frame = spriteSet.getFrame(((spriteSlot.frameNumber & 0x7fff) - 1) & 0x7f);
-		
+
 		if (spriteSlot.scale == -1) {
 			width = frame->width();
 			height = frame->height();
@@ -1271,8 +1270,8 @@ bool MadsSequenceList::addSubEntry(int index, SequenceSubEntryMode mode, int fra
 	return false;
 }
 
-int MadsSequenceList::add(int spriteListIndex, bool flipped, int frameIndex, int triggerCountdown, int delayTicks, int extraTicks, int numTicks, 
-		int msgX, int msgY, bool nonFixed, char scale, uint8 depth, int frameInc, SpriteAnimType animType, int numSprites, 
+int MadsSequenceList::add(int spriteListIndex, bool flipped, int frameIndex, int triggerCountdown, int delayTicks, int extraTicks, int numTicks,
+		int msgX, int msgY, bool nonFixed, char scale, uint8 depth, int frameInc, SpriteAnimType animType, int numSprites,
 		int frameStart) {
 
 	// Find a free slot
@@ -1341,7 +1340,7 @@ void MadsSequenceList::setSpriteSlot(int seqIndex, MadsSpriteSlot &spriteSlot) {
 	spriteSlot.frameNumber = (timerEntry.flipped ? 0x8000 : 0) | timerEntry.frameIndex;
 	spriteSlot.depth = timerEntry.depth;
 	spriteSlot.scale = timerEntry.scale;
-	
+
 	if (!timerEntry.nonFixed) {
 		spriteSlot.xp = timerEntry.msgPos.x;
 		spriteSlot.yp = timerEntry.msgPos.y;
@@ -1421,7 +1420,7 @@ bool MadsSequenceList::loadSprites(int seqIndex) {
 				seqEntry.frameInc = 1;
 			} else {
 				// Otherwise reset back to last sprite for further reverse animating
-				seqEntry.frameIndex = seqEntry.numSprites;		
+				seqEntry.frameIndex = seqEntry.numSprites;
 			}
 		}
 
@@ -1479,7 +1478,7 @@ void MadsSequenceList::tick() {
 			continue;
 
 		// Set the next timeout for the timer entry
-		seqEntry.timeout = currentTimer + seqEntry.numTicks;		
+		seqEntry.timeout = currentTimer + seqEntry.numTicks;
 
 		// Action the sprite
 		if (loadSprites(idx)) {
@@ -1510,7 +1509,7 @@ void MadsSequenceList::setAnimRange(int seqIndex, int startVal, int endVal) {
 		tempStart = 1;
 		break;
 	}
-	
+
 	switch (endVal) {
 	case -2:
 	case 0:
@@ -1559,7 +1558,7 @@ Animation::~Animation() {
 MadsView::MadsView(View *view): _view(view), _dynamicHotspots(*this), _sequenceList(*this),
 		_kernelMessages(*this), _spriteSlots(*this), _dirtyAreas(*this), _textDisplay(*this),
 		_screenObjects(*this), _action(*this) {
-		
+
 	_textSpacing = -1;
 	_newTimeout = 0;
 	_abortTimers = 0;
@@ -1591,8 +1590,8 @@ void MadsView::refresh() {
 
 	// Merge any identified dirty areas
 	_dirtyAreas.merge(1, DIRTY_AREAS_SIZE);
-	
-	// Copy dirty areas to the main display surface 
+
+	// Copy dirty areas to the main display surface
 	_dirtyAreas.copy(_viewport, _bgSurface, _posAdjust);
 
 	// Handle dirty areas for foreground objects
