@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/m4/saveload.cpp $
- * $Id: saveload.cpp 47705 2010-01-30 09:21:07Z dreammaster $
- *
  */
 
 #include "common/file.h"
@@ -99,7 +96,8 @@ SaveGameList *SaveLoad::getSaves() {
 				result->push_back(Common::String());
 			} else {
 				// Skip over byte offset
-				assert(saveFile->readUint32LE() < 0x100);
+				uint32 offset = saveFile->readUint32LE();
+				assert(offset < 0x100);
 
 				// Read in savegame name
 				saveFile->read(&saveName[0], MAX_SAVEGAME_NAME);
