@@ -18,17 +18,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/database.cpp $
- * $Id: database.cpp 51138 2010-07-22 11:20:16Z Bluddy $
- *
  */
 
-#include "common/system.h"
-#include "common/endian.h"
-#include "common/util.h"
-#include "common/savefile.h"
-
 #include "made/database.h"
+#include "made/redreader.h"
+
+#include "common/endian.h"
+#include "common/stream.h"
+#include "common/debug.h"
+#include "common/file.h"
+#include "common/savefile.h"
+#include "common/system.h"
 
 namespace Made {
 
@@ -108,7 +108,7 @@ void Object::setVectorItem(int16 index, int16 value) {
 	}
 }
 
-void Object::dump(const char *filename) {
+void Object::dump(const Common::String &filename) {
 	/*
 	FILE *o = fopen(filename, "wb");
 	fwrite(_objData, _objSize, 1, o);
@@ -275,7 +275,7 @@ void GameDatabase::openFromRed(const char *redFilename, const char *filename) {
 	_isRedSource = true;
 	_filename = filename;
 	_redFilename = redFilename;
-	Common::MemoryReadStream *fileS = RedReader::loadFromRed(redFilename, filename);
+	Common::SeekableReadStream *fileS = RedReader::loadFromRed(redFilename, filename);
 	if (!fileS)
 		error("GameDatabase::openFromRed() Could not load %s from %s", filename, redFilename);
 	load(*fileS);
@@ -289,7 +289,7 @@ void GameDatabase::reload() {
 			error("GameDatabase::reload() Could not open %s", _filename.c_str());
 		reloadFromStream(fd);
 	} else {
-		Common::MemoryReadStream *fileS = RedReader::loadFromRed(_redFilename.c_str(), _filename.c_str());
+		Common::SeekableReadStream *fileS = RedReader::loadFromRed(_redFilename.c_str(), _filename.c_str());
 		if (!fileS)
 			error("GameDatabase::openFromRed() Could not load %s from %s", _filename.c_str(), _redFilename.c_str());
 		reloadFromStream(*fileS);
@@ -375,9 +375,7 @@ int16 GameDatabase::setObjectProperty(int16 objectIndex, int16 propertyId, int16
 
 void GameDatabase::dumpObject(int16 index) {
 	Object *obj = getObject(index);
-	char fn[512];
-	sprintf(fn, "obj%04X.0", index);
-	obj->dump(fn);
+	obj->dump(Common::String::format("obj%04X.0", index));
 }
 
 
@@ -498,6 +496,7 @@ int16 GameDatabaseV2::savegame(const char *filename, const char *description, in
 	out->write(_gameState + 2, _gameStateSize - 2);
 	for (uint i = 0; i < _objects.size(); i++)
 		_objects[i]->save(*out);
+	out->finalize();
 	delete out;
 	return result;
 }
@@ -515,7 +514,7 @@ int16 GameDatabaseV2::loadgame(const char *filename, int16 version) {
 		_objects[i]->load(*in);
 	}
 	delete in;
-	
+
 	_objectPropertyCache.clear();	// make sure to clear cache
 	return result;
 }
@@ -646,7 +645,7 @@ void GameDatabaseV3::load(Common::SeekableReadStream &sourceS) {
 void GameDatabaseV3::reloadFromStream(Common::SeekableReadStream &sourceS) {
 	sourceS.seek(_gameStateOffs);
 	sourceS.read(_gameState, _gameStateSize);
-	
+
 	_objectPropertyCache.clear();	// make sure to clear cache
 }
 
@@ -659,7 +658,7 @@ bool GameDatabaseV3::getSavegameDescription(const char *filename, Common::String
 	}
 
 	uint32 header = in->readUint32BE();
-	if (header != MKID_BE('SGAM')) {
+	if (header != MKTAG('S','G','A','M')) {
 		warning("Save game header missing");
 		delete in;
 		return false;
@@ -696,11 +695,12 @@ int16 GameDatabaseV3::savegame(const char *filename, const char *description, in
 		return 6;
 	}
 	strncpy(desc, description, 64);
-	out->writeUint32BE(MKID_BE('SGAM'));
+	out->writeUint32BE(MKTAG('S','G','A','M'));
 	out->writeUint32LE(size);
 	out->writeUint16LE(version);
 	out->write(desc, 64);
 	out->write(_gameState, _gameStateSize);
+	out->finalize();
 	delete out;
 	return result;
 }
@@ -715,7 +715,7 @@ int16 GameDatabaseV3::loadgame(const char *filename, int16 version) {
 	}
 
 	uint32 header = in->readUint32BE();
-	if (header != MKID_BE('SGAM')) {
+	if (header != MKTAG('S','G','A','M')) {
 		warning("Save game header missing");
 		delete in;
 		return 1;
@@ -738,9 +738,9 @@ int16 GameDatabaseV3::loadgame(const char *filename, int16 version) {
 	in->skip(64); // skip savegame description
 	in->read(_gameState, _gameStateSize);
 	delete in;
-	
+
 	_objectPropertyCache.clear();	// make sure to clear cache
-	
+
 	return 0;
 }
 
