@@ -18,26 +18,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/database.h $
- * $Id: database.h 46102 2009-11-23 15:31:58Z john_doe $
- *
  */
 
 #ifndef MADE_DATABASE_H
 #define MADE_DATABASE_H
 
-#include "common/array.h"
 #include "common/hashmap.h"
-#include "common/util.h"
-#include "common/file.h"
-#include "common/stream.h"
-#include "common/str.h"
 
-#include "made/made.h"
-#include "made/redreader.h"
+namespace Common {
+class SeekableReadStream;
+class WriteStream;
+class String;
+}
 
 namespace Made {
 
+class MadeEngine;
+
 class Object {
 public:
 
@@ -65,7 +62,7 @@ public:
 	int16 getVectorItem(int16 index);
 	void setVectorItem(int16 index, int16 value);
 
-	void dump(const char *filename);
+	void dump(const Common::String &filename);
 
 protected:
 	bool _freeData;
