@@ -18,17 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/redreader.cpp $
- * $Id: redreader.cpp 47180 2010-01-08 22:07:35Z fingolfin $
- *
  */
 
 #include "made/redreader.h"
 
+#include "common/file.h"
+#include "common/memstream.h"
+
 namespace Made {
 
-
-Common::MemoryReadStream *RedReader::load(const char *redFilename, const char *filename) {
+Common::SeekableReadStream *RedReader::load(const char *redFilename, const char *filename) {
 
 	Common::File fd;
 	FileEntry fileEntry;
@@ -49,9 +48,9 @@ Common::MemoryReadStream *RedReader::load(const char *redFilename, const char *f
 
 }
 
-Common::MemoryReadStream *RedReader::loadFromRed(const char *redFilename, const char *filename) {
+Common::SeekableReadStream *RedReader::loadFromRed(const char *redFilename, const char *filename) {
 	RedReader* red = new RedReader();
-	Common::MemoryReadStream* stream = red->load(redFilename, filename);
+	Common::SeekableReadStream *stream = red->load(redFilename, filename);
 	delete red;
 	return stream;
 }
