@@ -18,29 +18,31 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/made/screen.cpp $
- * $Id: screen.cpp 47541 2010-01-25 01:39:44Z lordhoto $
- *
  */
 
-#include "made/made.h"
 #include "made/screen.h"
-#include "made/resource.h"
+#include "made/made.h"
+#include "made/screenfx.h"
 #include "made/database.h"
 
+#include "common/system.h"
+
+#include "graphics/surface.h"
+#include "graphics/palette.h"
+#include "graphics/cursorman.h"
+
 namespace Made {
 
 Screen::Screen(MadeEngine *vm) : _vm(vm) {
 
-	_screenPalette = new byte[256 * 4];
 	_palette = new byte[768];
 	_newPalette = new byte[768];
 
 	_backgroundScreen = new Graphics::Surface();
-	_backgroundScreen->create(320, 200, 1);
+	_backgroundScreen->create(320, 200, Graphics::PixelFormat::createFormatCLUT8());
 
 	_workScreen = new Graphics::Surface();
-	_workScreen->create(320, 200, 1);
+	_workScreen->create(320, 200, Graphics::PixelFormat::createFormatCLUT8());
 
 	_backgroundScreenDrawCtx.clipRect = Common::Rect(320, 200);
 	_workScreenDrawCtx.clipRect = Common::Rect(320, 200);
@@ -52,7 +54,7 @@ Screen::Screen(MadeEngine *vm) : _vm(vm) {
 	// Screen mask is only needed in v2 games
 	if (_vm->getGameID() != GID_RTZ) {
 		_screenMask = new Graphics::Surface();
-		_screenMask->create(320, 200, 1);
+		_screenMask->create(320, 200, Graphics::PixelFormat::createFormatCLUT8());
 		_maskDrawCtx.clipRect = Common::Rect(320, 200);
 		_maskDrawCtx.destSurface = _screenMask;
 	}
@@ -95,7 +97,6 @@ Screen::Screen(MadeEngine *vm) : _vm(vm) {
 
 Screen::~Screen() {
 
-	delete[] _screenPalette;
 	delete[] _palette;
 	delete[] _newPalette;
 
@@ -204,7 +205,7 @@ void Screen::drawSurface(Graphics::Surface *sourceSurface, int x, int y, int16 f
 	for (int16 yc = 0; yc < clipHeight; yc++) {
 		linePtr = source + sourceAdd;
 		for (int16 xc = 0; xc < clipWidth; xc++) {
-			if (*linePtr && (_vm->getGameID() == GID_RTZ || (mask == 0 || maskp[xc] == 0))) {
+			if (*linePtr && (_vm->getGameID() == GID_RTZ || (mask == 0 || (maskp && maskp[xc] == 0)))) {
 				if (*linePtr)
 					dest[xc] = *linePtr;
 			}
@@ -220,14 +221,7 @@ void Screen::drawSurface(Graphics::Surface *sourceSurface, int x, int y, int16 f
 }
 
 void Screen::setRGBPalette(byte *palRGB, int start, int count) {
-	for (int i = 0; i < count; i++) {
-		_screenPalette[i * 4 + 0] = palRGB[i * 3 + 0];
-		_screenPalette[i * 4 + 1] = palRGB[i * 3 + 1];
-		_screenPalette[i * 4 + 2] = palRGB[i * 3 + 2];
-		_screenPalette[i * 4 + 3] = 0;
-	}
-
-	_vm->_system->setPalette(_screenPalette, start, count);
+	_vm->_system->getPaletteManager()->setPalette(palRGB, start, count);
 }
 
 uint16 Screen::updateChannel(uint16 channelIndex) {
