@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 namespace Mohawk {
@@ -36,7 +33,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "ae3258c9c90128d274aa6a790b3ad181"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -54,7 +51,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("DEMO.DAT", "c39303dd53fb5c4e7f3c23231c606cd0"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_DEMO,
+			ADGF_DEMO | ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -72,7 +69,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "4beb3366ed3f3b9bfb6e81a14a43bdcc"),
 			Common::DE_DEU,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -90,7 +87,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "e0937cca1ab125e48e30dc3cd5046ddf"),
 			Common::DE_DEU,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -108,7 +105,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "f7e7d7ca69934f1351b5acd4fe4d44c2"),
 			Common::ES_ESP,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -126,7 +123,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "032c88e3b7e8db4ca475e7b7db9a66bb"),
 			Common::JA_JPN,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -144,7 +141,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "d631d42567a941c67c78f2e491f4ea58"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -162,7 +159,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MAKING.DAT", "f6387e8f0f7b8a3e42c95294315d6a0e"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MAKINGOF,
@@ -180,7 +177,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MAKING.DAT", "03ff62607e64419ab2b6ebf7b7bcdf63"),
 			Common::JA_JPN,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MAKINGOF,
@@ -198,7 +195,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "c4cae9f143b5947262e6cb2397e1617e"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -216,7 +213,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "c4cae9f143b5947262e6cb2397e1617e"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -234,7 +231,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "f88e0ace66dbca78eebdaaa1d3314ceb"),
 			Common::DE_DEU,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -252,7 +249,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MYST.DAT", "aea81633b2d2ae498f09072fb87263b6"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -270,7 +267,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "71145fdecbd68a0cfc292c2fbddf8e08"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -288,7 +285,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "d8ccae34a0e3c709135a73f449b783be"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -306,7 +303,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "249e8c995d191b03ee94c892c0eac775"),
 			Common::ES_ESP,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -324,7 +321,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "08fcaa5d5a2a01d7a5a6960f497212fe"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -342,7 +339,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "a5fe1c91a6033eb6ee54b287578b74b9"),
 			Common::DE_DEU,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -360,7 +357,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "aff2a384aaa9a0e0ec51010f708c5c04"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -378,7 +375,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("a_Data.MHK", "bae6b03bd8d6eb350d35fd13f0e3139f"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_DEMO,
+			ADGF_DEMO | ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -393,7 +390,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("signin.mhk", "410b4ce8d1a8702971e4d1ffba9b965d"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSTIME,
@@ -408,7 +405,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("iface.mhk", "5c1203712a16513bd158dc3c1b6cebd7"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_DEMO,
+			ADGF_DEMO | ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSTIME,
@@ -424,7 +421,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("ZOOMBINI.MHK", "98b758fec55104c096cfd129048be9a6"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_ZOOMBINI,
@@ -439,6 +436,21 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("ZOOMBINI.MHK", "0672f65c40dd065840c896e41c13f980"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			Common::GUIO_NONE
+		},
+		GType_ZOOMBINI,
+		GF_HASMIDI,
+		0
+	},
+
+	{
+		{
+			"zoombini",
+			"v2.0",
+			AD_ENTRY1("ZOOMBINI.MHK", "506b1122ffa740e2566cf0b583d24478"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
 			ADGF_NO_FLAGS,
 			Common::GUIO_NONE
 		},
@@ -454,7 +466,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("ZOOMBINI.MHK", "6ae0bdf791266b1fe3d4fabbf44c3faa"),
 			Common::DE_DEU,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_ZOOMBINI,
@@ -469,7 +481,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("ZOOMBINI.MHK", "8231e58525143ccf6e8b747df34b139f"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_ZOOMBINI,
@@ -484,7 +496,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("C2K.MHK", "605fe88380848031bbd0ff84ade6fe40"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSWORLD,
@@ -499,7 +511,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("C2K.MHK", "d4857aeb0f5e2e0c4ac556aa74f38c23"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSWORLD,
@@ -514,7 +526,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("AMTRAK.MHK", "2f95301f0bb950d555bb7b0e3b1b7eb1"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSAMTRAK,
@@ -641,6 +653,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"HARRY.EXE"
 	},
 
+	// part of "Super Living Books" compilation
+	// from rgemini, bug #3309343
+	{
+		{
+			"harryhh",
+			"",
+			AD_ENTRY1("HARRY.512", "39d11399796dfa36d3f631d2d87e8b85"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"HARRY.EXE"
+	},
+
 	{
 		{
 			"carmentq",
@@ -648,7 +677,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("Outline.txt", "67abce5dcda969c23f367a98c90439bc"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV5,
@@ -663,7 +692,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("Outline.txt", "6a281eefe72987afb0f8fb6cf84553f5"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV5,
@@ -671,6 +700,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0
 	},
 
+	// From afholman in bug #3309306
+	{
+		{
+			"lbsampler",
+			"v3",
+			AD_ENTRY1("outline", "8397cea6bed1ff90029f7602ef37684d"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV3,
+		0,
+		"Living Books Sampler"
+	},
+
 	{
 		{
 			"maggiesfa",
@@ -678,7 +723,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("Outline", "b7dc6e65fa9e80784a5bb8b557aa37c4"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -693,7 +738,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BookOutline", "1ce006d7daaa26cf61040203856b88f1"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -708,7 +753,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BRODER.MHK", "007299da8b2c6e8ec1cde9598c243024"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_JAMESMATH,
@@ -724,7 +769,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BRODER.MHK", "53c000938a50dca92860fd9b546dd276"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_JAMESMATH,
@@ -739,7 +784,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("MAINROOM.MHK", "12f51894d7f838af639ea9bf1bc8f45b"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_TREEHOUSE,
@@ -861,7 +906,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("AL236_1.MHK", "3ba145492a7b8b4dee0ef4222c5639c3"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_1STDEGREE,
@@ -879,7 +924,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("AL236_1.MHK", "0e0c70b1b702b6ddca61a1192ada1282"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_1STDEGREE,
@@ -894,7 +939,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("USAC2K.MHK", "b8c9d3a2586f62bce3a48b50d7a700e9"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_CSUSA,
@@ -917,6 +962,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"TORTOISE.EXE"
 	},
 
+	// part of "Super Living Books" compilation
+	// from rgemini, bug #3309343
+	{
+		{
+			"tortoise",
+			"",
+			AD_ENTRY1("TORTOISE.512", "e9ec7a6bc6b451c9e85e5b4f072d5143"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"TORTOISE.EXE"
+	},
+
 	// From afholman in bug#3309308
 	{
 		{
@@ -933,6 +995,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// From Torsten in bug#3422652
+	{
+		{
+			"tortoise",
+			"",
+			AD_ENTRY1("TORTB.LB", "9a80b66e7d95c7f59bdfd2c280e03e6e"),
+			Common::EN_GRB,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
 	// From afholman in bug#3309308
 	{
 		{
@@ -949,6 +1027,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// From Torsten in bug#3422652
+	{
+		{
+			"tortoise",
+			"",
+			AD_ENTRY1("TORTD.LB", "5d4d830116fe965ee35e328db85743b7"),
+			Common::DE_DEU,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
 	// From afholman in bug#3309308
 	{
 		{
@@ -965,6 +1059,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 		0,
 	},
 
+	// From Torsten in bug#3422652
+	{
+		{
+			"tortoise",
+			"",
+			AD_ENTRY1("TORTF.LB", "89f23bc3a1d1797bfe07dd0eaa7c13c4"),
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
 	{
 		{
 			"tortoise",
@@ -1041,6 +1151,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"ARTHUR.EXE"
 	},
 
+	// part of "Super Living Books" compilation
+	// from rgemini, bug #3309343
+	{
+		{
+			"arthur",
+			"",
+			AD_ENTRY1("PAGES.512", "cd995d20d0d7b4642476fd76044b4e5b"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		GF_LB_10,
+		"ARTHUR.EXE"
+	},
+
 	// From afholman in bug#3309308
 	{
 		{
@@ -1158,7 +1285,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("OUTLINE", "159c18b663c58d1aa17ad5e1ab1f0e12"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1183,6 +1310,70 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"GRANDMA.EXE"
 	},
 
+	// from jjnryan in bug #3389857
+	{
+		{
+			"grandma",
+			"v1.0",
+			AD_ENTRY1("PAGES.512", "613ca946bc8d91087fb7c10e9b84e88b"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		GF_LB_10,
+		"GRANDMA.EXE"
+	},
+
+	// From Torsten in bug#3422652
+	{
+		{
+			"grandma",
+			"",
+			AD_ENTRY1("JGMB.LB", "400b68a6f23b88ca23a01cfd11c6ef9f"),
+			Common::EN_GRB,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From Torsten in bug#3422652
+	{
+		{
+			"grandma",
+			"",
+			AD_ENTRY1("JGMD.LB", "c4fbfd73f805a2266cf9e15caa1b7462"),
+			Common::DE_DEU,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From Torsten in bug#3422652
+	{
+		{
+			"grandma",
+			"",
+			AD_ENTRY1("JGMF.LB", "0c3305e109a027f8b62a6bd8c5d2addb"),
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
 	{
 		{
 			"grandma",
@@ -1354,6 +1545,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"NEWKID.EXE"
 	},
 
+	// part of "Super Living Books" compilation
+	// from rgemini, bug #3309343
+	{
+		{
+			"newkid",
+			"",
+			AD_ENTRY1("NEWKID.512", "28a5aef3e6ef7e2ed7742485c25bdff6"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"NEWKID.EXE"
+	},
+
 	// From aluff in bug#3309981
 	{
 		{
@@ -1438,7 +1646,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("RACE.LB", "1645f36bcb36e440d928e920aa48c373"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1454,7 +1662,22 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("RACE32.LB", "292a05bc48c1dd9583821a4181a02ef2"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV3,
+		0,
+		0
+	},
+
+	{
+		{
+			"arthurrace",
+			"",
+			AD_ENTRY1("BookOutline", "f0a9251824a648fce1b49cb7c1a0ba67"),
+			Common::EN_ANY,
+			Common::kPlatformMacintosh,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1494,6 +1717,71 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"Living Books Player"
 	},
 
+	// From Torsten in bug#3422652
+	{
+		{
+			"arthurbday",
+			"",
+			AD_ENTRY1("AB16B.LB", "54223967c507a48e572902802650412f"),
+			Common::EN_GRB,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From Torsten in bug#3422652
+	{
+		{
+			"arthurbday",
+			"",
+			AD_ENTRY1("AB16D.LB", "1154bfdb9fe8c42ad8692e68071ec175"),
+			Common::DE_DEU,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// From Torsten in bug#3422652
+	{
+		{
+			"arthurbday",
+			"",
+			AD_ENTRY1("AB16F.LB", "60f439aa56c22a400bda27c9574115a9"),
+			Common::FR_FRA,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV2,
+		0,
+		0,
+	},
+
+	// Arthur Birthday (English) Version 2.0 Windows(R) August 8, 1997
+	// From jacecen in bug #3413119
+	{
+		{
+			"arthurbday",
+			"",
+			AD_ENTRY1("Outline", "3b793adf2b303722e0fb6c632f94e1fb"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_UNSTABLE,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV3,
+		0,
+		0
+	},
+
 	{
 		{
 			"arthurbday",
@@ -1689,7 +1977,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("Outline", "0b5ab6dd7c08cf23066efa709fa48bbc"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1704,7 +1992,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BookOutline", "e139903eee98f0b0c3f39247a23b8f10"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1719,7 +2007,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("outline", "525be248363fe27d50d750632c1e759e"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV4,
@@ -1734,7 +2022,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BookOutline", "54a324ee6f8260258bff7043a05b0004"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV4,
@@ -1752,7 +2040,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("outline", "36225e0b4986a80135cfdd9643cc7030"),
 			Common::FR_FRA,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV4,
@@ -1828,7 +2116,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("outline", "d239506f969ff68fa886f084082e9158"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1843,7 +2131,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BookOutline", "6dd1c0606f1db3b71207121b4370e487"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV3,
@@ -1866,6 +2154,23 @@ static const MohawkGameDescription gameDescriptions[] = {
 		"FIGHT.EXE"
 	},
 
+	// The Berenstain Bears Get in a Fight (English and Spanish) Version 1.0 1995
+	// From jacecen in bug #3413119
+	{
+		{
+			"bearfight",
+			"",
+			AD_ENTRY1("FIGHT.512", "e313242a4cba2fffcd8cded5ca23c68a"),
+			Common::EN_ANY,
+			Common::kPlatformWindows,
+			ADGF_NO_FLAGS,
+			Common::GUIO_NONE
+		},
+		GType_LIVINGBOOKSV1,
+		0,
+		"FIGHT.EXE"
+	},
+
 	{
 		{
 			"bearfight",
@@ -1937,7 +2242,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("OUTLINE", "dec4d1a05449f81b6012706932658326"),
 			Common::EN_ANY,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV4,
@@ -1952,7 +2257,7 @@ static const MohawkGameDescription gameDescriptions[] = {
 			AD_ENTRY1("BookOutline", "87bf1f9113340ce1c6c880932e815882"),
 			Common::EN_ANY,
 			Common::kPlatformMacintosh,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_LIVINGBOOKSV4,
@@ -2153,7 +2458,7 @@ static const MohawkGameDescription fallbackDescs[] = {
 			AD_ENTRY1(0, 0),
 			Common::UNK_LANG,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -2168,7 +2473,7 @@ static const MohawkGameDescription fallbackDescs[] = {
 			AD_ENTRY1(0, 0),
 			Common::UNK_LANG,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MAKINGOF,
@@ -2183,7 +2488,7 @@ static const MohawkGameDescription fallbackDescs[] = {
 			AD_ENTRY1(0, 0),
 			Common::UNK_LANG,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_MYST,
@@ -2198,7 +2503,7 @@ static const MohawkGameDescription fallbackDescs[] = {
 			AD_ENTRY1(0, 0),
 			Common::UNK_LANG,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -2213,7 +2518,7 @@ static const MohawkGameDescription fallbackDescs[] = {
 			AD_ENTRY1(0, 0),
 			Common::UNK_LANG,
 			Common::kPlatformWindows,
-			ADGF_NO_FLAGS,
+			ADGF_UNSTABLE,
 			Common::GUIO_NONE
 		},
 		GType_RIVEN,
@@ -2223,11 +2528,11 @@ static const MohawkGameDescription fallbackDescs[] = {
 };
 
 static const ADFileBasedFallback fileBased[] = {
-	{ &fallbackDescs[0],  { "MYST.DAT", 0 } },
-	{ &fallbackDescs[1],  { "MAKING.DAT", 0 } },
-	{ &fallbackDescs[2],  { "MYST.DAT", "Help.dat", 0 } },	// Help system doesn't exist in original
-	{ &fallbackDescs[3],  { "a_Data.MHK", 0 } },
-	{ &fallbackDescs[4],  { "a_Data.MHK", "t_Data1.MHK" , 0 } },
+	{ &fallbackDescs[0].desc,  { "MYST.DAT", 0 } },
+	{ &fallbackDescs[1].desc,  { "MAKING.DAT", 0 } },
+	{ &fallbackDescs[2].desc,  { "MYST.DAT", "Help.dat", 0 } },	// Help system doesn't exist in original
+	{ &fallbackDescs[3].desc,  { "a_Data.MHK", 0 } },
+	{ &fallbackDescs[4].desc,  { "a_Data.MHK", "t_Data1.MHK" , 0 } },
 	{ 0, { 0 } }
 };
 
