@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "mohawk/livingbooks.h"
@@ -31,10 +28,11 @@
 #include "common/config-manager.h"
 #include "common/error.h"
 #include "common/events.h"
-#include "common/EventRecorder.h"
 #include "common/fs.h"
 #include "common/archive.h"
 #include "common/textconsole.h"
+#include "common/system.h"
+#include "common/memstream.h"
 
 #include "graphics/palette.h"
 
@@ -45,7 +43,7 @@
 namespace Mohawk {
 
 // read a null-terminated string from a stream
-Common::String MohawkEngine_LivingBooks::readString(Common::SeekableSubReadStreamEndian *stream) {
+Common::String MohawkEngine_LivingBooks::readString(Common::ReadStream *stream) {
 	Common::String ret;
 	while (!stream->eos()) {
 		byte in = stream->readByte();
@@ -57,7 +55,7 @@ Common::String MohawkEngine_LivingBooks::readString(Common::SeekableSubReadStrea
 }
 
 // read a rect from a stream
-Common::Rect MohawkEngine_LivingBooks::readRect(Common::SeekableSubReadStreamEndian *stream) {
+Common::Rect MohawkEngine_LivingBooks::readRect(Common::ReadStreamEndian *stream) {
 	Common::Rect rect;
 
 	// the V1 mac games have their rects in QuickDraw order
@@ -84,13 +82,19 @@ LBPage::LBPage(MohawkEngine_LivingBooks *vm) : _vm(vm) {
 	_cascade = false;
 }
 
-void LBPage::open(MohawkArchive *mhk, uint16 baseId) {
+void LBPage::open(Archive *mhk, uint16 baseId) {
 	_mhk = mhk;
 	_baseId = baseId;
 
 	_vm->addArchive(_mhk);
-	if (_vm->hasResource(ID_BCOD, baseId))
+	if (!_vm->hasResource(ID_BCOD, baseId)) {
+		// assume that BCOD is mandatory for v4/v5
+		if (_vm->getGameType() == GType_LIVINGBOOKSV4 || _vm->getGameType() == GType_LIVINGBOOKSV5)
+			error("missing BCOD resource (id %d)", baseId);
+		_code = new LBCode(_vm, 0);
+	} else {
 		_code = new LBCode(_vm, baseId);
+	}
 
 	loadBITL(baseId);
 	for (uint i = 0; i < _items.size(); i++)
@@ -128,8 +132,7 @@ MohawkEngine_LivingBooks::MohawkEngine_LivingBooks(OSystem *syst, const MohawkGa
 
 	_alreadyShowedIntro = false;
 
-	_rnd = new Common::RandomSource();
-	g_eventRec.registerRandomSource(*_rnd, "livingbooks");
+	_rnd = new Common::RandomSource("livingbooks");
 
 	_page = NULL;
 
@@ -201,9 +204,12 @@ Common::Error MohawkEngine_LivingBooks::run() {
 				break;
 
 			case Common::EVENT_LBUTTONDOWN:
-				for (uint16 i = 0; i < _items.size(); i++)
-					if (_items[i]->contains(event.mouse))
-						found = _items[i];
+				for (Common::List<LBItem *>::const_iterator i = _orderedItems.begin(); i != _orderedItems.end(); ++i) {
+					if ((*i)->contains(event.mouse)) {
+						found = *i;
+						break;
+					}
+				}
 
 				if (found)
 					found->handleMouseDown(event.mouse);
@@ -293,6 +299,15 @@ void MohawkEngine_LivingBooks::loadBookInfo(const Common::String &filename) {
 	//     - fUse254ColorPalette         (always true?)
 	//     - nKBRequired                 (4096, RAM requirement?)
 	//     - fDebugWindow                (always 0?)
+
+	if (_bookInfoFile.hasSection("Globals")) {
+		const Common::ConfigFile::SectionKeyList globals = _bookInfoFile.getKeys("Globals");
+		for (Common::ConfigFile::SectionKeyList::const_iterator i = globals.begin(); i != globals.end(); i++) {
+			Common::String command = Common::String::format("%s = %s", i->key.c_str(), i->value.c_str());
+			debug("global: %s", command.c_str());
+			// TODO: run command
+		}
+	}
 }
 
 Common::String MohawkEngine_LivingBooks::stringForMode(LBMode mode) {
@@ -329,6 +344,7 @@ void MohawkEngine_LivingBooks::destroyPage() {
 
 	delete _page;
 	assert(_items.empty());
+	assert(_orderedItems.empty());
 	_page = NULL;
 
 	_notifyEvents.clear();
@@ -379,8 +395,8 @@ bool MohawkEngine_LivingBooks::loadPage(LBMode mode, uint page, uint subpage) {
 		warning("ignoring 'killgag' for filename '%s'", filename.c_str());
 	}
 
-	MohawkArchive *pageArchive = createMohawkArchive();
-	if (!filename.empty() && pageArchive->open(filename)) {
+	Archive *pageArchive = createArchive();
+	if (!filename.empty() && pageArchive->openFile(filename)) {
 		_page = new LBPage(this);
 		_page->open(pageArchive, 1000);
 	} else {
@@ -555,6 +571,7 @@ void MohawkEngine_LivingBooks::updatePage() {
 			case kLBDelayedEventDestroy:
 				_items.remove_at(i);
 				i--;
+				_orderedItems.remove(delayedEvent.item);
 				delete delayedEvent.item;
 				_page->itemDestroyed(delayedEvent.item);
 				if (_focus == delayedEvent.item)
@@ -584,11 +601,11 @@ void MohawkEngine_LivingBooks::updatePage() {
 	}
 }
 
-void MohawkEngine_LivingBooks::addArchive(MohawkArchive *archive) {
+void MohawkEngine_LivingBooks::addArchive(Archive *archive) {
 	_mhk.push_back(archive);
 }
 
-void MohawkEngine_LivingBooks::removeArchive(MohawkArchive *archive) {
+void MohawkEngine_LivingBooks::removeArchive(Archive *archive) {
 	for (uint i = 0; i < _mhk.size(); i++) {
 		if (archive != _mhk[i])
 			continue;
@@ -601,6 +618,8 @@ void MohawkEngine_LivingBooks::removeArchive(MohawkArchive *archive) {
 
 void MohawkEngine_LivingBooks::addItem(LBItem *item) {
 	_items.push_back(item);
+	_orderedItems.push_front(item);
+	item->_iterator = _orderedItems.begin();
 }
 
 void MohawkEngine_LivingBooks::removeItems(const Common::Array<LBItem *> &items) {
@@ -614,6 +633,7 @@ void MohawkEngine_LivingBooks::removeItems(const Common::Array<LBItem *> &items)
 			break;
 		}
 		assert(found);
+		_orderedItems.erase(items[i]->_iterator);
 	}
 }
 
@@ -746,6 +766,9 @@ void LBPage::loadBITL(uint16 resourceId) {
 		case kLBMiniGameItem:
 			res = new LBMiniGameItem(_vm, this, rect);
 			break;
+		case kLBProxyItem:
+			res = new LBProxyItem(_vm, this, rect);
+			break;
 		default:
 			warning("Unknown item type %04x", type);
 		case 3: // often used for buttons
@@ -759,6 +782,8 @@ void LBPage::loadBITL(uint16 resourceId) {
 		if (bitlStream->size() == bitlStream->pos())
 			break;
 	}
+
+	delete bitlStream;
 }
 
 Common::SeekableSubReadStreamEndian *MohawkEngine_LivingBooks::wrapStreamEndian(uint32 tag, uint16 id) {
@@ -854,8 +879,11 @@ Common::String MohawkEngine_LivingBooks::convertWinFileName(const Common::String
 	return filename;
 }
 
-MohawkArchive *MohawkEngine_LivingBooks::createMohawkArchive() const {
-	return isPreMohawk() ? new LivingBooksArchive_v1() : new MohawkArchive();
+Archive *MohawkEngine_LivingBooks::createArchive() const {
+	if (isPreMohawk())
+		return new LivingBooksArchive_v1();
+
+	return new MohawkArchive();
 }
 
 bool MohawkEngine_LivingBooks::isPreMohawk() const {
@@ -1299,8 +1327,13 @@ void MohawkEngine_LivingBooks::handleNotify(NotifyEvent &event) {
 		if (getGameType() == GType_LIVINGBOOKSV1) {
 			debug(2, "kLBNotifyChangeMode: %d", event.param);
 			quitGame();
-		} else {
-			debug(2, "kLBNotifyChangeMode: mode %d, page %d.%d",
+			break;
+		}
+
+		debug(2, "kLBNotifyChangeMode: v2 type %d", event.param);
+		switch (event.param) {
+		case 1:
+			debug(2, "kLBNotifyChangeMode:, mode %d, page %d.%d",
 				event.newMode, event.newPage, event.newSubpage);
 			// TODO: what is entry.newUnknown?
 			if (!event.newMode)
@@ -1311,6 +1344,13 @@ void MohawkEngine_LivingBooks::handleNotify(NotifyEvent &event) {
 						error("kLBNotifyChangeMode failed to move to mode %d, page %d.%d",
 							event.newMode, event.newPage, event.newSubpage);
 			}
+			break;
+		case 3:
+			debug(2, "kLBNotifyChangeMode: new cursor '%s'", event.newCursor.c_str());
+			_cursor->setCursor(event.newCursor);
+			break;
+		default:
+			error("unknown v2 kLBNotifyChangeMode type %d", event.param);
 		}
 		break;
 
@@ -1865,6 +1905,7 @@ uint16 LBAnimation::getParentId() {
 
 LBScriptEntry::LBScriptEntry() {
 	state = 0;
+	data = NULL;
 	argvParam = NULL;
 	argvTarget = NULL;
 }
@@ -1872,6 +1913,7 @@ LBScriptEntry::LBScriptEntry() {
 LBScriptEntry::~LBScriptEntry() {
 	delete[] argvParam;
 	delete[] argvTarget;
+	delete[] data;
 
 	for (uint i = 0; i < subentries.size(); i++)
 		delete subentries[i];
@@ -1935,7 +1977,10 @@ void LBItem::readFrom(Common::SeekableSubReadStreamEndian *stream) {
 		uint16 dataSize = stream->readUint16();
 
 		debug(4, "Data type %04x, size %d", dataType, dataSize);
-		readData(dataType, dataSize, stream);
+		byte *buf = new byte[dataSize];
+		stream->read(buf, dataSize);
+		readData(dataType, dataSize, buf);
+		delete[] buf;
 
 		if ((uint)stream->pos() != oldPos + 4 + (uint)dataSize)
 			error("Failed to read correct number of bytes (off by %d) for data type %04x (size %d)",
@@ -1948,7 +1993,7 @@ void LBItem::readFrom(Common::SeekableSubReadStreamEndian *stream) {
 	}
 }
 
-LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::SeekableSubReadStreamEndian *stream, bool isSubentry) {
+LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::MemoryReadStreamEndian *stream, bool isSubentry) {
 	if (size < 6)
 		error("Script entry of type 0x%04x was too small (%d)", type, size);
 
@@ -1991,30 +2036,40 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 		entry->argc = stream->readUint16();
 		size -= 2;
 
-		uint16 targetingType = entry->argc;
-		if (targetingType == 0x3f3f || targetingType == 0xffff) {
-			entry->argc = 0;
+		entry->targetingType = 0;
 
+		uint16 targetingType = entry->argc;
+		if (targetingType == kTargetTypeExpression || targetingType == kTargetTypeCode
+			|| targetingType == kTargetTypeName) {
+			entry->targetingType = targetingType;
+
+			// FIXME
+			if (targetingType == kTargetTypeCode)
+				error("encountered kTargetTypeCode");
+
+			if (size < 2)
+				error("not enough bytes (%d) reading special targeting", size);
 			uint16 count = stream->readUint16();
 			size -= 2;
 
 			debug(4, "%d targets with targeting type %04x", count, targetingType);
 
-			// FIXME: targeting by name
 			uint oldAlign = size % 2;
 			for (uint i = 0; i < count; i++) {
 				Common::String target = _vm->readString(stream);
-				warning("ignoring target '%s' in script entry", target.c_str());
+				debug(4, "target '%s'", target.c_str());
+				entry->targets.push_back(target);
+				if (target.size() + 1 > size)
+					error("failed to read target (ran out of stream)");
 				size -= target.size() + 1;
 			}
+			entry->argc = entry->targets.size();
 
 			if ((uint)(size % 2) != oldAlign) {
 				stream->skip(1);
 				size--;
 			}
-		}
-
-		if (entry->argc) {
+		} else if (entry->argc) {
 			entry->argvParam = new uint16[entry->argc];
 			entry->argvTarget = new uint16[entry->argc];
 			debug(4, "With %d targets:", entry->argc);
@@ -2049,16 +2104,32 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 	}
 
 	if (type == kLBNotifyScript && entry->opcode == kLBNotifyChangeMode && _vm->getGameType() != GType_LIVINGBOOKSV1) {
-		if (size < 8) {
-			error("%d unknown bytes in notify entry kLBNotifyChangeMode", size);
+		switch (entry->param) {
+		case 1:
+			if (size < 8)
+				error("%d unknown bytes in notify entry kLBNotifyChangeMode", size);
+			entry->newUnknown = stream->readUint16();
+			entry->newMode = stream->readUint16();
+			entry->newPage = stream->readUint16();
+			entry->newSubpage = stream->readUint16();
+			debug(4, "kLBNotifyChangeMode: unknown %04x, mode %d, page %d.%d",
+				entry->newUnknown, entry->newMode, entry->newPage, entry->newSubpage);
+			size -= 8;
+			break;
+		case 3:
+			{
+			Common::String newCursor = _vm->readString(stream);
+			entry->newCursor = newCursor;
+			if (size < newCursor.size() + 1)
+				error("failed to read newCursor in notify entry");
+			size -= newCursor.size() + 1;
+			debug(4, "kLBNotifyChangeMode: new cursor '%s'", newCursor.c_str());
+			}
+			break;
+		default:
+			// the original engine also does something when param==2 (but not a notify)
+			error("unknown v2 kLBNotifyChangeMode type %d", entry->param);
 		}
-		entry->newUnknown = stream->readUint16();
-		entry->newMode = stream->readUint16();
-		entry->newPage = stream->readUint16();
-		entry->newSubpage = stream->readUint16();
-		debug(4, "kLBNotifyChangeMode: unknown %04x, mode %d, page %d.%d",
-			entry->newUnknown, entry->newMode, entry->newPage, entry->newSubpage);
-		size -= 8;
 	}
 	if (entry->opcode == kLBOpSendExpression) {
 		if (size < 4)
@@ -2067,37 +2138,33 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 		debug(4, "kLBOpSendExpression: offset %08x", entry->offset);
 		size -= 4;
 	}
-	if (entry->opcode == 0xffff) {
+	if (entry->opcode == kLBOpRunData) {
 		if (size < 4)
-			error("didn't get enough bytes (%d) to read message in script entry", size);
-		uint16 msgId = stream->readUint16();
-		uint16 msgLen = stream->readUint16();
+			error("didn't get enough bytes (%d) to read data header in script entry", size);
+		entry->dataType = stream->readUint16();
+		entry->dataLen = stream->readUint16();
 		size -= 4;
 
-		if (msgId == kLBSetPlayInfo) {
-			if (size != 20)
-				error("wah, more than just the kLBSetPlayInfo in here");
-			// FIXME
-			warning("ignoring kLBSetPlayInfo");
-			size -= 20;
-			stream->skip(20);
-			return entry;
+		if (size < entry->dataLen)
+			error("didn't get enough bytes (%d) to read data in script entry", size);
+
+		if (entry->dataType == kLBCommand) {
+			Common::String command = _vm->readString(stream);
+			uint commandSize = command.size() + 1;
+			if (commandSize > entry->dataLen)
+				error("failed to read command in script entry: dataLen %d, command '%s' (%d chars)",
+					 entry->dataLen, command.c_str(), commandSize);
+			entry->dataLen = commandSize;
+			entry->data = new byte[commandSize];
+			memcpy(entry->data, command.c_str(), commandSize);
+			size -= commandSize;
+		} else {
+			if (conditionTag)
+				error("kLBOpRunData had unexpected conditionTag");
+			entry->data = new byte[entry->dataLen];
+			stream->read(entry->data, entry->dataLen);
+			size -= entry->dataLen;
 		}
-		if (msgId != kLBCommand)
-			error("expected a command in script entry, got 0x%04x", msgId);
-
-		if (msgLen != size - (entry->event == kLBEventNotified ? 4 : 0) && !conditionTag)
-			error("script entry msgLen %d is not equal to size %d", msgLen, size);
-
-		Common::String command = _vm->readString(stream);
-		if (command.size() + 1 > size) {
-			error("failed to read command in script entry: msgLen %d, command '%s' (%d chars)",
-				msgLen, command.c_str(), command.size());
-		}
-		size -= command.size() + 1;
-
-		entry->command = command;
-		debug(4, "script entry command '%s'", command.c_str());
 	}
 	if (entry->event == kLBEventNotified) {
 		if (size < 4)
@@ -2118,6 +2185,8 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 	}
 
 	if (conditionTag == 1) {
+		if (!size)
+			error("failed to read condition (empty stream)");
 		Common::String condition = _vm->readString(stream);
 		if (condition.size() == 0) {
 			size--;
@@ -2132,6 +2201,8 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 		entry->conditions.push_back(condition);
 		debug(4, "script entry condition '%s'", condition.c_str());
 	} else if (conditionTag == 2) {
+		if (size < 4)
+			error("expected more than %d bytes for conditionTag 2", size);
 		// FIXME
 		stream->skip(4);
 		size -= 4;
@@ -2148,7 +2219,12 @@ LBScriptEntry *LBItem::parseScriptEntry(uint16 type, uint16 &size, Common::Seeka
 	return entry;
 }
 
-void LBItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEndian *stream) {
+void LBItem::readData(uint16 type, uint16 size, byte *data) {
+	Common::MemoryReadStreamEndian stream(data, size, _vm->isBigEndian());
+	readData(type, size, &stream);
+}
+
+void LBItem::readData(uint16 type, uint16 size, Common::MemoryReadStreamEndian *stream) {
 	switch (type) {
 	case kLBMsgListScript:
 	case kLBNotifyScript:
@@ -2266,8 +2342,6 @@ void LBItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEnd
 		{
 		assert(size == 4);
 		uint offset = stream->readUint32();
-		if (!_page->_code)
-			error("no BCOD?");
 		_page->_code->runCode(this, offset);
 		}
 		break;
@@ -2539,6 +2613,7 @@ void LBItem::runScript(uint event, uint16 data, uint16 from) {
 				notifyEvent.newMode = entry->newMode;
 				notifyEvent.newPage = entry->newPage;
 				notifyEvent.newSubpage = entry->newSubpage;
+				notifyEvent.newCursor = entry->newCursor;
 				_vm->addNotifyEvent(notifyEvent);
 			} else
 				_vm->addNotifyEvent(NotifyEvent(entry->opcode, entry->param));
@@ -2604,15 +2679,59 @@ int LBItem::runScriptEntry(LBScriptEntry *entry) {
 			entry->type, entry->event, entry->opcode, entry->param);
 
 		if (entry->argc) {
-			uint16 targetId = entry->argvTarget[n];
-			// TODO: is this type, perhaps?
-			uint16 param = entry->argvParam[n];
-			target = _vm->getItemById(targetId);
-			if (!target) {
-				debug(2, "Target %04x (%04x) doesn't exist, skipping", targetId, param);
-				continue;
+			switch (entry->targetingType) {
+			case kTargetTypeExpression:
+				{
+				// FIXME: this should be EVALUATED
+				LBValue &tgt = _vm->_variables[entry->targets[n]];
+				switch (tgt.type) {
+				case kLBValueItemPtr:
+					target = tgt.item;
+					break;
+				case kLBValueString:
+					// FIXME: handle 'self', at least
+					// TODO: correct otherwise? or only self?
+					target = _vm->getItemByName(tgt.string);
+					break;
+				case kLBValueInteger:
+					target = _vm->getItemById(tgt.integer);
+					break;
+				default:
+					// FIXME: handle list
+					warning("Target '%s' (by expression) resulted in unknown type, skipping", entry->targets[n].c_str());
+					continue;
+				}
+				}
+				if (!target) {
+					debug(2, "Target '%s' (by expression) doesn't exist, skipping", entry->targets[n].c_str());
+					continue;
+				}
+				debug(2, "Target: '%s' (expression '%s')", target->_desc.c_str(), entry->targets[n].c_str());
+				break;
+			case kTargetTypeCode:
+				// FIXME
+				error("encountered kTargetTypeCode");
+				break;
+			case kTargetTypeName:
+				// FIXME: handle 'self'
+				target = _vm->getItemByName(entry->targets[n]);
+				if (!target) {
+					debug(2, "Target '%s' (by name) doesn't exist, skipping", entry->targets[n].c_str());
+					continue;
+				}
+				debug(2, "Target: '%s' (by name)", target->_desc.c_str());
+				break;
+			default:
+				uint16 targetId = entry->argvTarget[n];
+				// TODO: is this type, perhaps?
+				uint16 param = entry->argvParam[n];
+				target = _vm->getItemById(targetId);
+				if (!target) {
+					debug(2, "Target %04x (%04x) doesn't exist, skipping", targetId, param);
+					continue;
+				}
+				debug(2, "Target: %04x (%04x) '%s'", targetId, param, target->_desc.c_str());
 			}
-			debug(2, "Target: %04x (%04x) '%s'", targetId, param, target->_desc.c_str());
 		} else {
 			target = this;
 			debug(2, "Self-target on '%s'", _desc.c_str());
@@ -2700,10 +2819,20 @@ int LBItem::runScriptEntry(LBScriptEntry *entry) {
 			break;
 
 		case kLBOpLoad:
+			// FIXME
+			warning("ignoring kLBOpLoad (event 0x%04x, param 0x%04x, target '%s')",
+				entry->event, entry->param, target->_desc.c_str());
+			break;
+
 		case kLBOpPreload:
+			// FIXME
+			warning("ignoring kLBOpPreload (event 0x%04x, param 0x%04x, target '%s')",
+				entry->event, entry->param, target->_desc.c_str());
+			break;
+
 		case kLBOpUnload:
 			// FIXME
-			warning("ignoring kLBOpLoad/Preload/Unload (event 0x%04x, param 0x%04x, target '%s')",
+			warning("ignoring kLBOpUnload (event 0x%04x, param 0x%04x, target '%s')",
 				entry->event, entry->param, target->_desc.c_str());
 			break;
 
@@ -2735,8 +2864,6 @@ int LBItem::runScriptEntry(LBScriptEntry *entry) {
 			break;
 
 		case kLBOpSendExpression:
-			if (!_page->_code)
-				error("no BCOD?");
 			_page->_code->runCode(this, entry->offset);
 			break;
 
@@ -2763,15 +2890,13 @@ int LBItem::runScriptEntry(LBScriptEntry *entry) {
 			}
 			break;
 
-		case kLBOpRunCommand:
-			runCommand(entry->command);
+		case kLBOpRunData:
+			readData(entry->dataType, entry->dataLen, entry->data);
 			break;
 
 		case kLBOpJumpUnlessExpression:
 		case kLBOpBreakExpression:
 		case kLBOpJumpToExpression:
-			if (!_page->_code)
-				error("no BCOD?");
 			{
 			LBValue r = _page->_code->runCode(this, entry->offset);
 			// FIXME
@@ -2796,257 +2921,24 @@ void LBItem::setNextTime(uint16 min, uint16 max, uint32 start) {
 	debug(9, "nextTime is now %d frames away", _nextTime - (uint)(_vm->_system->getMillis() / 16));
 }
 
-enum LBTokenType {
-	kLBNoToken,
-	kLBNameToken,
-	kLBStringToken,
-	kLBOperatorToken,
-	kLBIntegerToken,
-	kLBEndToken
-};
-
-static Common::String readToken(const Common::String &source, uint &pos, LBTokenType &type) {
-	Common::String token;
-	type = kLBNoToken;
-
-	bool done = false;
-	while (pos < source.size() && !done) {
-		if (type == kLBStringToken) {
-			if (source[pos] == '"') {
-				pos++;
-				return token;
-			}
-
-			token += source[pos];
-			pos++;
-			continue;
-		}
-
-		switch (source[pos]) {
-		case ' ':
-			pos++;
-			done = true;
-			break;
-
-		case ')':
-			if (type == kLBNoToken) {
-				type = kLBEndToken;
-				return Common::String();
-			}
-			done = true;
-			break;
-
-		case ';':
-			if (type == kLBNoToken) {
-				pos++;
-				type = kLBEndToken;
-				return Common::String();
-			}
-			done = true;
-			break;
-
-		case '@':
-			// FIXME
-			error("found @ in string '%s', not supported yet", source.c_str());
-
-		case '+':
-		case '-':
-		case '!':
-		case '=':
-		case '>':
-		case '<':
-			if (type == kLBNoToken)
-				type = kLBOperatorToken;
-			if (type == kLBOperatorToken)
-				token += source[pos];
-			else
-				done = true;
-			break;
-
-		case '"':
-			if (type == kLBNoToken)
-				type = kLBStringToken;
-			else
-				done = true;
-			break;
-
-		case '0':
-		case '1':
-		case '2':
-		case '3':
-		case '4':
-		case '5':
-		case '6':
-		case '7':
-		case '8':
-		case '9':
-			if (type == kLBNoToken)
-				type = kLBIntegerToken;
-			if (type == kLBNameToken || type == kLBIntegerToken)
-				token += source[pos];
-			else
-				done = true;
-			break;
-
-		default:
-			if (type == kLBNoToken)
-				type = kLBNameToken;
-			if (type == kLBNameToken)
-				token += source[pos];
-			else
-				done = true;
-			break;
-		}
-
-		if (!done)
-			pos++;
-	}
-
-	if (type == kLBStringToken)
-		error("readToken: ran out of input while parsing string from '%s'", source.c_str());
-
-	if (!token.size()) {
-		assert(type == kLBNoToken);
-		type = kLBEndToken;
-	}
-
-	return token;
-}
-
-LBValue LBItem::parseValue(const Common::String &source, uint &pos) {
-	LBTokenType type, postOpType;
-	Common::String preOp, postOp;
-
-	Common::String str = readToken(source, pos, type);
-	if (type == kLBOperatorToken) {
-		preOp = str;
-		str = readToken(source, pos, type);
-	}
-
-	LBValue value;
-	if (type == kLBStringToken) {
-		value.type = kLBValueString;
-		value.string = str;
-	} else if (type == kLBIntegerToken) {
-		value.type = kLBValueInteger;
-		value.integer = atoi(str.c_str());
-	} else if (type == kLBNameToken) {
-		value = _vm->_variables[str];
-	} else {
-		error("expected string/integer as value in '%s', got '%s'", source.c_str(), str.c_str());
-	}
-
-	uint readAheadPos = pos;
-	postOp = readToken(source, readAheadPos, postOpType);
-	if (postOpType != kLBEndToken) {
-		if (postOpType != kLBOperatorToken)
-			error("expected operator after '%s' in '%s', got '%s'", str.c_str(), source.c_str(), postOp.c_str());
-		// might be a comparison operator, caller will handle other cases if valid
-		if (postOp == "-" || postOp == "+") {
-			pos = readAheadPos;
-			LBValue nextValue = parseValue(source, pos);
-			if (value.type != kLBValueInteger || nextValue.type != kLBValueInteger)
-				error("expected integer for arthmetic operator in '%s'", source.c_str());
-			if (postOp == "+")
-				value.integer += nextValue.integer;
-			else if (postOp == "-")
-				value.integer -= nextValue.integer;
-		}
-	}
-
-	if (preOp.size()) {
-		if (preOp == "!") {
-			if (value.type == kLBValueInteger)
-				value.integer = !value.integer;
-			else
-				error("expected integer after ! operator in '%s'", source.c_str());
-		} else {
-			error("expected valid operator before '%s' in '%s', got '%s'", str.c_str(), source.c_str(), preOp.c_str());
-		}
-	}
-
-	return value;
-}
-
 void LBItem::runCommand(const Common::String &command) {
-	uint pos = 0;
-	LBTokenType type;
+	LBCode tempCode(_vm, 0);
 
 	debug(2, "running command '%s'", command.c_str());
 
-	while (pos < command.size()) {
-		Common::String varname = readToken(command, pos, type);
-		if (type != kLBNameToken)
-			error("expected name as lvalue of command '%s', got '%s'", command.c_str(), varname.c_str());
-		Common::String op = readToken(command, pos, type);
-		if (type != kLBOperatorToken || (op != "=" && op != "++" && op != "--"))
-			error("expected assignment/postincrement/postdecrement operator for command '%s', got '%s'", command.c_str(), op.c_str());
-
-		if (op == "=") {
-			LBValue value = parseValue(command, pos);
-			_vm->_variables[varname] = value;
-		} else {
-			if (_vm->_variables[varname].type != kLBValueInteger)
-				error("expected integer after postincrement/postdecrement operator in '%s'", command.c_str());
-			if (op == "++")
-				_vm->_variables[varname].integer++;
-			else if (op == "--")
-				_vm->_variables[varname].integer--;
-		}
-
-		if (pos < command.size() && command[pos] == ';')
-			pos++;
-	}
+	uint offset = tempCode.parseCode(command);
+	tempCode.runCode(this, offset);
 }
 
 bool LBItem::checkCondition(const Common::String &condition) {
-	uint pos = 0;
-	LBTokenType type;
+	LBCode tempCode(_vm, 0);
 
 	debug(3, "checking condition '%s'", condition.c_str());
 
-	if (condition.size() <= pos || condition[pos] != '(')
-		error("bad condition '%s' (started wrong)", condition.c_str());
-	pos++;
+	uint offset = tempCode.parseCode(condition);
+	LBValue result = tempCode.runCode(this, offset);
 
-	LBValue value1 = parseValue(condition, pos);
-
-	Common::String op = readToken(condition, pos, type);
-	if (type == kLBEndToken) {
-		if (condition.size() != pos + 1 || condition[pos] != ')')
-			error("bad condition '%s' (ended wrong)", condition.c_str());
-
-		if (value1.type == kLBValueInteger)
-			return value1.integer;
-		else
-			error("expected comparison operator for condition '%s'", condition.c_str());
-	}
-	if (type != kLBOperatorToken || (op != "!=" && op != "==" && op != ">" && op != "<" && op != ">=" && op != "<="))
-		error("expected comparison operator for condition '%s', got '%s'", condition.c_str(), op.c_str());
-
-	LBValue value2 = parseValue(condition, pos);
-
-	if (condition.size() != pos + 1 || condition[pos] != ')')
-		error("bad condition '%s' (ended wrong)", condition.c_str());
-
-	if (op == "!=")
-		return (value1 != value2);
-	else if (op == "==")
-		return (value1 == value2);
-
-	if (value1.type != kLBValueInteger || value2.type != kLBValueInteger)
-		error("evaluation operator %s in condition '%s' expected two integer operands!", op.c_str(), condition.c_str());
-
-	if (op == ">")
-		return (value1.integer > value2.integer);
-	else if (op == ">=")
-		return (value1.integer >= value2.integer);
-	else if (op == "<")
-		return (value1.integer < value2.integer);
-	else if (op == "<=")
-		return (value1.integer <= value2.integer);
-
-	return false; // unreachable
+	return result.toInt();
 }
 
 LBSoundItem::LBSoundItem(MohawkEngine_LivingBooks *vm, LBPage *page, Common::Rect rect) : LBItem(vm, page, rect) {
@@ -3100,7 +2992,7 @@ LBGroupItem::LBGroupItem(MohawkEngine_LivingBooks *vm, LBPage *page, Common::Rec
 	_starting = false;
 }
 
-void LBGroupItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEndian *stream) {
+void LBGroupItem::readData(uint16 type, uint16 size, Common::MemoryReadStreamEndian *stream) {
 	switch (type) {
 	case kLBGroupData:
 		{
@@ -3221,7 +3113,7 @@ LBPaletteItem::~LBPaletteItem() {
 	delete[] _palette;
 }
 
-void LBPaletteItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEndian *stream) {
+void LBPaletteItem::readData(uint16 type, uint16 size, Common::MemoryReadStreamEndian *stream) {
 	switch (type) {
 	case kLBPaletteXData:
 		{
@@ -3301,7 +3193,7 @@ LBLiveTextItem::LBLiveTextItem(MohawkEngine_LivingBooks *vm, LBPage *page, Commo
 	debug(3, "new LBLiveTextItem");
 }
 
-void LBLiveTextItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEndian *stream) {
+void LBLiveTextItem::readData(uint16 type, uint16 size, Common::MemoryReadStreamEndian *stream) {
 	switch (type) {
 	case kLBLiveTextData:
 		{
@@ -3546,7 +3438,7 @@ LBPictureItem::LBPictureItem(MohawkEngine_LivingBooks *vm, LBPage *page, Common:
 	debug(3, "new LBPictureItem");
 }
 
-void LBPictureItem::readData(uint16 type, uint16 size, Common::SeekableSubReadStreamEndian *stream) {
+void LBPictureItem::readData(uint16 type, uint16 size, Common::MemoryReadStreamEndian *stream) {
 	switch (type) {
 	case kLBSetDrawMode:
 		{
@@ -3748,4 +3640,35 @@ bool LBMiniGameItem::togglePlaying(bool playing, bool restart) {
 	return false;
 }
 
+LBProxyItem::LBProxyItem(MohawkEngine_LivingBooks *vm, LBPage *page, Common::Rect rect) : LBItem(vm, page, rect) {
+	debug(3, "new LBProxyItem");
+
+	_page = NULL;
+}
+
+LBProxyItem::~LBProxyItem() {
+	delete _page;
+}
+
+void LBProxyItem::init() {
+	Common::String leftover;
+	Common::String filename = _vm->getFileNameFromConfig("Proxies", _desc.c_str(), leftover);
+	if (!leftover.empty())
+		error("LBProxyItem tried loading proxy '%s' but got leftover '%s'", _desc.c_str(), leftover.c_str());
+	uint16 baseId = 0;
+	for (uint i = 0; i < filename.size(); i++) {
+		if (filename[i] == ';') {
+			baseId = atoi(filename.c_str() + i + 1);
+			filename = Common::String(filename.c_str(), i);
+		}
+	}
+
+	debug(1, "LBProxyItem loading archive '%s' with id %d", filename.c_str(), baseId);
+	Archive *pageArchive = _vm->createArchive();
+	if (!pageArchive->openFile(filename))
+		error("failed to open archive '%s' (for proxy '%s')", filename.c_str(), _desc.c_str());
+	_page = new LBPage(_vm);
+	_page->open(pageArchive, baseId);
+}
+
 } // End of namespace Mohawk
