@@ -18,16 +18,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/config-manager.h"
 #include "common/events.h"
-#include "common/EventRecorder.h"
 #include "common/keyboard.h"
 #include "common/translation.h"
+#include "common/system.h"
 
 #include "mohawk/cursors.h"
 #include "mohawk/graphics.h"
@@ -121,8 +118,7 @@ Common::Error MohawkEngine_Riven::run() {
 	_optionsDialog = new RivenOptionsDialog(this);
 	_scriptMan = new RivenScriptManager(this);
 
-	_rnd = new Common::RandomSource();
-	g_eventRec.registerRandomSource(*_rnd, "riven");
+	_rnd = new Common::RandomSource("riven");
 
 	// Create the cursor manager
 	if (Common::File::exists("rivendmo.exe"))
@@ -147,13 +143,16 @@ Common::Error MohawkEngine_Riven::run() {
 	_extrasFile = new MohawkArchive();
 
 	// We need extras.mhk for inventory images, marble images, and credits images
-	if (!_extrasFile->open("extras.mhk")) {
+	if (!_extrasFile->openFile("extras.mhk")) {
 		Common::String message = "You're missing 'extras.mhk'. Using the 'arcriven.z' installer file also works.";
 		GUIErrorMessage(message);
 		warning("%s", message.c_str());
 		return Common::kNoGameDataFoundError;
 	}
 
+	// Set the transition speed
+	_gfx->setTransitionSpeed(_vars["transitionmode"]);
+
 	// Start at main cursor
 	_cursor->setCursor(kRivenMainCursor);
 	_cursor->showCursor();
@@ -182,7 +181,7 @@ Common::Error MohawkEngine_Riven::run() {
 		changeToCard(1);
 	}
 
-	
+
 	while (!_gameOver && !shouldQuit())
 		handleEvents();
 
@@ -213,8 +212,10 @@ void MohawkEngine_Riven::handleEvents() {
 			needsUpdate = true;
 			break;
 		case Common::EVENT_LBUTTONDOWN:
-			if (_curHotspot >= 0)
+			if (_curHotspot >= 0) {
+				checkSunnerAlertClick();
 				runHotspotScript(_curHotspot, kMouseDownScript);
+			}
 			break;
 		case Common::EVENT_LBUTTONUP:
 			// See RivenScript::switchCard() for more information on why we sometimes
@@ -321,7 +322,7 @@ void MohawkEngine_Riven::changeToStack(uint16 n) {
 		Common::String filename = Common::String(prefix) + endings[i];
 
 		MohawkArchive *mhk = new MohawkArchive();
-		if (mhk->open(filename))
+		if (mhk->openFile(filename))
 			_mhk.push_back(mhk);
 		else
 			delete mhk;
@@ -440,7 +441,7 @@ void MohawkEngine_Riven::loadCard(uint16 id) {
 void MohawkEngine_Riven::loadHotspots(uint16 id) {
 	// Clear old hotspots
 	delete[] _hotspots;
-	
+
 	// NOTE: The hotspot scripts are cleared by the RivenScriptManager automatically.
 
 	Common::SeekableReadStream *inStream = getResource(ID_HSPT, id);
@@ -464,8 +465,8 @@ void MohawkEngine_Riven::loadHotspots(uint16 id) {
 		// - tspit 371 (DVD: 377), hotspot 4
 		if (left >= right || top >= bottom) {
 			warning("%s %d hotspot %d is invalid: (%d, %d, %d, %d)", getStackName(_curStack).c_str(), _curCard, i, left, top, right, bottom);
-			left = top = right = bottom = 0; 	 
-			_hotspots[i].enabled = 0; 	 
+			left = top = right = bottom = 0;
+			_hotspots[i].enabled = 0;
 		}
 
 		_hotspots[i].rect = Common::Rect(left, top, right, bottom);
@@ -731,7 +732,7 @@ Common::Error MohawkEngine_Riven::loadGameState(int slot) {
 	return _saveLoad->loadGame(_saveLoad->generateSaveGameList()[slot]) ? Common::kNoError : Common::kUnknownError;
 }
 
-Common::Error MohawkEngine_Riven::saveGameState(int slot, const char *desc) {
+Common::Error MohawkEngine_Riven::saveGameState(int slot, const Common::String &desc) {
 	Common::StringArray saveList = _saveLoad->generateSaveGameList();
 
 	if ((uint)slot < saveList.size())
@@ -816,6 +817,138 @@ static void catherineIdleTimer(MohawkEngine_Riven *vm) {
 	vm->installTimer(&catherineIdleTimer, timeUntilNextMovie);
 }
 
+static void sunnersTopStairsTimer(MohawkEngine_Riven *vm) {
+	// If the sunners are gone, we have no video to play
+	if (vm->_vars["jsunners"] != 0) {
+		vm->removeTimer();
+		return;
+	}
+
+	// Play a random sunners video if the script one is not playing already
+	// and then set a new timer for when the new video should be played
+
+	VideoHandle oldHandle = vm->_video->findVideoHandleRiven(1);
+	uint32 timerTime = 500;
+
+	if (oldHandle == NULL_VID_HANDLE || vm->_video->endOfVideo(oldHandle)) {
+		uint32 &sunnerTime = vm->_vars["jsunnertime"];
+
+		if (sunnerTime == 0) {
+			timerTime = vm->_rnd->getRandomNumberRng(2, 15) * 1000;
+		} else if (sunnerTime < vm->getTotalPlayTime()) {
+			VideoHandle handle = vm->_video->playMovieRiven(vm->_rnd->getRandomNumberRng(1, 3));
+
+			timerTime = vm->_video->getDuration(handle) + vm->_rnd->getRandomNumberRng(2, 15) * 1000;
+		}
+
+		sunnerTime = timerTime + vm->getTotalPlayTime();
+	}
+
+	vm->installTimer(&sunnersTopStairsTimer, timerTime);
+}
+
+static void sunnersMidStairsTimer(MohawkEngine_Riven *vm) {
+	// If the sunners are gone, we have no video to play
+	if (vm->_vars["jsunners"] != 0) {
+		vm->removeTimer();
+		return;
+	}
+
+	// Play a random sunners video if the script one is not playing already
+	// and then set a new timer for when the new video should be played
+
+	VideoHandle oldHandle = vm->_video->findVideoHandleRiven(1);
+	uint32 timerTime = 500;
+
+	if (oldHandle == NULL_VID_HANDLE || vm->_video->endOfVideo(oldHandle)) {
+		uint32 &sunnerTime = vm->_vars["jsunnertime"];
+
+		if (sunnerTime == 0) {
+			timerTime = vm->_rnd->getRandomNumberRng(1, 10) * 1000;
+		} else if (sunnerTime < vm->getTotalPlayTime()) {
+			// Randomize the video
+			int randValue = vm->_rnd->getRandomNumber(5);
+			uint16 movie = 4;
+			if (randValue == 4)
+				movie = 2;
+			else if (randValue == 5)
+				movie = 3;
+
+			VideoHandle handle = vm->_video->playMovieRiven(movie);
+
+			timerTime = vm->_video->getDuration(handle) + vm->_rnd->getRandomNumberRng(1, 10) * 1000;
+		}
+
+		sunnerTime = timerTime + vm->getTotalPlayTime();
+	}
+
+	vm->installTimer(&sunnersMidStairsTimer, timerTime);
+}
+
+static void sunnersLowerStairsTimer(MohawkEngine_Riven *vm) {
+	// If the sunners are gone, we have no video to play
+	if (vm->_vars["jsunners"] != 0) {
+		vm->removeTimer();
+		return;
+	}
+
+	// Play a random sunners video if the script one is not playing already
+	// and then set a new timer for when the new video should be played
+
+	VideoHandle oldHandle = vm->_video->findVideoHandleRiven(1);
+	uint32 timerTime = 500;
+
+	if (oldHandle == NULL_VID_HANDLE || vm->_video->endOfVideo(oldHandle)) {
+		uint32 &sunnerTime = vm->_vars["jsunnertime"];
+
+		if (sunnerTime == 0) {
+			timerTime = vm->_rnd->getRandomNumberRng(1, 30) * 1000;
+		} else if (sunnerTime < vm->getTotalPlayTime()) {
+			VideoHandle handle = vm->_video->playMovieRiven(vm->_rnd->getRandomNumberRng(3, 5));
+
+			timerTime = vm->_video->getDuration(handle) + vm->_rnd->getRandomNumberRng(1, 30) * 1000;
+		}
+
+		sunnerTime = timerTime + vm->getTotalPlayTime();
+	}
+
+	vm->installTimer(&sunnersLowerStairsTimer, timerTime);
+}
+
+static void sunnersBeachTimer(MohawkEngine_Riven *vm) {
+	// If the sunners are gone, we have no video to play
+	if (vm->_vars["jsunners"] != 0) {
+		vm->removeTimer();
+		return;
+	}
+
+	// Play a random sunners video if the script one is not playing already
+	// and then set a new timer for when the new video should be played
+
+	VideoHandle oldHandle = vm->_video->findVideoHandleRiven(3);
+	uint32 timerTime = 500;
+
+	if (oldHandle == NULL_VID_HANDLE || vm->_video->endOfVideo(oldHandle)) {
+		uint32 &sunnerTime = vm->_vars["jsunnertime"];
+
+		if (sunnerTime == 0) {
+			timerTime = vm->_rnd->getRandomNumberRng(1, 30) * 1000;
+		} else if (sunnerTime < vm->getTotalPlayTime()) {
+			// Unlike the other cards' scripts which automatically
+			// activate the MLST, we have to set it manually here.
+			uint16 mlstID = vm->_rnd->getRandomNumberRng(3, 8);
+			vm->_video->activateMLST(mlstID, vm->getCurCard());
+			VideoHandle handle = vm->_video->playMovieRiven(mlstID);
+
+			timerTime = vm->_video->getDuration(handle) + vm->_rnd->getRandomNumberRng(1, 30) * 1000;
+		}
+
+		sunnerTime = timerTime + vm->getTotalPlayTime();
+	}
+
+	vm->installTimer(&sunnersBeachTimer, timerTime);
+}
+
 void MohawkEngine_Riven::installCardTimer() {
 	switch (getCurCardRMAP()) {
 	case 0x3a85: // Top of elevator on prison island
@@ -823,20 +956,61 @@ void MohawkEngine_Riven::installCardTimer() {
 		installTimer(&catherineIdleTimer, _rnd->getRandomNumberRng(1, 33) * 1000);
 		break;
 	case 0x77d6: // Sunners, top of stairs
-		// TODO: Background Sunner videos
+		installTimer(&sunnersTopStairsTimer, 500);
 		break;
 	case 0x79bd: // Sunners, middle of stairs
-		// TODO: Background Sunner videos
+		installTimer(&sunnersMidStairsTimer, 500);
 		break;
 	case 0x7beb: // Sunners, bottom of stairs
-		// TODO: Background Sunner videos
+		installTimer(&sunnersLowerStairsTimer, 500);
 		break;
 	case 0xb6ca: // Sunners, shoreline
-		// TODO: Background Sunner videos
+		installTimer(&sunnersBeachTimer, 500);
 		break;
 	}
 }
 
+void MohawkEngine_Riven::doVideoTimer(VideoHandle handle, bool force) {
+	assert(handle != NULL_VID_HANDLE);
+
+	uint16 id = _scriptMan->getStoredMovieOpcodeID();
+
+	if (handle != _video->findVideoHandleRiven(id)) // Check if we've got a video match
+		return;
+
+	// Run the opcode if we can at this point
+	if (force || _video->getElapsedTime(handle) >= _scriptMan->getStoredMovieOpcodeTime())
+		_scriptMan->runStoredMovieOpcode();
+}
+
+void MohawkEngine_Riven::checkSunnerAlertClick() {
+	// We need to do a manual hardcoded check for the sunners'
+	// alert movies.
+
+	uint32 &sunners = _vars["jsunners"];
+
+	// If the sunners are gone, there's nothing for us to do
+	if (sunners != 0)
+		return;
+
+	uint32 rmapCode = getCurCardRMAP();
+
+	// This is only for the mid/lower staircase sections
+	if (rmapCode != 0x79bd && rmapCode != 0x7beb)
+		return;
+
+	// Only set the sunners variable on the forward hotspot
+	if ((rmapCode == 0x79bd && _curHotspot != 1) || (rmapCode == 0x7beb && _curHotspot != 2))
+		return;
+
+	// If the alert video is no longer playing, we have nothing left to do
+	VideoHandle handle = _video->findVideoHandleRiven(1);
+	if (handle == NULL_VID_HANDLE || _video->endOfVideo(handle))
+		return;
+
+	sunners = 1;
+}
+
 bool ZipMode::operator== (const ZipMode &z) const {
 	return z.name == name && z.id == id;
 }
