@@ -18,20 +18,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/mohawk/riven.h $
- * $Id: riven.h 52661 2010-09-09 17:27:02Z mthreepwood $
- *
  */
 
 #ifndef MOHAWK_RIVEN_H
 #define MOHAWK_RIVEN_H
 
+#include "mohawk/installer_archive.h"
 #include "mohawk/mohawk.h"
 #include "mohawk/riven_scripts.h"
 
 #include "gui/saveload.h"
 
+#include "common/hashmap.h"
+#include "common/hash-str.h"
 #include "common/random.h"
+#include "common/rect.h"
 
 namespace Mohawk {
 
@@ -66,6 +67,13 @@ enum {
 	StackNames = 5
 };
 
+enum RivenTransitionSpeed {
+	kRivenTransitionSpeedNone = 5000,
+	kRivenTransitionSpeedFastest = 5001,
+	kRivenTransitionSpeedNormal = 5002,
+	kRivenTransitionSpeedBest = 5003
+};
+
 // Rects for the inventory object positions (initialized in
 // MohawkEngine_Riven's constructor).
 extern Common::Rect *g_atrusJournalRect1;
@@ -103,6 +111,8 @@ struct ZipMode {
 	bool operator== (const ZipMode& z) const;
 };
 
+typedef Common::HashMap<Common::String, uint32, Common::IgnoreCase_Hash, Common::IgnoreCase_EqualTo> RivenVariableMap;
+
 class MohawkEngine_Riven : public MohawkEngine {
 protected:
 	Common::Error run();
@@ -123,14 +133,19 @@ public:
 	bool canLoadGameStateCurrently() { return true; }
 	bool canSaveGameStateCurrently() { return true; }
 	Common::Error loadGameState(int slot);
-	Common::Error saveGameState(int slot, const char *desc);
+	Common::Error saveGameState(int slot, const Common::String &desc);
 	bool hasFeature(EngineFeature f) const;
 
+	typedef void (*TimerProc)(MohawkEngine_Riven *vm);
+
+	void doVideoTimer(VideoHandle handle, bool force);
+
 private:
 	MohawkArchive *_extrasFile; // We need a separate handle for the extra data
 	RivenConsole *_console;
 	RivenSaveLoad *_saveLoad;
 	RivenOptionsDialog *_optionsDialog;
+	InstallerArchive _installerArchive;
 
 	// Stack/Card-related functions and variables
 	uint16 _curCard;
@@ -144,14 +159,19 @@ private:
 	void checkInventoryClick();
 	bool _showHotspots;
 	void updateZipMode();
+	void checkHotspotChange();
 
 	// Variables
-	uint32 *_vars;
-	uint32 _varCount;
+	void initVars();
+
+	// Timer
+	TimerProc _timerProc;
+	uint32 _timerTime;
 
 	// Miscellaneous
 	bool _gameOver;
 	bool _ignoreNextMouseUp;
+	void checkSunnerAlertClick();
 
 public:
 	// Stack/card/script funtions
@@ -175,15 +195,11 @@ public:
 	void runHotspotScript(uint16 hotspot, uint16 scriptType);
 	int32 getCurHotspot() const { return _curHotspot; }
 	Common::String getHotspotName(uint16 hotspot);
-	void checkHotspotChange();
+	void updateCurrentHotspot();
 
-	// Variable functions
-	void initVars();
-	uint32 getVarCount() const { return _varCount; }
-	uint32 getGlobalVar(uint32 index);
-	Common::String getGlobalVarName(uint32 index);
-	uint32 *getLocalVar(uint32 index);
-	uint32 *getVar(const Common::String &varName);
+	// Variables
+	RivenVariableMap _vars;
+	uint32 &getStackVar(uint32 index);
 
 	// Miscellaneous
 	void setGameOver() { _gameOver = true; }
@@ -192,6 +208,12 @@ public:
 	bool _activatedSLST;
 	void runLoadDialog();
 	void delayAndUpdate(uint32 ms);
+
+	// Timer
+	void installTimer(TimerProc proc, uint32 time);
+	void installCardTimer();
+	void checkTimer();
+	void removeTimer();
 };
 
 } // End of namespace Mohawk
