@@ -18,13 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/callables_br.cpp $
- * $Id: callables_br.cpp 41061 2009-05-31 10:02:16Z eriktorbjorn $
- *
  */
 
 #include "parallaction/parallaction.h"
 
+#include "common/textconsole.h"
+
 namespace Parallaction {
 
 void Parallaction_br::_c_null(void*) {
