@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "graphics/iff.h"
@@ -228,7 +225,7 @@ void DosDisk_br::loadBitmap(Common::SeekableReadStream &stream, Graphics::Surfac
 		stream.skip(768);
 	}
 
-	surf.create(width, height, 1);
+	surf.create(width, height, Graphics::PixelFormat::createFormatCLUT8());
 	stream.read(surf.pixels, width * height);
 }
 
