@@ -19,9 +19,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/system.h"
@@ -523,7 +520,7 @@ void Gfx::invertBackground(const Common::Rect& r) {
 
 
 void setupLabelSurface(Graphics::Surface &surf, uint w, uint h) {
-	surf.create(w, h, 1);
+	surf.create(w, h, Graphics::PixelFormat::createFormatCLUT8());
 	surf.fillRect(Common::Rect(w,h), LABEL_TRANSPARENT_COLOR);
 }
 
@@ -568,7 +565,7 @@ void Gfx::showFloatingLabel(GfxObj *label) {
 		label->x = -1000;
 		label->y = -1000;
 		label->setFlags(kGfxObjVisible);
-	
+
 		_floatingLabel = label;
 		_labels.push_back(label);
 	}
@@ -676,7 +673,7 @@ void Gfx::showLabel(GfxObj *label, int16 x, int16 y) {
 
 	label->x = x;
 	label->y = y;
-	
+
 	_labels.push_back(label);
 }
 
@@ -698,7 +695,7 @@ void Gfx::unregisterLabel(GfxObj *label) {
 			_labels.remove_at(i);
 			break;
 		}
-	}	
+	}
 }
 
 
@@ -859,7 +856,7 @@ void Gfx::setBackground(uint type, BackgroundInfo *info) {
 		int height = CLIP(info->height, (int)_vm->_screenHeight, info->height);
 
 		if (width != _backBuffer.w || height != _backBuffer.h) {
-			_backBuffer.create(width, height, 1);
+			_backBuffer.create(width, height, Graphics::PixelFormat::createFormatCLUT8());
 		}
 	}
 
