@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/system.h"
@@ -226,10 +223,10 @@ public:
 			}
 			break;
 
-		default: 
+		default:
 			_vm->_nextPart = _firstLocation[selection].part;
 			_vm->scheduleLocationSwitch(_firstLocation[selection].location);
-		
+
 		}
 
 		_vm->_system->showMouse(false);
@@ -484,7 +481,7 @@ public:
 		_y = 90;
 
 		Graphics::Surface *surf = new Graphics::Surface;
-		surf->create(w, 110, 1);
+		surf->create(w, 110, Graphics::PixelFormat::createFormatCLUT8());
 		surf->fillRect(Common::Rect(0, 0, w, 110), 12);
 		surf->fillRect(Common::Rect(10, 10, w-10, 100), 15);
 
@@ -551,4 +548,3 @@ void Parallaction_br::startIngameMenu() {
 
 
 } // namespace Parallaction
-
