@@ -18,11 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/objects.cpp $
- * $Id: objects.cpp 48811 2010-04-27 08:59:13Z peres001 $
- *
  */
 
+#include "common/textconsole.h"
+
 #include "parallaction/parallaction.h"
 #include "parallaction/objects.h"
 #include "parallaction/parser.h"
@@ -221,7 +220,11 @@ bool Zone::hitRect(int x, int y) const {
 	if (_right < _left || _bottom < _top) {
 		return false;
 	}
-	return Common::Rect(_left, _top, _right, _bottom).contains(x, y);
+
+	Common::Rect r(_left, _top, _right + 1, _bottom + 1);
+	r.grow(-1);
+
+	return r.contains(x, y);
 }
 
 Dialogue::Dialogue() {
@@ -258,6 +261,14 @@ Answer::Answer() {
 	_hasCounterCondition = false;
 }
 
+bool Answer::textIsNull() {
+	return (_text.equalsIgnoreCase("NULL"));
+}
+
+int Answer::speakerMood() {
+	return _mood & 0xF;
+}
+
 Question::Question(const Common::String &name) : _name(name), _mood(0) {
 	memset(_answers, 0, sizeof(_answers));
 }
@@ -268,6 +279,19 @@ Question::~Question() {
 	}
 }
 
+bool Question::textIsNull() {
+	return (_text.equalsIgnoreCase("NULL"));
+}
+
+int Question::speakerMood() {
+	return _mood & 0xF;
+}
+
+int Question::balloonWinding() {
+	return _mood & 0x10;
+}
+
+
 Instruction::Instruction() {
 	_index = 0;
 	_flags = 0;
