@@ -18,21 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/parallaction.cpp $
- * $Id: parallaction.cpp 49146 2010-05-22 17:59:49Z peres001 $
- *
  */
 
-#include "common/config-manager.h"
 #include "common/debug-channels.h"
-#include "common/events.h"
-#include "common/EventRecorder.h"
-#include "common/file.h"
-#include "common/util.h"
 #include "common/system.h"
-
-#include "sound/mididrv.h"
-#include "sound/mixer.h"
+#include "common/textconsole.h"
 
 #include "parallaction/exec.h"
 #include "parallaction/input.h"
@@ -42,24 +32,21 @@
 #include "parallaction/sound.h"
 #include "parallaction/walk.h"
 
-
-
 namespace Parallaction {
-
 Parallaction *_vm = NULL;
 // public stuff
 
 char		_saveData1[30] = { '\0' };
 uint32		_engineFlags = 0;
-
 uint32		_globalFlags = 0;
 
 // private stuff
 
-
 Parallaction::Parallaction(OSystem *syst, const PARALLACTIONGameDescription *gameDesc) :
 	Engine(syst), _gameDescription(gameDesc), _location(getGameType()),
-	_dialogueMan(0) {
+	_dialogueMan(0), _rnd("parallaction") {
+	// Setup mixer
+	syncSoundSettings();
 
 	_vm = this;
 	DebugMan.addDebugChannel(kDebugDialogue, "dialogue", "Dialogues debug level");
@@ -72,11 +59,8 @@ Parallaction::Parallaction(OSystem *syst, const PARALLACTIONGameDescription *gam
 	DebugMan.addDebugChannel(kDebugAudio, "audio", "Audio debug level");
 	DebugMan.addDebugChannel(kDebugMenu, "menu", "Menu debug level");
 	DebugMan.addDebugChannel(kDebugInventory, "inventory", "Inventory debug level");
-
-	g_eventRec.registerRandomSource(_rnd, "parallaction");
 }
 
-
 Parallaction::~Parallaction() {
 	delete _debugger;
 	delete _globalFlagsNames;
@@ -94,15 +78,14 @@ Parallaction::~Parallaction() {
 	_balloonMan = 0;
 
 	delete _localFlagNames;
+	_char._ani.reset();
 	delete _gfx;
 	delete _soundMan;
 	delete _disk;
 	delete _input;
 }
 
-
 Common::Error Parallaction::init() {
-	
 	_gameType = getGameType();
 	_engineFlags = 0;
 	_objectsNames = NULL;
@@ -121,6 +104,7 @@ Common::Error Parallaction::init() {
 
 	strcpy(_characterName1, "null");
 
+	memset(_localFlags, 0, sizeof(_localFlags));
 	memset(_locationNames, 0, NUM_LOCATIONS * 32);
 
 	// this needs _disk to be already setup
@@ -160,8 +144,6 @@ void Parallaction::updateView() {
 	_system->delayMillis(30);
 }
 
-
-
 void Parallaction::pauseJobs() {
 	debugC(9, kDebugExec, "pausing jobs execution");
 
@@ -184,7 +166,6 @@ AnimationPtr Location::findAnimation(const char *name) {
 	return AnimationPtr();
 }
 
-
 void Parallaction::allocateLocationSlot(const char *name) {
 	// WORKAROUND: the original code erroneously incremented
 	// _currentLocationIndex, thus producing inconsistent
@@ -201,7 +182,7 @@ void Parallaction::allocateLocationSlot(const char *name) {
 	}
 
 	if (_di == 120)
-		error("No more location slots available. Please report this immediately to ScummVM team.");
+		error("No more location slots available. Please report this immediately to ScummVM team");
 
 	if (_currentLocationIndex  == -1) {
 		strcpy(_locationNames[_numLocations], name);
@@ -215,7 +196,6 @@ void Parallaction::allocateLocationSlot(const char *name) {
 	}
 }
 
-
 Location::Location(int gameType) : _gameType(gameType) {
 	cleanup(true);
 }
@@ -255,7 +235,6 @@ int Location::getScale(int z) const {
 	return scale;
 }
 
-
 void Parallaction::showSlide(const char *name, int x, int y) {
 	BackgroundInfo *info = new BackgroundInfo;
 	_disk->loadSlide(*info, name);
@@ -266,9 +245,8 @@ void Parallaction::showSlide(const char *name, int x, int y) {
 	_gfx->setBackground(kBackgroundSlide, info);
 }
 
-
 void Parallaction::showLocationComment(const Common::String &text, bool end) {
-	_balloonMan->setLocationBalloon(text.c_str(), end);
+	_balloonMan->setLocationBalloon(text, end);
 }
 
 void Parallaction::runGameFrame(int event) {
@@ -298,7 +276,6 @@ void Parallaction::runGameFrame(int event) {
 }
 
 void Parallaction::runGame() {
-
 	int event = _input->updateInput();
 	if (shouldQuit())
 		return;
@@ -328,9 +305,6 @@ void Parallaction::runGame() {
 	updateView();
 }
 
-
-
-
 //	displays transition before a new location
 //
 //	clears screen (in white??)
@@ -373,8 +347,6 @@ void Parallaction::doLocationEnterTransition() {
 	_gfx->setPalette(_gfx->_palette);
 
 	debugC(2, kDebugExec, "doLocationEnterTransition completed");
-
-	return;
 }
 
 void Parallaction::setLocationFlags(uint32 flags) {
@@ -393,8 +365,6 @@ uint32 Parallaction::getLocationFlags() {
 	return _localFlags[_currentLocationIndex];
 }
 
-
-
 void Parallaction::drawAnimation(AnimationPtr anim) {
 	if ((anim->_flags & kFlagsActive) == 0)   {
 		return;
@@ -487,7 +457,6 @@ void Parallaction::updateZones() {
 	debugC(9, kDebugExec, "Parallaction::updateZones done()\n");
 }
 
-
 void Parallaction::showZone(ZonePtr z, bool visible) {
 	if (!z) {
 		return;
@@ -505,10 +474,7 @@ void Parallaction::showZone(ZonePtr z, bool visible) {
 	}
 }
 
-
-//
 //	ZONE TYPE: EXAMINE
-//
 
 void Parallaction::enterCommentMode(ZonePtr z) {
 	if (!z) {
@@ -520,6 +486,7 @@ void Parallaction::enterCommentMode(ZonePtr z) {
 	TypeData *data = &_commentZone->u;
 
 	if (data->_examineText.empty()) {
+		exitCommentMode();
 		return;
 	}
 
@@ -531,18 +498,18 @@ void Parallaction::enterCommentMode(ZonePtr z) {
 			}
 
 			_gfx->setHalfbriteMode(true);
-			_balloonMan->setSingleBalloon(data->_examineText.c_str(), 0, 90, 0, BalloonManager::kNormalColor);
+			_balloonMan->setSingleBalloon(data->_examineText, 0, 90, 0, BalloonManager::kNormalColor);
 			Common::Rect r;
 			data->_gfxobj->getRect(0, r);
 			_gfx->setItem(data->_gfxobj, 140, (_screenHeight - r.height())/2);
 			_gfx->setItem(_char._head, 100, 152);
 		} else {
-			_balloonMan->setSingleBalloon(data->_examineText.c_str(), 140, 10, 0, BalloonManager::kNormalColor);
+			_balloonMan->setSingleBalloon(data->_examineText, 140, 10, 0, BalloonManager::kNormalColor);
 			_gfx->setItem(_char._talk, 190, 80);
 		}
 	} else
 	if (_gameType == GType_BRA) {
-		_balloonMan->setSingleBalloon(data->_examineText.c_str(), 0, 0, 1, BalloonManager::kNormalColor);
+		_balloonMan->setSingleBalloon(data->_examineText, 0, 0, 1, BalloonManager::kNormalColor);
 		_gfx->setItem(_char._talk, 10, 80);
 	}
 
@@ -569,7 +536,6 @@ void Parallaction::runCommentFrame() {
 	}
 }
 
-
 void Parallaction::runZone(ZonePtr z) {
 	debugC(3, kDebugExec, "runZone (%s)", z->_name);
 
@@ -618,9 +584,8 @@ void Parallaction::runZone(ZonePtr z) {
 	return;
 }
 
-//
 //	ZONE TYPE: DOOR
-//
+
 void Parallaction::updateDoor(ZonePtr z, bool close) {
 	z->_flags = close ? (z->_flags |= kFlagsClosed) : (z->_flags &= ~kFlagsClosed);
 
@@ -633,11 +598,7 @@ void Parallaction::updateDoor(ZonePtr z, bool close) {
 	return;
 }
 
-
-
-//
 //	ZONE TYPE: GET
-//
 
 bool Parallaction::pickupItem(ZonePtr z) {
 	if (z->_flags & kFlagsFixed) {
@@ -666,7 +627,7 @@ bool Parallaction::checkSpecialZoneBox(ZonePtr z, uint32 type, uint x, uint y) {
 			return false;
 		}
 	}
-	
+
 	// WORKAROUND: this huge condition is needed because we made TypeData a collection of structs
 	// instead of an union. So, merge->_obj1 and get->_icon were just aliases in the original engine,
 	// but we need to check it separately here. The same workaround is applied in freeZones.
@@ -693,19 +654,19 @@ bool Parallaction::checkSpecialZoneBox(ZonePtr z, uint32 type, uint x, uint y) {
 bool Parallaction::checkZoneType(ZonePtr z, uint32 type) {
 	if (_gameType == GType_Nippon) {
 		if ((type == 0) && (ITEMTYPE(z) == 0))
-			return true;		
+			return true;
 	}
 
 	if (_gameType == GType_BRA) {
 		if (type == 0) {
-			if (ITEMTYPE(z) == 0) {			
+			if (ITEMTYPE(z) == 0) {
 				if (ACTIONTYPE(z) != kZonePath) {
 					return true;
 				}
-			} 
+			}
 			if (ACTIONTYPE(z) == kZoneDoor) {
 				return true;
-			}	
+			}
 		}
 	}
 
@@ -766,11 +727,10 @@ bool Parallaction::checkLinkedAnimBox(ZonePtr z, uint32 type, uint x, uint y) {
 	return checkZoneType(z, type);
 }
 
-/* NOTE: hitZone needs to be passed absolute game coordinates to work.
-
-   When type is kZoneMerge, then x and y are the identifiers of the objects to merge,
-   and the above requirement does not apply.
-*/
+// NOTE: hitZone needs to be passed absolute game coordinates to work.
+//
+// When type is kZoneMerge, then x and y are the identifiers of the objects to merge,
+// and the above requirement does not apply.
 ZonePtr Parallaction::hitZone(uint32 type, uint16 x, uint16 y) {
 	uint16 _di = y;
 	uint16 _si = x;
@@ -791,7 +751,7 @@ ZonePtr Parallaction::hitZone(uint32 type, uint16 x, uint16 y) {
 		AnimationPtr a = *ait;
 
 		_a = (a->_flags & kFlagsActive) ? 1 : 0;	// _a: active Animation
-		
+
 		if (!_a) {
 			if (_gameType == GType_BRA && ACTIONTYPE(a) != kZoneTrap) {
 				continue;
@@ -812,7 +772,6 @@ ZonePtr Parallaction::hitZone(uint32 type, uint16 x, uint16 y) {
 	return ZonePtr();
 }
 
-
 ZonePtr Location::findZone(const char *name) {
 	for (ZoneList::iterator it = _zones.begin(); it != _zones.end(); ++it) {
 		if (!scumm_stricmp((*it)->_name, name)) return *it;
@@ -836,7 +795,6 @@ bool Location::keepAnimation_br(AnimationPtr a) {
 	return keepZone_br(a);
 }
 
-
 template <class T>
 void Location::freeList(Common::List<T> &list, bool removeAll, Common::MemFunc1<bool, T, Location> filter) {
 	typedef typename Common::List<T>::iterator iterator;
@@ -868,8 +826,6 @@ void Location::freeZones(bool removeAll) {
 	}
 }
 
-
-
 Character::Character() : _ani(new Animation) {
 	_talk = NULL;
 	_head = NULL;
@@ -883,7 +839,6 @@ Character::Character() : _ani(new Animation) {
 	strncpy(_ani->_name, "yourself", ZONENAME_LENGTH);
 }
 
-
 void Character::setName(const char *name) {
 	_name.bind(name);
 }
@@ -904,8 +859,6 @@ bool Character::dummy() const {
 	return _name.dummy();
 }
 
-
-
 // Various ways of detecting character modes used to exist
 // inside the engine, so they have been unified in the two
 // following macros.
@@ -936,7 +889,6 @@ CharacterName::CharacterName(const char *name) {
 	bind(name);
 }
 
-
 void CharacterName::bind(const char *name) {
 	const char *begin = name;
 	const char *end = begin + strlen(name);
@@ -947,22 +899,23 @@ void CharacterName::bind(const char *name) {
 	_dummy = IS_DUMMY_CHARACTER(name);
 
 	if (!_dummy) {
-		if (!strstr(name, "donna")) {
+		if (!strcmp(name, "donna")) {
 			_engineFlags &= ~kEngineTransformedDonna;
-		} else
-		if (_engineFlags & kEngineTransformedDonna) {
-			_suffix = _suffixTras;
 		} else {
-			const char *s = strstr(name, "tras");
-			if (s) {
-				_engineFlags |= kEngineTransformedDonna;
+			if (_engineFlags & kEngineTransformedDonna) {
 				_suffix = _suffixTras;
-				end = s;
+			} else {
+				const char *s = strstr(name, "tras");
+				if (s) {
+					_engineFlags |= kEngineTransformedDonna;
+					_suffix = _suffixTras;
+					end = s;
+				}
+			}
+			if (IS_MINI_CHARACTER(name)) {
+				_prefix = _prefixMini;
+				begin = name + 4;
 			}
-		}
-		if (IS_MINI_CHARACTER(name)) {
-			_prefix = _prefixMini;
-			begin = name+4;
 		}
 	}
 
@@ -1003,5 +956,4 @@ void Parallaction::scheduleLocationSwitch(const char *location) {
 	_engineFlags |= kEngineChangeLocation;
 }
 
-
-} // namespace Parallaction
+} // End of namespace Parallaction
