@@ -18,13 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/parallaction_br.cpp $
- * $Id: parallaction_br.cpp 54750 2010-12-03 11:36:51Z drmccoy $
- *
  */
 
 #include "common/system.h"
 #include "common/util.h"
+#include "common/textconsole.h"
 
 #include "parallaction/parallaction.h"
 #include "parallaction/exec.h"
@@ -61,9 +59,7 @@ Common::Error Parallaction_br::init() {
 			_disk = new DosDisk_br(this);
 		}
 		_disk->setLanguage(2);					// NOTE: language is now hardcoded to English. Original used command-line parameters.
-		MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_MIDI | MDT_ADLIB | MDT_PREFER_GM);
-		MidiDriver *driver = MidiDriver::createMidi(dev);
-		_soundManI = new DosSoundMan_br(this, driver);
+		_soundManI = new DosSoundMan_br(this);
 	} else {
 		_disk = new AmigaDisk_br(this);
 		_disk->setLanguage(2);					// NOTE: language is now hardcoded to English. Original used command-line parameters.
@@ -228,7 +224,6 @@ void Parallaction_br::freeCharacter() {
 void Parallaction_br::freeLocation(bool removeAll) {
 	// free open location stuff
 	clearSubtitles();
-	_subtitle[0] = _subtitle[1] = 0;
 
 	_localFlagNames->clear();
 
@@ -301,6 +296,7 @@ void Parallaction_br::changeLocation() {
 		_countersNames = _disk->loadTable("counters");
 
 		// TODO: maybe handle this into Disk
+		delete _objects;
 		if (getPlatform() == Common::kPlatformPC) {
 			_objects = _disk->loadObjects("icone.ico");
 		} else {
