@@ -18,11 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/parallaction/parser_ns.cpp $
- * $Id: parser_ns.cpp 49428 2010-06-04 13:48:09Z peres001 $
- *
  */
 
+#include "common/textconsole.h"
 
 #include "parallaction/parallaction.h"
 #include "parallaction/parser.h"
@@ -536,7 +534,7 @@ DECLARE_INSTRUCTION_PARSER(endscript)  {
 
 void ProgramParser_ns::parseRValue(ScriptVar &v, const char *str) {
 
-	if (isdigit(str[0]) || str[0] == '-') {
+	if (isdigit(static_cast<unsigned char>(str[0])) || str[0] == '-') {
 		v.setImmediate(atoi(str));
 		return;
 	}
@@ -1284,7 +1282,7 @@ DECLARE_ZONE_PARSER(commands)  {
 DECLARE_ZONE_PARSER(label)  {
 	debugC(7, kDebugParser, "ZONE_PARSER(label) ");
 
-//			printf("label: %s", _tokens[1]);
+//			debug("label: %s", _tokens[1]);
 	ctxt.z->_label = _vm->_gfx->renderFloatingLabel(_vm->_labelFont, _tokens[1]);
 	ctxt.z->_flags &= ~kFlagsNoName;
 }
@@ -1336,6 +1334,21 @@ void LocationParser_ns::parseGetData(ZonePtr z) {
 		obj->x = z->getX();
 		obj->y = z->getY();
 		obj->_prog = _zoneProg;
+
+		// WORKAROUND for script bug #2969913
+		// The katana object has the same default z index (kGfxObjGetZ or -100)
+		// as the cripta object (the safe) - a script bug.
+		// Game scripts do not set an explicit z for the katana (as it isn't an
+		// animation), but rather rely on the draw order to draw it over the
+		// safe. In this particular case, the safe is added to the scene after
+		// the katana, thus it is drawn over the katana. We explicitly set the
+		// z index of the katana to be higher than the safe, so that the katana
+		// is drawn correctly over it.
+		// This is a regression from the graphics rewrite (commits be2c5d3,
+		// 3c2c16c and 44906f5).
+		if (!scumm_stricmp(obj->getName(), "katana"))
+			obj->z = 0;
+
 		bool visible = (z->_flags & kFlagsRemove) == 0;
 		_vm->_gfx->showGfxObj(obj, visible);
 		data->_gfxobj = obj;
@@ -1413,6 +1426,24 @@ void LocationParser_ns::parseSpeakData(ZonePtr z) {
 	}
 }
 
+void LocationParser_ns::parseNoneData(ZonePtr z) {
+	// "None" zones should have no content, but some
+	// inconsistently define their command list after
+	// the TYPE marker. This routine catches these
+	// command lists that would be lost otherwise.
+	if (!scumm_stricmp(_tokens[0], "commands")) {
+		parseCommands(z->_commands);
+		ctxt.endcommands = false;
+		do {
+			_script->readLineToken(true);
+			_parser->parseStatement();
+		} while (!ctxt.endcommands);
+
+		// no need to parse one more line here, as
+		// it is done by the caller
+	}
+}
+
 typedef void (LocationParser_ns::*ZoneTypeParser)(ZonePtr);
 static ZoneTypeParser parsers[] = {
 	0,	// no type
@@ -1424,7 +1455,7 @@ static ZoneTypeParser parsers[] = {
 	&LocationParser_ns::parseHearData,
 	0,	// feel
 	&LocationParser_ns::parseSpeakData,
-	0,	// none
+	&LocationParser_ns::parseNoneData,
 	0,	// trap
 	0,	// you
 	0	// command
