@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -1084,10 +1081,10 @@ void Command::setAreas(uint16 command) {
 			Area *area = _vm->grid()->area(cmdArea->room, areaNum);
 			if (cmdArea->area > 0) {
 				// turn on area
-				area->mapNeighbours = ABS(area->mapNeighbours);
+				area->mapNeighbors = ABS(area->mapNeighbors);
 			} else {
 				// turn off area
-				area->mapNeighbours = -ABS(area->mapNeighbours);
+				area->mapNeighbors = -ABS(area->mapNeighbors);
 			}
 		}
 	}
