@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/textconsole.h"
@@ -1155,10 +1152,10 @@ void Cutaway::updateGameState() {
 
 				if (areaSubIndex > 0) {
 					Area *area = _vm->grid()->area(areaIndex, areaSubIndex);
-					area->mapNeighbours = ABS(area->mapNeighbours);
+					area->mapNeighbors = ABS(area->mapNeighbors);
 				} else {
 					Area *area = _vm->grid()->area(areaIndex, ABS(areaSubIndex));
-					area->mapNeighbours = -ABS(area->mapNeighbours);
+					area->mapNeighbors = -ABS(area->mapNeighbors);
 				}
 			}
 
