@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/queen/graphics.cpp $
- * $Id: graphics.cpp 48800 2010-04-25 21:53:09Z cyx $
- *
  */
 
 
@@ -34,6 +31,9 @@
 #include "queen/resource.h"
 #include "queen/sound.h"
 
+#include "common/debug.h"
+#include "common/textconsole.h"
+
 namespace Queen {
 
 void BobSlot::curPos(int16 xx, int16 yy) {
@@ -1201,7 +1201,7 @@ void BamScene::updateCarAnimation() {
 }
 
 void BamScene::updateFightAnimation() {
-	static const BamDataBlock *fightDataBlocks[] = {
+	static const BamDataBlock *const fightDataBlocks[] = {
 		_fight1Data,
 		_fight2Data,
 		_fight3Data
