@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -1629,7 +1626,7 @@ void Logic::asmSetLightsOn() {
 
 void Logic::asmSetManequinAreaOn() {
 	Area *a = _vm->grid()->area(ROOM_FLODA_FRONTDESK, 7);
-	a->mapNeighbours = ABS(a->mapNeighbours);
+	a->mapNeighbors = ABS(a->mapNeighbors);
 }
 
 void Logic::asmPanToJoe() {
