@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef QUEEN_RESOURCE_H
@@ -161,7 +158,7 @@ protected:
 	static const RetailGameVersion *detectGameVersionFromSize(uint32 size);
 
 	//! resource table filename (queen.tbl)
-	static const char *_tableFilename;
+	static const char *const _tableFilename;
 
 	//! known FOTAQ versions
 	static const RetailGameVersion _gameVersions[];
