@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/introproc_saga2.cpp $
- * $Id: introproc_saga2.cpp 49080 2010-05-18 14:57:02Z thebluegr $
- *
  */
 
 #ifdef ENABLE_SAGA2
@@ -31,9 +28,12 @@
 #include "saga/scene.h"
 #include "saga/gfx.h"
 
-#include "sound/mixer.h"
+#include "common/events.h"
+#include "common/keyboard.h"
+#include "common/system.h"
+#include "common/textconsole.h"
 #include "graphics/surface.h"
-#include "graphics/video/smk_decoder.h"
+#include "video/smk_decoder.h"
 
 namespace Saga {
 
@@ -92,7 +92,7 @@ int Scene::FTA2EndProc(FTA2Endings whichEnding) {
 }
 
 void Scene::playMovie(const char *filename) {
-	Graphics::SmackerDecoder *smkDecoder = new Graphics::SmackerDecoder(_vm->_mixer);
+	Video::SmackerDecoder *smkDecoder = new Video::SmackerDecoder(_vm->_mixer);
 
 	if (!smkDecoder->loadFile(filename))
 		return;
@@ -103,7 +103,7 @@ void Scene::playMovie(const char *filename) {
 
 	while (!_vm->shouldQuit() && !smkDecoder->endOfVideo() && !skipVideo) {
 		if (smkDecoder->needsUpdate()) {
-			Graphics::Surface *frame = smkDecoder->decodeNextFrame();
+			const Graphics::Surface *frame = smkDecoder->decodeNextFrame();
 			if (frame) {
 				_vm->_system->copyRectToScreen((byte *)frame->pixels, frame->pitch, x, y, frame->w, frame->h);
 
@@ -113,7 +113,7 @@ void Scene::playMovie(const char *filename) {
 				_vm->_system->updateScreen();
 			}
 		}
-	
+
 		Common::Event event;
 		while (_vm->_system->getEventManager()->pollEvent(event)) {
 			if ((event.type == Common::EVENT_KEYDOWN && event.kbd.keycode == Common::KEYCODE_ESCAPE) || event.type == Common::EVENT_LBUTTONUP)
