@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/saga/saga.cpp $
- * $Id: saga.cpp 50963 2010-07-17 18:38:42Z fingolfin $
- *
  */
 
 #include "common/file.h"
@@ -28,9 +25,8 @@
 #include "common/config-manager.h"
 #include "common/system.h"
 #include "common/events.h"
-#include "common/EventRecorder.h"
 
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 #include "saga/saga.h"
 
@@ -59,7 +55,7 @@ namespace Saga {
 #define MAX_TIME_DELTA 100
 
 SagaEngine::SagaEngine(OSystem *syst, const SAGAGameDescription *gameDesc)
-	: Engine(syst), _gameDescription(gameDesc) {
+	: Engine(syst), _gameDescription(gameDesc), _rnd("saga") {
 
 	_framesEsc = 0;
 
@@ -76,9 +72,8 @@ SagaEngine::SagaEngine(OSystem *syst, const SAGAGameDescription *gameDesc)
 	_readingSpeed = 0;
 
 	_copyProtection = false;
-	_gf_wyrmkeep = false;
 	_musicWasPlaying = false;
-
+	_hasITESceneSubstitutes = false;
 
 	_sndRes = NULL;
 	_sound = NULL;
@@ -136,7 +131,6 @@ SagaEngine::SagaEngine(OSystem *syst, const SAGAGameDescription *gameDesc)
 	SearchMan.addSubDirectoryMatching(gameDataDir, "video");
 
 	_displayClip.left = _displayClip.top = 0;
-	g_eventRec.registerRandomSource(_rnd, "saga");
 }
 
 SagaEngine::~SagaEngine() {
@@ -216,9 +210,9 @@ Common::Error SagaEngine::run() {
 	_subtitlesEnabled = ConfMan.getBool("subtitles");
 	_readingSpeed = getTalkspeed();
 	_copyProtection = ConfMan.getBool("copy_protection");
-	_gf_wyrmkeep = false;
 	_musicWasPlaying = false;
 	_isIHNMDemo = Common::File::exists("music.res");
+	_hasITESceneSubstitutes = Common::File::exists("boarhall.bbm");
 
 	if (_readingSpeed > 3)
 		_readingSpeed = 0;
@@ -291,7 +285,7 @@ Common::Error SagaEngine::run() {
 	_sound = new Sound(this, _mixer);
 
 	if (!isSaga2()) {
-		_interface->converseInit();
+		_interface->converseClear();
 		_script->setVerb(_script->getVerbType(kVerbWalkTo));
 	}
 
@@ -393,28 +387,26 @@ Common::Error SagaEngine::run() {
 	return Common::kNoError;
 }
 
-void SagaEngine::loadStrings(StringsTable &stringsTable, const byte *stringsPointer, size_t stringsLength) {
+void SagaEngine::loadStrings(StringsTable &stringsTable, const ByteArray &stringsData) {
 	uint16 stringsCount;
 	size_t offset;
 	size_t prevOffset = 0;
-	int i;
+	Common::Array<size_t> tempOffsets;
+	uint ui;
 
-	if (stringsLength == 0) {
+	if (stringsData.empty()) {
 		error("SagaEngine::loadStrings() Error loading strings list resource");
 	}
 
-	stringsTable.stringsPointer = (byte*)malloc(stringsLength);
-	memcpy(stringsTable.stringsPointer, stringsPointer, stringsLength);
 
-
-	MemoryReadStreamEndian scriptS(stringsTable.stringsPointer, stringsLength, isBigEndian()); //TODO: get endianess from context
+	ByteArrayReadStreamEndian scriptS(stringsData, isBigEndian()); //TODO: get endianess from context
 
 	offset = scriptS.readUint16();
 	stringsCount = offset / 2;
-	stringsTable.strings = (const char **)malloc(stringsCount * sizeof(*stringsTable.strings));
-	i = 0;
+	ui = 0;
 	scriptS.seek(0);
-	while (i < stringsCount) {
+	tempOffsets.resize(stringsCount);
+	while (ui < stringsCount) {
 		offset = scriptS.readUint16();
 		// In some rooms in IHNM, string offsets can be greater than the maximum value than a 16-bit integer can hold
 		// We detect this by checking the previous offset, and if it was bigger than the current one, an overflow
@@ -423,27 +415,47 @@ void SagaEngine::loadStrings(StringsTable &stringsTable, const byte *stringsPoin
 		if (prevOffset > offset)
 			offset += 65536;
 		prevOffset = offset;
-		if (offset == stringsLength) {
-			stringsCount = i;
-			stringsTable.strings = (const char **)realloc(stringsTable.strings, stringsCount * sizeof(*stringsTable.strings));
+		if (offset == stringsData.size()) {
+			stringsCount = ui;
+			tempOffsets.resize(stringsCount);
 			break;
 		}
-		if (offset > stringsLength) {
+		if (offset > stringsData.size()) {
 			// This case should never occur, but apparently it does in the Italian fan
 			// translation of IHNM
 			warning("SagaEngine::loadStrings wrong strings table");
-			stringsCount = i;
-			stringsTable.strings = (const char **)realloc(stringsTable.strings, stringsCount * sizeof(*stringsTable.strings));
+			stringsCount = ui;
+			tempOffsets.resize(stringsCount);
 			break;
 		}
-		stringsTable.strings[i] = (const char *)stringsTable.stringsPointer + offset;
-		debug(9, "string[%i]=%s", i, stringsTable.strings[i]);
-		i++;
+		tempOffsets[ui] = offset;
+		ui++;
+	}
+
+	prevOffset = scriptS.pos();
+	int32 left = scriptS.size() - prevOffset;
+	if (left < 0) {
+		error("SagaEngine::loadStrings() Error loading strings buffer");
+	}
+
+	stringsTable.buffer.resize(left);
+	if (left > 0) {
+		scriptS.read(&stringsTable.buffer.front(), left);
+	}
+
+	stringsTable.strings.resize(tempOffsets.size());
+	for (ui = 0; ui < tempOffsets.size(); ui++) {
+		offset = tempOffsets[ui] - prevOffset;
+		if (offset >= stringsTable.buffer.size()) {
+			error("SagaEngine::loadStrings() Wrong offset");
+		}
+		stringsTable.strings[ui] = &stringsTable.buffer[offset];
+
+		debug(9, "string[%i]=%s", ui, stringsTable.strings[ui]);
 	}
-	stringsTable.stringsCount = stringsCount;
 }
 
-const char *SagaEngine::getObjectName(uint16 objectId) {
+const char *SagaEngine::getObjectName(uint16 objectId) const {
 	ActorData *actor;
 	ObjectData *obj;
 	const HitZone *hitZone;
@@ -598,7 +610,7 @@ void SagaEngine::setTalkspeed(int talkspeed) {
 	ConfMan.setInt("talkspeed", (talkspeed * 255 + 3 / 2) / 3);
 }
 
-int SagaEngine::getTalkspeed() {
+int SagaEngine::getTalkspeed() const {
 	return (ConfMan.getInt("talkspeed") * 3 + 255 / 2) / 255;
 }
 
@@ -607,6 +619,8 @@ GUI::Debugger *SagaEngine::getDebugger() {
 }
 
 void SagaEngine::syncSoundSettings() {
+	Engine::syncSoundSettings();
+
 	_subtitlesEnabled = ConfMan.getBool("subtitles");
 	_readingSpeed = getTalkspeed();
 
