@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 // Scripting module: Script resource handling functions
@@ -29,6 +26,7 @@
 #include "saga/gfx.h"
 #include "saga/console.h"
 
+#include "saga/animation.h"
 #include "saga/script.h"
 #include "saga/interface.h"
 #include "saga/itedata.h"
@@ -944,6 +942,18 @@ void Script::opSpeak(SCRIPTOP_PARAMS) {
 		return;
 	}
 
+#ifdef ENABLE_IHNM
+	// WORKAROUND for script bug #3358007 in IHNM. When the zeppelin is landing
+	// and the player attempts to exit from the right door in room 13, the game
+	// scripts change to scene 5, but do not clear the cutaway that appears
+	// before Gorrister's speech starts, resulting in a deadlock. We do this
+	// manually here.
+	if (_vm->getGameId() == GID_IHNM && _vm->_scene->currentChapterNumber() == 1 && 
+		_vm->_scene->currentSceneNumber() == 5 && _vm->_anim->hasCutaway()) {
+		_vm->_anim->returnFromCutaway();
+	}
+#endif
+
 	int stringsCount = scriptS->readByte();
 	uint16 actorId = scriptS->readUint16LE();
 	uint16 speechFlags = scriptS->readByte();
@@ -1157,7 +1167,7 @@ void Script::showVerb(int statusColor) {
 	const char *verbName;
 	const char *object1Name;
 	const char *object2Name;
-	char statusString[STATUS_TEXT_LEN];
+	Common::String statusString;
 
 	if (_leftButtonVerb == getVerbType(kVerbNone)) {
 		_vm->_interface->setStatusText("");
@@ -1177,8 +1187,8 @@ void Script::showVerb(int statusColor) {
 	object1Name = _vm->getObjectName(_currentObject[0]);
 
 	if (!_secondObjectNeeded) {
-		snprintf(statusString, STATUS_TEXT_LEN, "%s %s", verbName, object1Name);
-		_vm->_interface->setStatusText(statusString, statusColor);
+		statusString = Common::String::format("%s %s", verbName, object1Name);
+		_vm->_interface->setStatusText(statusString.c_str(), statusColor);
 		return;
 	}
 
@@ -1190,15 +1200,15 @@ void Script::showVerb(int statusColor) {
 	}
 
 	if (_leftButtonVerb == getVerbType(kVerbGive)) {
-		snprintf(statusString, STATUS_TEXT_LEN, _vm->getTextString(kTextGiveTo), object1Name, object2Name);
-		_vm->_interface->setStatusText(statusString, statusColor);
+		statusString = Common::String::format(_vm->getTextString(kTextGiveTo), object1Name, object2Name);
+		_vm->_interface->setStatusText(statusString.c_str(), statusColor);
 	} else {
 		if (_leftButtonVerb == getVerbType(kVerbUse)) {
-			snprintf(statusString, STATUS_TEXT_LEN, _vm->getTextString(kTextUseWidth), object1Name, object2Name);
-			_vm->_interface->setStatusText(statusString, statusColor);
+			statusString = Common::String::format(_vm->getTextString(kTextUseWidth), object1Name, object2Name);
+			_vm->_interface->setStatusText(statusString.c_str(), statusColor);
 		} else {
-			snprintf(statusString, STATUS_TEXT_LEN, "%s %s", verbName, object1Name);
-			_vm->_interface->setStatusText(statusString, statusColor);
+			statusString = Common::String::format("%s %s", verbName, object1Name);
+			_vm->_interface->setStatusText(statusString.c_str(), statusColor);
 		}
 	}
 }
