@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/decompressor.h $
- * $Id: decompressor.h 48086 2010-02-17 23:38:43Z fingolfin $
- *
  */
 
 #ifndef SCI_DECOMPRESSOR_H
@@ -28,7 +25,9 @@
 
 #include "common/scummsys.h"
 
-namespace Common { class ReadStream; }
+namespace Common {
+class ReadStream;
+}
 
 namespace Sci {
 
@@ -179,10 +178,6 @@ protected:
 class DecompressorDCL : public Decompressor {
 public:
 	int unpack(Common::ReadStream *src, byte *dest, uint32 nPacked, uint32 nUnpacked);
-
-protected:
-	int unpackDCL(byte *dest);
-	int huffman_lookup(const int *tree);
 };
 
 #ifdef ENABLE_SCI32
@@ -202,4 +197,3 @@ protected:
 } // End of namespace Sci
 
 #endif // SCI_SCICORE_DECOMPRESSOR_H
-
