@@ -18,40 +18,51 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/gc.cpp $
- * $Id: gc.cpp 52465 2010-08-31 09:45:36Z thebluegr $
- *
  */
 
 #include "sci/engine/gc.h"
 #include "common/array.h"
+#include "sci/graphics/ports.h"
 
 namespace Sci {
 
 //#define GC_DEBUG_CODE
 
-struct WorklistManager {
-	Common::Array<reg_t> _worklist;
-	AddrSet _map;
-
-	void push(reg_t reg) {
-		if (!reg.segment) // No numbers
-			return;
-
-		debugC(2, kDebugLevelGC, "[GC] Adding %04x:%04x", PRINT_REG(reg));
-
-		if (_map.contains(reg))
-			return; // already dealt with it
-
-		_map.setVal(reg, true);
-		_worklist.push_back(reg);
-	}
-
-	void pushArray(const Common::Array<reg_t> &tmp) {
-		for (Common::Array<reg_t>::const_iterator it = tmp.begin(); it != tmp.end(); ++it)
-			push(*it);
-	}
+#ifdef GC_DEBUG_CODE
+const char *segmentTypeNames[] = {
+	"invalid",   // 0
+	"script",    // 1
+	"clones",    // 2
+	"locals",    // 3
+	"stack",     // 4
+	"obsolete",  // 5: obsolete system strings
+	"lists",     // 6
+	"nodes",     // 7
+	"hunk",      // 8
+	"dynmem",    // 9
+	"obsolete",  // 10: obsolete string fragments
+	"array",     // 11: SCI32 arrays
+	"string"     // 12: SCI32 strings
 };
+#endif
+
+void WorklistManager::push(reg_t reg) {
+	if (!reg.segment) // No numbers
+		return;
+
+	debugC(kDebugLevelGC, "[GC] Adding %04x:%04x", PRINT_REG(reg));
+
+	if (_map.contains(reg))
+		return; // already dealt with it
+
+	_map.setVal(reg, true);
+	_worklist.push_back(reg);
+}
+
+void WorklistManager::pushArray(const Common::Array<reg_t> &tmp) {
+	for (Common::Array<reg_t>::const_iterator it = tmp.begin(); it != tmp.end(); ++it)
+		push(*it);
+}
 
 static AddrSet *normalizeAddresses(SegManager *segMan, const AddrSet &nonnormal_map) {
 	AddrSet *normal_map = new AddrSet();
@@ -69,41 +80,51 @@ static AddrSet *normalizeAddresses(SegManager *segMan, const AddrSet &nonnormal_
 	return normal_map;
 }
 
+static void processWorkList(SegManager *segMan, WorklistManager &wm, const Common::Array<SegmentObj *> &heap) {
+	SegmentId stackSegment = segMan->findSegmentByType(SEG_TYPE_STACK);
+	while (!wm._worklist.empty()) {
+		reg_t reg = wm._worklist.back();
+		wm._worklist.pop_back();
+		if (reg.segment != stackSegment) { // No need to repeat this one
+			debugC(kDebugLevelGC, "[GC] Checking %04x:%04x", PRINT_REG(reg));
+			if (reg.segment < heap.size() && heap[reg.segment]) {
+				// Valid heap object? Find its outgoing references!
+				wm.pushArray(heap[reg.segment]->listAllOutgoingReferences(reg));
+			}
+		}
+	}
+}
 
 AddrSet *findAllActiveReferences(EngineState *s) {
-	SegManager *segMan = s->_segMan;
-	AddrSet *normal_map = NULL;
-	WorklistManager wm;
-	uint i;
-
 	assert(!s->_executionStack.empty());
 
-	// Initialise
-	// Init: Registers
+	WorklistManager wm;
+
+	// Initialize registers
 	wm.push(s->r_acc);
 	wm.push(s->r_prev);
-	// Init: Value Stack
+
+	// Initialize value stack
 	// We do this one by hand since the stack doesn't know the current execution stack
-	Common::List<ExecStack>::iterator iter = s->_executionStack.reverse_begin();
+	Common::List<ExecStack>::const_iterator iter = s->_executionStack.reverse_begin();
 
 	// Skip fake kernel stack frame if it's on top
-	if (((*iter).type == EXEC_STACK_TYPE_KERNEL))
+	if ((*iter).type == EXEC_STACK_TYPE_KERNEL)
 		--iter;
 
 	assert((iter != s->_executionStack.end()) && ((*iter).type != EXEC_STACK_TYPE_KERNEL));
 
-	ExecStack &xs = *iter;
-	reg_t *pos;
+	const StackPtr sp = iter->sp;
 
-	for (pos = s->stack_base; pos < xs.sp; pos++)
+	for (reg_t *pos = s->stack_base; pos < sp; pos++)
 		wm.push(*pos);
 
-	debugC(2, kDebugLevelGC, "[GC] -- Finished adding value stack");
+	debugC(kDebugLevelGC, "[GC] -- Finished adding value stack");
 
 	// Init: Execution Stack
 	for (iter = s->_executionStack.begin();
 	     iter != s->_executionStack.end(); ++iter) {
-		ExecStack &es = *iter;
+		const ExecStack &es = *iter;
 
 		if (es.type != EXEC_STACK_TYPE_KERNEL) {
 			wm.push(es.objp);
@@ -113,12 +134,13 @@ AddrSet *findAllActiveReferences(EngineState *s) {
 		}
 	}
 
-	debugC(2, kDebugLevelGC, "[GC] -- Finished adding execution stack");
+	debugC(kDebugLevelGC, "[GC] -- Finished adding execution stack");
 
-	const Common::Array<SegmentObj *> &heap = segMan->getSegments();
+	const Common::Array<SegmentObj *> &heap = s->_segMan->getSegments();
+	uint heapSize = heap.size();
 
 	// Init: Explicitly loaded scripts
-	for (i = 1; i < heap.size(); i++) {
+	for (uint i = 1; i < heapSize; i++) {
 		if (heap[i] && heap[i]->getType() == SEG_TYPE_SCRIPT) {
 			Script *script = (Script *)heap[i];
 
@@ -128,33 +150,21 @@ AddrSet *findAllActiveReferences(EngineState *s) {
 		}
 	}
 
-	debugC(2, kDebugLevelGC, "[GC] -- Finished explicitly loaded scripts, done with root set");
+	debugC(kDebugLevelGC, "[GC] -- Finished explicitly loaded scripts, done with root set");
 
-	// Run Worklist Algorithm
-	SegmentId stack_seg = segMan->findSegmentByType(SEG_TYPE_STACK);
-	while (!wm._worklist.empty()) {
-		reg_t reg = wm._worklist.back();
-		wm._worklist.pop_back();
-		if (reg.segment != stack_seg) { // No need to repeat this one
-			debugC(2, kDebugLevelGC, "[GC] Checking %04x:%04x", PRINT_REG(reg));
-			if (reg.segment < heap.size() && heap[reg.segment]) {
-				// Valid heap object? Find its outgoing references!
-				wm.pushArray(heap[reg.segment]->listAllOutgoingReferences(reg));
-			}
-		}
-	}
+	processWorkList(s->_segMan, wm, heap);
 
-	// Normalise
-	normal_map = normalizeAddresses(segMan, wm._map);
+	if (g_sci->_gfxPorts)
+		g_sci->_gfxPorts->processEngineHunkList(wm);
 
-	return normal_map;
+	return normalizeAddresses(s->_segMan, wm._map);
 }
 
 void run_gc(EngineState *s) {
 	SegManager *segMan = s->_segMan;
 
 	// Some debug stuff
-	debugC(2, kDebugLevelGC, "[GC] Running...");
+	debugC(kDebugLevelGC, "[GC] Running...");
 #ifdef GC_DEBUG_CODE
 	const char *segnames[SEG_TYPE_MAX + 1];
 	int segcount[SEG_TYPE_MAX + 1];
@@ -174,7 +184,7 @@ void run_gc(EngineState *s) {
 		if (mobj != NULL) {
 #ifdef GC_DEBUG_CODE
 			const SegmentType type = mobj->getType();
-			segnames[type] = SegmentObj::getSegmentTypeName(type);
+			segnames[type] = segmentTypeNames[type];
 #endif
 
 			// Get a list of all deallocatable objects in this segment,
@@ -185,7 +195,7 @@ void run_gc(EngineState *s) {
 				if (!activeRefs->contains(addr)) {
 					// Not found -> we can free it
 					mobj->freeAtAddress(segMan, addr);
-					debugC(2, kDebugLevelGC, "[GC] Deallocating %04x:%04x", PRINT_REG(addr));
+					debugC(kDebugLevelGC, "[GC] Deallocating %04x:%04x", PRINT_REG(addr));
 #ifdef GC_DEBUG_CODE
 					segcount[type]++;
 #endif
@@ -199,10 +209,10 @@ void run_gc(EngineState *s) {
 
 #ifdef GC_DEBUG_CODE
 	// Output debug summary of garbage collection
-	debugC(2, kDebugLevelGC, "[GC] Summary:");
+	debugC(kDebugLevelGC, "[GC] Summary:");
 	for (int i = 0; i <= SEG_TYPE_MAX; i++)
 		if (segcount[i])
-			debugC(2, kDebugLevelGC, "\t%d\t* %s", segcount[i], segnames[i]);
+			debugC(kDebugLevelGC, "\t%d\t* %s", segcount[i], segnames[i]);
 #endif
 }
 
