@@ -18,14 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/kstring.cpp $
- * $Id: kstring.cpp 52676 2010-09-11 13:30:42Z lskovlun $
- *
  */
 
 /* String and parser handling */
 
 #include "sci/resource.h"
+#include "sci/engine/features.h"
 #include "sci/engine/state.h"
 #include "sci/engine/message.h"
 #include "sci/engine/selector.h"
@@ -44,6 +42,14 @@ reg_t kStrCat(EngineState *s, int argc, reg_t *argv) {
 	Common::String s1 = s->_segMan->getString(argv[0]);
 	Common::String s2 = s->_segMan->getString(argv[1]);
 
+	// The Japanese version of PQ2 splits the two strings here
+	// (check bug #3396887).
+	if (g_sci->getGameId() == GID_PQ2 &&
+		g_sci->getLanguage() == Common::JA_JPN) {
+		s1 = g_sci->strSplit(s1.c_str(), NULL);
+		s2 = g_sci->strSplit(s2.c_str(), NULL);
+	}
+
 	s1 += s2;
 	s->_segMan->strcpy(argv[0], s1.c_str());
 	return argv[0];
@@ -68,8 +74,9 @@ reg_t kStrCpy(EngineState *s, int argc, reg_t *argv) {
 			s->_segMan->strncpy(argv[0], argv[1], length);
 		else
 			s->_segMan->memcpy(argv[0], argv[1], -length);
-	} else
+	} else {
 		s->_segMan->strcpy(argv[0], argv[1]);
+	}
 
 	return argv[0];
 }
@@ -110,7 +117,12 @@ reg_t kStrAt(EngineState *s, int argc, reg_t *argv) {
 			offset++;
 
 		reg_t &tmp = dest_r.reg[offset / 2];
-		if (!(offset & 1)) {
+
+		bool oddOffset = offset & 1;
+		if (g_sci->isBE())
+			oddOffset = !oddOffset;
+
+		if (!oddOffset) {
 			value = tmp.offset & 0x00ff;
 			if (argc > 2) { /* Request to modify this char */
 				tmp.offset &= 0xff00;
@@ -127,9 +139,7 @@ reg_t kStrAt(EngineState *s, int argc, reg_t *argv) {
 		}
 	}
 
-	s->r_acc = make_reg(0, value);
-
-	return s->r_acc;
+	return make_reg(0, value);
 }
 
 
@@ -155,17 +165,9 @@ reg_t kReadNumber(EngineState *s, int argc, reg_t *argv) {
 			source++;
 		}
 		while (*source) {
-			if ((*source < '0') || (*source > '9')) {
-				// Sierra's atoi stopped processing at anything which is not
-				// a digit. Sometimes the input has a trailing space, that's
-				// fine (example: lsl3)
-				if (*source != ' ') {
-					// TODO: this happens in lsl5 right in the intro -> we get '1' '3' 0xCD 0xCD 0xCD 0xCD 0xCD
-					//       find out why this happens and fix it
-					warning("Invalid character in kReadNumber input");
-				}
+			if ((*source < '0') || (*source > '9'))
+				// Stop if we encounter anything other than a digit (like atoi)
 				break;
-			}
 			result *= 10;
 			result += *source - 0x30;
 			source++;
@@ -179,7 +181,7 @@ reg_t kReadNumber(EngineState *s, int argc, reg_t *argv) {
 #define ALIGN_NONE 0
 #define ALIGN_RIGHT 1
 #define ALIGN_LEFT -1
-#define ALIGN_CENTRE 2
+#define ALIGN_CENTER 2
 
 /*  Format(targ_address, textresnr, index_inside_res, ...)
 ** or
@@ -194,24 +196,30 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 	char targetbuf[4096];
 	char *target = targetbuf;
 	reg_t position = argv[1]; /* source */
-	int index = argv[2].toUint16();
 	int mode = 0;
 	int paramindex = 0; /* Next parameter to evaluate */
 	char xfer;
 	int i;
 	int startarg;
-	int str_leng = 0; /* Used for stuff like "%13s" */
-	int unsigned_var = 0;
+	int strLength = 0; /* Used for stuff like "%13s" */
+	bool unsignedVar = false;
 
 	if (position.segment)
 		startarg = 2;
-	else
-		startarg = 3; /* First parameter to use for formatting */
+	else {
+		// WORKAROUND: QFG1 VGA Mac calls this without the first parameter (dest). It then
+		// treats the source as the dest and overwrites the source string with an empty string.
+		if (argc < 3)
+			return NULL_REG;
 
+		startarg = 3; /* First parameter to use for formatting */
+	}
+
+	int index = (startarg == 3) ? argv[2].toUint16() : 0;
 	Common::String source_str = g_sci->getKernel()->lookupText(position, index);
 	const char* source = source_str.c_str();
 
-	debugC(2, kDebugLevelStrings, "Formatting \"%s\"", source);
+	debugC(kDebugLevelStrings, "Formatting \"%s\"", source);
 
 
 	arguments = (uint16 *)malloc(sizeof(uint16) * argc);
@@ -228,7 +236,7 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 				mode = 0;
 			} else {
 				mode = 1;
-				str_leng = 0;
+				strLength = 0;
 			}
 		} else if (mode == 1) { /* xfer != '%' */
 			char fillchar = ' ';
@@ -238,32 +246,32 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 
 			/* int writelength; -- unused atm */
 
-			if (xfer && (isdigit(xfer) || xfer == '-' || xfer == '=')) {
+			if (xfer && (isdigit(static_cast<unsigned char>(xfer)) || xfer == '-' || xfer == '=')) {
 				char *destp;
 
 				if (xfer == '0')
 					fillchar = '0';
 				else if (xfer == '=')
-					align = ALIGN_CENTRE;
-				else if (isdigit(xfer) || (xfer == '-'))
+					align = ALIGN_CENTER;
+				else if (isdigit(static_cast<unsigned char>(xfer)) || (xfer == '-'))
 					source--; // Go to start of length argument
 
-				str_leng = strtol(source, &destp, 10);
+				strLength = strtol(source, &destp, 10);
 
 				if (destp > source)
 					source = destp;
 
-				if (str_leng < 0) {
+				if (strLength < 0) {
 					align = ALIGN_LEFT;
-					str_leng = -str_leng;
-				} else if (align != ALIGN_CENTRE)
+					strLength = -strLength;
+				} else if (align != ALIGN_CENTER)
 					align = ALIGN_RIGHT;
 
 				xfer = *source++;
 			} else
-				str_leng = 0;
+				strLength = 0;
 
-			assert((target - targetbuf) + str_leng + 1 <= maxsize);
+			assert((target - targetbuf) + strLength + 1 <= maxsize);
 
 			switch (xfer) {
 			case 's': { /* Copy string */
@@ -278,7 +286,7 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 				Common::String tempsource = g_sci->getKernel()->lookupText(reg,
 				                                  arguments[paramindex + 1]);
 				int slen = strlen(tempsource.c_str());
-				int extralen = str_leng - slen;
+				int extralen = strLength - slen;
 				assert((target - targetbuf) + extralen <= maxsize);
 				if (extralen < 0)
 					extralen = 0;
@@ -296,7 +304,7 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 						*target++ = ' '; /* Format into the text */
 					break;
 
-				case ALIGN_CENTRE: {
+				case ALIGN_CENTER: {
 					int half_extralen = extralen >> 1;
 					while (half_extralen-- > 0)
 						*target++ = ' '; /* Format into the text */
@@ -313,7 +321,7 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 
 				switch (align) {
 
-				case ALIGN_CENTRE: {
+				case ALIGN_CENTER: {
 					int half_extralen;
 					align = 0;
 					half_extralen = extralen - (extralen >> 1);
@@ -334,18 +342,25 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 			case 'c': { /* insert character */
 				assert((target - targetbuf) + 2 <= maxsize);
 				if (align >= 0)
-					while (str_leng-- > 1)
+					while (strLength-- > 1)
 						*target++ = ' '; /* Format into the text */
-
-				*target++ = arguments[paramindex++];
+				char argchar = arguments[paramindex++];
+				if (argchar)
+					*target++ = argchar;
 				mode = 0;
 			}
 			break;
 
 			case 'x':
 			case 'u':
-				unsigned_var = 1;
+				unsignedVar = true;
 			case 'd': { /* Copy decimal */
+				// In the new SCI2 kString function, %d is used for unsigned
+				// integers. An example is script 962 in Shivers - it uses %d
+				// to create file names.
+				if (getSciVersion() >= SCI_VERSION_2)
+					unsignedVar = true;
+
 				/* int templen; -- unused atm */
 				const char *format_string = "%d";
 
@@ -353,14 +368,14 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 					format_string = "%x";
 
 				int val = arguments[paramindex];
-				if (!unsigned_var)
+				if (!unsignedVar)
 					val = (int16)arguments[paramindex];
 
 				target += sprintf(target, format_string, val);
 				paramindex++;
 				assert((target - targetbuf) <= maxsize);
 
-				unsigned_var = 0;
+				unsignedVar = false;
 
 				mode = 0;
 			}
@@ -375,7 +390,7 @@ reg_t kFormat(EngineState *s, int argc, reg_t *argv) {
 
 			if (align) {
 				int written = target - writestart;
-				int padding = str_leng - written;
+				int padding = strLength - written;
 
 				if (padding > 0) {
 					if (align > 0) {
@@ -427,7 +442,7 @@ reg_t kGetFarText(EngineState *s, int argc, reg_t *argv) {
 	}
 
 	seeker = (char *)textres->data;
-	
+
 	// The second parameter (counter) determines the number of the string
 	// inside the text resource.
 	while (counter--) {
@@ -616,7 +631,14 @@ reg_t kText(EngineState *s, int argc, reg_t *argv) {
 }
 
 reg_t kString(EngineState *s, int argc, reg_t *argv) {
-	switch (argv[0].toUint16()) {
+	uint16 op = argv[0].toUint16();
+
+	if (g_sci->_features->detectSci2StringFunctionType() == kSci2StringFunctionNew) {
+		if (op >= 8)	// Dup, GetData have been removed
+			op += 2;
+	}
+
+	switch (op) {
 	case 0: { // New
 		reg_t stringHandle;
 		SciString *string = s->_segMan->allocateString(&stringHandle);
@@ -695,34 +717,22 @@ reg_t kString(EngineState *s, int argc, reg_t *argv) {
 
 		// A count of -1 means fill the rest of the array
 		uint32 count = argv[5].toSint16() == -1 ? string2Size - index2 + 1 : argv[5].toUint16();
-	
-		// We have a special case here for argv[1] being a system string
-		if (argv[1].segment == s->_segMan->getSysStringsSegment()) {
-			// Resize if necessary
-			const uint16 sysStringId = argv[1].toUint16();
-			SystemString *sysString = s->_segMan->getSystemString(sysStringId);
-			assert(sysString);
-			if ((uint32)sysString->_maxSize < index1 + count) {
-				free(sysString->_value);
-				sysString->_maxSize = index1 + count;
-				sysString->_value = (char *)calloc(index1 + count, sizeof(char));
-			}
+		reg_t strAddress = argv[1];
 
-			strncpy(sysString->_value + index1, string2 + index2, count);
-		} else {
-			SciString *string1 = s->_segMan->lookupString(argv[1]);
+		SciString *string1 = s->_segMan->lookupString(argv[1]);
+		//SciString *string1 = !argv[1].isNull() ? s->_segMan->lookupString(argv[1]) : s->_segMan->allocateString(&strAddress);
 
-			if (string1->getSize() < index1 + count)
-				string1->setSize(index1 + count);
+		if (string1->getSize() < index1 + count)
+			string1->setSize(index1 + count);
 
-			// Note: We're accessing from c_str() here because the
-			// string's size ignores the trailing 0 and therefore
-			// triggers an assert when doing string2[i + index2].
-			for (uint16 i = 0; i < count; i++)
-				string1->setValue(i + index1, string2[i + index2]);
-		}
-		
-	} return argv[1];
+		// Note: We're accessing from c_str() here because the
+		// string's size ignores the trailing 0 and therefore
+		// triggers an assert when doing string2[i + index2].
+		for (uint16 i = 0; i < count; i++)
+			string1->setValue(i + index1, string2[i + index2]);
+
+		return strAddress;
+	}
 	case 7: { // Cmp
 		Common::String string1 = argv[1].isNull() ? "" : s->_segMan->getString(argv[1]);
 		Common::String string2 = argv[2].isNull() ? "" : s->_segMan->getString(argv[2]);
@@ -735,6 +745,10 @@ reg_t kString(EngineState *s, int argc, reg_t *argv) {
 	case 8: { // Dup
 		const char *rawString = 0;
 		uint32 size = 0;
+		reg_t stringHandle;
+		// We allocate the new string first because if the StringTable needs to
+		// grow, our rawString pointer will be invalidated
+		SciString *dupString = s->_segMan->allocateString(&stringHandle);
 
 		if (argv[1].segment == s->_segMan->getStringSegmentId()) {
 			SciString *string = s->_segMan->lookupString(argv[1]);
@@ -746,8 +760,6 @@ reg_t kString(EngineState *s, int argc, reg_t *argv) {
 			size = string.size() + 1;
 		}
 
-		reg_t stringHandle;
-		SciString *dupString = s->_segMan->allocateString(&stringHandle);
 		dupString->setSize(size);
 
 		for (uint32 i = 0; i < size; i++)
@@ -780,6 +792,24 @@ reg_t kString(EngineState *s, int argc, reg_t *argv) {
 		Common::String string = s->_segMan->getString(argv[1]);
 		return make_reg(0, (uint16)atoi(string.c_str()));
 	}
+	// New subops in SCI2.1 late / SCI3
+	case 14:	// unknown
+		warning("kString, subop %d", op);
+		return NULL_REG;
+	case 15: { // upper
+		Common::String string = s->_segMan->getString(argv[1]);
+
+		string.toUppercase();
+		s->_segMan->strcpy(argv[1], string.c_str());
+		return NULL_REG;
+	}
+	case 16: { // lower
+		Common::String string = s->_segMan->getString(argv[1]);
+
+		string.toLowercase();
+		s->_segMan->strcpy(argv[1], string.c_str());
+		return NULL_REG;
+	}
 	default:
 		error("Unknown kString subop %d", argv[0].toUint16());
 	}
@@ -787,20 +817,6 @@ reg_t kString(EngineState *s, int argc, reg_t *argv) {
 	return NULL_REG;
 }
 
-/**
- * Debug function, used in the demo of Shivers. It's marked as a stub
- * in the original interpreter, but it gets called by the game scripts.
- */
-reg_t kPrintDebug(EngineState *s, int argc, reg_t *argv) {
-	Common::String debugTemplate = s->_segMan->getString(argv[0]);
-	char debugString[500];
-
-	sprintf(debugString, debugTemplate.c_str(), argv[1].toUint16());
-	debugC(2, "kPrintDebug: \"%s\"\n", debugString);
-
-	return s->r_acc;
-}
-
 #endif
 
 } // End of namespace Sci
