@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/seg_manager.h $
- * $Id: seg_manager.h 51572 2010-08-01 11:10:14Z thebluegr $
- *
  */
 
 #ifndef SCI_ENGINE_SEGMAN_H
@@ -35,15 +32,6 @@
 
 namespace Sci {
 
-/**
- * Verify the the given condition is true, output the message if condition is false, and exit.
- * @param cond	condition to be verified
- * @param msg	the message to be printed if condition fails
- */
-#define VERIFY( cond, msg ) if (!(cond)) {\
-		error("%s, line, %d, %s", __FILE__, __LINE__, msg); \
-	}
-
 /**
  * Parameters for getScriptSegment().
  */
@@ -83,7 +71,7 @@ public:
 	 */
 	Script *allocateScript(int script_nr, SegmentId *seg_id);
 
-	// The script must then be initialised; see section (1b.), below.
+	// The script must then be initialized; see section (1b.), below.
 
 	/**
 	 * Forcefully deallocate a previously allocated script.
@@ -91,11 +79,6 @@ public:
 	 */
 	void deallocateScript(int script_nr);
 
-	/**
-	 * Reconstructs scripts. Used when restoring saved games
-	 */
-	void reconstructScripts(EngineState *s);
-
 	/**
 	 * Reconstructs the stack. Used when restoring saved games
 	 */
@@ -443,22 +426,8 @@ public:
 	void setClassOffset(int index, reg_t offset) { _classTable[index].reg = offset;	}
 	void resizeClassTable(uint32 size) { _classTable.resize(size); }
 
-	/**
-	 * Obtains the system strings segment ID
-	 */
-	SegmentId getSysStringsSegment() { return _sysStringsSegId; }
-
-	/**
-	 * Get a pointer to the system string with the specified index,
-	 * or NULL if that index is invalid.
-	 *
-	 * This method is currently only used by kString().
-	 */
-	SystemString *getSystemString(uint idx) const {
-		if (idx >= SYS_STRINGS_MAX)
-			return NULL;
-		return &_sysStrings->_strings[idx];
-	}
+	reg_t getSaveDirPtr() const { return _saveDirPtr; }
+	reg_t getParserPtr() const { return _parserPtr; }
 
 #ifdef ENABLE_SCI32
 	SciArray<reg_t> *allocateArray(reg_t *addr);
@@ -485,9 +454,9 @@ private:
 	SegmentId _nodesSegId; ///< ID of the (a) node segment
 	SegmentId _hunksSegId; ///< ID of the (a) hunk segment
 
-	/* System strings */
-	SegmentId _sysStringsSegId;
-	SystemStrings *_sysStrings;
+	// Statically allocated memory for system strings
+	reg_t _saveDirPtr;
+	reg_t _parserPtr;
 
 #ifdef ENABLE_SCI32
 	SegmentId _arraysSegId;
@@ -496,7 +465,7 @@ private:
 
 private:
 	SegmentObj *allocSegment(SegmentObj *mem, SegmentId *segid);
-	int deallocate(SegmentId seg, bool recursive);
+	void deallocate(SegmentId seg);
 	void createClassTable();
 
 	SegmentId findFreeSegment() const;
