@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/selector.cpp $
- * $Id: selector.cpp 52508 2010-09-03 18:14:59Z m_kiewitz $
- *
  */
 
 #include "sci/sci.h"
@@ -40,10 +37,10 @@ namespace Sci {
 // The defines below can be used to construct static selector tables for games which don't have
 // a vocab.997 resource, by dumping the selector table from other similar versions or games
 #define FIND_SELECTOR(_slc_) _selectorCache._slc_ = findSelector(#_slc_); \
-	printf("\t{ \"%s\", %d },\n", #_slc_, _selectorCache._slc_)
+	debugN("\t{ \"%s\", %d },\n", #_slc_, _selectorCache._slc_)
 
 #define FIND_SELECTOR2(_slc_, _slcstr_) _selectorCache._slc_ = findSelector(_slcstr_); \
-	printf("\t{ \"%s\", %d },\n", _slcstr_, _selectorCache._slc_)
+	debugN("\t{ \"%s\", %d },\n", _slcstr_, _selectorCache._slc_)
 
 #endif
 
@@ -165,10 +162,12 @@ void Kernel::mapSelectors() {
 	FIND_SELECTOR(vanishingX);
 	FIND_SELECTOR(vanishingY);
 	FIND_SELECTOR(iconIndex);
+	FIND_SELECTOR(select);
 
 #ifdef ENABLE_SCI32
 	FIND_SELECTOR(data);
 	FIND_SELECTOR(picture);
+	FIND_SELECTOR(bitmap);
 	FIND_SELECTOR(plane);
 	FIND_SELECTOR(top);
 	FIND_SELECTOR(left);
@@ -214,7 +213,7 @@ void writeSelector(SegManager *segMan, reg_t object, Selector selectorId, reg_t
 		*address.getPointer(segMan) = value;
 }
 
-void invokeSelector(EngineState *s, reg_t object, int selectorId, 
+void invokeSelector(EngineState *s, reg_t object, int selectorId,
 	int k_argc, StackPtr k_argp, int argc, const reg_t *argv) {
 	int i;
 	int framesize = 2 + 1 * argc;
