@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/engine/state.cpp $
- * $Id: state.cpp 52474 2010-08-31 15:50:46Z m_kiewitz $
- *
  */
 
 #include "common/system.h"
@@ -94,10 +91,9 @@ void EngineState::reset(bool isRestoring) {
 	stack_base = 0;
 	stack_top = 0;
 
-	restAdjust = 0;
-
 	r_acc = NULL_REG;
 	r_prev = NULL_REG;
+	r_rest = 0;
 
 	lastWaitTime = 0;
 
@@ -106,6 +102,7 @@ void EngineState::reset(bool isRestoring) {
 	_throttleCounter = 0;
 	_throttleLastTime = 0;
 	_throttleTrigger = false;
+	_gameIsBenchmarking = false;
 
 	_lastSaveVirtualId = SAVEGAMEID_OFFICIALRANGE_START;
 	_lastSaveNewId = 0;
@@ -116,6 +113,9 @@ void EngineState::reset(bool isRestoring) {
 
 	scriptStepCounter = 0;
 	scriptGCInterval = GC_INTERVAL;
+
+	_videoState.reset();
+	_syncedAudioOptions = false;
 }
 
 void EngineState::speedThrottler(uint32 neededSleep) {
@@ -144,7 +144,7 @@ void EngineState::wait(int16 ticks) {
 
 void EngineState::initGlobals() {
 	Script *script_000 = _segMan->getScript(1);
-	
+
 	if (!script_000->_localsBlock)
 		error("Script 0 has no locals block");
 
@@ -192,10 +192,10 @@ static kLanguage charToLanguage(const char c) {
 	}
 }
 
-Common::String SciEngine::getSciLanguageString(const char *str, kLanguage lang, kLanguage *lang2) const {
+Common::String SciEngine::getSciLanguageString(const Common::String &str, kLanguage lang, kLanguage *lang2) const {
 	kLanguage secondLang = K_LANG_NONE;
 
-	const char *seeker = str;
+	const char *seeker = str.c_str();
 	while (*seeker) {
 		if ((*seeker == '%') || (*seeker == '#')) {
 			secondLang = charToLanguage(*(seeker + 1));
@@ -242,9 +242,9 @@ Common::String SciEngine::getSciLanguageString(const char *str, kLanguage lang,
 	}
 
 	if (seeker)
-		return Common::String(str, seeker - str);
+		return Common::String(str.c_str(), seeker - str.c_str());
 	else
-		return Common::String(str);
+		return str;
 }
 
 kLanguage SciEngine::getSciLanguage() {
@@ -307,9 +307,8 @@ Common::String SciEngine::strSplit(const char *str, const char *sep) {
 	kLanguage lang = getSciLanguage();
 	kLanguage subLang = K_LANG_NONE;
 
-	if (SELECTOR(subtitleLang) != -1) {
+	if (SELECTOR(subtitleLang) != -1)
 		subLang = (kLanguage)readSelectorValue(_gamestate->_segMan, _gameObjectAddress, SELECTOR(subtitleLang));
-	}
 
 	kLanguage secondLang;
 	Common::String retval = getSciLanguageString(str, lang, &secondLang);
@@ -332,7 +331,7 @@ void SciEngine::checkVocabularySwitch() {
 	uint16 parserLanguage = 1;
 	if (SELECTOR(parseLang) != -1)
 		parserLanguage = readSelectorValue(_gamestate->_segMan, _gameObjectAddress, SELECTOR(parseLang));
-		
+
 	if (parserLanguage != _vocabularyLanguage) {
 		delete _vocabulary;
 		_vocabulary = new Vocabulary(_resMan, parserLanguage > 1 ? true : false);
