@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "sci/sci.h"
@@ -470,9 +467,9 @@ void GfxPaint16::kernelGraphRedrawBox(Common::Rect rect) {
 #define SCI_DISPLAY_WIDTH				106
 #define SCI_DISPLAY_SAVEUNDER			107
 #define SCI_DISPLAY_RESTOREUNDER		108
-#define SCI_DISPLAY_DUMMY1				114 // used in longbow demo/qfg1 ega demo, not supported in sierra sci - no parameters
-#define SCI_DISPLAY_DUMMY2				115 // used in longbow demo, not supported in sierra sci - has 1 parameter
-#define SCI_DISPLAY_DUMMY3				117 // used in qfg1 ega demo, not supported in sierra sci - no parameters
+#define SCI_DISPLAY_DUMMY1				114
+#define SCI_DISPLAY_DUMMY2				115
+#define SCI_DISPLAY_DUMMY3				117
 #define SCI_DISPLAY_DONTSHOWBITS		121
 
 reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
@@ -542,26 +539,29 @@ reg_t GfxPaint16::kernelDisplay(const char *text, int argc, reg_t *argv) {
 			bRedraw = 0;
 			break;
 
-		// 2 Dummy functions, longbow-demo is using those several times but sierra sci doesn't support them at all
-		// The Quest for Glory 1 EGA demo also calls kDisplay(114) and kDisplay(117)
-		case SCI_DISPLAY_DUMMY1:
-		case SCI_DISPLAY_DUMMY2:
-		case SCI_DISPLAY_DUMMY3:
-			if (!g_sci->isDemo() || (g_sci->getGameId() != GID_LONGBOW && g_sci->getGameId() != GID_QFG1))
+		// The following three dummy calls are not supported by the Sierra SCI
+		// interpreter, but are erroneously called in some game scripts.
+		case SCI_DISPLAY_DUMMY1:	// Longbow demo (all rooms) and QFG1 EGA demo (room 11)
+		case SCI_DISPLAY_DUMMY2:	// Longbow demo (all rooms)
+		case SCI_DISPLAY_DUMMY3:	// QFG1 EGA demo (room 11) and PQ2 (room 23)
+			if (!(g_sci->getGameId() == GID_LONGBOW && g_sci->isDemo()) &&
+				!(g_sci->getGameId() == GID_QFG1    && g_sci->isDemo()) &&
+				!(g_sci->getGameId() == GID_PQ2))
 				error("Unknown kDisplay argument %d", displayArg.offset);
+
 			if (displayArg.offset == SCI_DISPLAY_DUMMY2) {
-				if (argc) {
-					argc--; argv++;
-				} else {
+				if (!argc)
 					error("No parameter left for kDisplay(115)");
-				}
+				argc--; argv++;
 			}
 			break;
 		default:
 			SciTrackOriginReply originReply;
 			SciWorkaroundSolution solution = trackOriginAndFindWorkaround(0, kDisplay_workarounds, &originReply);
 			if (solution.type == WORKAROUND_NONE)
-				error("Unknown kDisplay argument (%04x:%04x) from method %s::%s (script %d, localCall %x)", PRINT_REG(displayArg), originReply.objectName.c_str(), originReply.methodName.c_str(), originReply.scriptNr, originReply.localCallOffset);
+				error("Unknown kDisplay argument (%04x:%04x) from method %s::%s (script %d, localCall %x)", 
+						PRINT_REG(displayArg), originReply.objectName.c_str(), originReply.methodName.c_str(), 
+						originReply.scriptNr, originReply.localCallOffset);
 			assert(solution.type == WORKAROUND_IGNORE);
 			break;
 		}
