@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/paint16.h $
- * $Id: paint16.h 51994 2010-08-11 18:19:58Z m_kiewitz $
- *
  */
 
 #ifndef SCI_GRAPHICS_PAINT16_H
@@ -28,15 +25,12 @@
 
 #include "sci/graphics/paint.h"
 
-#include "common/hashmap.h"
-
 namespace Sci {
 
 class GfxPorts;
 class GfxScreen;
 class GfxPalette;
 class Font;
-class SciGuiPicture;
 class GfxView;
 
 /**
