@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/picture.cpp $
- * $Id: picture.cpp 52614 2010-09-07 07:41:28Z thebluegr $
- *
  */
 
 #include "common/stack.h"
@@ -36,6 +33,8 @@
 
 namespace Sci {
 
+//#define DEBUG_PICTURE_DRAW
+
 GfxPicture::GfxPicture(ResourceManager *resMan, GfxCoordAdjuster *coordAdjuster, GfxPorts *ports, GfxScreen *screen, GfxPalette *palette, GuiResourceId resourceId, bool EGAdrawingVisualize)
 	: _resMan(resMan), _coordAdjuster(coordAdjuster), _ports(ports), _screen(screen), _palette(palette), _resourceId(resourceId), _EGAdrawingVisualize(EGAdrawingVisualize) {
 	assert(resourceId != -1);
@@ -78,7 +77,7 @@ void GfxPicture::draw(int16 animationNr, bool mirroredFlag, bool addToFlag, int1
 #ifdef ENABLE_SCI32
 	case 0x0e: // SCI32 VGA picture
 		_resourceType = SCI_PICTURE_TYPE_SCI32;
-		//drawSci32Vga();
+		drawSci32Vga(0, 0, 0, 0, 0, false);
 		break;
 #endif
 	default:
@@ -133,7 +132,7 @@ void GfxPicture::drawSci11Vga() {
 		_palette->createFromData(inbuffer + palette_data_ptr, size - palette_data_ptr, &palette);
 		_palette->set(&palette, true);
 
-		drawCelData(inbuffer, size, cel_headerPos, cel_RlePos, cel_LiteralPos, 0, 0, 0);
+		drawCelData(inbuffer, size, cel_headerPos, cel_RlePos, cel_LiteralPos, 0, 0, 0, 0);
 	}
 
 	// process vector data
@@ -149,39 +148,47 @@ int16 GfxPicture::getSci32celCount() {
 	return inbuffer[2];
 }
 
-int16 GfxPicture::getSci32celY(int16 celNo) {
-	byte *inbuffer = _resource->data;
-	int header_size = READ_LE_UINT16(inbuffer);
-	int cel_headerPos = header_size + 42 * celNo;
-	return READ_LE_UINT16(inbuffer + cel_headerPos + 40);
-}
-
 int16 GfxPicture::getSci32celX(int16 celNo) {
 	byte *inbuffer = _resource->data;
-	int header_size = READ_LE_UINT16(inbuffer);
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
 	int cel_headerPos = header_size + 42 * celNo;
-	return READ_LE_UINT16(inbuffer + cel_headerPos + 38);
+	return READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 38);
+}
+
+int16 GfxPicture::getSci32celY(int16 celNo) {
+	byte *inbuffer = _resource->data;
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
+	int cel_headerPos = header_size + 42 * celNo;
+	return READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 40);
 }
 
 int16 GfxPicture::getSci32celWidth(int16 celNo) {
 	byte *inbuffer = _resource->data;
-	int header_size = READ_LE_UINT16(inbuffer);
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
 	int cel_headerPos = header_size + 42 * celNo;
-	return READ_LE_UINT16(inbuffer + cel_headerPos + 0);
+	return READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 0);
 }
 
+int16 GfxPicture::getSci32celHeight(int16 celNo) {
+	byte *inbuffer = _resource->data;
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
+	int cel_headerPos = header_size + 42 * celNo;
+	return READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 2);
+}
+
+
 int16 GfxPicture::getSci32celPriority(int16 celNo) {
 	byte *inbuffer = _resource->data;
-	int header_size = READ_LE_UINT16(inbuffer);
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
 	int cel_headerPos = header_size + 42 * celNo;
-	return READ_LE_UINT16(inbuffer + cel_headerPos + 36);
+	return READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 36);
 }
 
-void GfxPicture::drawSci32Vga(int16 celNo, int16 drawX, int16 drawY, int16 pictureX, bool mirrored) {
+void GfxPicture::drawSci32Vga(int16 celNo, int16 drawX, int16 drawY, int16 pictureX, int16 pictureY, bool mirrored) {
 	byte *inbuffer = _resource->data;
 	int size = _resource->size;
-	int header_size = READ_LE_UINT16(inbuffer);
-	int palette_data_ptr = READ_LE_UINT16(inbuffer + 6);
+	int header_size = READ_SCI11ENDIAN_UINT16(inbuffer);
+	int palette_data_ptr = READ_SCI11ENDIAN_UINT32(inbuffer + 6);
 //	int celCount = inbuffer[2];
 	int cel_headerPos = header_size;
 	int cel_RlePos, cel_LiteralPos;
@@ -211,48 +218,52 @@ void GfxPicture::drawSci32Vga(int16 celNo, int16 drawX, int16 drawY, int16 pictu
 	if (mirrored) {
 		// switch around relativeXpos
 		Common::Rect displayArea = _coordAdjuster->pictureGetDisplayArea();
-		drawX = displayArea.width() - drawX - READ_LE_UINT16(inbuffer + cel_headerPos + 0);
+		drawX = displayArea.width() - drawX - READ_SCI11ENDIAN_UINT16(inbuffer + cel_headerPos + 0);
 	}
 
-	cel_RlePos = READ_LE_UINT32(inbuffer + cel_headerPos + 24);
-	cel_LiteralPos = READ_LE_UINT32(inbuffer + cel_headerPos + 28);
+	cel_RlePos = READ_SCI11ENDIAN_UINT32(inbuffer + cel_headerPos + 24);
+	cel_LiteralPos = READ_SCI11ENDIAN_UINT32(inbuffer + cel_headerPos + 28);
 
-	drawCelData(inbuffer, size, cel_headerPos, cel_RlePos, cel_LiteralPos, drawX, drawY, pictureX);
+	drawCelData(inbuffer, size, cel_headerPos, cel_RlePos, cel_LiteralPos, drawX, drawY, pictureX, pictureY);
 	cel_headerPos += 42;
 }
 #endif
 
-void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos, int literalPos, int16 drawX, int16 drawY, int16 pictureX) {
+extern void unpackCelData(byte *inBuffer, byte *celBitmap, byte clearColor, int pixelCount, int rlePos, int literalPos, ViewType viewType, uint16 width, bool isMacSci11ViewData);
+
+void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos, int literalPos, int16 drawX, int16 drawY, int16 pictureX, int16 pictureY) {
 	byte *celBitmap = NULL;
 	byte *ptr = NULL;
 	byte *headerPtr = inbuffer + headerPos;
 	byte *rlePtr = inbuffer + rlePos;
-	byte *literalPtr = inbuffer + literalPos;
-	uint16 width = READ_LE_UINT16(headerPtr + 0);
-	uint16 height = READ_LE_UINT16(headerPtr + 2);
 	int16 displaceX, displaceY;
 	byte priority = _addToFlag ? _priority : 0;
 	byte clearColor;
 	bool compression = true;
-	byte curByte, runLength;
+	byte curByte;
 	int16 y, lastY, x, leftX, rightX;
-	int pixelNr, pixelCount;
+	int pixelCount;
+	uint16 width, height;
 
 #ifdef ENABLE_SCI32
 	if (_resourceType != SCI_PICTURE_TYPE_SCI32) {
 #endif
+		// Width/height here are always LE, even in Mac versions
+		width = READ_LE_UINT16(headerPtr + 0);
+		height = READ_LE_UINT16(headerPtr + 2);
 		displaceX = (signed char)headerPtr[4];
 		displaceY = (unsigned char)headerPtr[5];
-		if (_resourceType == SCI_PICTURE_TYPE_SCI11) {
+		if (_resourceType == SCI_PICTURE_TYPE_SCI11)
 			// SCI1.1 uses hardcoded clearcolor for pictures, even if cel header specifies otherwise
 			clearColor = _screen->getColorWhite();
-		} else {
+		else
 			clearColor = headerPtr[6];
-		}
 #ifdef ENABLE_SCI32
 	} else {
-		displaceX = READ_LE_UINT16(headerPtr + 4); // probably signed?!?
-		displaceY = READ_LE_UINT16(headerPtr + 6); // probably signed?!?
+		width = READ_SCI11ENDIAN_UINT16(headerPtr + 0);
+		height = READ_SCI11ENDIAN_UINT16(headerPtr + 2);
+		displaceX = READ_SCI11ENDIAN_UINT16(headerPtr + 4); // probably signed?!?
+		displaceY = READ_SCI11ENDIAN_UINT16(headerPtr + 6); // probably signed?!?
 		clearColor = headerPtr[8];
 		if (headerPtr[9] == 0)
 			compression = false;
@@ -262,98 +273,46 @@ void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos
 	if (displaceX || displaceY)
 		error("unsupported embedded cel-data in picture");
 
+	// We will unpack cel-data into a temporary buffer and then plot it to screen
+	//  That needs to be done cause a mirrored picture may be requested
 	pixelCount = width * height;
 	celBitmap = new byte[pixelCount];
 	if (!celBitmap)
 		error("Unable to allocate temporary memory for picture drawing");
 
-	if (compression) {
-		// We will unpack cel-data into a temporary buffer and then plot it to screen
-		//  That needs to be done cause a mirrored picture may be requested
-		memset(celBitmap, clearColor, pixelCount);
-		pixelNr = 0;
-		ptr = celBitmap;
-		if (literalPos == 0) {
-			// decompression for data that has only one stream (vecor embedded view data)
-			switch (_resMan->getViewType()) {
-			case kViewEga:
-				while (pixelNr < pixelCount) {
-					curByte = *rlePtr++;
-					runLength = curByte >> 4;
-					memset(ptr + pixelNr, curByte & 0x0F, MIN<uint16>(runLength, pixelCount - pixelNr));
-					pixelNr += runLength;
-				}
-				break;
-			case kViewVga:
-			case kViewVga11:
-				while (pixelNr < pixelCount) {
-					curByte = *rlePtr++;
-					runLength = curByte & 0x3F;
-					switch (curByte & 0xC0) {
-					case 0: // copy bytes as-is
-						while (runLength-- && pixelNr < pixelCount)
-							ptr[pixelNr++] = *rlePtr++;
-						break;
-					case 0x80: // fill with color
-						memset(ptr + pixelNr, *rlePtr++, MIN<uint16>(runLength, pixelCount - pixelNr));
-						pixelNr += runLength;
-						break;
-					case 0xC0: // fill with transparent
-						pixelNr += runLength;
-						break;
-					}
-				}
-				break;
-			case kViewAmiga:
-				while (pixelNr < pixelCount) {
-					curByte = *rlePtr++;
-					if (curByte & 0x07) { // fill with color
-						runLength = curByte & 0x07;
-						curByte = curByte >> 3;
-						while (runLength-- && pixelNr < pixelCount) {
-							ptr[pixelNr++] = curByte;
-						}
-					} else { // fill with transparent
-						runLength = curByte >> 3;
-						pixelNr += runLength;
-					}
-				}
-				break;
+	if (g_sci->getPlatform() == Common::kPlatformMacintosh && getSciVersion() >= SCI_VERSION_2) {
+		// See GfxView::unpackCel() for why this black/white swap is done
+		// This picture swap is only needed in SCI32, not SCI1.1
+		if (clearColor == 0)
+			clearColor = 0xff;
+		else if (clearColor == 0xff)
+			clearColor = 0;
+	}
 
-			default:
-				error("Unsupported picture viewtype");
-			}
-		} else {
-			// decompression for data that has two separate streams (probably SCI 1.1 picture)
-			while (pixelNr < pixelCount) {
-				curByte = *rlePtr++;
-				runLength = curByte & 0x3F;
-				switch (curByte & 0xC0) {
-				case 0: // copy bytes as-is
-					while (runLength-- && pixelNr < pixelCount)
-						ptr[pixelNr++] = *literalPtr++;
-					break;
-				case 0x80: // fill with color
-					memset(ptr + pixelNr, *literalPtr++, MIN<uint16>(runLength, pixelCount - pixelNr));
-					pixelNr += runLength;
-					break;
-				case 0xC0: // fill with transparent
-					pixelNr += runLength;
-					break;
-				}
-			}
-		}
-	} else {
+	if (compression)
+		unpackCelData(inbuffer, celBitmap, clearColor, pixelCount, rlePos, literalPos, _resMan->getViewType(), width, false);
+	else
 		// No compression (some SCI32 pictures)
 		memcpy(celBitmap, rlePtr, pixelCount);
+
+	if (g_sci->getPlatform() == Common::kPlatformMacintosh && getSciVersion() >= SCI_VERSION_2) {
+		// See GfxView::unpackCel() for why this black/white swap is done
+		// This picture swap is only needed in SCI32, not SCI1.1
+		for (int i = 0; i < pixelCount; i++) {
+			if (celBitmap[i] == 0)
+				celBitmap[i] = 0xff;
+			else if (celBitmap[i] == 0xff)
+				celBitmap[i] = 0;
+		}
 	}
 
 	Common::Rect displayArea = _coordAdjuster->pictureGetDisplayArea();
 
+	// Horizontal clipping
 	uint16 skipCelBitmapPixels = 0;
 	int16 displayWidth = width;
 	if (pictureX) {
-		// scroll position for picture active, we need to adjust drawX accordingly
+		// horizontal scroll position for picture active, we need to adjust drawX accordingly
 		drawX -= pictureX;
 		if (drawX < 0) {
 			skipCelBitmapPixels = -drawX;
@@ -362,7 +321,21 @@ void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos
 		}
 	}
 
-	if (displayWidth > 0) {
+	// Vertical clipping
+	uint16 skipCelBitmapLines = 0;
+	int16 displayHeight = height;
+	if (pictureY) {
+		// vertical scroll position for picture active, we need to adjust drawY accordingly
+		// TODO: Finish this
+		/*drawY -= pictureY;
+		if (drawY < 0) {
+			skipCelBitmapLines = -drawY;
+			displayHeight -= skipCelBitmapLines;
+			drawY = 0;
+		}*/
+	}
+
+	if (displayWidth > 0 && displayHeight > 0) {
 		y = displayArea.top + drawY;
 		lastY = MIN<int16>(height + y, displayArea.bottom);
 		leftX = displayArea.left + drawX;
@@ -373,16 +346,18 @@ void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos
 			sourcePixelSkipPerRow = width - (rightX - leftX);
 
 		// Change clearcolor to white, if we dont add to an existing picture. That way we will paint everything on screen
-		//  but white and that wont matter because the screen is supposed to be already white. It seems that most (if not all)
-		//  SCI1.1 games use color 0 as transparency and SCI1 games use color 255 as transparency. Sierra SCI seems to paint
-		//  the whole data to screen and wont skip over transparent pixels. So this will actually make it work like Sierra
-		if (!_addToFlag)
+		// but white and that won't matter because the screen is supposed to be already white. It seems that most (if not all)
+		// SCI1.1 games use color 0 as transparency and SCI1 games use color 255 as transparency. Sierra SCI seems to paint
+		// the whole data to screen and wont skip over transparent pixels. So this will actually make it work like Sierra.
+		// SCI32 doesn't use _addToFlag at all.
+		if (!_addToFlag && _resourceType != SCI_PICTURE_TYPE_SCI32)
 			clearColor = _screen->getColorWhite();
 
-		byte drawMask = priority == 255 ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL | GFX_SCREEN_MASK_PRIORITY;
+		byte drawMask = priority > 15 ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL | GFX_SCREEN_MASK_PRIORITY;
 
 		ptr = celBitmap;
 		ptr += skipCelBitmapPixels;
+		ptr += skipCelBitmapLines * width;
 		if (!_mirroredFlag) {
 			// Draw bitmap to screen
 			x = leftX;
@@ -406,7 +381,7 @@ void GfxPicture::drawCelData(byte *inbuffer, int size, int headerPos, int rlePos
 				curByte = *ptr++;
 				if ((curByte != clearColor) && (priority >= _screen->getPriority(x, y)))
 					_screen->putPixel(x, y, drawMask, curByte, priority, 0);
-			
+
 				if (x == leftX) {
 					ptr += sourcePixelSkipPerRow;
 					x = rightX;
@@ -439,6 +414,7 @@ enum {
 	PIC_OP_OPX = 0xfe,
 	PIC_OP_TERMINATE = 0xff
 };
+
 #define PIC_OP_FIRST PIC_OP_SET_COLOR
 
 enum {
@@ -461,6 +437,47 @@ enum {
 	PIC_OPX_VGA_PRIORITY_TABLE_EXPLICIT = 4
 };
 
+#ifdef DEBUG_PICTURE_DRAW
+const char *picOpcodeNames[] = {
+	"Set color",
+	"Disable visual",
+	"Set priority",
+	"Disable priority",
+	"Short patterns",
+	"Medium lines",
+	"Long lines",
+	"Short lines",
+	"Fill",
+	"Set pattern",
+	"Absolute pattern",
+	"Set control",
+	"Disable control",
+	"Medium patterns",
+	"Extended opcode",
+	"Terminate"
+};
+
+const char *picExOpcodeNamesEGA[] = {
+	"Set palette entries",
+	"Set palette",
+	"Mono0",
+	"Mono1",
+	"Mono2",
+	"Mono3",
+	"Mono4",
+	"Embedded view",
+	"Set priority table"
+};
+
+const char *picExOpcodeNamesVGA[] = {
+	"Set palette entries",
+	"Embedded view",
+	"Set palette",
+	"Set priority table (eqdist)",
+	"Set priority table (explicit)"
+};
+#endif
+
 #define PIC_EGAPALETTE_COUNT 4
 #define PIC_EGAPALETTE_SIZE  40
 #define PIC_EGAPALETTE_TOTALSIZE PIC_EGAPALETTE_COUNT*PIC_EGAPALETTE_SIZE
@@ -498,6 +515,7 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 	Palette palette;
 	int16 pattern_Code = 0, pattern_Texture = 0;
 	bool icemanDrawFix = false;
+	bool ignoreBrokenPriority = false;
 
 	memset(&palette, 0, sizeof(palette));
 
@@ -512,17 +530,37 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 		memcpy(&EGApriority, &vector_defaultEGApriority, sizeof(vector_defaultEGApriority));
 
 		if (g_sci->getGameId() == GID_ICEMAN) {
-			// WORKAROUND: we remove certain visual&priority lines in underwater rooms of iceman, when not dithering the
-			//              picture. Normally those lines aren't shown, because they share the same color as the dithered
-			//              fill color combination. When not dithering, those lines would appear and get distracting.
-			if ((_screen->getUnditherState()) && ((_resourceId >= 53 && _resourceId <= 58) || (_resourceId == 61)))
+			// WORKAROUND: we remove certain visual&priority lines in underwater
+			// rooms of iceman, when not dithering the picture. Normally those
+			// lines aren't shown, because they share the same color as the
+			// dithered fill color combination. When not dithering, those lines
+			// would appear and get distracting.
+			if ((_screen->isUnditheringEnabled()) && ((_resourceId >= 53 && _resourceId <= 58) || (_resourceId == 61)))
 				icemanDrawFix = true;
 		}
+		if (g_sci->getGameId() == GID_KQ5) {
+			// WORKAROUND: ignore the seemingly broken priority of picture 48
+			// (island overview). Fixes bug #3041044.
+			if (_resourceId == 48)
+				ignoreBrokenPriority = true;
+		}
+		if (g_sci->getGameId() == GID_SQ4) {
+			// WORKAROUND: ignore the seemingly broken priority of pictures 546
+			// and 547 (Vohaul's head and Roger Jr trapped). Fixes bug #3046543.
+			if (_resourceId == 546 || _resourceId == 547)
+				ignoreBrokenPriority = true;
+			// WORKAROUND: ignore the seemingly broken priority of picture 631
+			// (SQ1 view from the cockpit). Fixes bug #3046513.
+			if (_resourceId == 631)
+				ignoreBrokenPriority = true;
+		}
 	}
 
 	// Drawing
 	while (curPos < dataSize) {
-		//warning("%X at %d", data[curPos], curPos);
+#ifdef DEBUG_PICTURE_DRAW
+		debug("Picture op: %X (%s) at %d", data[curPos], picOpcodeNames[data[curPos] - 0xF0], curPos);
+#endif
 		switch (pic_op = data[curPos++]) {
 		case PIC_OP_SET_COLOR:
 			pic_color = data[curPos++];
@@ -537,9 +575,10 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 
 		case PIC_OP_SET_PRIORITY:
 			pic_priority = data[curPos++] & 0x0F;
-			if (isEGA) {
+			if (isEGA)
 				pic_priority = EGApriority[pic_priority];
-			}
+			if (ignoreBrokenPriority)
+				pic_priority = 255;
 			break;
 		case PIC_OP_DISABLE_PRIORITY:
 			pic_priority = 255;
@@ -602,14 +641,17 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 			}
 			break;
 
-		// Pattern opcodes are handled in sierra sci1.1+ as actual NOPs and normally they definitely should not occur
-		//  inside picture data for such games
+		// Pattern opcodes are handled in sierra sci1.1+ as actual NOPs and
+		// normally they definitely should not occur inside picture data for
+		// such games.
 		case PIC_OP_SET_PATTERN:
 			if (_resourceType >= SCI_PICTURE_TYPE_SCI11) {
 				if (g_sci->getGameId() == GID_SQ4) {
-					// WORKAROUND: For SQ4 / for some pictures handle this like a terminator
-					//  This picture includes garbage data, first a set pattern w/o parameter and then short pattern
-					//  I guess that garbage is a left over from the sq4-floppy (sci1) to sq4-cd (sci1.1) conversion
+					// WORKAROUND: For SQ4 / for some pictures handle this like
+					// a terminator. This picture includes garbage data, first a
+					// set pattern w/o parameter and then short pattern. I guess
+					// that garbage is a left over from the sq4-floppy (sci1) to
+					// sq4-cd (sci1.1) conversion.
 					switch (_resourceId) {
 					case 35:
 					case 381:
@@ -659,6 +701,9 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 
 		case PIC_OP_OPX: // Extended functions
 			if (isEGA) {
+#ifdef DEBUG_PICTURE_DRAW
+				debug("* Picture ex op: %X (%s) at %d", data[curPos], picExOpcodeNamesEGA[data[curPos]], curPos);
+#endif
 				switch (pic_op = data[curPos++]) {
 				case PIC_OPX_EGA_SET_PALETTE_ENTRIES:
 					while (vectorIsNonOpcode(data[curPos])) {
@@ -693,7 +738,7 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 					vectorGetAbsCoordsNoMirror(data, curPos, x, y);
 					size = READ_LE_UINT16(data + curPos); curPos += 2;
 					_priority = pic_priority; // set global priority so the cel gets drawn using current priority as well
-					drawCelData(data, _resource->size, curPos, curPos + 8, 0, x, y, 0);
+					drawCelData(data, _resource->size, curPos, curPos + 8, 0, x, y, 0, 0);
 					curPos += size;
 					break;
 				case PIC_OPX_EGA_SET_PRIORITY_TABLE:
@@ -704,6 +749,9 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 					error("Unsupported sci1 extended pic-operation %X", pic_op);
 				}
 			} else {
+#ifdef DEBUG_PICTURE_DRAW
+				debug("* Picture ex op: %X (%s) at %d", data[curPos], picExOpcodeNamesVGA[data[curPos]], curPos);
+#endif
 				switch (pic_op = data[curPos++]) {
 				case PIC_OPX_VGA_SET_PALETTE_ENTRIES:
 					while (vectorIsNonOpcode(data[curPos])) {
@@ -711,12 +759,12 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 					}
 					break;
 				case PIC_OPX_VGA_SET_PALETTE:
-					if (_resMan->isAmiga32color()) {
+					if (_resMan->getViewType() == kViewAmiga || _resMan->getViewType() == kViewAmiga64) {
 						if ((data[curPos] == 0x00) && (data[curPos + 1] == 0x01) && ((data[curPos + 32] & 0xF0) != 0xF0)) {
 							// Left-Over VGA palette, we simply ignore it
 							curPos += 256 + 4 + 1024;
 						} else {
-							// Setting half of the amiga palette
+							// Setting half of the Amiga palette
 							_palette->modifyAmigaPalette(&data[curPos]);
 							curPos += 32;
 						}
@@ -733,7 +781,7 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 					vectorGetAbsCoordsNoMirror(data, curPos, x, y);
 					size = READ_LE_UINT16(data + curPos); curPos += 2;
 					_priority = pic_priority; // set global priority so the cel gets drawn using current priority as well
-					drawCelData(data, _resource->size, curPos, curPos + 8, 0, x, y, 0);
+					drawCelData(data, _resource->size, curPos, curPos + 8, 0, x, y, 0, 0);
 					curPos += size;
 					break;
 				case PIC_OPX_VGA_PRIORITY_TABLE_EQDIST:
@@ -754,6 +802,19 @@ void GfxPicture::drawVectorData(byte *data, int dataSize) {
 			// Dithering EGA pictures
 			if (isEGA) {
 				_screen->dither(_addToFlag);
+				switch (g_sci->getGameId()) {
+				case GID_SQ3:
+					switch (_resourceId) {
+					case 154: // SQ3: intro, ship gets sucked in
+						_screen->ditherForceDitheredColor(0xD0);
+						break;
+					default:
+						break;
+					}
+					break;
+				default:
+					break;
+				}
 			}
 			return;
 		default:
@@ -822,7 +883,8 @@ void GfxPicture::vectorGetPatternTexture(byte *data, int &curPos, int16 pattern_
 	}
 }
 
-// Do not replace w/ some generic code. This algo really needs to behave exactly as the one from sierra
+// WARNING: Do not replace the following code with something else, like generic
+// code. This algo really needs to behave exactly as the one from sierra.
 void GfxPicture::vectorFloodFill(int16 x, int16 y, byte color, byte priority, byte control) {
 	Port *curPort = _ports->getPort();
 	Common::Stack<Common::Point> stack;
@@ -831,6 +893,8 @@ void GfxPicture::vectorFloodFill(int16 x, int16 y, byte color, byte priority, by
 	byte matchedMask, matchMask;
 	int16 w, e, a_set, b_set;
 
+	bool isEGA = (_resMan->getViewType() == kViewEga);
+
 	p.x = x + curPort->left;
 	p.y = y + curPort->top;
 	stack.push(p);
@@ -839,6 +903,18 @@ void GfxPicture::vectorFloodFill(int16 x, int16 y, byte color, byte priority, by
 	byte searchPriority = _screen->getPriority(p.x, p.y);
 	byte searchControl = _screen->getControl(p.x, p.y);
 
+	if (isEGA) {
+		// In EGA games a pixel in the framebuffer is only 4 bits. We store
+		// a full byte per pixel to allow undithering, but when comparing
+		// pixels for flood-fill purposes, we should only compare the
+		// visible color of a pixel.
+
+		if ((x ^ y) & 1)
+			searchColor = (searchColor ^ (searchColor >> 4)) & 0x0F;
+		else
+			searchColor = searchColor & 0x0F;
+	}
+
 	// This logic was taken directly from sierra sci, floodfill will get aborted on various occations
 	if (screenMask & GFX_SCREEN_MASK_VISUAL) {
 		if ((color == _screen->getColorWhite()) || (searchColor != _screen->getColorWhite()))
@@ -878,20 +954,20 @@ void GfxPicture::vectorFloodFill(int16 x, int16 y, byte color, byte priority, by
 	int b = curPort->rect.bottom + curPort->top - 1;
 	while (stack.size()) {
 		p = stack.pop();
-		if ((matchedMask = _screen->isFillMatch(p.x, p.y, matchMask, searchColor, searchPriority, searchControl)) == 0) // already filled
+		if ((matchedMask = _screen->isFillMatch(p.x, p.y, matchMask, searchColor, searchPriority, searchControl, isEGA)) == 0) // already filled
 			continue;
 		_screen->putPixel(p.x, p.y, screenMask, color, priority, control);
 		w = p.x;
 		e = p.x;
 		// moving west and east pointers as long as there is a matching color to fill
-		while (w > l && (matchedMask = _screen->isFillMatch(w - 1, p.y, matchMask, searchColor, searchPriority, searchControl)))
+		while (w > l && (matchedMask = _screen->isFillMatch(w - 1, p.y, matchMask, searchColor, searchPriority, searchControl, isEGA)))
 			_screen->putPixel(--w, p.y, screenMask, color, priority, control);
-		while (e < r && (matchedMask = _screen->isFillMatch(e + 1, p.y, matchMask, searchColor, searchPriority, searchControl)))
+		while (e < r && (matchedMask = _screen->isFillMatch(e + 1, p.y, matchMask, searchColor, searchPriority, searchControl, isEGA)))
 			_screen->putPixel(++e, p.y, screenMask, color, priority, control);
 		// checking lines above and below for possible flood targets
 		a_set = b_set = 0;
 		while (w <= e) {
-			if (p.y > t && (matchedMask = _screen->isFillMatch(w, p.y - 1, matchMask, searchColor, searchPriority, searchControl))) { // one line above
+			if (p.y > t && (matchedMask = _screen->isFillMatch(w, p.y - 1, matchMask, searchColor, searchPriority, searchControl, isEGA))) { // one line above
 				if (a_set == 0) {
 					p1.x = w;
 					p1.y = p.y - 1;
@@ -901,7 +977,7 @@ void GfxPicture::vectorFloodFill(int16 x, int16 y, byte color, byte priority, by
 			} else
 				a_set = 0;
 
-			if (p.y < b && (matchedMask = _screen->isFillMatch(w, p.y + 1, matchMask, searchColor, searchPriority, searchControl))) { // one line below
+			if (p.y < b && (matchedMask = _screen->isFillMatch(w, p.y + 1, matchMask, searchColor, searchPriority, searchControl, isEGA))) { // one line below
 				if (b_set == 0) {
 					p1.x = w;
 					p1.y = p.y + 1;
