@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/graphics/screen.h $
- * $Id: screen.h 51583 2010-08-01 17:54:48Z mthreepwood $
- *
  */
 
 #ifndef SCI_GRAPHICS_SCREEN_H
@@ -28,6 +25,7 @@
 
 #include "sci/sci.h"
 #include "sci/graphics/helpers.h"
+#include "sci/graphics/view.h"
 
 #include "graphics/sjis.h"
 
@@ -51,7 +49,7 @@ enum GfxScreenMasks {
 };
 
 enum {
-	SCI_SCREEN_UNDITHERMEMORIAL_SIZE = 256
+	DITHERED_BG_COLORS_SIZE = 256
 };
 
 /**
@@ -89,34 +87,37 @@ public:
 	void drawLine(int16 left, int16 top, int16 right, int16 bottom, byte color, byte prio, byte control) {
 		drawLine(Common::Point(left, top), Common::Point(right, bottom), color, prio, control);
 	}
-	int getUpscaledHires() const {
+
+	GfxScreenUpscaledMode getUpscaledHires() const {
 		return _upscaledHires;
 	}
-	bool getUnditherState() const {
-		return _unditherState;
+
+	bool isUnditheringEnabled() const {
+		return _unditheringEnabled;
 	}
+	void enableUndithering(bool flag);
+
 	void putKanjiChar(Graphics::FontSJIS *commonFont, int16 x, int16 y, uint16 chr, byte color);
 	byte getVisual(int x, int y);
 	byte getPriority(int x, int y);
 	byte getControl(int x, int y);
-	byte isFillMatch(int16 x, int16 y, byte drawMask, byte t_color, byte t_pri, byte t_con);
+	byte isFillMatch(int16 x, int16 y, byte drawMask, byte t_color, byte t_pri, byte t_con, bool isEGA);
 
 	int bitsGetDataSize(Common::Rect rect, byte mask);
 	void bitsSave(Common::Rect rect, byte mask, byte *memoryPtr);
 	void bitsGetRect(byte *memoryPtr, Common::Rect *destRect);
 	void bitsRestore(byte *memoryPtr);
 
-	void getPalette(Palette *pal);
-	void setPalette(Palette *pal);
+	void scale2x(const byte *src, byte *dst, int16 srcWidth, int16 srcHeight, byte bytesPerPixel = 1);
 
-	void scale2x(const byte *src, byte *dst, int16 srcWidth, int16 srcHeight);
-
-	void adjustToUpscaledCoordinates(int16 &y, int16 &x);
-	void adjustBackUpscaledCoordinates(int16 &y, int16 &x);
+	void adjustToUpscaledCoordinates(int16 &y, int16 &x, Sci32ViewNativeResolution viewScalingType = SCI_VIEW_NATIVERES_NONE);
+	void adjustBackUpscaledCoordinates(int16 &y, int16 &x, Sci32ViewNativeResolution viewScalingType = SCI_VIEW_NATIVERES_NONE);
 
 	void dither(bool addToFlag);
-	void debugUnditherSetState(bool flag);
-	int16 *unditherGetMemorial();
+
+	// Force a color combination as a dithered color
+	void ditherForceDitheredColor(byte color);
+	int16 *unditherGetDitheredBgColors();
 
 	void debugShowMap(int mapNo);
 
@@ -126,6 +127,9 @@ public:
 	int16 kernelPicNotValid(int16 newPicNotValid);
 	void kernelShakeScreen(uint16 shakeCount, uint16 direction);
 
+	void setFontIsUpscaled(bool isUpscaled) { _fontIsUpscaled = isUpscaled; }
+	bool fontIsUpscaled() const { return _fontIsUpscaled; }
+
 private:
 	uint16 _width;
 	uint16 _height;
@@ -144,8 +148,11 @@ private:
 
 	void setVerticalShakePos(uint16 shakePos);
 
-	bool _unditherState;
-	int16 _unditherMemorial[SCI_SCREEN_UNDITHERMEMORIAL_SIZE];
+	/**
+	 * If this flag is true, undithering is enabled, otherwise disabled.
+	 */
+	bool _unditheringEnabled;
+	int16 _ditheredPicColors[DITHERED_BG_COLORS_SIZE];
 
 	// These screens have the real resolution of the game engine (320x200 for
 	// SCI0/SCI1/SCI11 games, 640x480 for SCI2 games). SCI0 games will be
@@ -154,13 +161,13 @@ private:
 	byte *_priorityScreen;
 	byte *_controlScreen;
 
-	// This screen is the one that is actually displayed to the user. It may be
-	// 640x400 for japanese SCI1 games. SCI0 games may be undithered in here.
-	// Only read from this buffer for Save/ShowBits usage.
+	/**
+	 * This screen is the one that is actually displayed to the user. It may be
+	 * 640x400 for japanese SCI1 games. SCI0 games may be undithered in here.
+	 * Only read from this buffer for Save/ShowBits usage.
+	 */
 	byte *_displayScreen;
 
-	Common::Rect getScaledRect(Common::Rect rect);
-
 	ResourceManager *_resMan;
 
 	/**
@@ -169,13 +176,25 @@ private:
 	 */
 	byte *_activeScreen;
 
-	// This variable defines, if upscaled hires is active and what upscaled mode
-	// is used.
-	int _upscaledHires;
+	/**
+	 * This variable defines, if upscaled hires is active and what upscaled mode
+	 * is used.
+	 */
+	GfxScreenUpscaledMode _upscaledHires;
 
-	// This here holds a translation for vertical coordinates between native
-	// (visual) and actual (display) screen.
+	/**
+	 * This here holds a translation for vertical coordinates between native
+	 * (visual) and actual (display) screen.
+	 */
 	int _upscaledMapping[SCI_SCREEN_UPSCALEDMAXHEIGHT + 1];
+
+	/**
+	 * This defines whether or not the font we're drawing is already scaled
+	 * to the screen size (and we therefore should not upscale it ourselves).
+	 */
+	bool _fontIsUpscaled;
+
+	uint16 getLowResScreenHeight();
 };
 
 } // End of namespace Sci
