@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "sci/sci.h"
@@ -175,6 +172,20 @@ void GfxView::initData(GuiResourceId resourceId) {
 				cel->displaceX = (signed char)celData[4];
 				cel->displaceY = celData[5];
 				cel->clearKey = celData[6];
+
+				// HACK: Fix Ego's odd displacement in the QFG3 demo, scene 740.
+				// For some reason, ego jumps above the rope, so we fix his rope
+				// hanging view by displacing it down by 40 pixels. Fixes bug
+				// #3035693.
+				// FIXME: Remove this once we figure out why Ego jumps so high.
+				// Likely culprits include kInitBresen, kDoBresen and kCantBeHere.
+				// The scripts have the y offset that hero reaches (11) hardcoded,
+				// so it might be collision detection. However, since this requires
+				// extensive work to fix properly for very little gain, this hack
+				// here will suffice until the actual issue is found.
+				if (g_sci->getGameId() == GID_QFG3 && g_sci->isDemo() && resourceId == 39)
+					cel->displaceY = 98;
+
 				if (isEGA) {
 					cel->offsetEGA = celOffset + 7;
 					cel->offsetRLE = 0;
@@ -205,7 +216,7 @@ void GfxView::initData(GuiResourceId resourceId) {
 		palOffset = READ_SCI11ENDIAN_UINT32(_resourceData + 8);
 
 		// For SCI32, this is a scale flag
-		if (getSciVersion() >= SCI_VERSION_2) { 
+		if (getSciVersion() >= SCI_VERSION_2) {
 			_sci2ScaleRes = (Sci32ViewNativeResolution)_resourceData[5];
 			if (_screen->getUpscaledHires() == GFX_SCREEN_UPSCALED_DISABLED)
 				_sci2ScaleRes = SCI_VIEW_NATIVERES_NONE;
@@ -429,7 +440,7 @@ void unpackCelData(byte *inBuffer, byte *celBitmap, byte clearColor, int pixelCo
 		// compression for SCI1.1+ Mac
 		while (pixelNr < pixelCount) {
 			uint32 pixelLine = pixelNr;
-		
+
 			if (hasByteLengths) {
 				pixelNr += *rlePtr++;
 				runLength = *rlePtr++;
@@ -474,7 +485,8 @@ void unpackCelData(byte *inBuffer, byte *celBitmap, byte clearColor, int pixelCo
 			curByte = *rlePtr++;
 			if (curByte & 0xC0) { // fill with color
 				runLength = curByte >> 6;
-				memset(outPtr + pixelNr,    curByte & 0x3F, MIN<uint16>(runLength, pixelCount - pixelNr));
+				curByte = curByte & 0x3F;
+				memset(outPtr + pixelNr,           curByte, MIN<uint16>(runLength, pixelCount - pixelNr));
 			} else { // skip the next pixels (transparency)
 				runLength = curByte & 0x3F;
 			}
@@ -503,7 +515,7 @@ void unpackCelData(byte *inBuffer, byte *celBitmap, byte clearColor, int pixelCo
 				} else {
 					memcpy(outPtr + pixelNr,    literalPtr, MIN<uint16>(runLength, pixelCount - pixelNr));
 					literalPtr += runLength;
-				}			
+				}
 				break;
 			case 0x80: // fill with color
 				if (!literalPos)
@@ -695,7 +707,7 @@ void GfxView::draw(const Common::Rect &rect, const Common::Rect &clipRect, const
 	const int16 celHeight = celInfo->height;
 	const int16 celWidth = celInfo->width;
 	const byte clearKey = celInfo->clearKey;
-	const byte drawMask = (priority == 255) ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL|GFX_SCREEN_MASK_PRIORITY;
+	const byte drawMask = priority > 15 ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL|GFX_SCREEN_MASK_PRIORITY;
 	int x, y;
 
 	if (_embeddedPal)
@@ -756,7 +768,7 @@ void GfxView::drawScaled(const Common::Rect &rect, const Common::Rect &clipRect,
 	const int16 celHeight = celInfo->height;
 	const int16 celWidth = celInfo->width;
 	const byte clearKey = celInfo->clearKey;
-	const byte drawMask = (priority == 255) ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL|GFX_SCREEN_MASK_PRIORITY;
+	const byte drawMask = priority > 15 ? GFX_SCREEN_MASK_VISUAL : GFX_SCREEN_MASK_VISUAL|GFX_SCREEN_MASK_PRIORITY;
 	uint16 scalingX[640];
 	uint16 scalingY[480];
 	int16 scaledWidth, scaledHeight;
@@ -839,4 +851,13 @@ void GfxView::adjustBackUpscaledCoordinates(int16 &y, int16 &x) {
 	_screen->adjustBackUpscaledCoordinates(y, x, _sci2ScaleRes);
 }
 
+byte GfxView::getColorAtCoordinate(int16 loopNo, int16 celNo, int16 x, int16 y) {
+	const CelInfo *celInfo = getCelInfo(loopNo, celNo);
+	const byte *bitmap = getBitmap(loopNo, celNo);
+	const int16 celWidth = celInfo->width;
+
+	bitmap += (celWidth * y);
+	return bitmap[x];
+}
+
 } // End of namespace Sci
