@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 // Resource library
@@ -96,7 +93,7 @@ const char *getSciVersionDesc(SciVersion version) {
 
 //#define SCI_VERBOSE_RESMAN 1
 
-static const char *sci_error_types[] = {
+static const char *const sci_error_types[] = {
 	"No error",
 	"I/O error",
 	"Resource is empty (size 0)",
@@ -110,7 +107,7 @@ static const char *sci_error_types[] = {
 	"SCI version is unsupported"
 };
 
-static const char *s_resourceTypeNames[] = {
+static const char *const s_resourceTypeNames[] = {
 	"view", "pic", "script", "text", "sound",
 	"memory", "vocab", "font", "cursor",
 	"patch", "bitmap", "palette", "cdaudio",
@@ -123,7 +120,7 @@ static const char *s_resourceTypeNames[] = {
 // Resource type suffixes. Note that the
 // suffic of SCI3 scripts has been changed from
 // scr to csc
-static const char *s_resourceTypeSuffixes[] = {
+static const char *const s_resourceTypeSuffixes[] = {
 	"v56", "p56", "scr", "tex", "snd",
 	   "", "voc", "fon", "cur", "pat",
 	"bit", "pal", "cda", "aud", "syn",
@@ -131,7 +128,7 @@ static const char *s_resourceTypeSuffixes[] = {
 	"trn", "rbt", "vmd", "chk",    "",
 	"etc", "duk", "clu", "tga", "zzz",
 	   "",    "",    ""
-}; 
+};
 
 const char *getResourceTypeName(ResourceType restype) {
 	if (restype != kResourceTypeInvalid)
@@ -452,11 +449,11 @@ bool MacResourceForkResourceSource::isCompressableResource(ResourceType type) co
 		*ptr++ = value; \
 	}
 
-void MacResourceForkResourceSource::decompressResource(Common::SeekableReadStream *stream, Resource *resource) const {	
+void MacResourceForkResourceSource::decompressResource(Common::SeekableReadStream *stream, Resource *resource) const {
 	// KQ6 Mac is the only game not compressed. It's not worth writing a
 	// heuristic just for that game. Also, skip over any resource that cannot
 	// be compressed.
-	bool canBeCompressed = !(g_sci && g_sci->getGameId() == GID_KQ6) && isCompressableResource(resource->_id.getType()); 
+	bool canBeCompressed = !(g_sci && g_sci->getGameId() == GID_KQ6) && isCompressableResource(resource->_id.getType());
 	uint32 uncompressedSize = 0;
 
 	// GK2 Mac is crazy. In its Patches resource fork, picture 2315 is not
@@ -506,7 +503,7 @@ void MacResourceForkResourceSource::decompressResource(Common::SeekableReadStrea
 				// Copy chunk expanded
 				extraByte1 = stream->readByte();
 				extraByte2 = stream->readByte();
- 
+
 				literalLength = extraByte2 & 3;
 
 				OUTPUT_LITERAL()
@@ -827,7 +824,7 @@ void ChunkResourceSource::scanSource(ResourceManager *resMan) {
 
 	byte *ptr = chunk->data;
 	uint32 firstOffset = 0;
-	
+
 	for (;;) {
 		ResourceType type = resMan->convertResType(*ptr);
 		uint16 number = READ_LE_UINT16(ptr + 1);
@@ -847,7 +844,7 @@ void ChunkResourceSource::scanSource(ResourceManager *resMan) {
 		// There's no end marker to the data table, but the first resource
 		// begins directly after the entry table. So, when we hit the first
 		// resource, we're at the end of the entry table.
-		
+
 		if (!firstOffset)
 			firstOffset = entry.offset;
 
@@ -1161,8 +1158,10 @@ ResVersion ResourceManager::detectMapVersion() {
 		}
 	}
 
-	if (!fileStream)
-		error("Failed to open resource map file");
+	if (!fileStream) {
+		warning("Failed to open resource map file");
+		return kResVersionUnknown;
+	}
 
 	// detection
 	// SCI0 and SCI01 maps have last 6 bytes set to FF
@@ -1246,7 +1245,7 @@ ResVersion ResourceManager::detectVolVersion() {
 
 	for (Common::List<ResourceSource *>::iterator it = _sources.begin(); it != _sources.end(); ++it) {
 		rsrc = *it;
-	
+
 		if (rsrc->getSourceType() == kSourceVolume) {
 			if (rsrc->_resourceFile) {
 				fileStream = rsrc->_resourceFile->createReadStream();
@@ -1262,7 +1261,7 @@ ResVersion ResourceManager::detectVolVersion() {
 	}
 
 	if (!fileStream) {
-		error("Failed to open volume file - if you got resource.p01/resource.p02/etc. files, merge them together into resource.000");
+		warning("Failed to open volume file - if you got resource.p01/resource.p02/etc. files, merge them together into resource.000");
 		// resource.p01/resource.p02/etc. may be there when directly copying the files from the original floppies
 		// the sierra installer would merge those together (perhaps we could do this as well?)
 		// possible TODO
@@ -1294,7 +1293,7 @@ ResVersion ResourceManager::detectVolVersion() {
 		// loading SCI3 volumes, the format is otherwise
 		// identical to SCI2. We therefore get the compression
 		// indicator here, but disregard it in the following
-		// code. 
+		// code.
 		wCompression = fileStream->readUint16LE();
 
 		if (fileStream->eos()) {
@@ -1476,7 +1475,7 @@ void ResourceManager::readResourcePatchesBase36() {
 			name = (*x)->getName();
 
 			ResourceId resource36 = convertPatchNameBase36((ResourceType)i, name);
-			
+
 			/*
 			if (i == kResourceTypeAudio36)
 				debug("audio36 patch: %s => %s. tuple:%d, %s\n", name.c_str(), inputName.c_str(), resource36.tuple, resource36.toString().c_str());
@@ -1497,7 +1496,7 @@ void ResourceManager::readResourcePatchesBase36() {
 
 				// Check for SOL as well
 				tag = (tag << 16) | stream->readUint16BE();
-					
+
 				if (tag != MKTAG('S','O','L',0)) {
 					delete stream;
 					continue;
@@ -1558,7 +1557,7 @@ void ResourceManager::readResourcePatches() {
 			name = (*x)->getName();
 
 			// SCI1 scheme
-			if (isdigit(name[0])) {
+			if (isdigit(static_cast<unsigned char>(name[0]))) {
 				char *end = 0;
 				resourceNr = strtol(name.c_str(), &end, 10);
 				bAdd = (*end == '.'); // Ensure the next character is the period
@@ -1566,7 +1565,7 @@ void ResourceManager::readResourcePatches() {
 				// SCI0 scheme
 				int resname_len = strlen(szResType);
 				if (scumm_strnicmp(name.c_str(), szResType, resname_len) == 0
-					&& !isalpha(name[resname_len + 1])) {
+					&& !isalpha(static_cast<unsigned char>(name[resname_len + 1]))) {
 					resourceNr = atoi(name.c_str() + resname_len + 1);
 					bAdd = true;
 				}
@@ -1616,7 +1615,7 @@ int ResourceManager::readResourceMapSCI0(ResourceSource *map) {
 			warning("Error while reading %s", map->getLocationName().c_str());
 			return SCI_ERROR_RESMAP_NOT_FOUND;
 		}
-	
+
 		if (offset == 0xFFFFFFFF)
 			break;
 
@@ -1724,15 +1723,19 @@ int ResourceManager::readResourceMapSCI1(ResourceSource *map) {
 			if (!resource) {
 				addResource(resId, source, fileOffset);
 			} else {
-				// if resource is already present, change it to new content
-				//  this is needed at least for pharkas/german. This version
-				//  contains several duplicate resources INSIDE the resource
-				//  data files like fonts, views, scripts, etc. And if we use
-				//  the first entries, half of the game will be english and
-				//  umlauts will also be missing :P
-				resource->_source = source;
-				resource->_fileOffset = fileOffset;
-				resource->size = 0;
+				// If the resource is already present in a volume, change it to
+				// the new content (but only in a volume, so as not to overwrite
+				// external patches - refer to bug #3366295).
+				// This is needed at least for the German version of Pharkas.
+				// That version contains several duplicate resources INSIDE the
+				// resource data files like fonts, views, scripts, etc. Thus,
+				// if we use the first entries in the resource file, half of the
+				// game will be English and umlauts will also be missing :P
+				if (resource->_source->getSourceType() == kSourceVolume) {
+					resource->_source = source;
+					resource->_fileOffset = fileOffset;
+					resource->size = 0;
+				}
 			}
 		}
 	}
@@ -2132,7 +2135,7 @@ void ResourceManager::detectSciVersion() {
 	bool oldDecompressors = true;
 
 	ResourceCompression viewCompression;
-#ifdef ENABLE_SCI32	
+#ifdef ENABLE_SCI32
 	viewCompression = getViewCompression();
 #else
 	if (_volVersion >= kResVersionSci2) {
@@ -2176,17 +2179,18 @@ void ResourceManager::detectSciVersion() {
 		}
 #endif
 	}
-	
+
 	if (_volVersion == kResVersionSci11Mac) {
-		// SCI32 doesn't have the resource.cfg file, so we can figure out
-		// which of the games are SCI1.1. Note that there are no Mac SCI2 games.
-		// Yes, that means that GK1 Mac is SCI2.1 and not SCI2.
+		Resource *res = testResource(ResourceId(kResourceTypeScript, 64920));
+		// Distinguish between SCI1.1 and SCI32 games here. SCI32 games will
+		// always include script 64920 (the Array class). Note that there are
+		// no Mac SCI2 games. Yes, that means that GK1 Mac is SCI2.1 and not SCI2.
 
 		// TODO: Decide between SCI2.1 and SCI3
-		if (Common::File::exists("resource.cfg"))
-			s_sciVersion = SCI_VERSION_1_1;
-		else
+		if (res)
 			s_sciVersion = SCI_VERSION_2_1;
+		else
+			s_sciVersion = SCI_VERSION_1_1;
 		return;
 	}
 
@@ -2351,7 +2355,7 @@ bool ResourceManager::detectFontExtended() {
 }
 
 // detects, if SCI1.1 game uses palette merging or copying - this is supposed to only get used on SCI1.1 games
-bool ResourceManager::detectForPaletteMergingForSci11() {
+bool ResourceManager::detectPaletteMergingSci11() {
 	// Load palette 999 (default palette)
 	Resource *res = findResource(ResourceId(kResourceTypePalette, 999), false);
 
