@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifndef SCI_RESOURCE_H
@@ -357,7 +354,7 @@ public:
 	// Detects, if standard font of current game includes extended characters (>0x80)
 	bool detectFontExtended();
 	// Detects, if SCI1.1 game uses palette merging
-	bool detectForPaletteMergingForSci11();
+	bool detectPaletteMergingSci11();
 	// Detects, if SCI0EARLY game also has SCI0EARLY sound resources
 	bool detectEarlySound();
 
