@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sound/drivers/fb01.cpp $
- * $Id: fb01.cpp 52726 2010-09-14 21:53:22Z lordhoto $
- *
  */
 
 #include "sci/sci.h"
@@ -30,6 +27,7 @@
 
 #include "common/file.h"
 #include "common/system.h"
+#include "common/textconsole.h"
 
 namespace Sci {
 
@@ -129,7 +127,7 @@ private:
 
 MidiPlayer_Fb01::MidiPlayer_Fb01(SciVersion version) : MidiPlayer(version), _playSwitch(true), _masterVolume(15), _timerParam(NULL), _timerProc(NULL) {
 	MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_MIDI);
-	_driver = createMidi(dev);
+	_driver = MidiDriver::createMidi(dev);
 
 	_sysExBuf[0] = 0x43;
 	_sysExBuf[1] = 0x75;
@@ -486,6 +484,11 @@ int MidiPlayer_Fb01::open(ResourceManager *resMan) {
 	if (res) {
 		sendBanks(res->data, res->size);
 	} else {
+		// Early SCI0 games have the sound bank embedded in the IMF driver.
+		// Note that these games didn't actually support the FB-01 as a device,
+		// but the IMF, which is the same device on an ISA card. Check:
+		// http://wiki.vintage-computer.com/index.php/IBM_Music_feature_card
+
 		warning("FB-01 patch file not found, attempting to load sound bank from IMF.DRV");
 		// Try to load sound bank from IMF.DRV
 		Common::File f;
