@@ -18,25 +18,27 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sound/drivers/midi.cpp $
- * $Id: midi.cpp 52726 2010-09-14 21:53:22Z lordhoto $
- *
  */
 
 #include "sci/sci.h"
 
 #include "common/config-manager.h"
 #include "common/file.h"
+#include "common/memstream.h"
+#include "common/system.h"
 
-#include "sound/fmopl.h"
-#include "sound/softsynth/emumidi.h"
+#include "audio/fmopl.h"
 
 #include "sci/resource.h"
+#include "sci/engine/features.h"
+#include "sci/sound/drivers/gm_names.h"
 #include "sci/sound/drivers/mididriver.h"
 #include "sci/sound/drivers/map-mt32-to-gm.h"
 
 namespace Sci {
 
+Mt32ToGmMapList *Mt32dynamicMappings = NULL;
+
 class MidiPlayer_Midi : public MidiPlayer {
 public:
 	enum {
@@ -54,12 +56,17 @@ public:
 	void sysEx(const byte *msg, uint16 length);
 	bool hasRhythmChannel() const { return true; }
 	byte getPlayId() const;
-	int getPolyphony() const { return kVoices; }
+	int getPolyphony() const {
+		if (g_sci && g_sci->_features->useAltWinGMSound())
+			return 16;
+		else
+			return kVoices;
+	}
 	int getFirstChannel() const;
 	int getLastChannel() const;
 	void setVolume(byte volume);
 	int getVolume();
-	void setReverb(byte reverb);
+	void setReverb(int8 reverb);
 	void playSwitch(bool play);
 
 private:
@@ -94,7 +101,7 @@ private:
 		uint8 volume;
 
 		Channel() : mappedPatch(MIDI_UNMAPPED), patch(MIDI_UNMAPPED), velocityMapIdx(0), playing(false),
-			keyShift(0), volAdjust(0), pan(0x80), hold(0), volume(0x7f) { }
+			keyShift(0), volAdjust(0), pan(0x40), hold(0), volume(0x7f) { }
 	};
 
 	bool _isMt32;
@@ -122,7 +129,7 @@ private:
 
 MidiPlayer_Midi::MidiPlayer_Midi(SciVersion version) : MidiPlayer(version), _playSwitch(true), _masterVolume(15), _isMt32(false), _hasReverb(false), _useMT32Track(true) {
 	MidiDriver::DeviceHandle dev = MidiDriver::detectDevice(MDT_MIDI);
-	_driver = createMidi(dev);
+	_driver = MidiDriver::createMidi(dev);
 
 	if (MidiDriver::getMusicType(dev) == MT_MT32 || ConfMan.getBool("native_mt32"))
 		_isMt32 = true;
@@ -131,10 +138,21 @@ MidiPlayer_Midi::MidiPlayer_Midi(SciVersion version) : MidiPlayer(version), _pla
 	_sysExBuf[1] = 0x10;
 	_sysExBuf[2] = 0x16;
 	_sysExBuf[3] = 0x12;
+
+	Mt32dynamicMappings = new Mt32ToGmMapList();
 }
 
 MidiPlayer_Midi::~MidiPlayer_Midi() {
 	delete _driver;
+
+	const Mt32ToGmMapList::iterator end = Mt32dynamicMappings->end();
+	for (Mt32ToGmMapList::iterator it = Mt32dynamicMappings->begin(); it != end; ++it) {
+		delete[] (*it).name;
+		(*it).name = 0;
+	}
+
+	Mt32dynamicMappings->clear();
+	delete Mt32dynamicMappings;
 }
 
 void MidiPlayer_Midi::noteOn(int channel, int note, int velocity) {
@@ -227,11 +245,17 @@ void MidiPlayer_Midi::controlChange(int channel, int control, int value) {
 
 		_channels[channel].hold = value;
 		break;
+	case 0x4b:	// voice mapping
+		break;
+	case 0x4e:	// velocity
+		break;
 	case 0x7b:
 		if (!_channels[channel].playing)
 			return;
 
 		_channels[channel].playing = false;
+	default:
+		break;
 	}
 
 	_driver->send(0xb0 | channel, control, value);
@@ -304,8 +328,10 @@ void MidiPlayer_Midi::send(uint32 b) {
 	// In early SCI0, we may also get events for AdLib rhythm channels.
 	// While an MT-32 would ignore those with the default channel mapping,
 	// we filter these out for the benefit of other MIDI devices.
-	if (channel < 1 || channel > 9)
-		return;
+	if (_version == SCI_VERSION_0_EARLY) {
+		if (channel < 1 || channel > 9)
+			return;
+	}
 
 	switch (command) {
 	case 0x80:
@@ -320,6 +346,10 @@ void MidiPlayer_Midi::send(uint32 b) {
 	case 0xc0:
 		setPatch(channel, op1);
 		break;
+	// The original MIDI driver from sierra ignores aftertouch completely, so should we
+	case 0xa0: // Polyphonic key pressure (aftertouch)
+	case 0xd0: // Channel pressure (aftertouch)
+		break;
 	case 0xe0:
 		_driver->send(b);
 		break;
@@ -358,10 +388,13 @@ int MidiPlayer_Midi::getVolume() {
 	return _masterVolume;
 }
 
-void MidiPlayer_Midi::setReverb(byte reverb) {
-	_reverb = CLIP<byte>(reverb, 0, kReverbConfigNr - 1);
-	if (_hasReverb)
-		sendMt32SysEx(0x100001, _reverbConfig[_reverb], 3, true);
+void MidiPlayer_Midi::setReverb(int8 reverb) {
+	assert(reverb < kReverbConfigNr);
+
+	if (_hasReverb && (_reverb != reverb))
+		sendMt32SysEx(0x100001, _reverbConfig[reverb], 3, true);
+
+	_reverb = reverb;
 }
 
 void MidiPlayer_Midi::playSwitch(bool play) {
@@ -420,9 +453,9 @@ void MidiPlayer_Midi::sendMt32SysEx(const uint32 addr, Common::SeekableReadStrea
 		_sysExBuf[7 + i] = str->readByte();
 
 	for (int i = 4; i < 7 + len; i++)
-		chk += _sysExBuf[i];
+		chk -= _sysExBuf[i];
 
-	_sysExBuf[7 + len] = 128 - chk % 128;
+	_sysExBuf[7 + len] = chk & 0x7f;
 
 	if (noDelay)
 		_driver->sysEx(_sysExBuf, len + 8);
@@ -450,17 +483,18 @@ void MidiPlayer_Midi::readMt32Patch(const byte *data, int size) {
 	setMt32Volume(volume);
 
 	// Reverb default only used in (roughly) SCI0/SCI01
-	_reverb = str->readByte();
+	byte reverb = str->readByte();
+
 	_hasReverb = true;
 
 	// Skip reverb SysEx message
 	str->seek(11, SEEK_CUR);
 
-	// Read reverb data
-	for (int i = 0; i < kReverbConfigNr; i++) {
-		_reverbConfig[i][0] = str->readByte();
-		_reverbConfig[i][1] = str->readByte();
-		_reverbConfig[i][2] = str->readByte();
+	// Read reverb data (stored vertically - patch #3117434)
+	for (int j = 0; j < 3; ++j) {
+		for (int i = 0; i < kReverbConfigNr; i++) {
+			_reverbConfig[i][j] = str->readByte();
+		}
 	}
 
 	// Patches 1-48
@@ -488,6 +522,10 @@ void MidiPlayer_Midi::readMt32Patch(const byte *data, int size) {
 		sendMt32SysEx(0x100004, str, 9);
 	}
 
+	// Reverb for SCI0
+	if (_version <= SCI_VERSION_0_LATE)
+		setReverb(reverb);
+
 	// Send after-SysEx text
 	str->seek(0);
 	sendMt32SysEx(0x200000, str, 20);
@@ -569,41 +607,83 @@ void MidiPlayer_Midi::readMt32DrvData() {
 	if (f.open("MT32.DRV")) {
 		int size = f.size();
 
-		assert(size >= 166);
-
-		// Send before-SysEx text
-		f.seek(0x59);
+		// Skip before-SysEx text
+		if (size == 1773 || size == 1759 || size == 1747)	// XMAS88 / KQ4 early (0.000.253 / 0.000.274)
+			f.seek(0x59);
+		else if (size == 2771)				// LSL2 early
+			f.seek(0x29);
+		else
+			error("Unknown MT32.DRV size (%d)", size);
 
 		// Skip 2 extra 0 bytes in some drivers
 		if (f.readUint16LE() != 0)
 			f.seek(-2, SEEK_CUR);
 
+		// Send before-SysEx text
 		sendMt32SysEx(0x200000, static_cast<Common::SeekableReadStream *>(&f), 20);
 
-		// Send after-SysEx text (SSCI sends this before every song)
-		sendMt32SysEx(0x200000, static_cast<Common::SeekableReadStream *>(&f), 20);
+		if (size != 2271) {
+			// Send after-SysEx text (SSCI sends this before every song).
+			// There aren't any SysEx calls in old drivers, so this can
+			// be sent right after the before-SysEx text.
+			sendMt32SysEx(0x200000, static_cast<Common::SeekableReadStream *>(&f), 20);
+		} else {
+			// Skip the after-SysEx text in the newer patch version, we'll send
+			// it after the SysEx messages are sent.
+			f.skip(20);
+		}
 
-		// Save goodbye message
+		// Save goodbye message. This isn't a C string, so it may not be
+		// nul-terminated.
 		f.read(_goodbyeMsg, 20);
 
 		// Set volume
 		byte volume = CLIP<uint16>(f.readUint16LE(), 0, 100);
 		setMt32Volume(volume);
 
-		byte reverbSysEx[13];
-		// This old driver should have a full reverb SysEx
-		if ((f.read(reverbSysEx, 13) != 13) || (reverbSysEx[0] != 0xf0) || (reverbSysEx[12] != 0xf7))
-			error("Error reading MT32.DRV");
+		if (size == 2771) {
+			// MT32.DRV in LSL2 early contains more data, like a normal patch
+			byte reverb = f.readByte();
 
-		// Send reverb SysEx
-		sysEx(reverbSysEx + 1, 11);
-		_hasReverb = false;
+			_hasReverb = true;
 
-		f.seek(0x29);
+			// Skip reverb SysEx message
+			f.skip(11);
 
-		// Read AdLib->MT-32 patch map
-		for (int i = 0; i < 48; i++) {
-			_patchMap[i] = f.readByte();
+			// Read reverb data (stored vertically - patch #3117434)
+			for (int j = 0; j < 3; ++j) {
+				for (int i = 0; i < kReverbConfigNr; i++) {
+					_reverbConfig[i][j] = f.readByte();
+				}
+			}
+
+			f.skip(2235);	// skip driver code
+
+			// Patches 1-48
+			sendMt32SysEx(0x50000, static_cast<Common::SeekableReadStream *>(&f), 256);
+			sendMt32SysEx(0x50200, static_cast<Common::SeekableReadStream *>(&f), 128);
+
+			setReverb(reverb);
+
+			// Send the after-SysEx text
+			f.seek(0x3d);
+			sendMt32SysEx(0x200000, static_cast<Common::SeekableReadStream *>(&f), 20);
+		} else {
+			byte reverbSysEx[13];
+			// This old driver should have a full reverb SysEx
+			if ((f.read(reverbSysEx, 13) != 13) || (reverbSysEx[0] != 0xf0) || (reverbSysEx[12] != 0xf7))
+				error("Error reading MT32.DRV");
+
+			// Send reverb SysEx
+			sysEx(reverbSysEx + 1, 11);
+			_hasReverb = false;
+
+			f.seek(0x29);
+
+			// Read AdLib->MT-32 patch map
+			for (int i = 0; i < 48; i++) {
+				_patchMap[i] = f.readByte();
+			}
 		}
 
 		f.close();
@@ -615,22 +695,40 @@ void MidiPlayer_Midi::readMt32DrvData() {
 byte MidiPlayer_Midi::lookupGmInstrument(const char *iname) {
 	int i = 0;
 
+	if (Mt32dynamicMappings != NULL) {
+		const Mt32ToGmMapList::iterator end = Mt32dynamicMappings->end();
+		for (Mt32ToGmMapList::iterator it = Mt32dynamicMappings->begin(); it != end; ++it) {
+			if (scumm_strnicmp(iname, (*it).name, 10) == 0)
+				return getGmInstrument((*it));
+		}
+	}
+
 	while (Mt32MemoryTimbreMaps[i].name) {
 		if (scumm_strnicmp(iname, Mt32MemoryTimbreMaps[i].name, 10) == 0)
 			return getGmInstrument(Mt32MemoryTimbreMaps[i]);
 		i++;
 	}
+
 	return MIDI_UNMAPPED;
 }
 
 byte MidiPlayer_Midi::lookupGmRhythmKey(const char *iname) {
 	int i = 0;
 
+	if (Mt32dynamicMappings != NULL) {
+		const Mt32ToGmMapList::iterator end = Mt32dynamicMappings->end();
+		for (Mt32ToGmMapList::iterator it = Mt32dynamicMappings->begin(); it != end; ++it) {
+			if (scumm_strnicmp(iname, (*it).name, 10) == 0)
+				return (*it).gmRhythmKey;
+		}
+	}
+
 	while (Mt32MemoryTimbreMaps[i].name) {
 		if (scumm_strnicmp(iname, Mt32MemoryTimbreMaps[i].name, 10) == 0)
 			return Mt32MemoryTimbreMaps[i].gmRhythmKey;
 		i++;
 	}
+
 	return MIDI_UNMAPPED;
 }
 
@@ -644,7 +742,7 @@ uint8 MidiPlayer_Midi::getGmInstrument(const Mt32ToGmMap &Mt32Ins) {
 void MidiPlayer_Midi::mapMt32ToGm(byte *data, size_t size) {
 	// FIXME: Clean this up
 	int memtimbres, patches;
-	uint8 group, number, keyshift, finetune, bender_range;
+	uint8 group, number, keyshift, /*finetune,*/ bender_range;
 	uint8 *patchpointer;
 	uint32 pos;
 	int i;
@@ -683,7 +781,7 @@ void MidiPlayer_Midi::mapMt32ToGm(byte *data, size_t size) {
 		group = *patchpointer;
 		number = *(patchpointer + 1);
 		keyshift = *(patchpointer + 2);
-		finetune = *(patchpointer + 3);
+		//finetune = *(patchpointer + 3);
 		bender_range = *(patchpointer + 4);
 
 		debugCN(kDebugLevelSound, "  [%03d] ", i);
@@ -718,11 +816,13 @@ void MidiPlayer_Midi::mapMt32ToGm(byte *data, size_t size) {
 		if (_patchMap[i] == MIDI_UNMAPPED) {
 			debugC(kDebugLevelSound, "[Unmapped]");
 		} else {
+#ifndef REDUCE_MEMORY_USAGE
 			if (_patchMap[i] >= 128) {
 				debugC(kDebugLevelSound, "%s [Rhythm]", GmPercussionNames[_patchMap[i] - 128]);
 			} else {
 				debugC(kDebugLevelSound, "%s", GmInstrumentNames[_patchMap[i]]);
 			}
+#endif
 		}
 
 		_keyShift[i] = CLIP<uint8>(keyshift, 0, 48) - 24;
@@ -732,7 +832,7 @@ void MidiPlayer_Midi::mapMt32ToGm(byte *data, size_t size) {
 	if (size > pos && ((0x100 * *(data + pos) + *(data + pos + 1)) == 0xdcba)) {
 		debugC(kDebugLevelSound, "\n[MT32-to-GM] Mapping percussion..");
 
-		for (i = 0; i < 64 ; i++) {
+		for (i = 0; i < 64; i++) {
 			number = *(data + pos + 4 * i + 2);
 			byte ins = i + 24;
 
@@ -754,10 +854,12 @@ void MidiPlayer_Midi::mapMt32ToGm(byte *data, size_t size) {
 				}
 			}
 
+#ifndef REDUCE_MEMORY_USAGE
 			if (_percussionMap[ins] == MIDI_UNMAPPED)
 				debugC(kDebugLevelSound, "[Unmapped]");
 			else
 				debugC(kDebugLevelSound, "%s", GmPercussionNames[_percussionMap[ins]]);
+#endif
 
 			_percussionVelocityScale[ins] = *(data + pos + 4 * i + 3) * 127 / 100;
 		}
@@ -801,6 +903,16 @@ int MidiPlayer_Midi::open(ResourceManager *resMan) {
 
 	Resource *res = NULL;
 
+	if (g_sci && g_sci->_features->useAltWinGMSound()) {
+		res = resMan->findResource(ResourceId(kResourceTypePatch, 4), 0);
+		if (!(res && isMt32GmPatch(res->data, res->size))) {
+			// Don't do any mapping when a Windows alternative track is selected
+			// and no MIDI patch is available
+			_useMT32Track = false;
+			return 0;
+		}
+	}
+
 	if (_isMt32) {
 		// MT-32
 		resetMt32();
@@ -815,6 +927,7 @@ int MidiPlayer_Midi::open(ResourceManager *resMan) {
 				readMt32Patch(res->data, res->size);
 			}
 		} else {
+			// Early SCI0 games have the sound bank embedded in the MT-32 driver
 			readMt32DrvData();
 		}
 	} else {
@@ -825,17 +938,22 @@ int MidiPlayer_Midi::open(ResourceManager *resMan) {
 			// There is a GM patch
 			readMt32GmPatch(res->data, res->size);
 
-			// Detect the format of patch 1, so that we know what play mask to use
-			res = resMan->findResource(ResourceId(kResourceTypePatch, 1), 0);
-			if (!res)
+			if (g_sci && g_sci->_features->useAltWinGMSound()) {
+				// Always use the GM track if an alternative GM Windows soundtrack is selected
 				_useMT32Track = false;
-			else
-				_useMT32Track = !isMt32GmPatch(res->data, res->size);
+			} else {
+				// Detect the format of patch 1, so that we know what play mask to use
+				res = resMan->findResource(ResourceId(kResourceTypePatch, 1), 0);
+				if (!res)
+					_useMT32Track = false;
+				else
+					_useMT32Track = !isMt32GmPatch(res->data, res->size);
 
-			// Check if the songs themselves have a GM track
-			if (!_useMT32Track) {
-				if (!resMan->isGMTrackIncluded())
-					_useMT32Track = true;
+				// Check if the songs themselves have a GM track
+				if (!_useMT32Track) {
+					if (!resMan->isGMTrackIncluded())
+						_useMT32Track = true;
+				}
 			}
 		} else {
 			// No GM patch found, map instruments using MT-32 patch
@@ -844,7 +962,7 @@ int MidiPlayer_Midi::open(ResourceManager *resMan) {
 
 			// TODO: The MT-32 <-> GM mapping hasn't been worked on for SCI1 games. Throw
 			// a warning to the user
-			if (getSciVersion() >= SCI_VERSION_1_EGA)
+			if (getSciVersion() >= SCI_VERSION_1_EGA_ONLY)
 				warning("The automatic mapping for General MIDI hasn't been worked on for "
 						"SCI1 games. Music might sound wrong or broken. Please choose another "
 						"music driver for this game (e.g. Adlib or MT-32) if you are "
@@ -861,11 +979,19 @@ int MidiPlayer_Midi::open(ResourceManager *resMan) {
 			res = resMan->findResource(ResourceId(kResourceTypePatch, 1), 0);
 
 			if (res) {
-				if (!isMt32GmPatch(res->data, res->size))
+				if (!isMt32GmPatch(res->data, res->size)) {
 					mapMt32ToGm(res->data, res->size);
-				else
-					error("MT-32 patch has wrong type");
+				} else {
+					if (getSciVersion() <= SCI_VERSION_2_1) {
+						error("MT-32 patch has wrong type");
+					} else {
+						// Happens in the SCI3 interactive demo of Lighthouse
+						warning("TODO: Ignoring new SCI3 type of MT-32 patch for now (size = %d)", res->size);
+					}
+				}
 			} else {
+				// Early SCI0 games have the sound bank embedded in the MT-32 driver
+
 				// No MT-32 patch present, try to read from MT32.DRV
 				Common::File f;
 
