@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/sound/midiparser_sci.cpp $
- * $Id: midiparser_sci.cpp 52484 2010-09-01 19:20:17Z m_kiewitz $
- *
  */
 
 #include "sci/engine/kernel.h"
@@ -224,6 +221,7 @@ byte *MidiParser_SCI::midiFilterChannels(int channelMask) {
 	byte command = 0, lastCommand = 0;
 	int delta = 0;
 	int midiParamCount = 0;
+	bool containsMidiData = false;
 
 	_mixedData = outData;
 
@@ -250,6 +248,9 @@ byte *MidiParser_SCI::midiFilterChannels(int channelMask) {
 			}
 		}
 		if ((1 << curChannel) & channelMask) {
+			if (curChannel != 0xF)
+				containsMidiData = true;
+
 			if (command != kEndOfTrack) {
 				// Write delta
 				while (delta > 240) {
@@ -307,6 +308,11 @@ byte *MidiParser_SCI::midiFilterChannels(int channelMask) {
 	*outData++ = 0x00;
 	*outData++ = 0x00;
 
+	// This occurs in the music tracks of LB1 Amiga, when using the MT-32
+	// driver (bug #3297881)
+	if (!containsMidiData)
+		warning("MIDI parser: the requested SCI0 sound has no MIDI note data for the currently selected sound driver");
+
 	return _mixedData;
 }
 
@@ -349,17 +355,14 @@ void MidiParser_SCI::sendInitCommands() {
 		}
 	}
 
-	// Send a velocity off signal to all channels
-	for (int i = 0; i < 15; ++i) {
-		if (_channelUsed[i])
-			sendToDriver(0xB0 | i, 0x4E, 0);	// Reset velocity
-	}
-
-	// Center the pitch wheels and hold pedal in preparation for the next piece of music
+	// Reset all the parameters of the channels used by this song
 	for (int i = 0; i < 16; ++i) {
 		if (_channelUsed[i]) {
-			sendToDriver(0xE0 | i, 0, 0x40);	// Reset pitch wheel
-			sendToDriver(0xB0 | i, 0x40, 0);	// Reset hold pedal
+			sendToDriver(0xB0 | i, 0x07, 127);	// Reset volume to maximum
+			sendToDriver(0xB0 | i, 0x0A, 64);	// Reset panning to center
+			sendToDriver(0xB0 | i, 0x40, 0);	// Reset hold pedal to none
+			sendToDriver(0xB0 | i, 0x4E, 0);	// Reset velocity to none
+			sendToDriver(0xE0 | i,    0, 64);	// Reset pitch wheel to center
 		}
 	}
 }
@@ -474,11 +477,18 @@ void MidiParser_SCI::parseNextEvent(EventInfo &info) {
 		info.basic.param2 = 0;
 		if (info.channel() == 0xF) {// SCI special case
 			if (info.basic.param1 != kSetSignalLoop) {
-				// at least in kq5/french&mac the first scene in the intro has a song that sets signal to 4 immediately
-				//  on tick 0. Signal isn't set at that point by sierra sci and it would cause the castle daventry text to
-				//  get immediately removed, so we currently filter it.
-				// Sierra SCI ignores them as well at that time
-				if ((_position._play_tick) || (info.delta)) {
+				// At least in kq5/french&mac the first scene in the intro has
+				// a song that sets signal to 4 immediately on tick 0. Signal
+				// isn't set at that point by sierra sci and it would cause the
+				// castle daventry text to get immediately removed, so we
+				// currently filter it. Sierra SCI ignores them as well at that
+				// time. However, this filtering should only be performed for
+				// SCI1 and newer games. Signalling is done differently in SCI0
+				// though, so ignoring these signals in SCI0 games will result
+				// in glitches (e.g. the intro of LB1 Amiga gets stuck - bug
+				// #3297883). Refer to MusicEntry::setSignal() in sound/music.cpp.
+				if (_soundVersion <= SCI_VERSION_0_LATE ||
+					_position._play_tick || info.delta) {
 					_signalSet = true;
 					_signalToSet = info.basic.param1;
 				}
@@ -495,13 +505,28 @@ void MidiParser_SCI::parseNextEvent(EventInfo &info) {
 	case 0xB:
 		info.basic.param1 = *(_position._play_pos++);
 		info.basic.param2 = *(_position._play_pos++);
-		if (info.channel() == 0xF) {// SCI special
-			// Reference for some events:
-			// http://wiki.scummvm.org/index.php/SCI/Specifications/Sound/SCI0_Resource_Format#Status_Reference
-			// Also, sci/sound/iterator/iterator.cpp, function BaseSongIterator::parseMidiCommand()
+
+		// Reference for some events:
+		// http://wiki.scummvm.org/index.php/SCI/Specifications/Sound/SCI0_Resource_Format#Status_Reference
+		// Handle common special events
+		switch (info.basic.param1) {
+		case kSetReverb:
+			if (info.basic.param2 == 127)		// Set global reverb instead
+				_pSnd->reverb = _music->getGlobalReverb();
+			else
+				_pSnd->reverb = info.basic.param2;
+
+			((MidiPlayer *)_driver)->setReverb(_pSnd->reverb);
+			break;
+		default:
+			break;
+		}
+
+		// Handle events sent to the SCI special channel (15)
+		if (info.channel() == 0xF) {
 			switch (info.basic.param1) {
 			case kSetReverb:
-				((MidiPlayer *)_driver)->setReverb(info.basic.param2);
+				// Already handled above
 				break;
 			case kMidiHold:
 				// Check if the hold ID marker is the same as the hold ID
@@ -605,7 +630,11 @@ void MidiParser_SCI::parseNextEvent(EventInfo &info) {
 			if (info.ext.type == 0x2F) {// end of track reached
 				if (_pSnd->loop)
 					_pSnd->loop--;
-				if (_pSnd->loop) {
+				// QFG3 abuses the hold flag. Its scripts call kDoSoundSetHold,
+				// but sometimes there's no hold marker in the associated songs
+				// (e.g. song 110, during the intro). The original interpreter
+				// treats this case as an infinite loop (bug #3311911).
+				if (_pSnd->loop || _pSnd->hold > 0) {
 					// We need to play it again...
 					jumpToTick(_loopTick);
 				} else {
@@ -624,6 +653,21 @@ void MidiParser_SCI::parseNextEvent(EventInfo &info) {
 	}// switch (info.command())
 }
 
+byte MidiParser_SCI::getSongReverb() {
+	assert(_track);
+
+	if (_soundVersion >= SCI_VERSION_1_EARLY) {
+		for (int i = 0; i < _track->channelCount; i++) {
+			SoundResource::Channel &channel = _track->channels[i];
+			// Peek ahead in the control channel to get the default reverb setting
+			if (channel.number == 15 && channel.size >= 7)
+				return channel.data[6];
+		}
+	}
+
+	return 127;
+}
+
 void MidiParser_SCI::allNotesOff() {
 	if (!_driver)
 		return;
@@ -653,8 +697,10 @@ void MidiParser_SCI::allNotesOff() {
 	// support this...).
 
 	for (i = 0; i < 16; ++i) {
-		if (_channelRemap[i] != -1)
+		if (_channelRemap[i] != -1) {
 			sendToDriver(0xB0 | i, 0x7b, 0); // All notes off
+			sendToDriver(0xB0 | i, 0x40, 0); // Also send a sustain off event (bug #3116608)
+		}
 	}
 
 	memset(_active_notes, 0, sizeof(_active_notes));
