@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "audio/audiostream.h"
@@ -40,8 +37,8 @@
 
 namespace Sci {
 
-SciMusic::SciMusic(SciVersion soundVersion)
-	: _soundVersion(soundVersion), _soundOn(true), _masterVolume(0), _globalReverb(0) {
+SciMusic::SciMusic(SciVersion soundVersion, bool useDigitalSFX)
+	: _soundVersion(soundVersion), _soundOn(true), _masterVolume(0), _globalReverb(0), _useDigitalSFX(useDigitalSFX) {
 
 	// Reserve some space in the playlist, to avoid expensive insertion
 	// operations
@@ -66,12 +63,13 @@ void SciMusic::init() {
 	// SCI sound init
 	_dwTempo = 0;
 
-	// Default to MIDI in SCI2.1+ games, as many don't have AdLib support.
 	Common::Platform platform = g_sci->getPlatform();
-
 	uint32 deviceFlags = MDT_PCSPK | MDT_PCJR | MDT_ADLIB | MDT_MIDI;
 
-	if (getSciVersion() >= SCI_VERSION_2_1)
+	// Default to MIDI in SCI2.1+ games, as many don't have AdLib support.
+	// Also, default to MIDI for Windows versions of SCI1.1 games, as their
+	// soundtrack is written for GM.
+	if (getSciVersion() >= SCI_VERSION_2_1 || g_sci->_features->useAltWinGMSound())
 		deviceFlags |= MDT_PREFER_GM;
 
 	// Currently our CMS implementation only supports SCI1(.1)
@@ -112,8 +110,6 @@ void SciMusic::init() {
 		error("Failed to initialize sound driver");
 	}
 
-	_bMultiMidi = ConfMan.getBool("multi_midi");
-
 	// Find out what the first possible channel is (used, when doing channel
 	// remapping).
 	_driverFirstChannel = _pMidiDrv->getFirstChannel();
@@ -275,10 +271,10 @@ void SciMusic::soundInitSnd(MusicEntry *pSnd) {
 	SoundResource::Track *track = pSnd->soundRes->getTrackByType(_pMidiDrv->getPlayId());
 
 	// If MIDI device is selected but there is no digital track in sound
-	// resource try to use adlib's digital sample if possible. Also, if the
+	// resource try to use Adlib's digital sample if possible. Also, if the
 	// track couldn't be found, load the digital track, as some games depend on
 	// this (e.g. the Longbow demo).
-	if (!track || (_bMultiMidi && track->digitalChannelNr == -1)) {
+	if (!track || (_useDigitalSFX && track->digitalChannelNr == -1)) {
 		SoundResource::Track *digital = pSnd->soundRes->getDigitalTrack();
 		if (digital)
 			track = digital;
@@ -294,8 +290,8 @@ void SciMusic::soundInitSnd(MusicEntry *pSnd) {
 			if (_soundVersion >= SCI_VERSION_1_EARLY && g_sci->getPlatform() == Common::kPlatformAmiga)
 				flags = 0;
 			int endPart = track->digitalSampleEnd > 0 ? (track->digitalSampleSize - track->digitalSampleEnd) : 0;
-			pSnd->pStreamAud = Audio::makeRawStream(channelData + track->digitalSampleStart, 
-								track->digitalSampleSize - track->digitalSampleStart - endPart, 
+			pSnd->pStreamAud = Audio::makeRawStream(channelData + track->digitalSampleStart,
+								track->digitalSampleSize - track->digitalSampleStart - endPart,
 								track->digitalSampleRate, flags, DisposeAfterUse::NO);
 			delete pSnd->pLoopStream;
 			pSnd->pLoopStream = 0;
@@ -448,9 +444,9 @@ void SciMusic::soundPlay(MusicEntry *pSnd) {
 				// volume of the sound channels that the faded song occupies..
 				// Fixes bug #3266480 and partially fixes bug #3041738.
 				for (uint i = 0; i < playListCount; i++) {
-					// Is another MIDI song being faded? If yes, stop it
+					// Is another MIDI song being faded down? If yes, stop it
 					// immediately instead
-					if (_playList[i]->fadeStep && _playList[i]->pMidiParser) {
+					if (_playList[i]->fadeStep < 0 && _playList[i]->pMidiParser) {
 						_playList[i]->status = kSoundStopped;
 						if (_soundVersion <= SCI_VERSION_0_LATE)
 							_playList[i]->isQueued = false;
