@@ -18,16 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sci/video/seq_decoder.cpp $
- * $Id: seq_decoder.cpp 51725 2010-08-04 08:25:05Z fingolfin $
- *
  */
 
-#include "common/debug.h"
 #include "common/endian.h"
-#include "common/archive.h"
+#include "common/stream.h"
 #include "common/system.h"
-#include "common/util.h"
+#include "common/textconsole.h"
 
 #include "graphics/surface.h"
 
@@ -55,20 +51,25 @@ SeqDecoder::~SeqDecoder() {
 	close();
 }
 
-bool SeqDecoder::load(Common::SeekableReadStream *stream) {
+bool SeqDecoder::loadStream(Common::SeekableReadStream *stream) {
 	close();
 
 	_fileStream = stream;
 	_surface = new Graphics::Surface();
-	_surface->create(SEQ_SCREEN_WIDTH, SEQ_SCREEN_HEIGHT, 1);
+	_surface->create(SEQ_SCREEN_WIDTH, SEQ_SCREEN_HEIGHT, Graphics::PixelFormat::createFormatCLUT8());
 
 	_frameCount = _fileStream->readUint16LE();
 
 	// Set palette
-	int paletteSize = _fileStream->readUint32LE();
+	int paletteChunkSize = _fileStream->readUint32LE();
+	readPaletteChunk(paletteChunkSize);
 
-	byte *paletteData = new byte[paletteSize];
-	_fileStream->read(paletteData, paletteSize);
+	return true;
+}
+
+void SeqDecoder::readPaletteChunk(uint16 chunkSize) {
+	byte *paletteData = new byte[chunkSize];
+	_fileStream->read(paletteData, chunkSize);
 
 	// SCI1.1 palette
 	byte palFormat = paletteData[32];
@@ -88,7 +89,6 @@ bool SeqDecoder::load(Common::SeekableReadStream *stream) {
 
 	_dirtyPalette = true;
 	delete[] paletteData;
-	return true;
 }
 
 void SeqDecoder::close() {
@@ -107,7 +107,7 @@ void SeqDecoder::close() {
 	reset();
 }
 
-Graphics::Surface *SeqDecoder::decodeNextFrame() {
+const Graphics::Surface *SeqDecoder::decodeNextFrame() {
 	int16 frameWidth = _fileStream->readUint16LE();
 	int16 frameHeight = _fileStream->readUint16LE();
 	int16 frameLeft = _fileStream->readUint16LE();
