@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -76,10 +73,10 @@ static const int v1MMNESLookup[25] = {
 };
 
 static const byte v0ActorTalkArray[0x19] = {
-	0x00, 0x06, 0x06, 0x06, 0x06, 
-	0x06, 0x06, 0x00, 0x46, 0x06, 
-	0x06, 0x06, 0x06, 0xFF, 0xFF, 
-	0x06, 0xC0, 0x06, 0x06, 0x00, 
+	0x00, 0x06, 0x06, 0x06, 0x06,
+	0x06, 0x06, 0x00, 0x46, 0x06,
+	0x06, 0x06, 0x06, 0xFF, 0xFF,
+	0x06, 0xC0, 0x06, 0x06, 0x00,
 	0xC0, 0xC0, 0x00, 0x06, 0x06
 };
 
@@ -548,6 +545,13 @@ void ClassicCostumeRenderer::proc3_ami(Codec1 &v1) {
 	oldXpos = v1.x;
 	oldScaleIndexX = _scaleIndexX;
 
+	// Indy4 Amiga always uses the room map to match colors to the currently
+	// setup palette in the actor code in the original, thus we need to do this
+	// mapping over here too.
+	byte *amigaMap = 0;
+	if (_vm->_game.platform == Common::kPlatformAmiga && _vm->_game.id == GID_INDY4)
+		amigaMap = _vm->_roomPalette;
+
 	do {
 		len = *src++;
 		color = len >> v1.shr;
@@ -559,7 +563,10 @@ void ClassicCostumeRenderer::proc3_ami(Codec1 &v1) {
 				masked = (y < 0 || y >= _out.h) || (v1.x < 0 || v1.x >= _out.w) || (v1.mask_ptr && (mask[0] & maskbit));
 
 				if (color && !masked) {
-					*dst = _palette[color];
+					if (amigaMap)
+						*dst = amigaMap[_palette[color]];
+					else
+						*dst = _palette[color];
 				}
 
 				if (_scaleX == 255 || v1.scaletable[_scaleIndexX] < _scaleX) {
@@ -1420,7 +1427,7 @@ byte C64CostumeLoader::increaseAnims(Actor *a) {
 	if (A->_moving  && _vm->_currentRoom != 1 && _vm->_currentRoom != 44) {
 		if (a->_cost.soundPos == 0)
 			a->_cost.soundCounter++;
-		
+
 		// Is this the correct location?
 		// 0x073C
 		if (v0ActorTalkArray[a->_number] & 0x3F)
