@@ -18,12 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/debugger.cpp $
- * $Id: debugger.cpp 50963 2010-07-17 18:38:42Z fingolfin $
- *
  */
 
-#include "common/config-manager.h"
 #include "common/debug-channels.h"
 #include "common/file.h"
 #include "common/str.h"
@@ -35,7 +31,7 @@
 #include "scumm/debugger.h"
 #include "scumm/imuse/imuse.h"
 #include "scumm/object.h"
-#include "scumm/player_v2.h"
+#include "scumm/resource.h"
 #include "scumm/scumm.h"
 #include "scumm/sound.h"
 
@@ -87,7 +83,7 @@ ScummDebugger::ScummDebugger(ScummEngine *s)
 	if (_vm->_game.id == GID_LOOM)
 		DCmd_Register("drafts",  WRAP_METHOD(ScummDebugger, Cmd_PrintDraft));
 
-	if (_vm->_game.id == GID_MONKEY && Common::kPlatformSegaCD)
+	if (_vm->_game.id == GID_MONKEY && _vm->_game.platform == Common::kPlatformSegaCD)
 		DCmd_Register("passcode",  WRAP_METHOD(ScummDebugger, Cmd_Passcode));
 
 	DCmd_Register("loadgame",  WRAP_METHOD(ScummDebugger, Cmd_LoadGame));
@@ -108,17 +104,6 @@ ScummDebugger::~ScummDebugger() {
 	 // we need this destructor, even if it is empty, for __SYMBIAN32__
 }
 
-void ScummDebugger::preEnter() {
-	// Pause sound output
-	_old_soundsPaused = _vm->_sound->_soundsPaused;
-	_vm->_sound->pauseSounds(true);
-}
-
-void ScummDebugger::postEnter() {
-	// Resume previous sound state
-	_vm->_sound->pauseSounds(_old_soundsPaused);
-}
-
 ///////////////////////////////////////////////////
 // Now the fun stuff:
 
@@ -389,8 +374,8 @@ bool ScummDebugger::Cmd_Actor(int argc, const char **argv) {
 		DebugPrintf("Actor[%d]._elevation = %d\n", actnum, a->getElevation());
 		_vm->_fullRedraw = true;
 	} else if (!strcmp(argv[2], "costume")) {
-		if (value >= _vm->_res->num[rtCostume])
-			DebugPrintf("Costume not changed as %d exceeds max of %d\n", value, _vm->_res->num[rtCostume]);
+		if (value >= (int)_vm->_res->_types[rtCostume].size())
+			DebugPrintf("Costume not changed as %d exceeds max of %d\n", value, _vm->_res->_types[rtCostume].size());
 		else {
 			a->setActorCostume(value);
 			_vm->_fullRedraw = true;
@@ -414,14 +399,15 @@ bool ScummDebugger::Cmd_PrintActor(int argc, const char **argv) {
 	int i;
 	Actor *a;
 
-	DebugPrintf("+-----------------------------------------------------------+\n");
-	DebugPrintf("|# |  x |  y | w |elev|cos|box|mov| zp|frm|scl|dir|   cls   |\n");
-	DebugPrintf("+--+----+----+---+----+---+---+---+---+---+---+---+---------+\n");
+	DebugPrintf("+---------------------------------------------------------------+\n");
+	DebugPrintf("|# |  x |  y | w | h |elev|cos|box|mov| zp|frm|scl|dir|   cls   |\n");
+	DebugPrintf("+--+----+----+---+---+----+---+---+---+---+---+---+---+---------+\n");
 	for (i = 1; i < _vm->_numActors; i++) {
 		a = _vm->_actors[i];
 		if (a->_visible)
-			DebugPrintf("|%2d|%4d|%4d|%3d|%4d|%3d|%3d|%3d|%3d|%3d|%3d|%3d|$%08x|\n",
-						 a->_number, a->getRealPos().x, a->getRealPos().y, a->_width, a->getElevation(),
+			DebugPrintf("|%2d|%4d|%4d|%3d|%3d|%4d|%3d|%3d|%3d|%3d|%3d|%3d|%3d|$%08x|\n",
+						 a->_number, a->getRealPos().x, a->getRealPos().y, a->_width,  a->_bottom - a->_top,
+						 a->getElevation(),
 						 a->_costume, a->_walkbox, a->_moving, a->_forceClip, a->_frame,
 						 a->_scalex, a->getFacing(), _vm->_classData[a->_number]);
 	}
@@ -437,7 +423,7 @@ bool ScummDebugger::Cmd_PrintObjects(int argc, const char **argv) {
 	DebugPrintf("|num |  x |  y |width|height|state|fl|   cls   |\n");
 	DebugPrintf("+----+----+----+-----+------+-----+--+---------+\n");
 
-	for (i = 1; i < _vm->_numLocalObjects ; i++) {
+	for (i = 1; i < _vm->_numLocalObjects; i++) {
 		o = &(_vm->_objs[i]);
 		if (o->obj_nr == 0)
 			continue;
@@ -491,7 +477,7 @@ bool ScummDebugger::Cmd_Object(int argc, const char **argv) {
 			//is BgNeedsRedraw enough?
 			_vm->_bgNeedsRedraw = true;
 		} else {
-			DebugPrintf("object command 'state' requires a parameter\n");
+			DebugPrintf("State of object %d: %d\n", obj, _vm->getState(obj));
 		}
 	} else if (!strcmp(argv[2], "name")) {
 		DebugPrintf("Name of object %d: %s\n", obj, _vm->getObjOrActorName(obj));
@@ -529,7 +515,7 @@ bool ScummDebugger::Cmd_Debug(int argc, const char **argv) {
 	} else {
 		DebugPrintf("Usage: debug [+CHANNEL|-CHANNEL]\n");
 		DebugPrintf("Enables or disables the given debug channel.\n");
-		DebugPrintf("When used without parameters, lists all avaiable debug channels and their status.\n");
+		DebugPrintf("When used without parameters, lists all available debug channels and their status.\n");
 	}
 
 	return true;
