@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "common/archive.h"
@@ -97,6 +94,12 @@ int ScummEngine_v60he::convertFilePath(byte *dst, int dstSize) {
 	debug(1, "convertFilePath: original filePath is %s", dst);
 
 	int len = resStrLen(dst);
+
+	// Switch all \ to / for portablity
+	for (int i = 0; i < len; i++)
+		if (dst[i] == '\\')
+			dst[i] = '/';
+
 	if (_game.platform == Common::kPlatformMacintosh) {
 		// Remove : prefix in HE71 games
 		if (dst[0] == ':') {
@@ -110,12 +113,6 @@ int ScummEngine_v60he::convertFilePath(byte *dst, int dstSize) {
 			if (dst[i] == ':')
 				dst[i] = '/';
 		}
-	} else {
-		// Switch all \ to / for portablity
-		for (int i = 0; i < len; i++) {
-			if (dst[i] == '\\')
-				dst[i] = '/';
-		}
 	}
 
 	// Strip path
@@ -747,7 +744,7 @@ void ScummEngine_v60he::o60_closeFile() {
 			_hOutFileTable[slot] = 0;
 		}
 
-		delete _hInFileTable[slot];		
+		delete _hInFileTable[slot];
 		_hInFileTable[slot] = 0;
 	}
 }
