@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #ifdef ENABLE_HE
@@ -1463,7 +1460,7 @@ void ScummEngine_v90he::o90_getVideoData() {
 		break;
 	case 52:	// Get current frame
 		pop();
-		push(_moviePlay->endOfVideo() ? -1 : (_moviePlay->getCurFrame() + 1));
+		push(_moviePlay->getCurFrame());
 		break;
 	case 63:	// Get image number
 		pop();
@@ -2361,7 +2358,7 @@ void ScummEngine_v90he::o90_kernelSetFunctions() {
 		_wiz->_rectOverrideEnabled = false;
 		break;
 	case 714:
-		debug(5, "o90_kernelSetFunctions: case 714: type %d resId %d unk1 %d", args[1], args[2], args[3]);
+		setResourceOffHeap(args[1], args[2], args[3]);
 		break;
 	case 1492:
 		// Remote start script function
