@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 
@@ -29,10 +26,12 @@
 
 #include "common/util.h"
 #include "common/system.h"
+#include "common/endian.h"
 
 #include "scumm/imuse/imuse.h"
 #include "scumm/imuse/imuse_internal.h"
 #include "scumm/imuse/instrument.h"
+#include "scumm/resource.h"
 #include "scumm/saveload.h"
 #include "scumm/scumm.h"
 
@@ -45,31 +44,31 @@ namespace Scumm {
 ////////////////////////////////////////
 
 IMuseInternal::IMuseInternal() :
-_native_mt32(false),
-_enable_gs(false),
-_sc55(false),
-_midi_adlib(NULL),
-_midi_native(NULL),
-_base_sounds(NULL),
-_sysex(NULL),
-_paused(false),
-_initialized(false),
-_tempoFactor(0),
-_player_limit(ARRAYSIZE(_players)),
-_recycle_players(false),
-_queue_end(0),
-_queue_pos(0),
-_queue_sound(0),
-_queue_adding(0),
-_queue_marker(0),
-_queue_cleared(0),
-_master_volume(0),
-_music_volume(0),
-_trigger_count(0),
-_snm_trigger_index(0) {
-	memset(_channel_volume,0,sizeof(_channel_volume));
-	memset(_channel_volume_eff,0,sizeof(_channel_volume_eff));
-	memset(_volchan_table,0,sizeof(_volchan_table));
+	_native_mt32(false),
+	_enable_gs(false),
+	_sc55(false),
+	_midi_adlib(NULL),
+	_midi_native(NULL),
+	_sysex(NULL),
+	_paused(false),
+	_initialized(false),
+	_tempoFactor(0),
+	_player_limit(ARRAYSIZE(_players)),
+	_recycle_players(false),
+	_queue_end(0),
+	_queue_pos(0),
+	_queue_sound(0),
+	_queue_adding(0),
+	_queue_marker(0),
+	_queue_cleared(0),
+	_master_volume(0),
+	_music_volume(0),
+	_trigger_count(0),
+	_snm_trigger_index(0),
+	_pcSpeaker(false) {
+	memset(_channel_volume, 0, sizeof(_channel_volume));
+	memset(_channel_volume_eff, 0, sizeof(_channel_volume_eff));
+	memset(_volchan_table, 0, sizeof(_volchan_table));
 }
 
 IMuseInternal::~IMuseInternal() {
@@ -102,12 +101,17 @@ IMuseInternal::~IMuseInternal() {
 	}
 }
 
-byte *IMuseInternal::findStartOfSound(int sound) {
-	byte *ptr = NULL;
+byte *IMuseInternal::findStartOfSound(int sound, int ct) {
 	int32 size, pos;
 
-	if (_base_sounds)
-		ptr = _base_sounds[sound];
+	static const uint32 id[] = {
+		MKTAG('M', 'T', 'h', 'd'),
+		MKTAG('F', 'O', 'R', 'M'),
+		MKTAG('M', 'D', 'h', 'd'),
+		MKTAG('M', 'D', 'p', 'g')
+	};
+
+	byte *ptr = g_scumm->_res->_types[rtSound][sound]._address;
 
 	if (ptr == NULL) {
 		debug(1, "IMuseInternal::findStartOfSound(): Sound %d doesn't exist", sound);
@@ -115,12 +119,13 @@ byte *IMuseInternal::findStartOfSound(int sound) {
 	}
 
 	// Check for old-style headers first, like 'RO'
-	if (ptr[4] == 'R' && ptr[5] == 'O'&& ptr[6] != 'L')
-		return ptr + 4;
-	if (ptr[8] == 'S' && ptr[9] == 'O')
-		return ptr + 8;
+	int trFlag = (kMThd | kFORM);
+	if (ptr[0] == 'R' && ptr[1] == 'O' && ptr[2] != 'L')
+		return ct == trFlag ? ptr : 0;
+	if (ptr[4] == 'S' && ptr[5] == 'O')
+		return ct == trFlag ? ptr + 4 : 0;
 
-	ptr += 8;
+	ptr += 4;
 	size = READ_BE_UINT32(ptr);
 	ptr += 4;
 
@@ -129,55 +134,54 @@ byte *IMuseInternal::findStartOfSound(int sound) {
 	size = 48; // Arbitrary; we should find our tag within the first 48 bytes of the resource
 	pos = 0;
 	while (pos < size) {
-		if (!memcmp(ptr + pos, "MThd", 4) || !memcmp(ptr + pos, "FORM", 4))
-			return ptr + pos;
+		for (int i = 0; i < ARRAYSIZE(id); ++i) {
+			if ((ct & (1 << i)) && (READ_BE_UINT32(ptr + pos) == id[i]))
+				return ptr + pos;
+		}
 		++pos; // We could probably iterate more intelligently
 	}
 
-	debug(3, "IMuseInternal::findStartOfSound(): Failed to align on sound %d", sound);
+	if (ct == (kMThd | kFORM))
+		debug(3, "IMuseInternal::findStartOfSound(): Failed to align on sound %d", sound);
+
 	return 0;
 }
 
 bool IMuseInternal::isMT32(int sound) {
-	byte *ptr = NULL;
-	uint32 tag;
-
-	if (_base_sounds)
-		ptr = _base_sounds[sound];
-
+	byte *ptr = g_scumm->_res->_types[rtSound][sound]._address;
 	if (ptr == NULL)
 		return false;
 
-	tag = READ_BE_UINT32(ptr + 4);
+	uint32 tag = READ_BE_UINT32(ptr);
 	switch (tag) {
-	case MKTAG('A','D','L',' '):
-	case MKTAG('A','S','F','X'): // Special AD class for old AdLib sound effects
-	case MKTAG('S','P','K',' '):
+	case MKTAG('A', 'D', 'L', ' '):
+	case MKTAG('A', 'S', 'F', 'X'): // Special AD class for old AdLib sound effects
+	case MKTAG('S', 'P', 'K', ' '):
 		return false;
 
-	case MKTAG('A','M','I',' '):
-	case MKTAG('R','O','L',' '):
+	case MKTAG('A', 'M', 'I', ' '):
+	case MKTAG('R', 'O', 'L', ' '):
 		return true;
 
-	case MKTAG('M','A','C',' '):	// Occurs in the Mac version of FOA and MI2
+	case MKTAG('M', 'A', 'C', ' '): // Occurs in the Mac version of FOA and MI2
 		return true;
 
-	case MKTAG('G','M','D',' '):
+	case MKTAG('G', 'M', 'D', ' '):
 		return false;
 
-	case MKTAG('M','I','D','I'):	// Occurs in Sam & Max
+	case MKTAG('M', 'I', 'D', 'I'): // Occurs in Sam & Max
 		// HE games use Roland music
-		if (ptr[12] == 'H' && ptr[13] == 'S')
+		if (ptr[8] == 'H' && ptr[9] == 'S')
 			return true;
 		else
 			return false;
 	}
 
 	// Old style 'RO' has equivalent properties to 'ROL'
-	if (ptr[4] == 'R' && ptr[5] == 'O')
+	if (ptr[0] == 'R' && ptr[1] == 'O')
 		return true;
 	// Euphony tracks show as 'SO' and have equivalent properties to 'ADL'
-	if (ptr[8] == 'S' && ptr[9] == 'O')
+	if (ptr[4] == 'S' && ptr[5] == 'O')
 		return false;
 
 	error("Unknown music type: '%c%c%c%c'", (char)tag >> 24, (char)tag >> 16, (char)tag >> 8, (char)tag);
@@ -186,40 +190,35 @@ bool IMuseInternal::isMT32(int sound) {
 }
 
 bool IMuseInternal::isMIDI(int sound) {
-	byte *ptr = NULL;
-	uint32 tag;
-
-	if (_base_sounds)
-		ptr = _base_sounds[sound];
-
+	byte *ptr = g_scumm->_res->_types[rtSound][sound]._address;
 	if (ptr == NULL)
 		return false;
 
-	tag = READ_BE_UINT32(ptr + 4);
+	uint32 tag = READ_BE_UINT32(ptr);
 	switch (tag) {
-	case MKTAG('A','D','L',' '):
-	case MKTAG('A','S','F','X'): // Special AD class for old AdLib sound effects
-	case MKTAG('S','P','K',' '):
+	case MKTAG('A', 'D', 'L', ' '):
+	case MKTAG('A', 'S', 'F', 'X'): // Special AD class for old AdLib sound effects
+	case MKTAG('S', 'P', 'K', ' '):
 		return false;
 
-	case MKTAG('A','M','I',' '):
-	case MKTAG('R','O','L',' '):
+	case MKTAG('A', 'M', 'I', ' '):
+	case MKTAG('R', 'O', 'L', ' '):
 		return true;
 
-	case MKTAG('M','A','C',' '):	// Occurs in the Mac version of FOA and MI2
+	case MKTAG('M', 'A', 'C', ' '): // Occurs in the Mac version of FOA and MI2
 		return true;
 
-	case MKTAG('G','M','D',' '):
-	case MKTAG('M','I','D','I'):	// Occurs in Sam & Max
+	case MKTAG('G', 'M', 'D', ' '):
+	case MKTAG('M', 'I', 'D', 'I'): // Occurs in Sam & Max
 		return true;
 	}
 
 	// Old style 'RO' has equivalent properties to 'ROL'
-	if (ptr[4] == 'R' && ptr[5] == 'O')
+	if (ptr[0] == 'R' && ptr[1] == 'O')
 		return true;
 	// Euphony tracks show as 'SO' and have equivalent properties to 'ADL'
 	// FIXME: Right now we're pretending it's GM.
-	if (ptr[8] == 'S' && ptr[9] == 'O')
+	if (ptr[4] == 'S' && ptr[5] == 'O')
 		return true;
 
 	error("Unknown music type: '%c%c%c%c'", (char)tag >> 24, (char)tag >> 16, (char)tag >> 8, (char)tag);
@@ -383,7 +382,8 @@ int IMuseInternal::save_or_load(Serializer *ser, ScummEngine *scumm) {
 	for (i = 0; i < ARRAYSIZE(_parts); ++i)
 		_parts[i].saveLoadWithSerializer(ser);
 
-	{ // Load/save the instrument definitions, which were revamped with V11.
+	{
+		// Load/save the instrument definitions, which were revamped with V11.
 		Part *part = &_parts[0];
 		if (ser->getVersion() >= VER(11)) {
 			for (i = ARRAYSIZE(_parts); i; --i, ++part) {
@@ -426,11 +426,6 @@ int32 IMuseInternal::doCommand(int numargs, int a[]) {
 	return doCommand_internal(numargs, a);
 }
 
-void IMuseInternal::setBase(byte **base) {
-	Common::StackLock lock(_mutex, "IMuseInternal::setBase()");
-	_base_sounds = base;
-}
-
 uint32 IMuseInternal::property(int prop, uint32 value) {
 	Common::StackLock lock(_mutex, "IMuseInternal::property()");
 	switch (prop) {
@@ -474,6 +469,10 @@ uint32 IMuseInternal::property(int prop, uint32 value) {
 	case IMuse::PROP_GAME_ID:
 		_game_id = value;
 		break;
+
+	case IMuse::PROP_PC_SPEAKER:
+		_pcSpeaker = (value != 0);
+		break;
 	}
 
 	return 0;
@@ -529,7 +528,7 @@ void IMuseInternal::stopAllSounds() {
 
 int IMuseInternal::getSoundStatus(int sound) const {
 	Common::StackLock lock(_mutex, "IMuseInternal::getSoundStatus()");
-	return getSoundStatus_internal (sound, true);
+	return getSoundStatus_internal(sound, true);
 }
 
 int IMuseInternal::getMusicTimer() {
@@ -572,11 +571,11 @@ bool IMuseInternal::startSound_internal(int sound, int offset) {
 	int i;
 	ImTrigger *trigger = _snm_triggers;
 	for (i = ARRAYSIZE(_snm_triggers); i; --i, ++trigger) {
-		if (trigger->sound && trigger->id && trigger->command[0] == 8 && trigger->command[1] == sound && getSoundStatus_internal (trigger->sound,true))
+		if (trigger->sound && trigger->id && trigger->command[0] == 8 && trigger->command[1] == sound && getSoundStatus_internal(trigger->sound, true))
 			return false;
 	}
 
-	void *ptr = findStartOfSound(sound);
+	byte *ptr = findStartOfSound(sound);
 	if (!ptr) {
 		debug(2, "IMuseInternal::startSound(): Couldn't find sound %d", sound);
 		return false;
@@ -596,8 +595,11 @@ bool IMuseInternal::startSound_internal(int sound, int offset) {
 	// Bug #590511 and Patch #607175 (which was reversed to fix
 	// an FOA regression: Bug #622606).
 	Player *player = findActivePlayer(sound);
-	if (!player)
-		player = allocate_player(128);
+	if (!player) {
+		ptr = findStartOfSound(sound, IMuseInternal::kMDhd);
+		player = allocate_player(ptr ? (READ_BE_UINT32(&ptr[4]) && ptr[10] ? ptr[10] : 128) : 128);
+	}
+
 	if (!player)
 		return false;
 
@@ -645,6 +647,7 @@ int IMuseInternal::stopSound_internal(int sound) {
 }
 
 int IMuseInternal::stopAllSounds_internal() {
+	clear_queue();
 	Player *player = _players;
 	for (int i = ARRAYSIZE(_players); i; i--, player++) {
 		if (player->isActive())
@@ -666,9 +669,7 @@ int IMuseInternal::getSoundStatus_internal(int sound, bool ignoreFadeouts) const
 	return (sound == -1) ? 0 : get_queue_sound_status(sound);
 }
 
-int32 IMuseInternal::doCommand_internal
-	(int a, int b, int c, int d, int e, int f, int g, int h)
-{
+int32 IMuseInternal::doCommand_internal(int a, int b, int c, int d, int e, int f, int g, int h) {
 	int args[8];
 	args[0] = a;
 	args[1] = b;
@@ -736,7 +737,7 @@ int32 IMuseInternal::doCommand_internal(int numargs, int a[]) {
 			}
 			return -1;
 		case 13:
-			return getSoundStatus_internal (a[1], true);
+			return getSoundStatus_internal(a[1], true);
 		case 14:
 			// Sam and Max: Parameter fade
 			player = findActivePlayer(a[1]);
@@ -782,8 +783,7 @@ int32 IMuseInternal::doCommand_internal(int numargs, int a[]) {
 				a[0] = 0;
 				for (i = 0; i < ARRAYSIZE(_snm_triggers); ++i) {
 					if (_snm_triggers[i].sound == a[1] && _snm_triggers[i].id &&
-					   (a[3] == -1 || _snm_triggers[i].id == a[3]))
-					{
+					        (a[3] == -1 || _snm_triggers[i].id == a[3])) {
 						++a[0];
 					}
 				}
@@ -945,54 +945,22 @@ void IMuseInternal::sequencer_timers(MidiDriver *midi) {
 }
 
 void IMuseInternal::handle_marker(uint id, byte data) {
-	uint16 *p = 0;
-	uint pos;
-
-	if (_queue_adding && _queue_sound == id && data == _queue_marker)
+	if ((_queue_end == _queue_pos) || (_queue_adding && _queue_sound == id && data == _queue_marker))
 		return;
 
-	// Fix for bug #733401, revised for bug #761637:
-	// It would seem that sometimes a marker is in the queue
-	// but not at the head position. In the case of our bug,
-	// this seems to be the result of commands in the queue
-	// for songs that are no longer playing. So we skip
-	// ahead to the appropriate marker, effectively chomping
-	// anything in the queue before it. This fixes the FOA
-	// end credits music, but needs to be tested for inappopriate
-	// behavior elsewhere.
-	pos = _queue_end;
-	while (pos != _queue_pos) {
-		p = _cmd_queue[pos].array;
-		if (p[0] == TRIGGER_ID && p[1] == id && p[2] == data)
-			break;
-		pos = (pos + 1) % ARRAYSIZE(_cmd_queue);
-	}
-
-	if (pos == _queue_pos)
+	uint16 *p = _cmd_queue[_queue_end].array;
+	if (p[0] != TRIGGER_ID || id != p[1] || data != p[2])
 		return;
 
-	if (pos != _queue_end)
-		debug(0, "Skipping entries in iMuse command queue to reach marker");
-
 	_trigger_count--;
 	_queue_cleared = false;
-	do {
-		pos = (pos + 1) % ARRAYSIZE(_cmd_queue);
-		if (_queue_pos == pos)
-			break;
-		p = _cmd_queue[pos].array;
-		if (*p++ != COMMAND_ID)
-			break;
-		_queue_end = pos;
+	_queue_end = (_queue_end + 1) % ARRAYSIZE(_cmd_queue);
 
-		doCommand_internal(p[0], p[1], p[2], p[3], p[4], p[5], p[6], 0);
-
-		if (_queue_cleared)
-			return;
-		pos = _queue_end;
-	} while (1);
-
-	_queue_end = pos;
+	while (_queue_end != _queue_pos && _cmd_queue[_queue_end].array[0] == COMMAND_ID && !_queue_cleared) {
+		p = _cmd_queue[_queue_end].array;
+		doCommand_internal(p[1], p[2], p[3], p[4], p[5], p[6], p[7], 0);
+		_queue_end = (_queue_end + 1) % ARRAYSIZE(_cmd_queue);
+	}
 }
 
 int IMuseInternal::get_channel_volume(uint a) {
@@ -1037,9 +1005,9 @@ int IMuseInternal::get_queue_sound_status(int sound) const {
 		i = (i + 1) % ARRAYSIZE(_cmd_queue);
 	}
 
-	for (i = 0; i < ARRAYSIZE (_deferredCommands); ++i) {
+	for (i = 0; i < ARRAYSIZE(_deferredCommands); ++i) {
 		if (_deferredCommands[i].time_left && _deferredCommands[i].a == 8 &&
-			_deferredCommands[i].b == sound) {
+		        _deferredCommands[i].b == sound) {
 			return 2;
 		}
 	}
@@ -1248,7 +1216,7 @@ int32 IMuseInternal::ImSetTrigger(int sound, int id, int a, int b, int c, int d,
 	// NOTE: We ONLY do this if the sound that will trigger the command is actually
 	// playing. Otherwise, there's a problem when exiting and re-entering the
 	// Bumpusville mansion. Ref Bug #780918.
-	if (trig->command[0] == 8 && getSoundStatus_internal(trig->command[1],true) && getSoundStatus_internal(sound,true))
+	if (trig->command[0] == 8 && getSoundStatus_internal(trig->command[1], true) && getSoundStatus_internal(sound, true))
 		stopSound_internal(trig->command[1]);
 	return 0;
 }
@@ -1281,8 +1249,7 @@ int32 IMuseInternal::ImFireAllTriggers(int sound) {
 	return (count > 0) ? 0 : -1;
 }
 
-int IMuseInternal::set_channel_volume(uint chan, uint vol)
-{
+int IMuseInternal::set_channel_volume(uint chan, uint vol) {
 	if (chan >= 8 || vol > 127)
 		return -1;
 
@@ -1462,7 +1429,7 @@ void IMuseInternal::initMT32(MidiDriver *midi) {
 	// Display a welcome message on MT-32 displays.
 	memcpy(&buffer[0], "\x41\x10\x16\x12\x20\x00\x00", 7);
 	memcpy(&buffer[7], "                    ", 20);
-	memcpy(buffer + 7 +(20 - len) / 2, info, len);
+	memcpy(buffer + 7 + (20 - len) / 2, info, len);
 	byte checksum = 0;
 	for (int i = 4; i < 27; ++i)
 		checksum -= buffer[i];
@@ -1508,9 +1475,9 @@ void IMuseInternal::initGM(MidiDriver *midi) {
 
 			// Set Channels 1-16 to SC-55 Map, then CM-64/32L Variation
 			for (i = 0; i < 16; ++i) {
-				midi->send((  127 << 16) | (0  << 8) | (0xB0 | i));
-				midi->send((  1   << 16) | (32 << 8) | (0xB0 | i));
-				midi->send((  0   << 16) | (0  << 8) | (0xC0 | i));
+				midi->send((127 << 16) | (0  << 8) | (0xB0 | i));
+				midi->send((1   << 16) | (32 << 8) | (0xB0 | i));
+				midi->send((0   << 16) | (0  << 8) | (0xC0 | i));
 			}
 			debug(2, "GS Program Change: CM-64/32L Map Selected");
 
@@ -1531,7 +1498,7 @@ void IMuseInternal::initGM(MidiDriver *midi) {
 		// Set Channels 1-16 Reverb to 64, which is the
 		// equivalent of MT-32 default Reverb Level 5
 		for (i = 0; i < 16; ++i)
-			midi->send((  64   << 16) | (91 << 8) | (0xB0 | i));
+			midi->send((64   << 16) | (91 << 8) | (0xB0 | i));
 		debug(2, "GM Controller 91 Change: Channels 1-16 Reverb Level is 64");
 
 		// Set Channels 1-16 Pitch Bend Sensitivity to
@@ -1672,8 +1639,8 @@ void IMuseInternal::reallocateMidiChannels(MidiDriver *midi) {
 		hipart = NULL;
 		for (i = 32, part = _parts; i; i--, part++) {
 			if (part->_player && part->_player->getMidiDriver() == midi &&
-						!part->_percussion && part->_on &&
-						!part->_mc && part->_pri_eff >= hipri) {
+			        !part->_percussion && part->_on &&
+			        !part->_mc && part->_pri_eff >= hipri) {
 				hipri = part->_pri_eff;
 				hipart = part;
 			}
@@ -1703,16 +1670,35 @@ void IMuseInternal::reallocateMidiChannels(MidiDriver *midi) {
 	}
 }
 
-void IMuseInternal::setGlobalAdLibInstrument(byte slot, byte *data) {
+void IMuseInternal::setGlobalInstrument(byte slot, byte *data) {
 	if (slot < 32) {
-		_global_adlib_instruments[slot].adlib(data);
+		if (_pcSpeaker)
+			_global_instruments[slot].pcspk(data);
+		else
+			_global_instruments[slot].adlib(data);
 	}
 }
 
-void IMuseInternal::copyGlobalAdLibInstrument(byte slot, Instrument *dest) {
+void IMuseInternal::copyGlobalInstrument(byte slot, Instrument *dest) {
 	if (slot >= 32)
 		return;
-	_global_adlib_instruments[slot].copy_to(dest);
+
+	// Both the AdLib code and the PC Speaker code use an all zero instrument
+	// as default in the original, thus we do the same.
+	// PC Speaker instrument size is 23, while AdLib instrument size is 30.
+	// Thus we just use a 30 byte instrument data array as default.
+	const byte defaultInstr[30] = { 0 };
+
+	if (_global_instruments[slot].isValid()) {
+		// In case we have an valid instrument set up, copy it to the part.
+		_global_instruments[slot].copy_to(dest);
+	} else if (_pcSpeaker) {
+		debug(0, "Trying to use non-existant global PC Speaker instrument %d", slot);
+		dest->pcspk(defaultInstr);
+	} else {
+		debug(0, "Trying to use non-existant global AdLib instrument %d", slot);
+		dest->adlib(defaultInstr);
+	}
 }
 
 
