@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/imuse_digi/dimuse_sndmgr.h $
- * $Id: dimuse_sndmgr.h 47064 2010-01-06 00:01:27Z lordhoto $
  */
 
 #ifndef SCUMM_IMUSE_DIGI_SNDMGR_H
@@ -27,7 +24,7 @@
 
 
 #include "common/scummsys.h"
-#include "sound/audiostream.h"
+#include "audio/audiostream.h"
 #include "scumm/imuse_digi/dimuse_bndmgr.h"
 
 namespace Scumm {
@@ -113,7 +110,7 @@ private:
 	bool checkForProperHandle(SoundDesc *soundDesc);
 	SoundDesc *allocSlot();
 	void prepareSound(byte *ptr, SoundDesc *sound);
-	void prepareSoundFromRMAP(Common::File *file, SoundDesc *sound, int32 offset, int32 size);
+	void prepareSoundFromRMAP(Common::SeekableReadStream *file, SoundDesc *sound, int32 offset, int32 size);
 
 	ScummEngine *_vm;
 	byte _disk;
