@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/insane/insane.cpp $
- * $Id: insane.cpp 45616 2009-11-02 21:54:57Z fingolfin $
- *
  */
 
 
@@ -31,6 +28,7 @@
 
 #include "scumm/actor.h"
 #include "scumm/file.h"
+#include "scumm/resource.h"
 #include "scumm/scumm_v7.h"
 #include "scumm/sound.h"
 
@@ -944,7 +942,7 @@ bool Insane::actor1StateFlags(int state) {
 	bool retvalue = 0;
 	unsigned int i;
 
-	for (i = 0; i < sizeof(spans); i++) {
+	for (i = 0; i < ARRAYSIZE(spans); i++) {
 		retvalue = !retvalue;
 		if (spans[i] <= state)
 			break;
@@ -1099,7 +1097,7 @@ bool Insane::actor0StateFlags1(int state) {
 	bool retvalue = 1;
 	unsigned int i;
 
-	for (i = 0; i < sizeof(spans); i++) {
+	for (i = 0; i < ARRAYSIZE(spans); i++) {
 		retvalue = !retvalue;
 		if (spans[i] >= state)
 			break;
@@ -1119,7 +1117,7 @@ bool Insane::actor0StateFlags2(int state) {
 	bool retvalue = 1;
 	unsigned int i;
 
-	for (i = 0; i < sizeof(spans); i++) {
+	for (i = 0; i < ARRAYSIZE(spans); i++) {
 		retvalue = !retvalue;
 		if (spans[i] >= state)
 			break;
@@ -1413,7 +1411,7 @@ int32 Insane::smush_setupSanWithFlu(const char *filename, int32 setupsan2, int32
 	_smush_setupsan1 = setupsan1;
 
 	/* skip FLUP marker */
-	if (READ_BE_UINT32(fluPtr) == MKID_BE('FLUP'))
+	if (READ_BE_UINT32(fluPtr) == MKTAG('F','L','U','P'))
 		tmp += 8;
 
 	_smush_setupsan2 = setupsan2;
