@@ -18,9 +18,6 @@
  * aint32 with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/player_nes.cpp $
- * $Id: player_nes.cpp 51679 2010-08-03 11:25:20Z sev $
- *
  */
 
 #ifndef DISABLE_NES_APU
@@ -28,7 +25,7 @@
 #include "engines/engine.h"
 #include "scumm/player_nes.h"
 #include "scumm/scumm.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Scumm {
 
