@@ -18,18 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/player_pce.h $
- * $Id: player_pce.h 48359 2010-03-22 20:28:08Z fingolfin $
- *
  */
 
 #ifndef SCUMM_PLAYER_PCE_H
 #define SCUMM_PLAYER_PCE_H
 
 #include "common/scummsys.h"
+#include "common/mutex.h"
 #include "scumm/music.h"
-#include "sound/audiostream.h"
-#include "sound/mixer.h"
+#include "audio/audiostream.h"
+#include "audio/mixer.h"
 
 // PCE sound engine is only used by Loom, which requires 16bit color support
 #ifdef USE_RGB_COLOR
