@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/player_sid.cpp $
- * $Id: player_sid.cpp 52151 2010-08-17 11:02:27Z sev $
- *
  */
 
 #ifndef DISABLE_SID
@@ -28,7 +25,7 @@
 #include "engines/engine.h"
 #include "scumm/player_sid.h"
 #include "scumm/scumm.h"
-#include "sound/mixer.h"
+#include "audio/mixer.h"
 
 namespace Scumm {
 
@@ -1287,7 +1284,7 @@ uint8 *Player_SID::getResource(int resID) {
 int Player_SID::readBuffer(int16 *buffer, const int numSamples) {
 	int samplesLeft = numSamples;
 
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 
 	while (samplesLeft > 0) {
 		// update SID status after each frame
@@ -1296,13 +1293,11 @@ int Player_SID::readBuffer(int16 *buffer, const int numSamples) {
 			_cpuCyclesLeft = timingProps[_videoSystem].cyclesPerFrame;
 		}
 		// fetch samples
-		int sampleCount = _sid->clock(_cpuCyclesLeft, (short*)buffer, samplesLeft);
+		int sampleCount = _sid->updateClock(_cpuCyclesLeft, (short*)buffer, samplesLeft);
 		samplesLeft -= sampleCount;
 		buffer += sampleCount;
 	}
 
-	_mutex.unlock();
-
 	return numSamples;
 }
 
@@ -1337,7 +1332,7 @@ void Player_SID::startSound(int nr) {
 	// prio 7 is never used in any sound file use this byte for auto-detection.
 	bool isMusic = (data[4] == 0x07);
 
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 
 	if (isMusic) {
 		initMusic(nr);
@@ -1345,29 +1340,25 @@ void Player_SID::startSound(int nr) {
 		stopSound_intern(nr);
 		initSound(nr);
 	}
-
-	_mutex.unlock();
 }
 
 void Player_SID::stopSound(int nr) {
 	if (nr == -1)
 		return;
 
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	stopSound_intern(nr);
-	_mutex.unlock();
 }
 
 void Player_SID::stopAllSounds() {
-	_mutex.lock();
+	Common::StackLock lock(_mutex);
 	stopAllSounds_intern();
-	_mutex.unlock();
 }
 
 int Player_SID::getSoundStatus(int nr) const {
 	int result = 0;
 
-	//_mutex.lock();
+	//Common::StackLock lock(_mutex);
 
 	if (resID_song == nr && isMusicPlaying) {
 		result = 1;
@@ -1379,8 +1370,6 @@ int Player_SID::getSoundStatus(int nr) const {
 		}
 	}
 
-	//_mutex.unlock();
-
 	return result;
 }
 
