@@ -18,18 +18,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/player_v4a.h $
- * $Id: player_v4a.h 47541 2010-01-25 01:39:44Z lordhoto $
- *
  */
 
 #ifndef SCUMM_PLAYER_V4A_H
 #define SCUMM_PLAYER_V4A_H
 
 #include "common/scummsys.h"
+#include "common/util.h"
 #include "scumm/music.h"
-#include "sound/mixer.h"
-#include "sound/mods/tfmx.h"
+#include "audio/mixer.h"
+#include "audio/mods/tfmx.h"
 
 class Mixer;
 
@@ -69,7 +67,7 @@ private:
 //		byte type;
 	} _sfxSlots[4];
 
-	int8 _initState; // < 0: failed, 0: uninitialised, > 0: initialised
+	int8 _initState; // < 0: failed, 0: uninitialized, > 0: initialized
 
 	int getSfxChan(int id) const {
 		for (int i = 0; i < ARRAYSIZE(_sfxSlots); ++i)
