@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/scumm/verbs.cpp $
- * $Id: verbs.cpp 53804 2010-10-25 07:53:01Z Kirben $
- *
  */
 
 #include "scumm/actor.h"
@@ -155,7 +152,7 @@ void ScummEngine_v0::setNewKidVerbs() {
 
 void ScummEngine_v0::switchActor(int slot) {
 	resetSentence(false);
-	
+
 	if (_currentRoom == 45)
 		return;
 
@@ -167,11 +164,6 @@ void ScummEngine_v0::switchActor(int slot) {
 	if (_currentMode == 0 || _currentMode == 1 || _currentMode == 2)
 		return;
 
-	// verbs disabled for the current actor
-	ActorC64 *a = (ActorC64 *)derefActor(VAR(VAR_EGO), "switchActor");
-	if (a->_miscflags & 0x40)
-		return;
-
 	VAR(VAR_EGO) = VAR(97 + slot);
 	resetVerbs();
 	actorFollowCamera(VAR(VAR_EGO));
@@ -726,7 +718,7 @@ void ScummEngine_v2::checkExecVerbs() {
 }
 
 void ScummEngine_v0::runObject(int obj, int entry) {
-	int prev = _v0ObjectInInventory;
+	bool prev = _v0ObjectInInventory;
 
 	if (getVerbEntrypoint(obj, entry) == 0) {
 		// If nothing was found, attempt to find the 'WHAT-IS' verb script
@@ -736,7 +728,7 @@ void ScummEngine_v0::runObject(int obj, int entry) {
 			entry = 0x0F;
 		}
 	}
-	
+
 	_v0ObjectInInventory = prev;
 
 	if (getVerbEntrypoint(obj, entry) != 0) {
@@ -755,19 +747,6 @@ void ScummEngine_v0::runObject(int obj, int entry) {
 	}
 }
 
-void ScummEngine_v2::runObject(int obj, int entry) {
-	if (getVerbEntrypoint(obj, entry) != 0) {
-		runObjectScript(obj, entry, false, false, NULL);
-	} else if (entry != 13 && entry != 15) {
-		VAR(9) = entry;
-		runScript(3, 0, 0, 0);
-	}
-
-	_activeInventory = 0;
-	_activeObject = 0;
-	_activeVerb = 13;
-}
-
 bool ScummEngine_v0::verbMoveToActor(int actor) {
 	Actor *a = derefActor(VAR(VAR_EGO), "verbMoveToActor");
 	Actor *a2 = derefActor(actor, "verbMoveToActor");
@@ -851,7 +830,7 @@ bool ScummEngine_v0::verbObtain(int obj, int objIndex) {
 		} else {
 			_verbPickup = false;
 		}
-		
+
 		// Ignore verbs?
 		Actor *a = derefActor(VAR(VAR_EGO), "verbObtain");
 		if (((ActorC64 *)a)->_miscflags & 0x40) {
@@ -870,7 +849,7 @@ bool ScummEngine_v0::verbObtain(int obj, int objIndex) {
 				if (whereIsObject(obj) == WIO_INVENTORY)
 					_activeInventory = obj;
 				else
-					resetSentence();
+					resetSentence(false);
 
 				_v0ObjectInInventory = false;
 			}
@@ -907,7 +886,7 @@ bool ScummEngine_v0::verbExec() {
 	int entry = (_currentMode != 0 && _currentMode != 1) ? _activeVerb : 15;
 
 	if ((!_activeInvExecute && _activeObject && getObjectIndex(_activeObject) == -1)) {
-		resetSentence();
+		resetSentence(false);
 		return false;
 	}
 
@@ -958,7 +937,7 @@ bool ScummEngine_v0::verbExec() {
 		runObject(_activeInventory , 3);
 		_v0ObjectInInventory = false;
 
-		resetSentence();
+		resetSentence(false);
 		return false;
 	}
 
@@ -969,7 +948,7 @@ bool ScummEngine_v0::verbExec() {
 		_v0ObjectIndex = false;
 		_verbExecuting = false;
 
-		resetSentence();
+		resetSentence(false);
 		return false;
 	}
 
@@ -983,13 +962,14 @@ bool ScummEngine_v0::verbExec() {
 		if ((_currentMode == 3 || _currentMode == 2) && _activeVerb == 13)
 			return false;
 
-		resetSentence();
+		resetSentence(false);
 		return false;
 	}
 
 	// We acted on an inventory item
 	if (_activeInventory && verbExecutes(_activeInventory, true) && _activeVerb != 3) {
 		_v0ObjectInInventory = true;
+		_activeObject = _activeInventory;
 		runObject(_activeInventory, _activeVerb);
 
 		_verbExecuting = false;
@@ -999,7 +979,7 @@ bool ScummEngine_v0::verbExec() {
 			return false;
 		}
 
-		resetSentence();
+		resetSentence(false);
 		return false;
 	}
 
@@ -1009,7 +989,7 @@ bool ScummEngine_v0::verbExec() {
 		runObject(_activeObjectIndex, entry);
 		_v0ObjectIndex = false;
 	} else if (_activeInventory) {
-		// Not sure this is the correct way to do this, 
+		// Not sure this is the correct way to do this,
 		// however its working for most situations - segra
 		if (verbExecutes(_activeInventory, true) == false) {
 			if (_activeObject2 && _activeObject2Inv && verbExecutes(_activeObject2, true)) {
@@ -1021,7 +1001,7 @@ bool ScummEngine_v0::verbExec() {
 				runObject(_activeObject, _activeVerb);
 			} else {
 				_v0ObjectInInventory = true;
-					
+
 				if (_activeObject2) {
 					_activeObject = _activeObject2;
 
@@ -1042,13 +1022,13 @@ bool ScummEngine_v0::verbExec() {
 		return false;
 	}
 
-	resetSentence();
+	resetSentence(false);
 
 	return false;
 }
 
 void ScummEngine_v0::checkExecVerbs() {
-	Actor *a = derefActor(VAR(VAR_EGO), "checkExecVerbs");
+	ActorC64 *a = (ActorC64 *)derefActor(VAR(VAR_EGO), "checkExecVerbs");
 	VirtScreen *zone = findVirtScreen(_mouse.y);
 
 	// Is a verb currently executing
@@ -1105,7 +1085,7 @@ void ScummEngine_v0::checkExecVerbs() {
 
 			// Click into V2 inventory
 			checkV2Inventory(_mouse.x, _mouse.y);
-			
+
 			// Did the Inventory position changed (arrows pressed, do nothing)
 			if (invOff != _inventoryOffset)
 				return;
@@ -1164,26 +1144,27 @@ void ScummEngine_v0::checkExecVerbs() {
 				objIdx = 0;
 			}
 
+			if (a->_miscflags & 0x80) {
+				if (_activeVerb != 7 && over != 7) {
+					_activeVerb = 0;
+					over = 0;
+				}
+			}
+
 			// Handle New Kid verb options
 			if (_activeVerb == 7 || over == 7) {
 				// Disable New-Kid (in the secret lab)
 				if (_currentMode == 2 || _currentMode == 0)
 					return;
-				
-				if (!(((ActorC64 *)a)->_miscflags & 0x80)) {
-					if (_activeVerb != 7) {
-						_activeVerb = over;
-						over = 0;
-					}
-				}
 
-				if (over) {
+				if (_activeVerb == 7 && over) {
 					_activeVerb = 13;
 					switchActor(_verbs[over].verbid - 1);
 					return;
 				}
 
 				setNewKidVerbs();
+				_activeVerb = 7;
 
 				return;
 			}
@@ -1191,7 +1172,7 @@ void ScummEngine_v0::checkExecVerbs() {
 			// Clicked on nothing, walk here?
 			if (!over && !act && _activeVerb == 13 && !obj && _currentMode != 0) {
 				// Clear all selected
-				resetSentence();
+				resetSentence(false);
 
 				// 0xB31
 				VAR(6) = _virtualMouse.x / V12_X_MULTIPLIER;
@@ -1199,7 +1180,7 @@ void ScummEngine_v0::checkExecVerbs() {
 
 				if (zone->number == kMainVirtScreen) {
 					// Ignore verbs?
-					if (((ActorC64 *)a)->_miscflags & 0x40) {
+					if (a->_miscflags & 0x40) {
 						resetSentence(false);
 						return;
 					}
@@ -1222,7 +1203,7 @@ void ScummEngine_v0::checkExecVerbs() {
 			if (_activeVerb != over) {
 				_activeVerb = over;
 				if (_activeVerb == 13) {
-					resetSentence();
+					resetSentence(false);
 				}
 				return;
 			}
@@ -1459,13 +1440,17 @@ void ScummEngine::drawVerb(int verb, int mode) {
 }
 
 void ScummEngine::restoreVerbBG(int verb) {
-
 	VerbSlot *vs;
 
 	vs = &_verbs[verb];
+	uint8 col =
+#ifndef DISABLE_TOWNS_DUAL_LAYER_MODE
+		((_game.platform == Common::kPlatformFMTowns) && (_game.id == GID_MONKEY2 || _game.id == GID_INDY4) && (vs->bkcolor == _townsOverrideShadowColor)) ? 0 :
+#endif
+		vs->bkcolor;
 
 	if (vs->oldRect.left != -1) {
-		restoreBackground(vs->oldRect, vs->bkcolor);
+		restoreBackground(vs->oldRect, col);
 		vs->oldRect.left = -1;
 	}
 }
@@ -1510,7 +1495,7 @@ void ScummEngine::drawVerbBitmap(int verb, int x, int y) {
 		}
 		imptr = getObjectImage(obim, 1);
 	} else {
-		const ImageHeader *imhd = (const ImageHeader *)findResourceData(MKID_BE('IMHD'), obim);
+		const ImageHeader *imhd = (const ImageHeader *)findResourceData(MKTAG('I','M','H','D'), obim);
 		if (_game.version >= 7) {
 			imgw = READ_LE_UINT16(&imhd->v7.width) / 8;
 			imgh = READ_LE_UINT16(&imhd->v7.height) / 8;
