@@ -18,16 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sky/logic.cpp $
- * $Id: logic.cpp 45616 2009-11-02 21:54:57Z fingolfin $
- *
  */
 
 #include "common/endian.h"
 #include "common/rect.h"
-#include "common/events.h"
-#include "common/EventRecorder.h"
-#include "common/system.h"
+#include "common/textconsole.h"
 
 #include "sky/autoroute.h"
 #include "sky/compact.h"
@@ -72,8 +67,8 @@ void Logic::setupLogicTable() {
 	_logicTable = logicTable;
 }
 
-Logic::Logic(SkyCompact *skyCompact, Screen *skyScreen, Disk *skyDisk, Text *skyText, MusicBase *skyMusic, Mouse *skyMouse, Sound *skySound) {
-	g_eventRec.registerRandomSource(_rnd, "sky");
+Logic::Logic(SkyCompact *skyCompact, Screen *skyScreen, Disk *skyDisk, Text *skyText, MusicBase *skyMusic, Mouse *skyMouse, Sound *skySound)
+	: _rnd("sky") {
 
 	_skyCompact = skyCompact;
 	_skyScreen = skyScreen;
@@ -1253,6 +1248,17 @@ script:
 
 	debug(3, "Doing Script: %d:%d:%x", moduleNo, scriptNo & 0xFFF, offset ? (offset - moduleStart[scriptNo & 0xFFF]) : 0);
 
+	// WORKAROUND for bug #3149412: "Invalid Mode when giving shades to travel agent"
+	// Using the dark glasses on Trevor (travel agent) multiple times in succession would
+	// wreck the trevor compact's mode, as the script in question doesn't account for using
+	// this item at this point in the game (you will only have it here if you play the game
+	// in an unusual way) and thus would loop indefinitely / never drop out.
+	// To prevent this, we trigger the generic response by pretending we're using an item
+	// which the script /does/ handle.
+	if (scriptNo == TREVOR_SPEECH && _scriptVariables[OBJECT_HELD] == IDO_SHADES)
+		_scriptVariables[OBJECT_HELD] = IDO_GLASS;
+
+
 	// Check whether we have an offset or what
 	if (offset)
 		scriptData = moduleStart + offset;
@@ -1823,7 +1829,7 @@ bool Logic::fnHighlight(uint32 itemNo, uint32 pen, uint32 c) {
 	pen += 241;
 	Compact *textCompact = _skyCompact->fetchCpt(itemNo);
 	uint8 *sprData = (uint8 *)SkyEngine::fetchItem(textCompact->flag);
-	_skyText->changeTextSpriteColour(sprData, (uint8)pen);
+	_skyText->changeTextSpriteColor(sprData, (uint8)pen);
 	return true;
 }
 
@@ -1895,7 +1901,7 @@ bool Logic::fnCheckRequest(uint32 a, uint32 b, uint32 c) {
 }
 
 bool Logic::fnStartMenu(uint32 firstObject, uint32 b, uint32 c) {
-	/// initialise the top menu bar
+	/// initialize the top menu bar
 	// firstObject is o0 for game menu, k0 for linc
 
 	uint i;
@@ -1944,7 +1950,7 @@ bool Logic::fnStartMenu(uint32 firstObject, uint32 b, uint32 c) {
 	else if (menuLength < _scriptVariables[SCROLL_OFFSET] + 11)
 		_scriptVariables[SCROLL_OFFSET] = menuLength - 11;
 
-	// (6) AND FINALLY, INITIALISE THE 11 OBJECTS SO THEY APPEAR ON SCREEEN
+	// (6) AND FINALLY, INITIALIZE THE 11 OBJECTS SO THEY APPEAR ON SCREEEN
 
 	uint16 rollingX = TOP_LEFT_X + 28;
 	for (i = 0; i < 11; i++) {
@@ -2510,7 +2516,7 @@ bool Logic::fnUnPauseFx(uint32 a, uint32 b, uint32 c) {
 }
 
 bool Logic::fnPrintf(uint32 a, uint32 b, uint32 c) {
-	printf("fnPrintf: %d\n", a);
+	debug("fnPrintf(%d, %d, %d)", a, b, c);
 	return true;
 }
 
@@ -2547,7 +2553,7 @@ void Logic::stdSpeak(Compact *target, uint32 textNum, uint32 animNum, uint32 bas
 		// form the text sprite, if player wants subtitles or
 		// if we couldn't find the speech file
 		DisplayedText textInfo;
-		textInfo = _skyText->lowTextManager(textNum, FIXED_TEXT_WIDTH, 0, (uint8)target->spColour, true);
+		textInfo = _skyText->lowTextManager(textNum, FIXED_TEXT_WIDTH, 0, (uint8)target->spColor, true);
 		Compact *textCompact = _skyCompact->fetchCpt(textInfo.compactNum);
 		target->spTextId = textInfo.compactNum;	//So we know what text to kill
 		byte *textGfx = textInfo.textData;
