@@ -18,28 +18,28 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/sword1/animation.cpp $
- * $Id: animation.cpp 49154 2010-05-23 11:16:10Z eriktorbjorn $
- *
  */
 
 #include "common/file.h"
+#include "common/events.h"
+#include "common/keyboard.h"
+#include "common/textconsole.h"
+#include "common/translation.h"
 #include "sword1/sword1.h"
 #include "sword1/animation.h"
 #include "sword1/text.h"
-#include "sound/decoders/vorbis.h"
+#include "sword1/resman.h"
 
-#include "common/config-manager.h"
-#include "common/endian.h"
 #include "common/str.h"
 #include "common/system.h"
+#include "graphics/palette.h"
 #include "graphics/surface.h"
 
 #include "gui/message.h"
 
 namespace Sword1 {
 
-static const char *sequenceList[20] = {
+static const char *const sequenceList[20] = {
 	"ferrari",  // 0  CD2   ferrari running down fitz in sc19
 	"ladder",   // 1  CD2   george walking down ladder to dig sc24->sc$
 	"steps",    // 2  CD2   george walking down steps sc23->sc24
@@ -66,8 +66,8 @@ static const char *sequenceList[20] = {
 // Basic movie player
 ///////////////////////////////////////////////////////////////////////////////
 
-MoviePlayer::MoviePlayer(SwordEngine *vm, Text *textMan, Audio::Mixer *snd, OSystem *system, Audio::SoundHandle *bgSoundHandle, Graphics::VideoDecoder *decoder, DecoderType decoderType)
-	: _vm(vm), _textMan(textMan), _snd(snd), _bgSoundHandle(bgSoundHandle), _system(system) {
+MoviePlayer::MoviePlayer(SwordEngine *vm, Text *textMan, ResMan *resMan, Audio::Mixer *snd, OSystem *system, Audio::SoundHandle *bgSoundHandle, Video::VideoDecoder *decoder, DecoderType decoderType)
+	: _vm(vm), _textMan(textMan), _resMan(resMan), _snd(snd), _bgSoundHandle(bgSoundHandle), _system(system) {
 	_bgSoundStream = NULL;
 	_decoderType = decoderType;
 	_decoder = decoder;
@@ -77,8 +77,8 @@ MoviePlayer::MoviePlayer(SwordEngine *vm, Text *textMan, Audio::Mixer *snd, OSys
 }
 
 MoviePlayer::~MoviePlayer() {
-	delete _decoder;
 	delete _bgSoundHandle;
+	delete _decoder;
 }
 
 /**
@@ -87,7 +87,7 @@ MoviePlayer::~MoviePlayer() {
  */
 bool MoviePlayer::load(uint32 id) {
 	Common::File f;
-	char filename[20];
+	Common::String filename;
 
 	if (_decoderType == kVideoDecoderDXA)
 		_bgSoundStream = Audio::SeekableAudioStream::openStreamFile(sequenceList[id]);
@@ -95,7 +95,7 @@ bool MoviePlayer::load(uint32 id) {
 		_bgSoundStream = NULL;
 
 	if (SwordEngine::_systemVars.showText) {
-		sprintf(filename, "%s.txt", sequenceList[id]);
+		filename = Common::String::format("%s.txt", sequenceList[id]);
 		if (f.open(filename)) {
 			Common::String line;
 			int lineNo = 0;
@@ -115,20 +115,20 @@ bool MoviePlayer::load(uint32 id) {
 				int startFrame = strtoul(ptr, const_cast<char **>(&ptr), 10);
 				int endFrame = strtoul(ptr, const_cast<char **>(&ptr), 10);
 
-				while (*ptr && isspace(*ptr))
+				while (*ptr && isspace(static_cast<unsigned char>(*ptr)))
 					ptr++;
 
 				if (startFrame > endFrame) {
-					warning("%s:%d: startFrame (%d) > endFrame (%d)", filename, lineNo, startFrame, endFrame);
+					warning("%s:%d: startFrame (%d) > endFrame (%d)", filename.c_str(), lineNo, startFrame, endFrame);
 					continue;
 				}
 
 				if (startFrame <= lastEnd) {
-					warning("%s:%d startFrame (%d) <= lastEnd (%d)", filename, lineNo, startFrame, lastEnd);
+					warning("%s:%d startFrame (%d) <= lastEnd (%d)", filename.c_str(), lineNo, startFrame, lastEnd);
 					continue;
 				}
 
-				_movieTexts.push_back(new MovieText(startFrame, endFrame, ptr));
+				_movieTexts.push_back(MovieText(startFrame, endFrame, ptr));
 				lastEnd = endFrame;
 			}
 			f.close();
@@ -137,14 +137,14 @@ bool MoviePlayer::load(uint32 id) {
 
 	switch (_decoderType) {
 	case kVideoDecoderDXA:
-		snprintf(filename, sizeof(filename), "%s.dxa", sequenceList[id]);
+		filename = Common::String::format("%s.dxa", sequenceList[id]);
 		break;
 	case kVideoDecoderSMK:
-		snprintf(filename, sizeof(filename), "%s.smk", sequenceList[id]);
+		filename = Common::String::format("%s.smk", sequenceList[id]);
 		break;
 	}
 
-	return _decoder->loadFile(filename);
+	return _decoder->loadFile(filename.c_str());
 }
 
 void MoviePlayer::play() {
@@ -163,8 +163,7 @@ void MoviePlayer::play() {
 
 	_textMan->releaseText(2, false);
 
-	while (!_movieTexts.empty())
-		delete _movieTexts.remove_at(_movieTexts.size() - 1);
+	_movieTexts.clear();
 
 	while (_snd->isSoundHandleActive(*_bgSoundHandle))
 		_system->delayMillis(100);
@@ -174,25 +173,25 @@ void MoviePlayer::play() {
 	// previous location would be momentarily drawn, before switching to
 	// the new one. Work around this by setting the palette to black.
 
-	byte pal[4 * 256];
+	byte pal[3 * 256];
 	memset(pal, 0, sizeof(pal));
-	_system->setPalette(pal, 0, 256);
+	_system->getPaletteManager()->setPalette(pal, 0, 256);
 }
 
 void MoviePlayer::performPostProcessing(byte *screen) {
 	if (!_movieTexts.empty()) {
-		if (_decoder->getCurFrame() == _movieTexts[0]->_startFrame) {
-			_textMan->makeTextSprite(2, (uint8 *)_movieTexts[0]->_text, 600, LETTER_COL);
+		if (_decoder->getCurFrame() == _movieTexts.front()._startFrame) {
+			_textMan->makeTextSprite(2, (const uint8 *)_movieTexts.front()._text.c_str(), 600, LETTER_COL);
 
 			FrameHeader *frame = _textMan->giveSpriteData(2);
-			_textWidth = frame->width;
-			_textHeight = frame->height;
+			_textWidth = _resMan->toUint16(frame->width);
+			_textHeight = _resMan->toUint16(frame->height);
 			_textX = 320 - _textWidth / 2;
 			_textY = 420 - _textHeight;
 		}
-		if (_decoder->getCurFrame() == _movieTexts[0]->_endFrame) {
+		if (_decoder->getCurFrame() == _movieTexts.front()._endFrame) {
 			_textMan->releaseText(2, false);
-			delete _movieTexts.remove_at(0);
+			_movieTexts.pop_front();
 		}
 	}
 
@@ -252,7 +251,7 @@ bool MoviePlayer::playVideo() {
 
 	while (!_vm->shouldQuit() && !_decoder->endOfVideo()) {
 		if (_decoder->needsUpdate()) {
-			Graphics::Surface *frame = _decoder->decodeNextFrame();
+			const Graphics::Surface *frame = _decoder->decodeNextFrame();
 			if (frame)
 				_vm->_system->copyRectToScreen((byte *)frame->pixels, frame->pitch, x, y, frame->w, frame->h);
 
@@ -263,8 +262,8 @@ bool MoviePlayer::playVideo() {
 				uint32 minWeight = 0xFFFFFFFF;
 				uint32 weight;
 				byte r, g, b;
-				
-				byte *palette = _decoder->getPalette();
+
+				const byte *palette = _decoder->getPalette();
 
 				for (int i = 0; i < 256; i++) {
 					r = *palette++;
@@ -318,49 +317,48 @@ uint32 DXADecoderWithSound::getElapsedTime() const {
 	if (_mixer->isSoundHandleActive(*_bgSoundHandle))
 		return _mixer->getSoundElapsedTime(*_bgSoundHandle);
 
-	return VideoDecoder::getElapsedTime();
+	return DXADecoder::getElapsedTime();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 // Factory function for creating the appropriate cutscene player
 ///////////////////////////////////////////////////////////////////////////////
 
-MoviePlayer *makeMoviePlayer(uint32 id, SwordEngine *vm, Text *textMan, Audio::Mixer *snd, OSystem *system) {
-	char filename[20];
-	char buf[60];
+MoviePlayer *makeMoviePlayer(uint32 id, SwordEngine *vm, Text *textMan, ResMan *resMan, Audio::Mixer *snd, OSystem *system) {
+	Common::String filename;
 	Audio::SoundHandle *bgSoundHandle = new Audio::SoundHandle;
 
-	snprintf(filename, sizeof(filename), "%s.smk", sequenceList[id]);
+	filename = Common::String::format("%s.smk", sequenceList[id]);
 
 	if (Common::File::exists(filename)) {
-		Graphics::SmackerDecoder *smkDecoder = new Graphics::SmackerDecoder(snd);
-		return new MoviePlayer(vm, textMan, snd, system, bgSoundHandle, smkDecoder, kVideoDecoderSMK);
+		Video::SmackerDecoder *smkDecoder = new Video::SmackerDecoder(snd);
+		return new MoviePlayer(vm, textMan, resMan, snd, system, bgSoundHandle, smkDecoder, kVideoDecoderSMK);
 	}
 
-	snprintf(filename, sizeof(filename), "%s.dxa", sequenceList[id]);
+	filename = Common::String::format("%s.dxa", sequenceList[id]);
 
 	if (Common::File::exists(filename)) {
 #ifdef USE_ZLIB
 		DXADecoderWithSound *dxaDecoder = new DXADecoderWithSound(snd, bgSoundHandle);
-		return new MoviePlayer(vm, textMan, snd, system, bgSoundHandle, dxaDecoder, kVideoDecoderDXA);
+		return new MoviePlayer(vm, textMan, resMan, snd, system, bgSoundHandle, dxaDecoder, kVideoDecoderDXA);
 #else
-		GUI::MessageDialog dialog("DXA cutscenes found but ScummVM has been built without zlib support", "OK");
+		GUI::MessageDialog dialog(_("DXA cutscenes found but ScummVM has been built without zlib support"), _("OK"));
 		dialog.runModal();
 		return NULL;
 #endif
 	}
 
 	// Old MPEG2 cutscenes
-	snprintf(filename, sizeof(filename), "%s.mp2", sequenceList[id]);
+	filename = Common::String::format("%s.mp2", sequenceList[id]);
 
 	if (Common::File::exists(filename)) {
-		GUI::MessageDialog dialog("MPEG2 cutscenes are no longer supported", "OK");
+		GUI::MessageDialog dialog(_("MPEG2 cutscenes are no longer supported"), _("OK"));
 		dialog.runModal();
 		return NULL;
 	}
 
-	sprintf(buf, "Cutscene '%s' not found", sequenceList[id]);
-	GUI::MessageDialog dialog(buf, "OK");
+	Common::String buf = Common::String::format(_("Cutscene '%s' not found"), sequenceList[id]);
+	GUI::MessageDialog dialog(buf, _("OK"));
 	dialog.runModal();
 
 	return NULL;
