@@ -20,9 +20,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
  */
 
 
@@ -480,6 +477,8 @@ void Widget::createSurfaceImage(int state, uint32 res, int x, int y, uint32 pc)
 
 	// Points to just after frame header, ie. start of sprite data
 	_sprites[state].data = frame + FrameHeader::size();
+	_sprites[state].colorTable = colTablePtr;
+	_sprites[state].isText = false;
 
 	_vm->_screen->createSurface(&_sprites[state], &_surfaces[state]._surface);
 	_surfaces[state]._original = true;
@@ -621,7 +620,7 @@ public:
 
 	// The sound mute switches have 0 as their "down" state and 1 as
 	// their "up" state, so this function is needed to get consistent
-	// behaviour.
+	// behavior.
 
 	void reverseStates() {
 		_upState = 1;
