@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 /*
@@ -251,7 +248,7 @@ VectorImage::VectorImage(const byte *pFileData, uint fileSize, bool &success, co
 	}
 
 	// readout SWF size
-	Common::Rect movieRect = flashRectToBSRect(bs);
+	flashRectToBSRect(bs);
 
 	// Get frame rate and frame count
 	/* uint32 frameRate = */
@@ -324,6 +321,8 @@ ArtBpath *VectorImage::storeBez(ArtBpath *bez, int lineStyle, int fillStyle0, in
 	bez[*bezNodes].code = ART_END;
 
 	ArtBpath *bez1 = art_new(ArtBpath, *bezNodes + 1);
+	if (!bez1)
+		error("[VectorImage::storeBez] Cannot allocate memory");
 
 	for (int i = 0; i <= *bezNodes; i++)
 		bez1[i] = bez[i];
