@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/detection.cpp $
- * $Id: detection.cpp 49788 2010-06-15 10:59:23Z sev $
  */
 
 #include "common/system.h"
@@ -82,30 +79,18 @@ static const ADGameDescription teenAgentGameDescriptions[] = {
 	AD_TABLE_END_MARKER,
 };
 
-static const ADParams detectionParams = {
-	(const byte *)teenAgentGameDescriptions,
-	sizeof(ADGameDescription),
-	5000,
-	teenAgentGames,
-	0,
-	"teenagent",
-	0,
-	0,
-	Common::GUIO_NONE,
-	1,
-	0
+enum {
+	MAX_SAVES = 20
 };
 
-#define MAX_SAVES 20
-
-
 class TeenAgentMetaEngine : public AdvancedMetaEngine {
 public:
-	TeenAgentMetaEngine() : AdvancedMetaEngine(detectionParams) {
+	TeenAgentMetaEngine() : AdvancedMetaEngine(teenAgentGameDescriptions, sizeof(ADGameDescription), teenAgentGames) {
+		_singleid = "teenagent";
 	}
 
 	virtual const char *getName() const {
-		return "Teen Agent Engine";
+		return "TeenAgent";
 	}
 
 	virtual const char *getOriginalCopyright() const {
@@ -132,12 +117,8 @@ public:
 		return desc != 0;
 	}
 
-//	virtual const ADGameDescription *fallbackDetect(const Common::FSList &fslist) const {
-//		return 0;
-//	}
-
 	static Common::String generateGameStateFileName(const char *target, int slot) {
-		return Common::String::printf("%s.%02d", target, slot);
+		return Common::String::format("%s.%02d", target, slot);
 	}
 
 	virtual SaveStateList listSaves(const char *target) const {
@@ -196,9 +177,8 @@ public:
 		ssd.setDeletableFlag(true);
 
 		//checking for the thumbnail
-		Common::ScopedPtr<Graphics::Surface> thumb(new Graphics::Surface);
-		if (Graphics::loadThumbnail(*in, *thumb))
-			ssd.setThumbnail(thumb.release());
+		if (Graphics::Surface *const thumb = Graphics::loadThumbnail(*in))
+			ssd.setThumbnail(thumb);
 
 		return ssd;
 	}
