@@ -17,15 +17,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/font.cpp $
- * $Id: font.cpp 48340 2010-03-20 20:37:36Z megath $
  */
 
 #include "teenagent/font.h"
 #include "teenagent/pack.h"
+#include "common/debug.h"
+#include "common/endian.h"
 #include "common/stream.h"
+#include "common/textconsole.h"
 #include "common/ptr.h"
+#include "graphics/surface.h"
 
 namespace TeenAgent {
 
