@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/teenagent/segment.cpp $
- * $Id: segment.cpp 43954 2009-09-05 08:16:35Z megath $
  */
 
 #include "teenagent/segment.h"
+#include "common/textconsole.h"
 #include "common/util.h"
 
 namespace TeenAgent {
