@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
  */
 
 #ifndef TESTBED_SOUND_H
@@ -72,10 +69,6 @@ public:
 	const char *getDescription() const {
 		return "Sound Subsystem";
 	}
-
-private:
-	bool _isTestDataFound;
-
 };
 
 } // End of namespace Testbed
