@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/actors.cpp $
- * $Id: actors.cpp 50924 2010-07-16 03:14:03Z eriktorbjorn $
- *
  * Handles things to do with actors, delegates much moving actor stuff.
  */
 
@@ -44,6 +41,7 @@
 #include "tinsel/tinsel.h"
 #include "tinsel/token.h"
 
+#include "common/textconsole.h"
 #include "common/util.h"
 
 namespace Tinsel {
@@ -79,6 +77,8 @@ struct T2_ACTOR_STRUC {
 
 #define MAX_REELS 6
 
+// FIXME: Avoid non-const global vars
+
 static int LeadActorId = 0;		// The lead actor
 
 static int NumActors = 0;	// The total number of actors in the game
@@ -106,7 +106,7 @@ struct ACTORINFO {
 	bool		bEscOn;
 	int			escEvent;
 
-	COLORREF	textColour;	// Text colour
+	COLORREF	textColor;	// Text color
 
 	SCNHANDLE	playFilm;	// revert to this after talks
 	SCNHANDLE	talkFilm;	// this be deleted in the future!
@@ -138,7 +138,7 @@ typedef TAGACTOR *PTAGACTOR;
 
 static ACTORINFO *actorInfo = NULL;
 
-static COLORREF defaultColour = 0;		// Text colour
+static COLORREF defaultColor = 0;		// Text color
 
 static bool bActorsOn = false;
 
@@ -199,6 +199,10 @@ void RegisterActors(int num) {
 void FreeActors() {
 	free(actorInfo);
 	actorInfo = NULL;
+	if (TinselV2) {
+		free(zFactors);
+		zFactors = NULL;
+	}
 }
 
 /**
@@ -310,10 +314,19 @@ static void ActorRestoredProcess(CORO_PARAM, const void *param) {
 
 	// get the stuff copied to process when it was created
 	const RATP_INIT *r = (const RATP_INIT *)param;
+	bool isSavegame = r->pic->resumeState == RES_SAVEGAME;
 
 	CORO_BEGIN_CODE(_ctx);
 
 	_ctx->pic = RestoreInterpretContext(r->pic);
+	
+	// The newly added check here specially sets the process to RES_NOT when loading a savegame. 
+	// This is needed particularly for the Psychiatrist scene in Discworld 1 - otherwise Rincewind
+	// can't go upstairs without leaving the building and returning.  If this patch causes problems
+	// in other scenes, an added check for the hCode == 1174490602 could be added.
+	if (isSavegame && TinselV1)
+		_ctx->pic->resumeState = RES_NOT;
+
 	CORO_INVOKE_1(Interpret, _ctx->pic);
 
 	// If it gets here, actor's code has run to completion
@@ -322,8 +335,10 @@ static void ActorRestoredProcess(CORO_PARAM, const void *param) {
 	CORO_END_CODE;
 }
 
-void RestoreActorProcess(int id, INT_CONTEXT *pic) {
+void RestoreActorProcess(int id, INT_CONTEXT *pic, bool savegameFlag) {
 	RATP_INIT r = { pic, id };
+	if (savegameFlag)
+		pic->resumeState = RES_SAVEGAME;
 
 	g_scheduler->createProcess(PID_TCODE, ActorRestoredProcess, &r, sizeof(r));
 }
@@ -430,7 +445,7 @@ void StartTaggedActors(SCNHANDLE ah, int numActors, bool bRunScript) {
 		memset(taggedActors, 0, sizeof(taggedActors));
 		numTaggedActors = numActors;
 	} else {
-		// Only actors with code blocks got (x, y) re-initialised, so...
+		// Only actors with code blocks got (x, y) re-initialized, so...
 		for (i = 0; i < NumActors; i++) {
 			actorInfo[i].x = actorInfo[i].y = 0;
 			actorInfo[i].mtype = 0;
@@ -473,13 +488,13 @@ void DropActors() {
 
 	for (int i = 0; i < NumActors; i++) {
 		if (TinselV2) {
-			// Save text colour
-			COLORREF tColour = actorInfo[i].textColour;
+			// Save text color
+			COLORREF tColor = actorInfo[i].textColor;
 
 			memset(&actorInfo[i], 0, sizeof(ACTORINFO));
 
-			// Restor text colour
-			actorInfo[i].textColour = tColour;
+			// Restor text color
+			actorInfo[i].textColor = tColor;
 
 			// Clear extra arrays
 			memset(zFactors, 0, NumActors);
@@ -625,7 +640,7 @@ int NextTaggedActor() {
 	PMOVER	pActor;
 	bool	hid;
 
-	do {
+	while (ti < NumActors) {
 		if (actorInfo[ti].tagged) {
 			pActor = GetMover(ti+1);
 			if (pActor)
@@ -637,7 +652,8 @@ int NextTaggedActor() {
 				return ++ti;
 			}
 		}
-	} while (++ti < NumActors);
+		++ti;
+	}
 
 	return 0;
 }
@@ -1271,7 +1287,7 @@ void SetMoverZ(PMOVER pMover, int y, int32 zFactor) {
 
 /**
  * Stores actor's attributes.
- * Currently only the speech colours.
+ * Currently only the speech colors.
  */
 void storeActorAttr(int ano, int r1, int g1, int b1) {
 	assert((ano > 0 && ano <= NumActors) || ano == -1); // illegal actor number
@@ -1281,36 +1297,36 @@ void storeActorAttr(int ano, int r1, int g1, int b1) {
 	if (b1 > MAX_INTENSITY)	b1 = MAX_INTENSITY;	// }
 
 	if (ano == -1)
-		defaultColour = TINSEL_RGB(r1, g1, b1);
+		defaultColor = TINSEL_RGB(r1, g1, b1);
 	else
-		actorInfo[ano - 1].textColour = TINSEL_RGB(r1, g1, b1);
+		actorInfo[ano - 1].textColor = TINSEL_RGB(r1, g1, b1);
 }
 
 /**
- * Called from ActorRGB() - Stores actor's speech colour.
+ * Called from ActorRGB() - Stores actor's speech color.
  */
 
-void SetActorRGB(int ano, COLORREF colour) {
+void SetActorRGB(int ano, COLORREF color) {
 	assert(ano >= 0 && ano <= NumActors);
 
 	if (ano)
-		actorInfo[ano - 1].textColour = TO_LE_32(colour);
+		actorInfo[ano - 1].textColor = TO_LE_32(color);
 	else
-		defaultColour = TO_LE_32(colour);
+		defaultColor = TO_LE_32(color);
 }
 
 /**
- * Get the actor's stored speech colour.
+ * Get the actor's stored speech color.
  * @param ano			Actor Id
  */
 COLORREF GetActorRGB(int ano) {
 	// Not used in JAPAN version
 	assert((ano >= -1) && (ano <= NumActors)); // illegal actor number
 
-	if ((ano == -1) || !actorInfo[ano - 1].textColour)
-		return defaultColour;
+	if ((ano == -1) || !actorInfo[ano - 1].textColor)
+		return defaultColor;
 	else
-		return actorInfo[ano - 1].textColour;
+		return actorInfo[ano - 1].textColor;
 }
 
 /**
