@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "base/plugins.h"
@@ -66,7 +63,7 @@ uint16 TinselEngine::getVersion() const {
 	return _gameDescription->version;
 }
 
-}
+} // End of namespace Tinsel
 
 static const PlainGameDescriptor tinselGames[] = {
 	{"tinsel", "Tinsel engine game"},
@@ -77,37 +74,14 @@ static const PlainGameDescriptor tinselGames[] = {
 
 #include "tinsel/detection_tables.h"
 
-static const ADParams detectionParams = {
-	// Pointer to ADGameDescription or its superset structure
-	(const byte *)Tinsel::gameDescriptions,
-	// Size of that superset structure
-	sizeof(Tinsel::TinselGameDescription),
-	// Number of bytes to compute MD5 sum for
-	5000,
-	// List of all engine targets
-	tinselGames,
-	// Structure for autoupgrading obsolete targets
-	0,
-	// Name of single gameid (optional)
-	"tinsel",
-	// List of files for file-based fallback detection (optional)
-	0,
-	// Flags
-	0,
-	// Additional GUI options (for every game}
-	Common::GUIO_NONE,
-	// Maximum directory depth
-	1,
-	// List of directory globs
-	0
-};
-
 class TinselMetaEngine : public AdvancedMetaEngine {
 public:
-	TinselMetaEngine() : AdvancedMetaEngine(detectionParams) {}
+	TinselMetaEngine() : AdvancedMetaEngine(Tinsel::gameDescriptions, sizeof(Tinsel::TinselGameDescription), tinselGames) {
+		_singleid = "tinsel";
+	}
 
 	virtual const char *getName() const {
-		return "Tinsel Engine";
+		return "Tinsel";
 	}
 
 	virtual const char *getOriginalCopyright() const {
@@ -115,7 +89,7 @@ public:
 	}
 
 	virtual bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const;
-	const ADGameDescription *fallbackDetect(const Common::FSList &fslist) const;
+	const ADGameDescription *fallbackDetect(const FileMap &allFiles, const Common::FSList &fslist) const;
 
 	virtual bool hasFeature(MetaEngineFeature f) const;
 	virtual SaveStateList listSaves(const char *target) const;
@@ -201,7 +175,7 @@ typedef Common::Array<const ADGameDescription*> ADGameDescList;
  * Fallback detection scans the list of Discworld 2 targets to see if it can detect an installation
  * where the files haven't been renamed (i.e. don't have the '1' just before the extension)
  */
-const ADGameDescription *TinselMetaEngine::fallbackDetect(const Common::FSList &fslist) const {
+const ADGameDescription *TinselMetaEngine::fallbackDetect(const FileMap &allFilesXXX, const Common::FSList &fslist) const {
 	Common::String extra;
 	FileMap allFiles;
 	SizeMD5Map filesSizeMD5;
@@ -268,7 +242,7 @@ const ADGameDescription *TinselMetaEngine::fallbackDetect(const Common::FSList &
 
 				if (testFile.open(allFiles[fname])) {
 					tmp.size = (int32)testFile.size();
-					tmp.md5 = computeStreamMD5AsString(testFile, detectionParams.md5Bytes);
+					tmp.md5 = computeStreamMD5AsString(testFile, _md5Bytes);
 				} else {
 					tmp.size = -1;
 				}
@@ -288,11 +262,6 @@ const ADGameDescription *TinselMetaEngine::fallbackDetect(const Common::FSList &
 
 		bool fileMissing = false;
 
-		if ((detectionParams.flags & kADFlagUseExtraAsHint) && !extra.empty() && g->desc.extra != extra)
-			continue;
-
-		bool allFilesPresent = true;
-
 		// Try to match all files for this game
 		for (fileDesc = g->desc.filesDescriptions; fileDesc->fileName; fileDesc++) {
 			// Get the next filename, stripping off any '1' suffix character
@@ -310,7 +279,6 @@ const ADGameDescription *TinselMetaEngine::fallbackDetect(const Common::FSList &
 
 			if (!filesSizeMD5.contains(tstr)) {
 				fileMissing = true;
-				allFilesPresent = false;
 				break;
 			}
 
@@ -354,9 +322,21 @@ int TinselMetaEngine::getMaximumSaveSlot() const { return 99; }
 
 void TinselMetaEngine::removeSaveState(const char *target, int slot) const {
 	Tinsel::setNeedLoad();
-	Tinsel::getList(g_system->getSavefileManager(), target);
+	// Same issue here as with loadGameState(): we need the physical savegame
+	// slot. Refer to bug #3387551.
+	int listSlot = -1;
+	const int numStates = Tinsel::getList(g_system->getSavefileManager(), target);
+	for (int i = 0; i < numStates; ++i) {
+		const char *fileName = Tinsel::ListEntry(i, Tinsel::LE_NAME);
+		const int saveSlot = atoi(fileName + strlen(fileName) - 3);
 
-	g_system->getSavefileManager()->removeSavefile(Tinsel::ListEntry(slot, Tinsel::LE_NAME));
+		if (saveSlot == slot) {
+			listSlot = i;
+			break;
+		}
+	}
+
+	g_system->getSavefileManager()->removeSavefile(Tinsel::ListEntry(listSlot, Tinsel::LE_NAME));
 	Tinsel::setNeedLoad();
 	Tinsel::getList(g_system->getSavefileManager(), target);
 }
@@ -413,7 +393,7 @@ Common::Error TinselEngine::loadGameState(int slot) {
 }
 
 #if 0
-Common::Error TinselEngine::saveGameState(int slot, const char *desc) {
+Common::Error TinselEngine::saveGameState(int slot, const Common::String &desc) {
 	Common::String saveName = _vm->getSavegameFilename((int16)(slot + 1));
 	char saveDesc[SG_DESC_LEN];
 	Common::strlcpy(saveDesc, desc, SG_DESC_LEN);
