@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/font.cpp $
- * $Id: font.cpp 45616 2009-11-02 21:54:57Z fingolfin $
  */
 
 #include "tinsel/actors.h"
@@ -35,6 +32,8 @@ namespace Tinsel {
 
 //----------------- LOCAL GLOBAL DATA --------------------
 
+// FIXME: Avoid non-const global vars
+
 static char tBuffer[TBUFSZ];
 
 static SCNHANDLE hTagFont = 0, hTalkFont = 0;
@@ -116,10 +115,10 @@ void FettleFontPal(SCNHANDLE fontPal) {
 	else
 		pImg->hImgPal = 0;
 
-	if (TinselV2 && SysVar(SV_TAGCOLOUR)) {
-		static COLORREF c = GetActorRGB(-1);
+	if (TinselV2 && SysVar(SV_TAGCOLOR)) {
+		const COLORREF c = GetActorRGB(-1);
 		SetTagColorRef(c);
-		UpdateDACqueue(SysVar(SV_TAGCOLOUR), 1, &c);
+		UpdateDACqueue(SysVar(SV_TAGCOLOR), c);
 	}
 }
 
