@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/heapmem.cpp $
- * $Id: heapmem.cpp 45616 2009-11-02 21:54:57Z fingolfin $
- *
  * This file contains the handle based Memory Manager code.
  */
 
@@ -57,6 +54,9 @@ struct MEM_NODE {
 // If the memory is not enough, the engine throws an "Out of memory" error in handle.cpp inside LockMem()
 static const uint32 MemoryPoolSize[3] = {5 * 1024 * 1024, 5 * 1024 * 1024, 10 * 1024 * 1024};
 
+// FIXME: Avoid non-const global vars
+
+
 // list of all memory nodes
 MEM_NODE mnodeList[NUM_MNODES];
 
@@ -94,13 +94,13 @@ static void MemoryStats() {
 		}
 	}
 
-	printf("%d nodes used, %d alloced, %d locked; %d bytes locked, %d used\n",
+	debug("%d nodes used, %d alloced, %d locked; %d bytes locked, %d used",
 			usedNodes, allocedNodes, lockedNodes, lockedSize, totalSize);
 }
 #endif
 
 /**
- * Initialises the memory manager.
+ * Initializes the memory manager.
  */
 void MemoryInit() {
 	// place first node on free list
@@ -133,7 +133,7 @@ void MemoryInit() {
 }
 
 /**
- * Deinitialises the memory manager.
+ * Deinitializes the memory manager.
  */
 void MemoryDeinit() {
 	const MEM_NODE *pHeap = &heapSentinel;
