@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/saveload.cpp $
- * $Id: saveload.cpp 49447 2010-06-06 01:12:41Z dreammaster $
- *
  * Save and restore scene and game.
  */
 
@@ -36,6 +33,8 @@
 
 #include "common/serializer.h"
 #include "common/savefile.h"
+#include "common/textconsole.h"
+#include "common/translation.h"
 
 #include "gui/message.h"
 
@@ -77,9 +76,6 @@ SRSTATE SRstate = SR_IDLE;
 // in DOS_DW.C
 extern void syncSCdata(Common::Serializer &s);
 
-// in DOS_MAIN.C
-//char HardDriveLetter();
-
 // in PCODE.C
 extern void syncGlobInfo(Common::Serializer &s);
 
@@ -88,6 +84,8 @@ extern void syncPolyInfo(Common::Serializer &s);
 
 extern int sceneCtr;
 
+extern bool ASceneIsSaved;
+
 //----------------- LOCAL DEFINES --------------------
 
 struct SaveGameHeader {
@@ -106,8 +104,22 @@ enum {
 
 #define SAVEGAME_ID (TinselV2 ? (uint32)DW2_SAVEGAME_ID : (uint32)DW1_SAVEGAME_ID)
 
+enum {
+	// FIXME: Save file names in ScummVM can be longer than 8.3, overflowing the
+	// name field in savedFiles. Raising it to 256 as a preliminary fix.
+	FNAMELEN	= 256 // 8.3
+};
+
+struct SFILES {
+	char	name[FNAMELEN];
+	char	desc[SG_DESC_LEN + 2];
+	TimeDate dateTime;
+};
+
 //----------------- LOCAL GLOBAL DATA --------------------
 
+// FIXME: Avoid non-const global vars
+
 static int	numSfiles = 0;
 static SFILES	savedFiles[MAX_SAVED_FILES];
 
@@ -144,8 +156,15 @@ static bool syncSaveGameHeader(Common::Serializer &s, SaveGameHeader &hdr) {
 	syncTime(s, hdr.dateTime);
 
 	int tmp = hdr.size - s.bytesSynced();
+
+	// NOTE: We can't use SAVEGAME_ID here when attempting to remove a saved game from the launcher,
+	// as there is no TinselEngine initialized then. This means that we can't check if this is a DW1
+	// or DW2 savegame in this case, but it doesn't really matter, as the saved game is about to be
+	// deleted anyway. Refer to bug #3387551.
+	bool correctID = _vm ? (hdr.id == SAVEGAME_ID) : (hdr.id == DW1_SAVEGAME_ID || hdr.id == DW2_SAVEGAME_ID);
+
 	// Perform sanity check
-	if (tmp < 0 || hdr.id != SAVEGAME_ID || hdr.ver > CURRENT_VER || hdr.size > 1024)
+	if (tmp < 0 || !correctID || hdr.ver > CURRENT_VER || hdr.size > 1024)
 		return false;
 	// Skip over any extra bytes
 	s.skip(tmp);
@@ -153,8 +172,7 @@ static bool syncSaveGameHeader(Common::Serializer &s, SaveGameHeader &hdr) {
 }
 
 static void syncSavedMover(Common::Serializer &s, SAVED_MOVER &sm) {
-	SCNHANDLE *pList[3] = { (SCNHANDLE *)&sm.walkReels,
-		(SCNHANDLE *)&sm.standReels, (SCNHANDLE *)&sm.talkReels };
+	int i, j;
 
 	s.syncAsUint32LE(sm.bActive);
 	s.syncAsSint32LE(sm.actorID);
@@ -162,17 +180,27 @@ static void syncSavedMover(Common::Serializer &s, SAVED_MOVER &sm) {
 	s.syncAsSint32LE(sm.objY);
 	s.syncAsUint32LE(sm.hLastfilm);
 
-	for (int pIndex = 0; pIndex < 3; ++pIndex) {
-		SCNHANDLE *p = pList[pIndex];
-		for (int i = 0; i < TOTAL_SCALES * 4; ++i)
-			s.syncAsUint32LE(*p++);
-	}
+	// Sync walk reels
+	for (i = 0; i < TOTAL_SCALES; ++i)
+		for (j = 0; j < 4; ++j)
+			s.syncAsUint32LE(sm.walkReels[i][j]);
+
+	// Sync stand reels
+	for (i = 0; i < TOTAL_SCALES; ++i)
+		for (j = 0; j < 4; ++j)
+			s.syncAsUint32LE(sm.standReels[i][j]);
+
+	// Sync talk reels
+	for (i = 0; i < TOTAL_SCALES; ++i)
+		for (j = 0; j < 4; ++j)
+			s.syncAsUint32LE(sm.talkReels[i][j]);
+
 
 	if (TinselV2) {
 		s.syncAsByte(sm.bHidden);
 
 		s.syncAsSint32LE(sm.brightness);
-		s.syncAsSint32LE(sm.startColour);
+		s.syncAsSint32LE(sm.startColor);
 		s.syncAsSint32LE(sm.paletteLength);
 	}
 }
@@ -269,32 +297,6 @@ static void syncSavedData(Common::Serializer &s, SAVED_DATA &sd) {
 	}
 }
 
-
-/**
- * Called when saving a game to a new file.
- * Generates a new, unique, filename.
- */
-static char *NewName() {
-	static char result[FNAMELEN];
-	int	i;
-	int	ano = 1;	// Allocated number
-
-	while (1) {
-		Common::String fname = _vm->getSavegameFilename(ano);
-		strcpy(result, fname.c_str());
-
-		for (i = 0; i < numSfiles; i++)
-			if (!strcmp(savedFiles[i].name, result))
-				break;
-
-		if (i == numSfiles)
-			break;
-		ano++;
-	}
-
-	return result;
-}
-
 /**
  * Compare two TimeDate structs to see which one was earlier.
  * Returns 0 if they are equal, a negative value if a is lower / first, and
@@ -318,9 +320,9 @@ static int cmpTimeDate(const TimeDate &a, const TimeDate &b) {
 }
 
 /**
- * Interrogate the current DOS directory for saved game files.
+ * Compute a list of all available saved game files.
  * Store the file details, ordered by time, in savedFiles[] and return
- * the number of files found).
+ * the number of files found.
  */
 int getList(Common::SaveFileManager *saveFileMan, const Common::String &target) {
 	// No change since last call?
@@ -438,6 +440,11 @@ static void DoSync(Common::Serializer &s) {
 		SAVED_DATA *sdPtr = SaveSceneSsData;
 		for (int i = 0; i < *SaveSceneSsCount; ++i, ++sdPtr)
 			syncSavedData(s, *sdPtr);
+
+		// Flag that there is a saved scene to return to. Note that in this context 'saved scene'
+		// is a stored scene to return to from another scene, such as from the Summoning Book close-up
+		// in Discworld 1 to whatever scene Rincewind was in prior to that
+		ASceneIsSaved = true;
 	}
 
 	if (!TinselV2)
@@ -472,7 +479,7 @@ static bool DoRestore() {
 	delete f;
 
 	if (failed) {
-		GUI::MessageDialog dialog("Failed to load game state from file.");
+		GUI::MessageDialog dialog(_("Failed to load game state from file."));
 		dialog.runModal();
 	}
 
@@ -484,19 +491,37 @@ static bool DoRestore() {
  */
 static void DoSave() {
 	Common::OutSaveFile *f;
-	const char *fname;
+	char tmpName[FNAMELEN];
 
 	// Next getList() must do its stuff again
 	NeedLoad = true;
 
-	if (SaveSceneName == NULL)
-		SaveSceneName = NewName();
+	if (SaveSceneName == NULL) {
+		// Generate a new unique save name
+		int	i;
+		int	ano = 1;	// Allocated number
+
+		while (1) {
+			Common::String fname = _vm->getSavegameFilename(ano);
+			strcpy(tmpName, fname.c_str());
+
+			for (i = 0; i < numSfiles; i++)
+				if (!strcmp(savedFiles[i].name, tmpName))
+					break;
+
+			if (i == numSfiles)
+				break;
+			ano++;
+		}
+
+		SaveSceneName = tmpName;
+	}
+
+
 	if (SaveSceneDesc[0] == 0)
 		SaveSceneDesc = "unnamed";
 
-	fname = SaveSceneName;
-
-	f = _vm->getSaveFileMan()->openForSaving(fname);
+	f = _vm->getSaveFileMan()->openForSaving(SaveSceneName);
 	Common::Serializer s(0, f);
 
 	if (f == NULL)
@@ -523,14 +548,16 @@ static void DoSave() {
 
 	f->finalize();
 	delete f;
+	SaveSceneName = NULL;	// Invalidate save name
 	return;
 
 save_failure:
 	if (f) {
 		delete f;
-		_vm->getSaveFileMan()->removeSavefile(fname);
+		_vm->getSaveFileMan()->removeSavefile(SaveSceneName);
+		SaveSceneName = NULL;	// Invalidate save name
 	}
-	GUI::MessageDialog dialog("Failed to save game state to file.");
+	GUI::MessageDialog dialog(_("Failed to save game state to file."));
 	dialog.runModal();
 }
 
