@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  * Save and restore scene and game.
  */
 
@@ -86,7 +83,7 @@ extern SRSTATE SRstate;
 
 // FIXME: Avoid non-const global vars
 
-static bool ASceneIsSaved = false;
+bool ASceneIsSaved = false;
 
 static int savedSceneCount = 0;
 
@@ -153,14 +150,14 @@ void DoRestoreScene(SAVED_DATA *sd, bool bFadeOut) {
 		RestoreSceneCount = RS_COUNT;	// Set restore scene count
 }
 
-void InitialiseSaveScenes() {
+void InitializeSaveScenes() {
 	if (ssData == NULL) {
 		ssData = (SAVED_DATA *)calloc(MAX_NEST, sizeof(SAVED_DATA));
 		if (ssData == NULL) {
 			error("Cannot allocate memory for scene changes");
 		}
 	} else {
-		// Re-initialise - no scenes saved
+		// Re-initialize - no scenes saved
 		savedSceneCount = 0;
 	}
 }
@@ -284,7 +281,7 @@ void ResumeInterprets() {
 			if (TinselV2)
 				RestoreProcess(&rsd->SavedICInfo[i]);
 			else
-				RestoreActorProcess(rsd->SavedICInfo[i].idActor, &rsd->SavedICInfo[i]);
+				RestoreActorProcess(rsd->SavedICInfo[i].idActor, &rsd->SavedICInfo[i], rsd == &sgData);
 			break;
 
 		case GS_POLYGON:
