@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/sched.cpp $
- * $Id: sched.cpp 48534 2010-04-05 07:22:34Z lordhoto $
- *
  * Process scheduler.
  */
 
@@ -30,6 +27,7 @@
 #include "tinsel/polygons.h"
 #include "tinsel/sched.h"
 
+#include "common/textconsole.h"
 #include "common/util.h"
 
 namespace Tinsel {
@@ -45,10 +43,10 @@ struct PROCESS_STRUC {
 
 #include "common/pack-end.h"	// END STRUCT PACKING
 
-CoroContext nullContext = NULL;
-
 //----------------- LOCAL GLOBAL DATA --------------------
 
+// FIXME: Avoid non-const global vars
+
 static uint32 numSceneProcess;
 static SCNHANDLE hSceneProcess;
 
@@ -72,11 +70,20 @@ Scheduler::Scheduler() {
 
 	active = new PROCESS;
 	active->pPrevious = NULL;
+	active->pNext = NULL;
 
 	g_scheduler = this;	// FIXME HACK
 }
 
 Scheduler::~Scheduler() {
+	// Kill all running processes (i.e. free memory allocated for their state).
+	PROCESS *pProc = active->pNext;
+	while (pProc != NULL) {
+		delete pProc->state;
+		pProc->state = 0;
+		pProc = pProc->pNext;
+	}
+
 	free(processList);
 	processList = NULL;
 
@@ -107,6 +114,14 @@ void Scheduler::reset() {
 		memset(processList, 'S', MAX_PROCESSES * sizeof(PROCESS));
 	}
 
+	// Kill all running processes (i.e. free memory allocated for their state).
+	PROCESS *pProc = active->pNext;
+	while (pProc != NULL) {
+		delete pProc->state;
+		pProc->state = 0;
+		pProc = pProc->pNext;
+	}
+
 	// no active processes
 	pCurrent = active->pNext = NULL;
 
@@ -126,7 +141,7 @@ void Scheduler::reset() {
  * Shows the maximum number of process used at once.
  */
 void Scheduler::printStats() {
-	printf("%i process of %i used.\n", maxProcs, NUM_PROCESS);
+	debug("%i process of %i used", maxProcs, NUM_PROCESS);
 }
 #endif
 
@@ -280,7 +295,8 @@ void Scheduler::giveWay(PPROCESS pReSchedProc) {
 	PPROCESS pEnd;
 
 	// Find the last process in the list.
-	for (pEnd = pCurrent; pEnd->pNext != NULL; pEnd = pEnd->pNext) ;
+	for (pEnd = pCurrent; pEnd->pNext != NULL; pEnd = pEnd->pNext)
+		;
 	assert(pEnd->pNext == NULL);
 
 
@@ -392,6 +408,7 @@ void Scheduler::killProcess(PROCESS *pKillProc) {
 		(pRCfunction)(pKillProc);
 
 	delete pKillProc->state;
+	pKillProc->state = 0;
 
 	// Take the process out of the active chain list
 	pKillProc->pPrevious->pNext = pKillProc->pNext;
@@ -458,6 +475,7 @@ int Scheduler::killMatchingProcess(int pidKill, int pidMask) {
 					(pRCfunction)(pProc);
 
 				delete pProc->state;
+				pProc->state = 0;
 
 				// make prev point to next to unlink pProc
 				pPrev->pNext = pProc->pNext;
@@ -752,6 +770,7 @@ void GlobalProcesses(uint32 numProcess, byte *pProcess) {
  */
 void FreeGlobalProcesses() {
 	delete[] pGlobalProcess;
+	pGlobalProcess = 0;
 	numGlobalProcess = 0;
 }
 
