@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/engines/tinsel/tinsel.h $
- * $Id: tinsel.h 52374 2010-08-25 07:41:35Z sev $
- *
  */
 
 #ifndef TINSEL_H
@@ -34,9 +31,6 @@
 #include "common/random.h"
 #include "common/util.h"
 
-#include "sound/mididrv.h"
-#include "sound/mixer.h"
-
 #include "engines/engine.h"
 #include "tinsel/debugger.h"
 #include "tinsel/graphics.h"
@@ -48,7 +42,7 @@
  *
  * Status of this engine: Complete
  *
- * Supported games:
+ * Games using this engine:
  * - Discworld
  * - Discworld 2: Missing Presumed ...!?
  */
@@ -56,6 +50,7 @@ namespace Tinsel {
 
 class BMVPlayer;
 class Config;
+class MidiDriver;
 class MidiMusicPlayer;
 class PCMMusicPlayer;
 class Scheduler;
@@ -81,7 +76,9 @@ enum TinselGameFeatures {
 	// None of these defined -> 1 language, in ENGLISH.TXT
 	GF_USE_3FLAGS = 1 << 6,	// French, German, Spanish
 	GF_USE_4FLAGS = 1 << 7,	// French, German, Spanish, Italian
-	GF_USE_5FLAGS = 1 << 8	// All 5 flags
+	GF_USE_5FLAGS = 1 << 8,	// All 5 flags
+
+	GF_BIG_ENDIAN = 1 << 9
 };
 
 /**
@@ -123,8 +120,8 @@ typedef bool (*KEYFPTR)(const Common::KeyState &);
 
 #define	SCREEN_WIDTH	(_vm->screen().w)	// PC screen dimensions
 #define	SCREEN_HEIGHT	(_vm->screen().h)
-#define	SCRN_CENTRE_X	((SCREEN_WIDTH  - 1) / 2)	// screen centre x
-#define	SCRN_CENTRE_Y	((SCREEN_HEIGHT - 1) / 2)	// screen centre y
+#define	SCRN_CENTER_X	((SCREEN_WIDTH  - 1) / 2)	// screen center x
+#define	SCRN_CENTER_Y	((SCREEN_HEIGHT - 1) / 2)	// screen center y
 #define UNUSED_LINES	48
 #define EXTRA_UNUSED_LINES	3
 //#define	SCREEN_BOX_HEIGHT1	(SCREEN_HEIGHT - UNUSED_LINES)
@@ -139,6 +136,12 @@ typedef bool (*KEYFPTR)(const Common::KeyState &);
 #define TinselV1 (TinselVersion == TINSEL_V1)
 #define TinselV2 (TinselVersion == TINSEL_V2)
 #define TinselV1PSX (TinselVersion == TINSEL_V1 && _vm->getPlatform() == Common::kPlatformPSX)
+#define TinselV1Mac (TinselVersion == TINSEL_V1 && _vm->getPlatform() == Common::kPlatformMacintosh)
+
+#define IsDemo (_vm->getFeatures() & GF_DEMO)
+
+#define READ_16(v) ((_vm->getFeatures() & GF_BIG_ENDIAN) ? READ_BE_UINT16(v) : READ_LE_UINT16(v))
+#define READ_32(v) ((_vm->getFeatures() & GF_BIG_ENDIAN) ? READ_BE_UINT32(v) : READ_LE_UINT32(v))
 
 // Global reference to the TinselEngine object
 extern TinselEngine *_vm;
@@ -153,9 +156,9 @@ class TinselEngine : public Engine {
 	Console *_console;
 	Scheduler *_scheduler;
 
-	static const char *_sampleIndices[][3];
-	static const char *_sampleFiles[][3];
-	static const char *_textFiles[][3];
+	static const char *const _sampleIndices[][3];
+	static const char *const _sampleFiles[][3];
+	static const char *const _textFiles[][3];
 
 protected:
 
@@ -164,7 +167,7 @@ protected:
 	virtual bool hasFeature(EngineFeature f) const;
 	Common::Error loadGameState(int slot);
 #if 0
-	Common::Error saveGameState(int slot, const char *desc);
+	Common::Error saveGameState(int slot, const Common::String &desc);
 #endif
 	bool canLoadGameStateCurrently();
 #if 0
@@ -183,6 +186,7 @@ public:
 	uint32 getFeatures() const;
 	Common::Language getLanguage() const;
 	uint16 getVersion() const;
+	uint32 getFlags() const;
 	Common::Platform getPlatform() const;
 
 	const char *getSampleIndex(LANGUAGE lang);
@@ -210,9 +214,6 @@ public:
 	RectList _clipRects;
 
 private:
-	//MidiMusicPlayer *_midiMusic;
-	int _musicVolume;
-
 	void NextGameCycle();
 	void CreateConstProcesses();
 	void RestartGame();
