@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "tsage/events.h"
@@ -33,7 +30,7 @@
 #include "graphics/surface.h"
 #include "tsage/globals.h"
 
-namespace tSage {
+namespace TsAGE {
 
 /**
  * Creates a new graphics surface with the specified area of another surface
@@ -123,7 +120,7 @@ GfxSurface surfaceFromRes(const byte *imgData) {
 
 GfxSurface surfaceFromRes(int resNum, int rlbNum, int subNum) {
 	uint size;
-	byte *imgData = _resourceManager->getSubResource(resNum, rlbNum, subNum, &size);
+	byte *imgData = g_resourceManager->getSubResource(resNum, rlbNum, subNum, &size);
 	GfxSurface surface = surfaceFromRes(imgData);
 	DEALLOCATE(imgData);
 
@@ -205,14 +202,14 @@ void Rect::resize(const GfxSurface &surface, int xp, int yp, int percent) {
  * Expands the pane region to contain the specified Rect
  */
 void Rect::expandPanes() {
-	_globals->_paneRegions[0].uniteRect(*this);
-	_globals->_paneRegions[1].uniteRect(*this);
+	g_globals->_paneRegions[0].uniteRect(*this);
+	g_globals->_paneRegions[1].uniteRect(*this);
 }
 
 /**
  * Serialises the given rect
  */
-void Rect::synchronise(Serialiser &s) {
+void Rect::synchronize(Serializer &s) {
 	s.syncAsSint16LE(left);
 	s.syncAsSint16LE(top);
 	s.syncAsSint16LE(right);
@@ -227,6 +224,7 @@ GfxSurface::GfxSurface() : _bounds(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT) {
 	_lockSurfaceCtr = 0;
 	_customSurface = NULL;
 	_screenSurfaceP = NULL;
+	_transColor = -1;
 }
 
 GfxSurface::GfxSurface(const GfxSurface &s) {
@@ -257,8 +255,13 @@ void GfxSurface::setScreenSurface() {
 void GfxSurface::create(int width, int height) {
 	assert((width >= 0) && (height >= 0));
 	_screenSurface = false;
+	if (_customSurface) {
+		_customSurface->free();
+		delete _customSurface;
+	}
 	_customSurface = new Graphics::Surface();
-	_customSurface->create(width, height, 1);
+	_customSurface->create(width, height, Graphics::PixelFormat::createFormatCLUT8());
+	Common::set_to((byte *)_customSurface->pixels, (byte *)_customSurface->pixels + (width * height), 0);
 	_bounds = Rect(0, 0, width, height);
 }
 
@@ -283,7 +286,7 @@ Graphics::Surface GfxSurface::lockSurface() {
 	result.w = _bounds.width();
 	result.h = _bounds.height();
 	result.pitch = src->pitch;
-	result.bytesPerPixel = src->bytesPerPixel;
+	result.format = src->format;
 	result.pixels = src->getBasePtr(_bounds.left, _bounds.top);
 
 	return result;
@@ -301,6 +304,43 @@ void GfxSurface::unlockSurface() {
 	}
 }
 
+void GfxSurface::synchronize(Serializer &s) {
+	assert(!_lockSurfaceCtr);
+	assert(!_screenSurface);
+
+	s.syncAsByte(_disableUpdates);
+	_bounds.synchronize(s);
+	s.syncAsSint16LE(_centroid.x);
+	s.syncAsSint16LE(_centroid.y);
+	s.syncAsSint16LE(_transColor);
+
+	if (s.isSaving()) {
+		// Save contents of the surface
+		if (_customSurface) {
+			s.syncAsSint16LE(_customSurface->w);
+			s.syncAsSint16LE(_customSurface->h);
+			s.syncBytes((byte *)_customSurface->pixels, _customSurface->w * _customSurface->h);
+		} else {
+			int zero = 0;
+			s.syncAsSint16LE(zero);
+			s.syncAsSint16LE(zero);
+		}
+	} else {
+		int w = 0, h = 0;
+		s.syncAsSint16LE(w);
+		s.syncAsSint16LE(h);
+
+		if ((w == 0) || (h == 0)) {
+			if (_customSurface)
+				delete _customSurface;
+			_customSurface = NULL;
+		} else {
+			create(w, h);
+			s.syncBytes((byte *)_customSurface->pixels, w * h);
+		}
+	}
+}
+
 /**
  * Fills a specified rectangle on the surface with the specified color
  *
@@ -332,7 +372,7 @@ GfxSurface &GfxSurface::operator=(const GfxSurface &s) {
 	if (_customSurface) {
 		// Surface owns the internal data, so replicate it so new surface owns it's own
 		_customSurface = new Graphics::Surface();
-		_customSurface->create(s._customSurface->w, s._customSurface->h, 1);
+		_customSurface->create(s._customSurface->w, s._customSurface->h, Graphics::PixelFormat::createFormatCLUT8());
 		const byte *srcP = (const byte *)s._customSurface->getBasePtr(0, 0);
 		byte *destP = (byte *)_customSurface->getBasePtr(0, 0);
 
@@ -368,7 +408,7 @@ bool GfxSurface::displayText(const Common::String &msg, const Common::Point &pt)
 
 	// Write for a  mouse or keypress
 	Event event;
-	while (!_globals->_events.getEvent(event, EVENT_BUTTON_DOWN | EVENT_KEYPRESS) && !_vm->getEventManager()->shouldQuit())
+	while (!g_globals->_events.getEvent(event, EVENT_BUTTON_DOWN | EVENT_KEYPRESS) && !g_vm->shouldQuit())
 		;
 
 	// Restore the display area
@@ -383,15 +423,15 @@ bool GfxSurface::displayText(const Common::String &msg, const Common::Point &pt)
  * Loads a quarter of a screen from a resource
  */
 void GfxSurface::loadScreenSection(Graphics::Surface &dest, int xHalf, int yHalf, int xSection, int ySection) {
-	int screenNum = _globals->_sceneManager._scene->_activeScreenNumber;
+	int screenNum = g_globals->_sceneManager._scene->_activeScreenNumber;
 	Rect updateRect(0, 0, 160, 100);
 	updateRect.translate(xHalf * 160, yHalf * 100);
-	int xHalfCount = (_globals->_sceneManager._scene->_backgroundBounds.right + 159) / 160;
-	int yHalfCount = (_globals->_sceneManager._scene->_backgroundBounds.bottom + 99) / 100;
+	int xHalfCount = (g_globals->_sceneManager._scene->_backgroundBounds.right + 159) / 160;
+	int yHalfCount = (g_globals->_sceneManager._scene->_backgroundBounds.bottom + 99) / 100;
 
 	if (xSection < xHalfCount && ySection < yHalfCount) {
 		int rlbNum = xSection * yHalfCount + ySection;
-		byte *data = _resourceManager->getResource(RES_BITMAP, screenNum, rlbNum);
+		byte *data = g_resourceManager->getResource(RES_BITMAP, screenNum, rlbNum);
 
 		for (int y = 0; y < updateRect.height(); ++y) {
 			byte *pSrc = data + y * 160;
@@ -417,11 +457,11 @@ static int *scaleLine(int size, int srcSize) {
 	int *v = new int[size];
 	Common::set_to(v, &v[size], -1);
 
-	int distCtr = 0;
+	int distCtr = PRECISION_FACTOR / 2;
 	int *destP = v;
 	for (int distIndex = 0; distIndex < srcSize; ++distIndex) {
 		distCtr += scale;
-		while (distCtr >= PRECISION_FACTOR) {
+		while (distCtr > PRECISION_FACTOR) {
 			assert(destP < &v[size]);
 			*destP++ = distIndex;
 			distCtr -= PRECISION_FACTOR;
@@ -484,6 +524,8 @@ static GfxSurface ResizeSurface(GfxSurface &src, int xSize, int ySize, int trans
  */
 void GfxSurface::copyFrom(GfxSurface &src, Rect srcBounds, Rect destBounds, Region *priorityRegion) {
 	GfxSurface srcImage;
+	if (srcBounds.isEmpty())
+		return;
 
 	if (srcBounds == src.getBounds())
 		srcImage = src;
@@ -540,8 +582,8 @@ void GfxSurface::copyFrom(GfxSurface &src, Rect srcBounds, Rect destBounds, Regi
 
 				while (tempSrc < (pSrc + destBounds.width())) {
 					if (!priorityRegion || !priorityRegion->contains(Common::Point(
-							xp + _globals->_sceneManager._scene->_sceneBounds.left,
-							destBounds.top + y + _globals->_sceneManager._scene->_sceneBounds.top))) {
+							xp + g_globals->_sceneManager._scene->_sceneBounds.left,
+							destBounds.top + y + g_globals->_sceneManager._scene->_sceneBounds.top))) {
 						if (*tempSrc != src._transColor)
 							*tempDest = *tempSrc;
 					}
@@ -567,7 +609,7 @@ void GfxSurface::draw(const Common::Point &pt, Rect *rect) {
 		*rect = tempRect;
 	} else {
 		// Draw image
-		_globals->gfxManager().copyFrom(*this, tempRect, NULL);
+		g_globals->gfxManager().copyFrom(*this, tempRect, NULL);
 	}
 }
 
@@ -581,9 +623,12 @@ GfxElement::GfxElement() {
 
 void GfxElement::setDefaults() {
 	_flags = 0;
-	_fontNumber = _globals->_gfxFontNumber;
-	_colors = _globals->_gfxColors;
-	_fontColors = _globals->_fontColors;
+	_fontNumber = g_globals->_gfxFontNumber;
+	_colors = g_globals->_gfxColors;
+	_fontColors = g_globals->_fontColors;
+	_color1 = g_globals->_color1;
+	_color2 = g_globals->_color2;
+	_color3 = g_globals->_color3;
 }
 
 /**
@@ -591,13 +636,13 @@ void GfxElement::setDefaults() {
  */
 void GfxElement::highlight() {
 	// Get a lock on the surface
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 	Graphics::Surface surface = gfxManager.lockSurface();
 
 	// Scan through the contents of the element, switching any occurances of the foreground
 	// color with the background color and vice versa
 	Rect tempRect(_bounds);
-	tempRect.collapse(2, 2);
+	tempRect.collapse(g_globals->_gfxEdgeAdjust - 1, g_globals->_gfxEdgeAdjust - 1);
 
 	for (int yp = tempRect.top; yp < tempRect.bottom; ++yp) {
 		byte *lineP = (byte *)surface.getBasePtr(tempRect.left, yp);
@@ -616,7 +661,7 @@ void GfxElement::highlight() {
  */
 void GfxElement::drawFrame() {
 	// Get a lock on the surface and save the active font
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 	gfxManager.lockSurface();
 
 	uint8 bgColor, fgColor;
@@ -629,7 +674,7 @@ void GfxElement::drawFrame() {
 	}
 
 	Rect tempRect = _bounds;
-	tempRect.collapse(3, 3);
+	tempRect.collapse(g_globals->_gfxEdgeAdjust, g_globals->_gfxEdgeAdjust);
 	tempRect.collapse(-1, -1);
 	gfxManager.fillRect(tempRect, _colors.background);
 
@@ -665,12 +710,18 @@ void GfxElement::drawFrame() {
  * @event Event to process
  */
 bool GfxElement::focusedEvent(Event &event) {
+	Common::Point mousePos = event.mousePos;
 	bool highlightFlag = false;
 
-	while (!_vm->getEventManager()->shouldQuit()) {
+	// HACK: It should use the GfxManager object to figure out the relative
+	// position, but for now this seems like the easiest way.
+	int xOffset = mousePos.x - g_globals->_events._mousePos.x;
+	int yOffset = mousePos.y - g_globals->_events._mousePos.y;
+
+	while (event.eventType != EVENT_BUTTON_UP && !g_vm->shouldQuit()) {
 		g_system->delayMillis(10);
 
-		if (_bounds.contains(event.mousePos)) {
+		if (_bounds.contains(mousePos)) {
 			if (!highlightFlag) {
 				// First highlight call to show the highlight
 				highlightFlag = true;
@@ -682,8 +733,12 @@ bool GfxElement::focusedEvent(Event &event) {
 			highlight();
 		}
 
-		if (_globals->_events.getEvent(event, EVENT_BUTTON_UP))
-			break;
+		if (g_globals->_events.getEvent(event, EVENT_MOUSE_MOVE | EVENT_BUTTON_UP)) {
+			if (event.eventType == EVENT_MOUSE_MOVE) {
+				mousePos.x = event.mousePos.x + xOffset;
+				mousePos.y = event.mousePos.y + yOffset;
+			}
+		}
 	}
 
 	if (highlightFlag) {
@@ -714,7 +769,7 @@ void GfxImage::setDefaults() {
 
 	// Decode the image
 	uint size;
-	byte *imgData = _resourceManager->getSubResource(_resNum, _rlbNum, _cursorNum, &size);
+	byte *imgData = g_resourceManager->getSubResource(_resNum, _rlbNum, _cursorNum, &size);
 	_surface = surfaceFromRes(imgData);
 	DEALLOCATE(imgData);
 
@@ -726,9 +781,9 @@ void GfxImage::setDefaults() {
 
 void GfxImage::draw() {
 	Rect tempRect = _bounds;
-	tempRect.translate(_globals->gfxManager()._topLeft.x, _globals->gfxManager()._topLeft.y);
+	tempRect.translate(g_globals->gfxManager()._topLeft.x, g_globals->gfxManager()._topLeft.y);
 
-	_globals->gfxManager().copyFrom(_surface, tempRect);
+	g_globals->gfxManager().copyFrom(_surface, tempRect);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -750,7 +805,7 @@ void GfxMessage::setDefaults() {
 	GfxElement::setDefaults();
 
 	GfxFontBackup font;
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 	Rect tempRect;
 
 	gfxManager._font.setFontNumber(this->_fontNumber);
@@ -763,12 +818,15 @@ void GfxMessage::setDefaults() {
 
 void GfxMessage::draw() {
 	GfxFontBackup font;
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 
 	// Set the font and color
 	gfxManager.setFillFlag(false);
 	gfxManager._font.setFontNumber(_fontNumber);
-	gfxManager._font._colors.foreground = this->_colors.foreground;
+
+	gfxManager._font._colors.foreground = this->_color1;
+	gfxManager._font._colors2.background = this->_color2;
+	gfxManager._font._colors2.foreground = this->_color3;
 
 	// Display the text
 	gfxManager._font.writeLines(_message.c_str(), _bounds, _textAlign);
@@ -780,7 +838,7 @@ void GfxButton::setDefaults() {
 	GfxElement::setDefaults();
 
 	GfxFontBackup font;
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 	Rect tempRect;
 
 	// Get the string bounds and round up the x end to a multiple of 16
@@ -788,8 +846,10 @@ void GfxButton::setDefaults() {
 	gfxManager._font.getStringBounds(_message.c_str(), tempRect, 240);
 	tempRect.right = ((tempRect.right + 15) / 16) * 16;
 
-	// Set the button bounds to a reduced area
-	tempRect.collapse(-3, -3);
+	// Set the button bounds
+	tempRect.collapse(-g_globals->_gfxEdgeAdjust, -g_globals->_gfxEdgeAdjust);
+	if (g_vm->getFeatures() & GF_CD)
+		--tempRect.top;
 	tempRect.moveTo(_bounds.left, _bounds.top);
 	_bounds = tempRect;
 }
@@ -797,7 +857,7 @@ void GfxButton::setDefaults() {
 void GfxButton::draw() {
 	// Get a lock on the surface and save the active font
 	GfxFontBackup font;
-	GfxManager &gfxManager = _globals->gfxManager();
+	GfxManager &gfxManager = g_globals->gfxManager();
 	gfxManager.lockSurface();
 
 	// Draw a basic frame for the button
@@ -805,11 +865,17 @@ void GfxButton::draw() {
 
 	// Set the font and color
 	gfxManager._font.setFontNumber(_fontNumber);
-	gfxManager._font._colors.foreground = this->_colors.foreground;
+
+	//
+	gfxManager._font._colors.foreground = this->_color1;
+	gfxManager._font._colors2.background = this->_color2;
+	gfxManager._font._colors2.foreground = this->_color3;
 
 	// Display the button's text
 	Rect tempRect(_bounds);
-	tempRect.collapse(3, 3);
+	tempRect.collapse(g_globals->_gfxEdgeAdjust, g_globals->_gfxEdgeAdjust);
+	if (g_vm->getFeatures() & GF_CD)
+		++tempRect.top;
 	gfxManager._font.writeLines(_message.c_str(), tempRect, ALIGN_CENTER);
 
 	gfxManager.unlockSurface();
@@ -829,7 +895,7 @@ bool GfxButton::process(Event &event) {
 
 	case EVENT_KEYPRESS:
 		if (!event.handled && (event.kbd.keycode == _keycode)) {
-			// TODO: Ensure momentary click operation displays
+			// Highlight the button momentarily
 			highlight();
 			g_system->delayMillis(20);
 			highlight();
@@ -859,7 +925,7 @@ GfxDialog::~GfxDialog() {
 void GfxDialog::setDefaults() {
 	GfxElement::setDefaults();
 
-	// Initialise the embedded graphics manager
+	// Initialize the embedded graphics manager
 	_gfxManager.setDefaults();
 
 	// Figure out a rect needed for all the added elements
@@ -870,14 +936,14 @@ void GfxDialog::setDefaults() {
 
 	// Set the dialog boundaries
 	_gfxManager._bounds = tempRect;
-	tempRect.collapse(-6, -6);
+	tempRect.collapse(-g_globals->_gfxEdgeAdjust * 2, -g_globals->_gfxEdgeAdjust * 2);
 	_bounds = tempRect;
 }
 
 void GfxDialog::remove() {
 	if (_savedArea) {
 		// Restore the area the dialog covered
-		_globals->_gfxManagerInstance.copyFrom(*_savedArea, _bounds.left, _bounds.top);
+		g_globals->_gfxManagerInstance.copyFrom(*_savedArea, _bounds.left, _bounds.top);
 
 		delete _savedArea;
 		_savedArea = NULL;
@@ -888,7 +954,7 @@ void GfxDialog::draw() {
 	Rect tempRect(_bounds);
 
 	// Make a backup copy of the area the dialog will occupy
-	_savedArea = Surface_getArea(_globals->_gfxManagerInstance.getSurface(), _bounds);
+	_savedArea = Surface_getArea(g_globals->_gfxManagerInstance.getSurface(), _bounds);
 
 	// Set the palette for use in the dialog
 	setPalette();
@@ -900,7 +966,7 @@ void GfxDialog::draw() {
 	drawFrame();
 
 	// Reset the dialog's graphics manager to only draw within the dialog boundaries
-	tempRect.translate(6, 6);
+	tempRect.translate(g_globals->_gfxEdgeAdjust * 2, g_globals->_gfxEdgeAdjust * 2);
 	_gfxManager._bounds = tempRect;
 
 	// Draw each element in the dialog in order
@@ -937,7 +1003,7 @@ void GfxDialog::addElements(GfxElement *ge, ...) {
 }
 
 void GfxDialog::setTopLeft(int xp, int yp) {
-	_bounds.moveTo(xp - 6, yp - 6);
+	_bounds.moveTo(xp - g_globals->_gfxEdgeAdjust * 2, yp - g_globals->_gfxEdgeAdjust * 2);
 }
 
 void GfxDialog::setCenter(int xp, int yp) {
@@ -962,9 +1028,10 @@ GfxButton *GfxDialog::execute(GfxButton *defaultButton) {
 	// Event loop
 	GfxButton *selectedButton = NULL;
 
-	while (!_vm->getEventManager()->shouldQuit()) {
+	bool breakFlag = false;
+	while (!g_vm->shouldQuit() && !breakFlag) {
 		Event event;
-		while (_globals->_events.getEvent(event)) {
+		while (g_globals->_events.getEvent(event) && !breakFlag) {
 			// Adjust mouse positions to be relative within the dialog
 			event.mousePos.x -= _gfxManager._bounds.left;
 			event.mousePos.y -= _gfxManager._bounds.top;
@@ -973,19 +1040,25 @@ GfxButton *GfxDialog::execute(GfxButton *defaultButton) {
 				if ((*i)->process(event))
 					selectedButton = static_cast<GfxButton *>(*i);
 			}
-		}
 
-		if (selectedButton)
-			break;
-		else if (!event.handled) {
-			if ((event.eventType == EVENT_KEYPRESS) && (event.kbd.keycode == Common::KEYCODE_ESCAPE)) {
-				selectedButton = NULL;
-				break;
-			} else if ((event.eventType == EVENT_KEYPRESS) && (event.kbd.keycode == Common::KEYCODE_RETURN)) {
-				selectedButton = defaultButton;
+			if (selectedButton) {
+				breakFlag = true;
 				break;
+			} else if (!event.handled) {
+				if ((event.eventType == EVENT_KEYPRESS) && (event.kbd.keycode == Common::KEYCODE_ESCAPE)) {
+					selectedButton = NULL;
+					breakFlag = true;
+					break;
+				} else if ((event.eventType == EVENT_KEYPRESS) && (event.kbd.keycode == Common::KEYCODE_RETURN)) {
+					selectedButton = defaultButton;
+					breakFlag = true;
+					break;
+				}
 			}
 		}
+
+		g_system->delayMillis(10);
+		g_system->updateScreen();
 	}
 
 	_gfxManager.deactivate();
@@ -996,17 +1069,28 @@ GfxButton *GfxDialog::execute(GfxButton *defaultButton) {
 }
 
 void GfxDialog::setPalette() {
-	_globals->_scenePalette.loadPalette(0);
-	_globals->_scenePalette.setPalette(0, 1);
-	_globals->_scenePalette.setPalette(_globals->_scenePalette._colors.foreground, 1);
-	_globals->_scenePalette.setPalette(_globals->_fontColors.background, 1);
-	_globals->_scenePalette.setPalette(_globals->_fontColors.foreground, 1);
-	_globals->_scenePalette.setPalette(255, 1);
+	if (g_vm->getGameID() == GType_BlueForce) {
+		g_globals->_scenePalette.loadPalette(2);
+		g_globals->_scenePalette.setPalette(0, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_gfxColors.background, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_gfxColors.foreground, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_fontColors.background, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_fontColors.foreground, 1);
+		g_globals->_scenePalette.setEntry(255, 0xff, 0xff, 0xff);
+		g_globals->_scenePalette.setPalette(255, 1);	
+	} else {
+		g_globals->_scenePalette.loadPalette(0);
+		g_globals->_scenePalette.setPalette(0, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_scenePalette._colors.foreground, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_fontColors.background, 1);
+		g_globals->_scenePalette.setPalette(g_globals->_fontColors.foreground, 1);
+		g_globals->_scenePalette.setPalette(255, 1);
+	}
 }
 
 /*--------------------------------------------------------------------------*/
 
-GfxManager::GfxManager() : _surface(_globals->_screenSurface), _oldManager(NULL) {
+GfxManager::GfxManager() : _surface(g_globals->_screenSurface), _oldManager(NULL) {
 	_font.setOwner(this);
 	_font._fillFlag = false;
 	_bounds = Rect(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT);
@@ -1025,19 +1109,19 @@ void GfxManager::setDefaults() {
 	_pane0Rect4 = screenBounds;
 
 	_font._edgeSize = Common::Point(1, 1);
-	_font._colors = _globals->_fontColors;
-	_font.setFontNumber(_globals->_gfxFontNumber);
+	_font._colors = g_globals->_fontColors;
+	_font.setFontNumber(g_globals->_gfxFontNumber);
 }
 
 void GfxManager::activate() {
-	assert(!contains(_globals->_gfxManagers, this));
-	_globals->_gfxManagers.push_front(this);
+	assert(!contains(g_globals->_gfxManagers, this));
+	g_globals->_gfxManagers.push_front(this);
 }
 
 void GfxManager::deactivate() {
 	// Assert that there will still be another manager, and we're correctly removing our own
-	assert((_globals->_gfxManagers.size() > 1) && (&_globals->gfxManager() == this));
-	_globals->_gfxManagers.pop_front();
+	assert((g_globals->_gfxManagers.size() > 1) && (&g_globals->gfxManager() == this));
+	g_globals->_gfxManagers.pop_front();
 }
 
 int GfxManager::getStringWidth(const char *s, int numChars) {
@@ -1075,7 +1159,7 @@ void GfxManager::setDialogPalette() {
 	// Get the main palette information
 	byte palData[256 * 3];
 	uint count, start;
-	_resourceManager->getPalette(0, &palData[0], &start, &count);
+	g_resourceManager->getPalette(0, &palData[0], &start, &count);
 	g_system->getPaletteManager()->setPalette(&palData[0], start, count);
 
 	// Miscellaneous
@@ -1110,7 +1194,7 @@ int GfxManager::getAngle(const Common::Point &p1, const Common::Point &p2) {
 
 
 GfxFont::GfxFont() {
-	_fontNumber = (_vm->getFeatures() & GF_DEMO) ? 0 : 50;
+	_fontNumber = (g_vm->getFeatures() & GF_DEMO) ? 0 : 50;
 	_numChars = 0;
 	_bpp = 0;
 	_fontData = NULL;
@@ -1134,9 +1218,9 @@ void GfxFont::setFontNumber(uint32 fontNumber) {
 
 	_fontNumber = fontNumber;
 
-	_fontData = _resourceManager->getResource(RES_FONT, _fontNumber, 0, true);
+	_fontData = g_resourceManager->getResource(RES_FONT, _fontNumber, 0, true);
 	if (!_fontData)
-		_fontData = _resourceManager->getResource(RES_FONT, _fontNumber, 0);
+		_fontData = g_resourceManager->getResource(RES_FONT, _fontNumber, 0);
 
 	_numChars = READ_LE_UINT16(_fontData + 4);
 	_fontSize.y = READ_LE_UINT16(_fontData + 6);
@@ -1187,7 +1271,7 @@ int GfxFont::getStringWidth(const char *s) {
 /**
  * Returns the maximum number of characters for words that will fit into a given width
  *
- * @s Message to be analysed
+ * @s Message to be analyzed
  * @maxWidth Maximum allowed width
  */
 int GfxFont::getStringFit(const char *&s, int maxWidth) {
@@ -1233,7 +1317,7 @@ int GfxFont::getStringFit(const char *&s, int maxWidth) {
  * Fills out the passed rect with the dimensions of a given string word-wrapped to a
  * maximum specified width
  *
- * @s Message to be analysed
+ * @s Message to be analyzed
  * @bounds Rectangle to put output size into
  * @maxWidth Maximum allowed line width in pixels
  */
@@ -1425,18 +1509,18 @@ void GfxFont::writeLines(const char *s, const Rect &bounds, TextAlign align) {
 /*--------------------------------------------------------------------------*/
 
 GfxFontBackup::GfxFontBackup() {
-	_edgeSize = _globals->gfxManager()._font._edgeSize;
-	_position = _globals->gfxManager()._font._position;
-	_colors = _globals->gfxManager()._font._colors;
-	_fontNumber = _globals->gfxManager()._font._fontNumber;
+	_edgeSize = g_globals->gfxManager()._font._edgeSize;
+	_position = g_globals->gfxManager()._font._position;
+	_colors = g_globals->gfxManager()._font._colors;
+	_fontNumber = g_globals->gfxManager()._font._fontNumber;
 }
 
 GfxFontBackup::~GfxFontBackup() {
-	_globals->gfxManager()._font.setFontNumber(_fontNumber);
-	_globals->gfxManager()._font._edgeSize = _edgeSize;
-	_globals->gfxManager()._font._position = _position;
-	_globals->gfxManager()._font._colors = _colors;
+	g_globals->gfxManager()._font.setFontNumber(_fontNumber);
+	g_globals->gfxManager()._font._edgeSize = _edgeSize;
+	g_globals->gfxManager()._font._position = _position;
+	g_globals->gfxManager()._font._colors = _colors;
 }
 
 
-} // End of namespace tSage
+} // End of namespace TsAGE
