@@ -18,19 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/graphics/VectorRenderer.cpp $
- * $Id: VectorRenderer.cpp 44634 2009-10-04 21:26:33Z fingolfin $
- *
  */
 
+#include "common/textconsole.h"
 #include "common/util.h"
-#include "common/system.h"
-#include "common/events.h"
 
-#include "graphics/surface.h"
-#include "graphics/colormasks.h"
-
-#include "gui/ThemeEngine.h"
 #include "graphics/VectorRenderer.h"
 
 #define VECTOR_RENDERER_FAST_TRIANGLES
@@ -103,7 +95,7 @@ void VectorRenderer::stepGetPositions(const DrawStep &step, const Common::Rect &
 			break;
 
 		default:
-			error("Vertical alignment in horizontal data.");
+			error("Vertical alignment in horizontal data");
 		}
 	} else {
 		in_x = area.left;
@@ -132,7 +124,7 @@ void VectorRenderer::stepGetPositions(const DrawStep &step, const Common::Rect &
 			break;
 
 		default:
-			error("Horizontal alignment in vertical data.");
+			error("Horizontal alignment in vertical data");
 		}
 	} else {
 		in_y = area.top;
