@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
  */
 
 #ifndef GRAPHICS_FONT_H
@@ -28,7 +25,6 @@
 #include "common/str.h"
 
 namespace Common {
-class SeekableReadStream;
 template<class T> class Array;
 }
 
@@ -117,80 +113,6 @@ public:
 	int wordWrapText(const Common::String &str, int maxWidth, Common::Array<Common::String> &lines) const;
 };
 
-/**
- * A SCUMM style font.
- */
-class ScummFont : public Font {
-public:
-	virtual int getFontHeight() const { return 8; }
-	virtual int getMaxCharWidth() const { return 8; }
-
-	virtual int getCharWidth(byte chr) const;
-	virtual void drawChar(Surface *dst, byte chr, int x, int y, uint32 color) const;
-};
-
-typedef uint16 bitmap_t; /* bitmap image unit size*/
-
-struct BBX {
-	int8 w;
-	int8 h;
-	int8 x;
-	int8 y;
-};
-
-/* builtin C-based proportional/fixed font structure */
-/* based on The Microwindows Project http://microwindows.org */
-struct FontDesc {
-	const char *	name;		/* font name*/
-	int		maxwidth;	/* max width in pixels*/
-	int		height;		/* height in pixels*/
-	int	fbbw, fbbh, fbbx, fbby;	/* max bounding box */
-	int		ascent;		/* ascent (baseline) height*/
-	int		firstchar;	/* first character in bitmap*/
-	int		size;		/* font size in glyphs*/
-	const bitmap_t*	bits;		/* 16-bit right-padded bitmap data*/
-	const unsigned long* offset;	/* offsets into bitmap data*/
-	const unsigned char* width;	/* character widths or NULL if fixed*/
-	const BBX* bbx;			/* character bounding box or NULL if fixed */
-	int		defaultchar;	/* default char (not glyph index)*/
-	long	bits_size;	/* # words of bitmap_t bits*/
-};
-
-struct NewFontData;
-
-class NewFont : public Font {
-protected:
-	FontDesc desc;
-	NewFontData *font;
-
-public:
-	NewFont(const FontDesc &d, NewFontData *font_ = 0) : desc(d), font(font_) {}
-	~NewFont();
-
-	virtual int getFontHeight() const { return desc.height; }
-	virtual int getMaxCharWidth() const { return desc.maxwidth; }
-
-	virtual int getCharWidth(byte chr) const;
-	virtual void drawChar(Surface *dst, byte chr, int x, int y, uint32 color) const;
-
-	static NewFont *loadFont(Common::SeekableReadStream &stream);
-	static bool cacheFontData(const NewFont &font, const Common::String &filename);
-	static NewFont *loadFromCache(Common::SeekableReadStream &stream);
-};
-
-#define DEFINE_FONT(n) \
-		const NewFont *n = 0;	\
-		void create_##n() {	\
-			n = new NewFont(desc);	\
-		}
-
-#define FORWARD_DECLARE_FONT(n) \
-		extern const NewFont *n; \
-		extern void create_##n()
-
-#define INIT_FONT(n) \
-		create_##n()
-
 } // End of namespace Graphics
 
 #endif
