@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/graphics/fontman.h $
- * $Id: fontman.h 49773 2010-06-15 10:51:26Z sev $
  */
 
 #ifndef GRAPHICS_FONTMAN_H
@@ -30,15 +27,16 @@
 #include "common/str.h"
 #include "common/hashmap.h"
 #include "common/hash-str.h"
-#include "graphics/font.h"
 
 
 namespace Graphics {
 
+class Font;
+
 class FontManager : public Common::Singleton<FontManager> {
 public:
 	enum FontUsage {
-		kOSDFont = 0,
+		kLocalizedFont = 0,
 		kConsoleFont = 1,
 		kGUIFont = 2,
 		kBigGUIFont = 3
@@ -59,14 +57,24 @@ public:
 	 * @param font	the font object
 	 * @return true on success, false on failure
 	 */
-	bool assignFontToName(const Common::String &name, const Font *font) { _fontMap[name] = font; return true; }
+	bool assignFontToName(const Common::String &name, const Font *font);
+
+	/**
+	 * Associates a BDF font object with an 'usage'. This is useful for platforms
+	 * with a screen DPI much larger than a regular desktop workstation.
+	 *
+	 * @param name	the name of the font
+	 * @param font	the font object
+	 * @return true on success, false on failure
+	 */
+  bool setFont(FontUsage usage, const Font *font);
 
 	/**
 	 * Removes binding from name to font
 	 *
 	 * @param name	name which should be removed
 	 */
-	void removeFontName(const Common::String &name) { _fontMap.erase(name); }
+	void removeFontName(const Common::String &name);
 
 	/**
 	 * Retrieve a font object based on what it is supposed
@@ -77,8 +85,26 @@ public:
 	 */
 	const Font *getFontByUsage(FontUsage usage) const;
 
+	/**
+	 * Get the localized font for the current TranslationManager charset from the
+	 * non localized font name
+	 *
+	 * @param filename the non-localized font file name.
+	 * @return The localized font file name.
+	 */
+	Common::String genLocalizedFontFilename(const Common::String &filename) const;
+
 	//const Font *getFontBySize(int size???) const;
 
+protected:
+	/**
+	 * Get the name of the localized font for the given usage. There is no garanty that
+	 * the font exists. If the usage is kLocalizedFont it returns an empty string.
+	 *
+	 * @param usage	a FontUsage enum value indicating what the font will be used for.
+	 * @return the name of a localized font or an empty string if no suitable font was found.
+	 */
+	Common::String getLocalizedFontNameByUsage(FontUsage usage) const;
 
 private:
 	friend class Common::Singleton<SingletonBaseType>;
