@@ -17,12 +17,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/graphics/imagedec.cpp $
- * $Id: imagedec.cpp 44634 2009-10-04 21:26:33Z fingolfin $
  */
 
 #include "graphics/imagedec.h"
+#include "graphics/pixelformat.h"
+#include "graphics/surface.h"
 
 #include "common/file.h"
 
@@ -116,7 +115,7 @@ Surface *BMPDecoder::decodeImage(Common::SeekableReadStream &stream, const Pixel
 	uint8 r = 0, g = 0, b = 0;
 	Surface *newSurf = new Surface;
 	assert(newSurf);
-	newSurf->create(info.width, info.height, sizeof(OverlayColor));
+	newSurf->create(info.width, info.height, format);
 	assert(newSurf->pixels);
 	OverlayColor *curPixel = (OverlayColor*)newSurf->pixels + (newSurf->h-1) * newSurf->w;
 	int pitchAdd = info.width % 4;
