@@ -18,9 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL$
- * $Id$
- *
  */
 
 #include "graphics/conversion.h"
@@ -96,7 +93,7 @@ Surface *JPEG::getSurface(const PixelFormat &format) {
 	Graphics::Surface *vComponent = getComponent(3);
 
 	Graphics::Surface *output = new Graphics::Surface();
-	output->create(yComponent->w, yComponent->h, format.bytesPerPixel);
+	output->create(yComponent->w, yComponent->h, format);
 
 	for (uint16 i = 0; i < output->h; i++) {
 		for (uint16 j = 0; j < output->w; j++) {
@@ -444,7 +441,7 @@ bool JPEG::readSOS() {
 
 	// Initialize the scan surfaces
 	for (uint16 c = 0; c < _numScanComp; c++) {
-		_scanComp[c]->surface.create(xMCU * _maxFactorH * 8, yMCU * _maxFactorV * 8, 1);
+		_scanComp[c]->surface.create(xMCU * _maxFactorH * 8, yMCU * _maxFactorV * 8, PixelFormat::createFormatCLUT8());
 	}
 
 	bool ok = true;
@@ -711,9 +708,9 @@ uint8 JPEG::readBit() {
 				if (byte2 == 0xDC) {
 					// DNL marker: Define Number of Lines
 					// TODO: terminate scan
-					printf("DNL marker detected: terminate scan\n");
+					warning("DNL marker detected: terminate scan");
 				} else {
-					printf("Error: marker 0x%02X read in entropy data\n", byte2);
+					warning("Error: marker 0x%02X read in entropy data", byte2);
 				}
 			}
 		}
