@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/gui/launcher.cpp $
- * $Id: launcher.cpp 53063 2010-10-08 00:29:58Z jvprat $
  */
 
 #include "base/version.h"
@@ -28,7 +25,6 @@
 #include "common/events.h"
 #include "common/fs.h"
 #include "common/util.h"
-#include "common/savefile.h"
 #include "common/system.h"
 #include "common/translation.h"
 
@@ -38,20 +34,17 @@
 #include "gui/launcher.h"
 #include "gui/massadd.h"
 #include "gui/message.h"
-#include "gui/GuiManager.h"
+#include "gui/gui-manager.h"
 #include "gui/options.h"
 #include "gui/saveload.h"
-#include "gui/EditTextWidget.h"
-#include "gui/ListWidget.h"
-#include "gui/TabWidget.h"
-#include "gui/PopUpWidget.h"
+#include "gui/widgets/edittext.h"
+#include "gui/widgets/list.h"
+#include "gui/widgets/tab.h"
+#include "gui/widgets/popup.h"
 #include "gui/ThemeEval.h"
 
 #include "graphics/cursorman.h"
 
-#include "sound/mididrv.h"
-
-
 using Common::ConfigManager;
 
 namespace GUI {
@@ -188,8 +181,8 @@ EditGameDialog::EditGameDialog(const String &domain, const String &desc)
 	// Language popup
 	_langPopUpDesc = new StaticTextWidget(tab, "GameOptions_Game.LangPopupDesc", _("Language:"), _("Language of the game. This will not turn your Spanish game version into English"));
 	_langPopUp = new PopUpWidget(tab, "GameOptions_Game.LangPopup", _("Language of the game. This will not turn your Spanish game version into English"));
-	_langPopUp->appendEntry(_("<default>"), 0);
-	_langPopUp->appendEntry("", 0);
+	_langPopUp->appendEntry(_("<default>"), (uint32)Common::UNK_LANG);
+	_langPopUp->appendEntry("", (uint32)Common::UNK_LANG);
 	const Common::LanguageDescription *l = Common::g_languages;
 	for (; l->code; ++l) {
 		if (checkGameGUIOptionLanguage(l->id, _guioptionsString))
@@ -341,7 +334,8 @@ void EditGameDialog::open() {
 	e = ConfMan.hasKey("gfx_mode", _domain) ||
 		ConfMan.hasKey("render_mode", _domain) ||
 		ConfMan.hasKey("fullscreen", _domain) ||
-		ConfMan.hasKey("aspect_ratio", _domain);
+		ConfMan.hasKey("aspect_ratio", _domain) ||
+		ConfMan.hasKey("disable_dithering", _domain);
 	_globalGraphicsOverride->setState(e);
 
 	e = ConfMan.hasKey("music_driver", _domain) ||
@@ -371,6 +365,8 @@ void EditGameDialog::open() {
 
 	if (ConfMan.hasKey("language", _domain)) {
 		_langPopUp->setSelectedTag(lang);
+	} else {
+		_langPopUp->setSelectedTag((uint32)Common::UNK_LANG);
 	}
 
 	if (_langPopUp->numEntries() <= 3) { // If only one language is avaliable
@@ -689,10 +685,7 @@ void LauncherDialog::updateListing() {
 		}
 
 		if (description.empty()) {
-			char tmp[200];
-
-			snprintf(tmp, 200, "Unknown (target %s, gameid %s)", iter->_key.c_str(), gameid.c_str());
-			description = tmp;
+			description = Common::String::format("Unknown (target %s, gameid %s)", iter->_key.c_str(), gameid.c_str());
 		}
 
 		if (!gameid.empty() && !description.empty()) {
@@ -845,12 +838,10 @@ Common::String addGameToConf(const GameDescriptor &result) {
 	assert(!domain.empty());
 	if (ConfMan.hasGameDomain(domain)) {
 		int suffixN = 1;
-		char suffix[16];
 		Common::String gameid(domain);
 
 		while (ConfMan.hasGameDomain(domain)) {
-			snprintf(suffix, 16, "-%d", suffixN);
-			domain = gameid + suffix;
+			domain = gameid + Common::String::format("-%d", suffixN);
 			suffixN++;
 		}
 	}
@@ -925,6 +916,7 @@ void LauncherDialog::loadGame(int item) {
 		gameId = _domains[item];
 
 	const EnginePlugin *plugin = 0;
+
 	EngineMan.findGame(gameId, &plugin);
 
 	String target = _domains[item];
@@ -933,7 +925,7 @@ void LauncherDialog::loadGame(int item) {
 	if (plugin) {
 		if ((*plugin)->hasFeature(MetaEngine::kSupportsListSaves) &&
 			(*plugin)->hasFeature(MetaEngine::kSupportsLoadingDuringStartup)) {
-			int slot = _loadDialog->runModal(plugin, target);
+			int slot = _loadDialog->runModalWithPluginAndTarget(plugin, target);
 			if (slot >= 0) {
 				ConfMan.setActiveDomain(_domains[item]);
 				ConfMan.setInt("save_slot", slot, Common::ConfigManager::kTransientDomain);
@@ -1057,10 +1049,10 @@ void LauncherDialog::updateButtons() {
 	int modifiers = g_system->getEventManager()->getModifierState();
 	const bool massAdd = (modifiers & Common::KBD_SHIFT) != 0;
 	const bool lowRes = g_system->getOverlayWidth() <= 320;
-	
+
 	const char *newAddButtonLabel = massAdd
 		? (lowRes ? _c("Mass Add...", "lowres") : _("Mass Add..."))
-		: (lowRes ? _c("Add Game...", "lowres") : _("Add Game..."));
+		: (lowRes ? _c("~A~dd Game...", "lowres") : _("~A~dd Game..."));
 
 	if (_addButton->getLabel() != newAddButtonLabel)
 		_addButton->setLabel(newAddButtonLabel);
