@@ -17,15 +17,13 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/gui/object.cpp $
- * $Id: object.cpp 48275 2010-03-18 15:04:15Z fingolfin $
  */
 
-#include "common/system.h"
+#include "common/textconsole.h"
+
 #include "gui/object.h"
 #include "gui/widget.h"
-#include "gui/GuiManager.h"
+#include "gui/gui-manager.h"
 #include "gui/ThemeEval.h"
 
 namespace GUI {
