@@ -17,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
  */
 
 #include "gui/browser.h"
@@ -141,8 +138,8 @@ void OptionsDialog::init() {
 	_subSpeedDesc = 0;
 	_subSpeedSlider = 0;
 	_subSpeedLabel = 0;
-	_oldTheme = g_gui.theme()->getThemeId(); 
-	
+	_oldTheme = g_gui.theme()->getThemeId();
+
 	// Retrieve game GUI options
 	_guioptions = 0;
 	if (ConfMan.hasKey("guioptions", _domain)) {
@@ -244,11 +241,8 @@ void OptionsDialog::open() {
 		}
 
 		// MIDI gain setting
-		char buf[10];
-
 		_midiGainSlider->setValue(ConfMan.getInt("midi_gain", _domain));
-		sprintf(buf, "%.2f", (double)_midiGainSlider->getValue() / 100.0);
-		_midiGainLabel->setLabel(buf);
+		_midiGainLabel->setLabel(Common::String::format("%.2f", (double)_midiGainSlider->getValue() / 100.0));
 	}
 
 	// MT-32 options
@@ -308,8 +302,14 @@ void OptionsDialog::close() {
 	if (getResult()) {
 
 		// Graphic options
+		bool graphicsModeChanged = false;
 		if (_fullscreenCheckbox) {
 			if (_enableGraphicSettings) {
+				if (ConfMan.getBool("fullscreen", _domain) != _fullscreenCheckbox->getState())
+					graphicsModeChanged = true;
+				if (ConfMan.getBool("aspect_ratio", _domain) != _aspectCheckbox->getState())
+					graphicsModeChanged = true;
+
 				ConfMan.setBool("fullscreen", _fullscreenCheckbox->getState(), _domain);
 				ConfMan.setBool("aspect_ratio", _aspectCheckbox->getState(), _domain);
 				ConfMan.setBool("disable_dithering", _disableDitheringCheckbox->getState(), _domain);
@@ -321,6 +321,8 @@ void OptionsDialog::close() {
 
 					while (gm->name) {
 						if (gm->id == (int)_gfxPopUp->getSelectedTag()) {
+							if (ConfMan.get("gfx_mode", _domain) != gm->name)
+								graphicsModeChanged = true;
 							ConfMan.set("gfx_mode", gm->name, _domain);
 							isSet = true;
 							break;
@@ -342,6 +344,64 @@ void OptionsDialog::close() {
 			}
 		}
 
+		// Setup graphics again if needed
+		if (_domain == Common::ConfigManager::kApplicationDomain && graphicsModeChanged) {
+			g_system->beginGFXTransaction();
+			g_system->setGraphicsMode(ConfMan.get("gfx_mode", _domain).c_str());
+
+			if (ConfMan.hasKey("aspect_ratio"))
+				g_system->setFeatureState(OSystem::kFeatureAspectRatioCorrection, ConfMan.getBool("aspect_ratio", _domain));
+			if (ConfMan.hasKey("fullscreen"))
+				g_system->setFeatureState(OSystem::kFeatureFullscreenMode, ConfMan.getBool("fullscreen", _domain));
+			OSystem::TransactionError gfxError = g_system->endGFXTransaction();
+
+			// Since this might change the screen resolution we need to give
+			// the GUI a chance to update it's internal state. Otherwise we might
+			// get a crash when the GUI tries to grab the overlay.
+			//
+			// This fixes bug #3303501 "Switching from HQ2x->HQ3x crashes ScummVM"
+			//
+			// It is important that this is called *before* any of the current
+			// dialog's widgets are destroyed (for example before
+			// Dialog::close) is called, to prevent crashes caused by invalid
+			// widgets being referenced or similar errors.
+			g_gui.checkScreenChange();
+
+			if (gfxError != OSystem::kTransactionSuccess) {
+				// Revert ConfMan to what OSystem is using.
+				Common::String message = _("Failed to apply some of the graphic options changes:");
+
+				if (gfxError & OSystem::kTransactionModeSwitchFailed) {
+					const OSystem::GraphicsMode *gm = g_system->getSupportedGraphicsModes();
+					while (gm->name) {
+						if (gm->id == g_system->getGraphicsMode()) {
+							ConfMan.set("gfx_mode", gm->name, _domain);
+							break;
+						}
+						gm++;
+					}
+					message += "\n";
+					message += _("the video mode could not be changed.");
+				}
+
+				if (gfxError & OSystem::kTransactionAspectRatioFailed) {
+					ConfMan.setBool("aspect_ratio", g_system->getFeatureState(OSystem::kFeatureAspectRatioCorrection), _domain);
+					message += "\n";
+					message += _("the fullscreen setting could not be changed");
+				}
+
+				if (gfxError & OSystem::kTransactionFullscreenFailed) {
+					ConfMan.setBool("fullscreen", g_system->getFeatureState(OSystem::kFeatureFullscreenMode), _domain);
+					message += "\n";
+					message += _("the aspect ratio setting could not be changed");
+				}
+
+				// And display the error
+				GUI::MessageDialog dialog(message);
+				dialog.runModal();
+			}
+		}
+
 		// Volume options
 		if (_musicVolumeSlider) {
 			if (_enableVolumeSettings) {
@@ -470,12 +530,9 @@ void OptionsDialog::close() {
 }
 
 void OptionsDialog::handleCommand(CommandSender *sender, uint32 cmd, uint32 data) {
-	char buf[10];
-
 	switch (cmd) {
 	case kMidiGainChanged:
-		sprintf(buf, "%.2f", (double)_midiGainSlider->getValue() / 100.0);
-		_midiGainLabel->setLabel(buf);
+		_midiGainLabel->setLabel(Common::String::format("%.2f", (double)_midiGainSlider->getValue() / 100.0));
 		_midiGainLabel->draw();
 		break;
 	case kMusicVolumeChanged:
@@ -751,7 +808,7 @@ void OptionsDialog::addMIDIControls(GuiObject *boss, const Common::String &prefi
 					_gmDevicePopUp->appendEntry(d->getCompleteName(), d->getHandle());
 			} else if (d->getMusicDriverId() == "auto") {
 				_gmDevicePopUp->appendEntry(_("Use first available device"), d->getHandle());
-			}		
+			}
 		}
 	}
 
@@ -798,7 +855,7 @@ void OptionsDialog::addMT32Controls(GuiObject *boss, const Common::String &prefi
 	// Make sure the null device is the first one in the list to avoid undesired
 	// auto detection for users who don't have a saved setting yet.
 	for (MusicPlugin::List::const_iterator m = p.begin(); m != p.end(); ++m) {
-		MusicDevices i = (**m)->getDevices();		
+		MusicDevices i = (**m)->getDevices();
 		for (MusicDevices::iterator d = i.begin(); d != i.end(); ++d) {
 			if (d->getMusicDriverId() == "null")
 				_mt32DevicePopUp->appendEntry(_("Don't use Roland MT-32 music"), d->getHandle());
@@ -1235,7 +1292,7 @@ void GlobalOptionsDialog::close() {
 			// only become active *after* the options dialog has closed.
 			g_gui.loadNewTheme(g_gui.theme()->getThemeId(), ThemeEngine::kGfxDisabled, true);
 #else
-			MessageDialog error(_("You have to restart ScummVM to take the effect."));
+			MessageDialog error(_("You have to restart ScummVM before your changes will take effect."));
 			error.runModal();
 #endif
 		}
