@@ -17,18 +17,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/tags/release-1-2-1/gui/options.h $
- * $Id: options.h 51265 2010-07-24 22:29:17Z sev $
  */
 
 #ifndef OPTIONS_DIALOG_H
 #define OPTIONS_DIALOG_H
 
 #include "gui/dialog.h"
-#include "gui/TabWidget.h"
 #include "common/str.h"
-#include "sound/musicplugin.h"
+#include "audio/mididrv.h"
 
 #ifdef SMALL_SCREEN_DEVICE
 #include "gui/KeysDialog.h"
@@ -36,17 +32,22 @@
 
 namespace GUI {
 
-class BrowserDialog;
 class CheckboxWidget;
 class PopUpWidget;
 class SliderWidget;
 class StaticTextWidget;
-class ListWidget;
+class TabWidget;
+class ButtonWidget;
+class CommandSender;
+class GuiObject;
+class RadiobuttonGroup;
+class RadiobuttonWidget;
 
 class OptionsDialog : public Dialog {
 public:
 	OptionsDialog(const Common::String &domain, int x, int y, int w, int h);
 	OptionsDialog(const Common::String &domain, const Common::String &name);
+	~OptionsDialog();
 
 	void init();
 
@@ -96,6 +97,7 @@ private:
 	PopUpWidget *_gfxPopUp;
 	CheckboxWidget *_fullscreenCheckbox;
 	CheckboxWidget *_aspectCheckbox;
+	CheckboxWidget *_disableDitheringCheckbox;
 	StaticTextWidget *_renderModePopUpDesc;
 	PopUpWidget *_renderModePopUp;
 
@@ -115,8 +117,6 @@ private:
 	StaticTextWidget *_gmDevicePopUpDesc;
 	PopUpWidget *_gmDevicePopUp;
 
-
-
 	//
 	// MIDI controls
 	//
@@ -174,6 +174,11 @@ protected:
 	//
 	uint32 _guioptions;
 	Common::String _guioptionsString;
+
+	//
+	//Theme Options
+	//
+	Common::String _oldTheme;
 };
 
 
